#line 1 "tmp/all.te"
#
# Declarations for type attributes.
# 

# A type attribute can be used to identify a set of types with a similar
# property.  Each type can have any number of attributes, and each
# attribute can be associated with any number of types.  Attributes are
# explicitly declared here, and can then be associated with particular
# types in type declarations.  Attribute names can then be used throughout 
# the configuration to express the set of types that are associated with 
# the attribute.  Except for the MLS attributes, attributes have no implicit
# meaning to SELinux.  The meaning of all other attributes are completely 
# defined through their usage within the configuration, but should be 
# documented here as comments preceding the attribute declaration.  

#####################
# Attributes for MLS:
#

# The mlstrustedreader attribute identifies every domain that can
# override the normal MLS restrictions on reading (i.e. domains
# that can read up).  
attribute mlstrustedreader;

# The mlstrustedwriter attribute identifies every domain that can
# override the normal MLS restrictions on writing (i.e. domains
# that can write down).  
attribute mlstrustedwriter;

# The mlstrustedobject attribute identifies every type that can
# be accessed without normal MLS restrictions (i.e. processes can
# read or write objects with this type regardless of MLS level).  
# Examples:  /dev/null, descriptors created by login
attribute mlstrustedobject;


#########################
# Attributes for domains:
#

# The domain attribute identifies every type that can be 
# assigned to a process.  This attribute is used in TE rules 
# that should be applied to all domains, e.g. permitting 
# init to kill all processes or permitting all processes
# to read a particular file.
attribute domain;

# The privuser attribute identifies every domain that can 
# change its SELinux user identity.  This attribute is used 
# in the constraints configuration.  NOTE:  This attribute
# is not required for domains that merely change the Linux
# uid attributes, only for domains that must change the
# SELinux user identity.
attribute privuser;

# The privrole attribute identifies every domain that can 
# change its SELinux role.  This attribute is used in the 
# constraints configuration.
attribute privrole;

# The privowner attribute identifies every domain that can 
# assign a different SELinux user identity to a file.  This 
# attribute is used in the constraints configuration.
attribute privowner;

# The privlog attribute identifies every domain that can 
# communicate with syslogd through its Unix domain socket.
# This attribute is used in the TE rules in 
# domains/program/syslogd.te to grant such access.  
# XXX If you want to mandate the use of this attribute for all 
# XXX domains that can log, then you should also write corresponding 
# XXX assertions in assert.te to enforce this restriction.  Otherwise,
# XXX it is just an optional convenience for domain writers.
attribute privlog;

# The privmem attribute identifies every domain that can 
# access kernel memory devices.
# This attribute is used in the TE assertions to verify
# that such access is limited to domains that are explicitly
# tagged with this attribute.
attribute privmem;

# The privfd attribute identifies every domain that should have
# file handles inherited widely (IE sshd_t and getty_t).
attribute privfd;

# The privhome attribute identifies every domain that can create files under
# regular user home directories in the regular context (IE act on behalf of
# a user in writing regular files)
attribute privhome;

# The auth attribute identifies every domain that needs
# to perform user authentication and requires access to
# the corresponding authentication data.  
# XXX This attribute is no longer in use except in type declarations.
# XXX It was introduced for the original attempt to put /etc/shadow into
# XXX a separate type and to limit read access to certain domains.  
# XXX Doing so transparently to applications is problematic due to
# XXX the fact that both /etc/passwd and /etc/shadow are recreated
# XXX by the same processes and live in the same directory, so file type
# XXX transition rules cannot specify different default types.  Relocating
# XXX /etc/shadow to a separate subdirectory was tried, but required
# XXX modifications to a lot of applications even after changing
# XXX the pwdb shared library.
attribute auth;

# The admin attribute identifies every administrator domain.
# It is used in TE assertions when verifying that only administrator 
# domains have certain permissions.  
# This attribute is presently associated with sysadm_t and 
# certain administrator utility domains.  
# XXX The use of this attribute should be reviewed for consistency.
# XXX Might want to partition into several finer-grained attributes 
# XXX used in different assertions within assert.te.
attribute admin;

# The userdomain attribute identifies every user domain, presently
# user_t and sysadm_t.  It is used in TE rules that should be applied
# to all user domains.
attribute userdomain;

# attribute for all non-administrative devpts types
attribute userpty_type;

# The user_crond_domain attribute identifies every user_crond domain, presently
# user_crond_t and sysadm_crond_t.  It is used in TE rules that should be
# applied to all user domains.
attribute user_crond_domain;

# The unpriv_userdomain identifies non-administrative users (default user_t)
attribute unpriv_userdomain;

# This attribute is for the main user home directory for unpriv users
attribute user_home_dir_type;

# The gphdomain attribute identifies every gnome-pty-helper derived
# domain.  It is used in TE rules to permit inheritance and use of
# descriptors created by these domains.
attribute gphdomain;


############################
# Attributes for file types:
#

# The file_type attribute identifies all types assigned to files 
# in persistent filesystems.  It is used in TE rules to permit
# the association of all such file types with persistent filesystem
# types, and to permit certain domains to access all such types as 
# appropriate.
attribute file_type;

# The sysadmfile attribute identifies all types assigned to files 
# that should be completely accessible to administrators.  It is used
# in TE rules to grant such access for administrator domains.
attribute sysadmfile;

# The fs_type attribute identifies all types assigned to filesystems
# (not limited to persistent filesystems).
# It is used in TE rules to permit certain domains to mount
# any filesystem and to permit most domains to obtain the
# overall filesystem statistics.
attribute fs_type;

# The root_dir_type attribute identifies all types assigned to 
# root directories of filesystems (not limited to persistent
# filesystems).
# XXX This attribute was used to grant mountassociate permission,
# XXX but this permission is no longer defined.  We can likely
# XXX remove this attribute.
attribute root_dir_type;

# The exec_type attribute identifies all types assigned
# to entrypoint executables for domains.  This attribute is 
# used in TE rules and assertions that should be applied to all 
# such executables.
attribute exec_type;

# The tmpfile attribute identifies all types assigned to temporary 
# files.  This attribute is used in TE rules to grant certain 
# domains the ability to remove all such files (e.g. init, crond).
attribute tmpfile;

# The user_tmpfile attribute identifies all types associated with temporary
# files for unpriv_userdomain domains.
attribute user_tmpfile;

# for the user_xserver_tmp_t etc
attribute xserver_tmpfile;

# The tmpfsfile attribute identifies all types defined for tmpfs 
# type transitions. 
# It is used in TE rules to grant certain domains the ability to
# access all such files.
attribute tmpfsfile;

# The home_type attribute identifies all types assigned to home
# directories.  This attribute is used in TE rules to grant certain
# domains the ability to access all home directory types.
attribute home_type;

# This attribute is for the main user home directory /home/user, to
# distinguish it from sub-dirs.  Often you want a process to be able to
# read the user home directory but not read the regular directories under it.
attribute home_dir_type;

# The ttyfile attribute identifies all types assigned to ttys.
# It is used in TE rules to grant certain domains the ability to
# access all ttys.
attribute ttyfile;

# The ptyfile attribute identifies all types assigned to ptys.
# It is used in TE rules to grant certain domains the ability to
# access all ptys.
attribute ptyfile;

# The pidfile attribute identifies all types assigned to pid files.
# It is used in TE rules to grant certain domains the ability to
# access all such files.
attribute pidfile;


############################
# Attributes for network types:
#

# The socket_type attribute identifies all types assigned to 
# kernel-created sockets.  Ordinary sockets are assigned the 
# domain of the creating process.
# XXX This attribute is unused.  Remove?
attribute socket_type;

# Identifies all types assigned to port numbers to control binding.
attribute port_type;

# Identifies all types assigned to network interfaces to control
# operations on the interface (XXX obsolete, not supported via LSM) 
# and to control traffic sent or received on the interface.
attribute netif_type;

# Identifies all default types assigned to packets received 
# on network interfaces.  
attribute netmsg_type;

# Identifies all types assigned to network nodes/hosts to control
# traffic sent to or received from the node.
attribute node_type;

# Identifier for log files or directories that only exist for log files.
attribute logfile;

# Identifier for lock files (/var/lock/*) or directories that only exist for
# lock files.
attribute lockfile;



##############################
# Attributes for security policy types:
#

# The login_contexts attribute idenitifies the files used
# to define default contexts for login types (e.g., login, cron).
attribute login_contexts;

# Identifier for a domain used by "sendmail -t" (IE user_mail_t,
# sysadm_mail_t, etc)
attribute user_mail_domain;

# Identifies domains that can transition to system_mail_t
attribute privmail;

# Type for non-sysadm home directory
attribute user_home_type;

# For domains that are part of a mail server and need to read user files and
# fifos, and inherit file handles to enable user email to get to the mail
# spool
attribute mta_user_agent;

# For domains that are part of a mail server for delivering messages to the
# user
attribute mta_delivery_agent;




























#
# Macros for all admin domains.
#

#
# admin_domain(domain_prefix)
#
# Define derived types and rules for an administrator domain.
#
# The type declaration and role authorization for the domain must be
# provided separately.  Likewise, domain transitions into this domain
# must be specified separately.  If the every_domain() rules are desired,
# then these rules must also be specified separately.
#

#line 461

##############################
#
# Global macros for the type enforcement (TE) configuration.
#

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
# Modified: Howard Holm (NSA), <hdholm@epoch.ncsc.mil>
#           System V IPC added
#

#################################
# 
# Macros for groups of classes and 
# groups of permissions.
#

#
# All directory and file classes
#


#
# All non-directory file classes.
#


#
# Non-device file classes.
#


#
# Device file classes.
#


#
# All socket classes.
#


#
# Datagram socket classes.
# 


#
# Stream socket classes.
#


#
# Unprivileged socket classes (exclude rawip, netlink, packet).
#



# 
# Permissions for getting file attributes.
#


# 
# Permissions for executing files.
#


# 
# Permissions for reading files and their attributes.
#


# 
# Permissions for reading and executing files.
#


# 
# Permissions for reading and writing files and their attributes.
#


# 
# Permissions for reading and appending to files.
#


#
# Permissions for linking, unlinking and renaming files.
# 


#
# Permissions for creating and using files.
# 


# 
# Permissions for reading directories and their attributes.
#


# 
# Permissions for reading and writing directories and their attributes.
#


# 
# Permissions for reading and adding names to directories.
#



#
# Permissions for creating and using directories.
# 


#
# Permissions to mount and unmount file systems.
#


#
# Permissions for using sockets.
# 


#
# Permissions for creating and using sockets.
# 


#
# Permissions for using stream sockets.
# 


#
# Permissions for creating and using stream sockets.
# 



#
# Permissions for sending all signals.
#


#
# Permissions for sending and receiving network packets.
#


#
# Permissions for using System V IPC
#







#################################
# 
# Macros for type transition rules and
# access vector rules.
#

#
# Simple combinations for reading and writing both
# directories and files.
# 
#line 640


#line 645


#line 650


#line 655


#line 660


#line 665


#line 670


#################################
#
# domain_trans(parent_domain, program_type, child_domain)
#
# Permissions for transitioning to a new domain.
#

#line 717


#################################
#
# domain_auto_trans(parent_domain, program_type, child_domain)
#
# Define a default domain transition and allow it.
#
#line 728


#line 733


#################################
#
# uses_shlib(domain)
#
# Permissions for using shared libraries.
#
#line 750


#################################
#
# can_ptrace(domain, domain)
#
# Permissions for running ptrace (strace or gdb) on another domain
#
#line 760


#################################
#
# can_exec(domain, type)
#
# Permissions for executing programs with
# a specified type without changing domains.
#
#line 771


#################################
#
# can_exec_any(domain)
#
# Permissions for executing a variety
# of executable types.
#
#line 789



#################################
#
# file_type_trans(domain, dir_type, file_type)
#
# Permissions for transitioning to a new file type.
#

#line 816


#################################
#
# file_type_auto_trans(creator_domain, parent_directory_type, file_type, object_class)
#
# the object class will default to notdevfile_class_set if not specified as
# the fourth parameter
#
# Define a default file type transition and allow it.
#
#line 837


#################################
#
# can_network(domain)
#
# Permissions for accessing the network.
# See types/network.te for the network types.
# See net_contexts for security contexts for network entities.
#
#line 915


#################################
#
# can_unix_connect(client, server)
#
# Permissions for establishing a Unix stream connection.
#
#line 925


#################################
#
# can_unix_send(sender, receiver)
#
# Permissions for sending Unix datagrams.
#
#line 935


#################################
#
# can_tcp_connect(client, server)
#
# Permissions for establishing a TCP connection.
#
#line 948


#################################
#
# can_udp_send(sender, receiver)
#
# Permissions for sending/receiving UDP datagrams.
#
#line 959


#################################
#
# can_sysctl(domain)
#
# Permissions for modifying sysctl parameters.
#
#line 983



##################################
#
# can_create_pty(domain_prefix, attributes)
#
# Permissions for creating ptys.
#
#line 1012



##################################
#
# can_create_other_pty(domain_prefix,other_domain)
#
# Permissions for creating ptys for another domain.
#
#line 1036




################################################
#
# The following macros are an attempt to start
# partitioning every_domain into finer-grained subsets
# that can be used by individual domains.
#

#
# general_domain_access(domain)
#
# Grant permissions within the domain.
# This includes permissions to processes, /proc/PID files,
# file descriptors, pipes, Unix sockets, and System V IPC objects
# labeled with the domain.
#
#line 1080


#
# general_proc_read_access(domain)
#
# Grant read/search permissions to most of /proc, excluding
# the /proc/PID directories and the /proc/kmsg and /proc/kcore files.
# The general_domain_access macro grants access to the domain /proc/PID
# directories, but not to other domains.  Only permissions to stat
# are granted for /proc/kmsg and /proc/kcore, since these files are more
# sensitive.
# 
#line 1115


#
# base_file_read_access(domain)
#
# Grant read/search permissions to a few system file types.
#
#line 1139


#
# general_file_read_access(domain)
#
# Grant read/search permissions to many system file types.
#
#line 1278


#
# general_file_write_access(domain)
#
# Grant write permissions to a small set of system file types, e.g. 
# /dev/tty, /dev/null, etc.
#
# For shared directories like /tmp, each domain should have its own derived
# type (with a file_type_auto_trans rule) for files created in the shared
# directory.
#
#line 1299


#
# every_test_domain(domain)
#
# Grant permissions common to the test domains.
#
#line 1336


################################
#
# every_domain(domain)
#
# Grant permissions common to most domains.
#
# This macro replaces the rules formerly located in domains/every.te.
# An every_domain macro has been inserted into each domain .te file
# for each domain defined within that file.  If you want a new domain
# to inherit these rules, then you can likewise use this macro in
# your new domain .te file.  However, for least privilege purposes, you 
# may want to consider using macros or individual rules that only include 
# a subset of these permissions for your new domain.  This macro has already 
# been partitioned into a few subsets, with corresponding macros defined 
# above and used in defining this macro.  
#
#line 1363


#######################
# daemon_base_domain(domain_prefix, attribs)
#
# Define a daemon domain with a base set of type declarations
# and permissions that are common to most daemons.
# attribs is the list of attributes which must start with `,' if it is not empty
#
# Author:  Russell Coker <russell@coker.com.au>
#
#line 1399

#line 1415

#line 1421


# define a sub-domain, $1_t is the parent domain, $2 is the name
# of the sub-domain.
#
#line 1449



#line 1455


#line 1460


#line 1465


#line 1470


#######################
# application_domain(domain_prefix)
#
# Define a domain with a base set of type declarations
# and permissions that are common to simple applications.
#
# Author:  Russell Coker <russell@coker.com.au>
#
#line 1486


#line 1492


#line 1500


#
# Macros for all user login domains.
#

#
# user_domain(domain_prefix)
#
# Define derived types and rules for an ordinary user domain.
#
# The type declaration and role authorization for the domain must be
# provided separately.  Likewise, domain transitions into this domain
# must be specified separately.  
#

#line 1731



###########################################################################
#
# Domains for ordinary users.
#

#line 1839



#line 1845


#
# Macros for chkpwd domains.
#

#
# chkpwd_domain(domain_prefix)
#
# Define a derived domain for the *_chkpwd program when executed
# by a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/su.te. 
#

#line 1893

#line 1893

#line 1893

#line 1893


# macro for chroot environments
# Author Russell Coker

# chroot(initial_domain, basename, role, tty_device_type)
#line 2025

#
# Macros for clamscan
#
# Author:  Brian May <bam@snoopy.apana.org.au>
#

#
# clamscan_domain(domain_prefix)
#
# Define a derived domain for the clamscan program when executed
#
#line 2060


#line 2069

#
# Macros for crond domains.
#

#
# Authors:  Jonathan Crowley (MITRE) <jonathan@mitre.org>,
#	    Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser
#

#
# crond_domain(domain_prefix)
#
# Define a derived domain for cron jobs executed by crond on behalf 
# of a user domain.  These domains are separate from the top-level domain
# defined for the crond daemon and the domain defined for system cron jobs,
# which are specified in domains/program/crond.te.
#

#line 2140


# When system_crond_t domain executes a type $1 executable then transition to
# domain $2, allow $2 to interact with crond_t as well.
#line 2150

#
# Macros for crontab domains.
#

#
# Authors:  Jonathan Crowley (MITRE) <jonathan@mitre.org>
# Revised by Stephen Smalley <sds@epoch.ncsc.mil>
#

#
# crontab_domain(domain_prefix)
#
# Define a derived domain for the crontab program when executed by
# a user domain.  
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/crontab.te. 
#

#line 2228

#
# Macro for fingerd
#
# Author:  Russell Coker <russell@coker.com.au>
#

#
# fingerd_macro(domain_prefix)
#
# allow fingerd to create a fingerlog file in the user home dir
#
#line 2243

#
# Macros for gpg and pgp
#
# Author:  Russell Coker <russell@coker.com.au>
#
# based on the work of:
# Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser
#

#
# gpg_domain(domain_prefix)
#
# Define a derived domain for the gpg/pgp program when executed by
# a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/gpg.te.
#
#line 2328

#
# Macros for gnome-pty-helper domains.
#

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser 
#

#
# gph_domain(domain_prefix)
#
# Define a derived domain for the gnome-pty-helper program when
# executed by a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/gnome-pty-helper.te. 
#
# The *_gph_t domains are for the gnome_pty_helper program.
# This program is executed by gnome-terminal to handle
# updates to utmp and wtmp.  In this regard, it is similar
# to utempter.  However, unlike utempter, gnome-pty-helper
# also creates the pty file for the terminal program.
# There is one *_gph_t domain for each user domain.  
#

#line 2400


#
# Macros for irc domains.
#

#
# Author:  Russell Coker <russell@coker.com.au>
#

#
# irc_domain(domain_prefix)
#
# Define a derived domain for the irc program when executed
# by a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/irc.te. 
#

#line 2490

#line 2490

#line 2490

#line 2490

#line 2490

#
# Macros for lpr domains.
#

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser 
#

#
# lpr_domain(domain_prefix)
#
# Define a derived domain for the lpr/lpq/lprm programs when executed
# by a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/lpr.te. 
#

#line 2579

#
# Macros for mount
#
# Author:  Brian May <bam@snoopy.apana.org.au>
# Extended by Russell Coker <russell@coker.com.au>
#

#
# mount_domain(domain_prefix,dst_domain_prefix)
#
# Define a derived domain for the mount program for anyone.
#
#line 2621

#
# Macros for MTA domains.
#

#
# Author:   Russell Coker <russell@coker.com.au>
# Based on the work of: Stephen Smalley <sds@epoch.ncsc.mil>
#                       Timothy Fraser 
#

#
# mail_domain(domain_prefix)
#
# Define a derived domain for the sendmail program when executed by
# a user domain to send outgoing mail.  These domains are separate and
# independent of the domain used for the sendmail daemon process.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/mta.te. 
#

#line 2712

#
# Macros for netscape/mozilla (or other browser) domains.
#

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser 
#

#
# netscape_domain(domain_prefix)
#
# Define a derived domain for the netscape/mozilla program when executed by
# a user domain.  
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/netscape.te. 
#
#line 2749

# $1 is the source domain (or domains), $2 is the source role (or roles) and $3
# is the base name for the domain to run.  $1 is normally sysadm_t, and $2 is
# normally sysadm_r.  $4 is the type of program to run and $5 is the domain to
# transition to.
# sample usage:
# run_program(sysadm_t, sysadm_r, init, etc_t, initrc_t)
#
# if you have several users who run the same run_init type program for
# different purposes (think of a run_db program used by several database
# administrators to start several databases) then you can list all the source
# domains in $1, all the source roles in $2, but you may not want to list all
# types of programs to run in $4 and target domains in $5 (as that may permit
# entering a domain from the wrong type).  In such a situation just specify
# one value for each of $4 and $5 and have some rules such as the following:
# domain_trans(run_whatever_t, whatever_exec_t, whatever_t)

#line 2792

#
# Macros for screen domains.
#

#
# Author: Russell Coker <russell@coker.com.au>
# Based on the work of Stephen Smalley <sds@epoch.ncsc.mil>
# and Timothy Fraser
#

#
# screen_domain(domain_prefix)
#
# Define a derived domain for the screen program when executed
# by a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/screen.te. 
#

#line 2882

#line 2882

#line 2882

#line 2882

#line 2882

#
# Macros for sendmail domains.
#

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser 
#           Russell Coker <russell@coker.com.au>
#

#
# sendmail_user_domain(domain_prefix)
#
# Define a derived domain for the sendmail program when executed by
# a user domain to send outgoing mail.  These domains are separate and
# independent of the domain used for the sendmail daemon process.
#

#line 2922


#
# Macros for ssh domains.
#

#
# Author:  Stephen Smalley <sds@epoch.ncsc.mil>
#

# 
# ssh_domain(domain_prefix)
#
# Define a derived domain for the ssh program when executed
# by a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/ssh.te. 
#

#line 3082

#line 3082

#line 3082

#line 3082

#
# Macros for su domains.
#

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser
#

#
# su_domain(domain_prefix)
#
# Define a derived domain for the su program when executed
# by a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/su.te. 
#


#line 3165

#line 3165

#line 3165

#line 3165

#
# Macros for xauth domains.
#

#
# Author:  Russell Coker <russell@coker.com.au>
#

#
# xauth_domain(domain_prefix)
#
# Define a derived domain for the xauth program when executed
# by a user domain.
#
# The type declaration for the executable type for this program is
# provided separately in domains/program/xauth.te. 
#

#line 3263

#line 3263

#line 3263

#line 3263

#line 3263

#
# Macros for X client programs ($2 etc)
#

#
# Author: Russell Coker <russell@coker.com.au>
# Based on the work of Stephen Smalley <sds@epoch.ncsc.mil>
# and Timothy Fraser 
#

#
# x_client_domain(domain_prefix)
#
# Define a derived domain for an X program when executed by
# a user domain.  
#
# The type declaration for the executable type for this program ($2_exec_t)
# must be provided separately!
#
# The first parameter is the base name for the domain/role (EG user or sysadm)
# The second parameter is the program name (EG $2)
# The third parameter is the attributes for the domain (if any)
#
#line 3402
#
# Macros for X server domains.
#

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser
#

#################################
#
# xserver_domain(domain_prefix)
#
# Define a derived domain for the X server when executed
# by a user domain (e.g. via startx).  See the xdm_t domain
# in domains/program/xdm.te if using an X Display Manager.
#
# The type declarations for the executable type for this program 
# and the log type are provided separately in domains/program/xserver.te. 
#
# FIXME!  The X server requires far too many privileges.
#

#line 3563

#line 3563

#line 3563

#line 3563

#line 3563


#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

############################################
#
# Device types
#

#
# device_t is the type of /dev.
#
type device_t, file_type;

#
# null_device_t is the type of /dev/null.
#
type null_device_t, file_type, mlstrustedobject;

#
# zero_device_t is the type of /dev/zero.
#
type zero_device_t, file_type, mlstrustedobject;

#
# console_device_t is the type of /dev/console.
#
type console_device_t, file_type;

#
# memory_device_t is the type of /dev/kmem,
# /dev/mem, and /dev/port.
#
type memory_device_t, file_type;

#
# random_device_t is the type of /dev/urandom
# and /dev/random.
#
type random_device_t, file_type;

#
# devtty_t is the type of /dev/tty.
#
type devtty_t, file_type, mlstrustedobject;

#
# tty_device_t is the type of /dev/*tty*
#
type tty_device_t, file_type;

#
# fixed_disk_device_t is the type of 
# /dev/hd* and /dev/sd*.
#
type fixed_disk_device_t, file_type;

#
# removable_device_t is the type of
# /dev/scd* and /dev/fd*.
#
type removable_device_t, file_type;

#
# clock_device_t is the type of
# /dev/rtc.
#
type clock_device_t, file_type;

#
# tun_tap_device_t is the type of /dev/net/tun/* and /dev/net/tap/*
#
type tun_tap_device_t, file_type;

#
# misc_device_t is the type of miscellaneous devices.
# XXX:  FIXME!  Appropriate access to these devices need to be identified.
#
type misc_device_t, file_type;

#
# psaux_t is the type of the /dev/psaux mouse device.
# This type is deprecated and will be removed.
#
type psaux_t, file_type;

#
# A more general type for mouse devices.
#
type mouse_device_t, file_type;

#
# Not sure what these devices are for, but X wants access to them.
#
type agp_device_t, file_type;
type dri_device_t, file_type;

# Type for sound devices.
type sound_device_t, file_type;

# Type for /dev/ppp.
type ppp_device_t, file_type;

# Type for frame buffer /dev/fb/*
type framebuf_device_t, file_type;

# Type for /dev/.devfsd
type devfs_control_t, file_type;

# Type for /dev/cpu/mtrr
type mtrr_device_t, file_type;


# Type for /dev/apm_bios
type apm_bios_t, file_type;

# Type for v4l
type v4l_device_t, file_type;
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

############################################
#
# Devpts types
#

#
# ptmx_t is the type for /dev/ptmx.
#
type ptmx_t, file_type, sysadmfile;

#
# devpts_t is the type of the devpts file system and 
# the type of the root directory of the file system.
#
type devpts_t, fs_type, root_dir_type;


#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

#######################################
#
# General file-related types
#

#
# unlabeled_t is the type of unlabeled objects.
# Eventually, once all objects are labeled and 
# controlled by the security policy, unlabeled_t 
# will not be used.
#
type unlabeled_t, fs_type, file_type, root_dir_type, sysadmfile;

#
# fs_t is the default type of an unlabeled
# file system.  When an unlabeled file system is
# mounted read-write, the file system is labeled
# with this type.  Except for the root file system,
# other types may be specified using the fs_contexts
# or fs_contexts.mls file.
#
type fs_t, fs_type;

#
# file_t is the default type of an unlabeled
# file.  When an unlabeled file system is mounted
# read-write, all files in the file system are labeled
# with this type.   Except for the root file system,
# other types may be specified using the fs_contexts
# or fs_contexts.mls file.
#
type file_t, file_type, root_dir_type, sysadmfile;

#
# root_t is the type for the root directory.
#
type root_t, file_type, sysadmfile;

#
# home_root_t is the type for the directory where user home directories
# are created
#
type home_root_t, file_type, sysadmfile;

#
# lost_found_t is the type for the lost+found directories.
#
type lost_found_t, file_type, sysadmfile;

#
# boot_t is the type for files in /boot,
# including the kernel.
#
type boot_t, file_type, root_dir_type, sysadmfile;
# system_map_t is for the system.map files in /boot
type system_map_t, file_type, sysadmfile;

#
# boot_runtime_t is the type for /boot/kernel.h,
# which is automatically generated at boot time.
# only for red hat
type boot_runtime_t, file_type, sysadmfile;

#
# tmp_t is the type of /tmp and /var/tmp.
#
type tmp_t, file_type, sysadmfile, tmpfile;

#
# etc_t is the type of the system etc directories.
#
type etc_t, file_type, sysadmfile;
#
# shadow_t is the type of the /etc/shadow file
#
type shadow_t, file_type;
allow auth shadow_t:file { getattr read };

#
# ld_so_cache_t is the type of /etc/ld.so.cache.
#
type ld_so_cache_t, file_type, sysadmfile;

#
# etc_runtime_t is the type of various
# files in /etc that are automatically
# generated during initialization.
#
type etc_runtime_t, file_type, sysadmfile;

#
# etc_aliases_t is the type of the aliases database.
# etc_mail_t is the type of /etc/mail.
# sendmail needs write access to these files.
#
type etc_aliases_t, file_type, sysadmfile;
type etc_mail_t, file_type, sysadmfile;

# resolv_conf_t is the type of the /etc/resolv.conf file.
# pump needs write access to this file.
type resolv_conf_t, file_type, sysadmfile;

#
# lib_t is the type of files in the system lib directories.
#
type lib_t, file_type, sysadmfile;

#
# shlib_t is the type of shared objects in the system lib
# directories.
#
type shlib_t, file_type, sysadmfile;

#
# ld_so_t is the type of the system dynamic loaders.
#
type ld_so_t, file_type, sysadmfile;

#
# bin_t is the type of files in the system bin directories.
#
type bin_t, file_type, sysadmfile;

#
# ls_exec_t is the type of the ls program.
#
type ls_exec_t, file_type, exec_type, sysadmfile;

#
# shell_exec_t is the type of user shells such as /bin/bash.
#
type shell_exec_t, file_type, exec_type, sysadmfile;

#
# sbin_t is the type of files in the system sbin directories.
#
type sbin_t, file_type, sysadmfile;

#
# usr_t is the type for /usr.
#
type usr_t, file_type, root_dir_type, sysadmfile;

#
# src_t is the type of files in the system src directories.
#
type src_t, file_type, sysadmfile;

#
# var_t is the type for /var.
#
type var_t, file_type, root_dir_type, sysadmfile;

#
# Types for subdirectories of /var.
#
type var_run_t, file_type, sysadmfile;
type var_log_t, file_type, sysadmfile, logfile;
type faillog_t, file_type, sysadmfile, logfile;
type var_lock_t, file_type, sysadmfile, lockfile;
type var_lib_t, file_type, sysadmfile;
# for /var/{spool,lib}/texmf index files
type tetex_data_t, file_type, sysadmfile, tmpfile;
type var_spool_t, file_type, sysadmfile;
type var_yp_t, file_type, sysadmfile;

# Type for /var/log/sa.
type var_log_sa_t, file_type, sysadmfile, logfile;

# Type for /var/log/ksyms.
type var_log_ksyms_t, file_type, sysadmfile, logfile;

# Type for /var/log/lastlog.
type lastlog_t, file_type, sysadmfile, logfile;

# Type for /var/lib/nfs.
type var_lib_nfs_t, file_type, sysadmfile;

#
# wtmp_t is the type of /var/log/wtmp.
#
type wtmp_t, file_type, sysadmfile, logfile;

#
# catman_t is the type for /var/catman.
#
type catman_t, file_type, sysadmfile, tmpfile;

#
# at_spool_t is the type for /var/spool/at.
#
type at_spool_t, file_type, sysadmfile;

#
# cron_spool_t is the type for /var/spool/cron.
#
type cron_spool_t, file_type, sysadmfile;

#
# print_spool_t is the type for /var/spool/lpd and /var/spool/cups.
#
type print_spool_t, file_type, sysadmfile;

#
# mail_spool_t is the type for /var/spool/mail.
#
type mail_spool_t, file_type, sysadmfile;

#
# mqueue_spool_t is the type for /var/spool/mqueue.
#
type mqueue_spool_t, file_type, sysadmfile;

#
# man_t is the type for the man directories.
#
type man_t, file_type, sysadmfile;

#
# readable_t is a general type for
# files that are readable by all domains.
#
type readable_t, file_type, sysadmfile;

# 
# Base type for the tests directory.
# 
type test_file_t, file_type, sysadmfile;

#
# poly_t is the type for the polyinstantiated directories.
#
type poly_t, file_type, sysadmfile;

#
# swapfile_t is for swap files
#
type swapfile_t, file_type, sysadmfile;

#
# locale_t is the type for system localization
# 
type locale_t, file_type;

#
# Allow each file type to be associated with 
# the default file system type.
#
allow file_type fs_t:filesystem associate;

# Allow the pty to be associated with the file system.
allow devpts_t devpts_t:filesystem associate;

type tmpfs_t, file_type, sysadmfile, fs_type, root_dir_type;
allow { tmpfs_t tmp_t } tmpfs_t:filesystem associate;

type usbdevfs_t, fs_type, root_dir_type, sysadmfile;
allow usbdevfs_t usbdevfs_t:filesystem associate;
type usbdevfs_device_t, file_type, sysadmfile;
allow usbdevfs_device_t usbdevfs_t:filesystem associate;

type sysfs_t alias driverfs_t, fs_type, root_dir_type, sysadmfile;
allow sysfs_t sysfs_t:filesystem associate;

type iso9660_t, fs_type, root_dir_type, sysadmfile;
allow iso9660_t iso9660_t:filesystem associate;

type dosfs_t, fs_type, root_dir_type, sysadmfile;
allow dosfs_t dosfs_t:filesystem associate;
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

# Modified by Reino Wallin <reino@oribium.com>
# Multi NIC, and IPSEC features

# Modified by Russell Coker
# Move port types to their respective domains, add ifdefs, other cleanups.

############################################
#
# Network types
#

# 
# any_socket_t is the default destination
# socket type for UDP traffic.  Unless a 
# destination socket type is explicitly specified
# using sendto_secure/sendmsg_secure, this type
# is used for the udp_socket sendto permission check.
#
type any_socket_t, socket_type;
role system_r types any_socket_t;

#
# igmp_packet_t is the type of kernel-generated IGMP packets.
# icmp_socket_t is the type of the kernel socket used to send ICMP messages.
# tcp_socket_t is the type of the kernel socket used to send TCP resets.
# scmp_packet_t is the type for SCMP packets used by the SELOPT packet labeling.
#
type igmp_packet_t;
role system_r types igmp_packet_t;
type icmp_socket_t, socket_type;
role system_r types icmp_socket_t;
type tcp_socket_t, socket_type;
role system_r types tcp_socket_t;
type scmp_packet_t;
role system_r types scmp_packet_t;

#
# port_t is the default type of INET port numbers.
# The *_port_t types are used for specific port
# numbers in net_contexts or net_contexts.mls.
#
type port_t, port_type;

#
# netif_t is the default type of network interfaces.
# The netif_*_t types are used for specific network
# interfaces in net_contexts or net_contexts.mls.
#
type netif_t, netif_type;
type netif_eth0_t, netif_type;
type netif_eth1_t, netif_type;
type netif_eth2_t, netif_type;
type netif_lo_t, netif_type;
type netif_ippp0_t, netif_type;

type netif_ipsec0_t, netif_type;
type netif_ipsec1_t, netif_type;
type netif_ipsec2_t, netif_type;

#
# netmsg_t is the default type of unlabeled received messages.
# The netmsg_*_t types are used for specific network
# interfaces in net_contexts or net_contexts.mls.
#
type netmsg_t, netmsg_type;
type netmsg_eth0_t, netmsg_type;
type netmsg_eth1_t, netmsg_type;
type netmsg_eth2_t, netmsg_type;
type netmsg_lo_t, netmsg_type;
type netmsg_ippp0_t, netmsg_type;

type netmsg_ipsec0_t, netmsg_type;
type netmsg_ipsec1_t, netmsg_type;
type netmsg_ipsec2_t, netmsg_type;

#
# node_t is the default type of network nodes.
# The node_*_t types are used for specific network
# nodes in net_contexts or net_contexts.mls.
#
type node_t, node_type;
type node_lo_t, node_type;
type node_internal_t, node_type;

#
# Permissions for the kernel-generated IGMP packets.
#
allow igmp_packet_t netif_type:netif { rawip_send rawip_recv };
allow igmp_packet_t node_type:node { rawip_send rawip_recv };

#
# Permissions for the kernel ICMP socket.
#
allow icmp_socket_t netif_type:netif { rawip_send rawip_recv };
allow icmp_socket_t node_type:node { rawip_send rawip_recv };
allow icmp_socket_t netmsg_type:rawip_socket recvfrom;

#
# Permissions for the kernel TCP reset socket.
#
allow tcp_socket_t netif_type:netif { tcp_send tcp_recv };
allow tcp_socket_t netmsg_type:tcp_socket recvfrom;
allow tcp_socket_t node_type:node { tcp_send tcp_recv };

#
# Allow network messages to be received.
#
allow netmsg_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_eth0_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_eth0_t netif_eth0_t:netif { tcp_recv udp_recv rawip_recv };
allow netmsg_eth1_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_eth1_t netif_eth1_t:netif { tcp_recv udp_recv rawip_recv };
allow netmsg_eth2_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_eth2_t netif_eth2_t:netif { tcp_recv udp_recv rawip_recv };
allow netmsg_lo_t node_lo_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_lo_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_lo_t netif_lo_t:netif { tcp_recv udp_recv rawip_recv };
allow netmsg_ippp0_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_ippp0_t netif_ippp0_t:netif { tcp_recv udp_recv rawip_recv };
allow netmsg_ipsec0_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_ipsec0_t netif_ipsec0_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_ipsec1_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_ipsec1_t netif_ipsec1_t:netif { tcp_recv udp_recv rawip_recv };
allow netmsg_ipsec2_t node_t:node { tcp_recv udp_recv rawip_recv };
allow netmsg_ipsec2_t netif_ipsec2_t:netif { tcp_recv udp_recv rawip_recv };

#
# Allow ICMP echo requests to be sent and received, and echo replies to 
# be received (when packets are labeled)
#
#line 4114

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

#############################################
#
# NFS types
#

#
# nfs_t is the default type for NFS file systems 
# and their files.  
# The nfs_*_t types are used for specific NFS
# servers in net_contexts or net_contexts.mls.
#
type nfs_t, fs_type, root_dir_type;

#
# Allow NFS files to be associated with an NFS file system.
#
allow nfs_t nfs_t:filesystem associate;
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

############################################
#
# Procfs types
#

#
# proc_t is the type of /proc.
# proc_kmsg_t is the type of /proc/kmsg.
# proc_kcore_t is the type of /proc/kcore.
#
type proc_t, fs_type, root_dir_type;
type proc_kmsg_t;
type proc_kcore_t;

#
# sysctl_t is the type of /proc/sys.
# sysctl_fs_t is the type of /proc/sys/fs.
# sysctl_kernel_t is the type of /proc/sys/kernel.
# sysctl_modprobe_t is the type of /proc/sys/kernel/modprobe.
# sysctl_net_t is the type of /proc/sys/net.
# sysctl_net_unix_t is the type of /proc/sys/net/unix.
# sysctl_vm_t is the type of /proc/sys/vm.
# sysctl_dev_t is the type of /proc/sys/dev.
#
# These types are applied to both the entries in
# /proc/sys and the corresponding sysctl parameters.
#
type sysctl_t;
type sysctl_fs_t;
type sysctl_kernel_t;
type sysctl_modprobe_t;
type sysctl_net_t;
type sysctl_net_unix_t;
type sysctl_vm_t;
type sysctl_dev_t;


#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

############################################
#
# Security types
#

# 
# security_t is the target type when checking
# most of the permissions in the security class.
# The two exceptions are sid_to_context and load_policy.
# The sid_to_context permission uses the type attribute
# of the SID parameter, and the load_policy permission
# uses the type of the policy file.
#
type security_t;

#
# policy_config_t is the type of /ss_policy,
# the security server policy configuration.
#
type policy_config_t, file_type;

#
# policy_src_t is the type of the policy source
# files.
#
type policy_src_t, file_type;

#
# default_context_t is the type applied to 
# /etc/security/default_context
#
type default_context_t, file_type, sysadmfile, login_contexts;

#
# file_labels_t is the type of the persistent
# label mapping stored in each file system.
# The mapping files are in the ...security
# subdirectory at the root of each file system.
#
type file_labels_t, file_type, sysadmfile;

#
# no_access_t is the type for objects that should
# only be accessed administratively. 
#
type no_access_t, file_type, sysadmfile;


#DESC Admin - Domains for administrators.
#
#################################

# sysadm_t is the system administrator domain.
type sysadm_t, domain, privlog, privowner, admin, userdomain, privhome;
allow privhome home_root_t:dir search;

# system_r is authorized for sysadm_t for single-user mode.
role system_r types sysadm_t; 

# sysadm_r is authorized for sysadm_t for the initial login domain.
role sysadm_r types sysadm_t;

# sysadm_t is granted the permissions common to most domains.

#line 4244

#line 4244
# Grant the permissions common to the test domains.
#line 4244

#line 4244
# Grant permissions within the domain.
#line 4244

#line 4244
# Access other processes in the same domain.
#line 4244
allow sysadm_t self:process *;
#line 4244

#line 4244
# Access /proc/PID files for processes in the same domain.
#line 4244
allow sysadm_t self:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4244

#line 4244
# Access file descriptions, pipes, and sockets
#line 4244
# created by processes in the same domain.
#line 4244
allow sysadm_t self:fd *;
#line 4244
allow sysadm_t self:fifo_file { ioctl read getattr lock write append };
#line 4244
allow sysadm_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4244
allow sysadm_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4244

#line 4244
# Allow the domain to communicate with other processes in the same domain.
#line 4244
allow sysadm_t self:unix_dgram_socket sendto;
#line 4244
allow sysadm_t self:unix_stream_socket connectto;
#line 4244

#line 4244
# Access System V IPC objects created by processes in the same domain.
#line 4244
allow sysadm_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4244
allow sysadm_t self:msg  { send receive };
#line 4244
allow sysadm_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4244
allow sysadm_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4244

#line 4244

#line 4244

#line 4244
# Grant read/search permissions to most of /proc.
#line 4244

#line 4244
# Read system information files in /proc.
#line 4244
allow sysadm_t proc_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4244

#line 4244
# Stat /proc/kmsg and /proc/kcore.
#line 4244
allow sysadm_t proc_kmsg_t:file { getattr };
#line 4244
allow sysadm_t proc_kcore_t:file { getattr };
#line 4244

#line 4244
# Read system variables in /proc/sys.
#line 4244
allow sysadm_t sysctl_modprobe_t:file { read getattr lock ioctl };
#line 4244
allow sysadm_t sysctl_t:file { read getattr lock ioctl };
#line 4244
allow sysadm_t sysctl_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t sysctl_fs_t:file { read getattr lock ioctl };
#line 4244
allow sysadm_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t sysctl_kernel_t:file { read getattr lock ioctl };
#line 4244
allow sysadm_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t sysctl_net_t:file { read getattr lock ioctl };
#line 4244
allow sysadm_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t sysctl_vm_t:file { read getattr lock ioctl };
#line 4244
allow sysadm_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t sysctl_dev_t:file { read getattr lock ioctl };
#line 4244
allow sysadm_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 4244

#line 4244

#line 4244
# Grant read/search permissions to many system file types.
#line 4244

#line 4244

#line 4244
# Get attributes of file systems.
#line 4244
allow sysadm_t fs_type:filesystem getattr;
#line 4244

#line 4244

#line 4244
# Read /.
#line 4244
allow sysadm_t root_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4244

#line 4244
# Read /home.
#line 4244
allow sysadm_t home_root_t:dir { read getattr lock search ioctl };
#line 4244

#line 4244
# Read /usr.
#line 4244
allow sysadm_t usr_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4244

#line 4244
# Read bin and sbin directories.
#line 4244
allow sysadm_t bin_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4244
allow sysadm_t sbin_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4244

#line 4244

#line 4244
# Read directories and files with the readable_t type.
#line 4244
# This type is a general type for "world"-readable files.
#line 4244
allow sysadm_t readable_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4244

#line 4244
# Stat /...security and lost+found.
#line 4244
allow sysadm_t file_labels_t:dir getattr;
#line 4244
allow sysadm_t lost_found_t:dir getattr;
#line 4244

#line 4244
# Read the devpts root directory.  
#line 4244
allow sysadm_t devpts_t:dir { read getattr lock search ioctl };
#line 4244

#line 4244

#line 4244
# Read the /tmp directory and any /tmp files with the base type.
#line 4244
# Temporary files created at runtime will typically use derived types.
#line 4244
allow sysadm_t tmp_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t tmp_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244

#line 4244
# Read /var.
#line 4244
allow sysadm_t var_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4244

#line 4244
# Read /var/catman.
#line 4244
allow sysadm_t catman_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t catman_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244

#line 4244
# Read /var/lib.
#line 4244
allow sysadm_t var_lib_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t var_lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4244
allow sysadm_t var_lib_nfs_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t var_lib_nfs_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4244

#line 4244

#line 4244
allow sysadm_t tetex_data_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t tetex_data_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244

#line 4244

#line 4244
# Read /var/yp.
#line 4244
allow sysadm_t var_yp_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t var_yp_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4244

#line 4244
# Read /var/spool.
#line 4244
allow sysadm_t var_spool_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4244

#line 4244
# Read /var/run, /var/lock, /var/log.
#line 4244
allow sysadm_t var_run_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244
allow sysadm_t var_log_t:dir { read getattr lock search ioctl };
#line 4244
#allow sysadm_t var_log_t:{ file lnk_file } r_file_perms;
#line 4244
allow sysadm_t var_log_sa_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t var_log_sa_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244
allow sysadm_t var_log_ksyms_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244

#line 4244
allow sysadm_t var_lock_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t var_lock_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244

#line 4244
# Read /var/run/utmp and /var/log/wtmp.
#line 4244
allow sysadm_t initrc_var_run_t:file { read getattr lock ioctl };
#line 4244
allow sysadm_t wtmp_t:file { read getattr lock ioctl };
#line 4244

#line 4244
# Read /boot, /boot/System.map*, and /vmlinuz*
#line 4244
allow sysadm_t boot_t:dir { search getattr };
#line 4244
allow sysadm_t boot_t:file getattr;
#line 4244
allow sysadm_t system_map_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244

#line 4244
allow sysadm_t boot_t:lnk_file read;
#line 4244

#line 4244
# Read /etc.
#line 4244
allow sysadm_t etc_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4244
allow sysadm_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244
allow sysadm_t etc_aliases_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244
allow sysadm_t etc_mail_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t etc_mail_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244
allow sysadm_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244
allow sysadm_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4244

#line 4244
# Read /lib.
#line 4244
allow sysadm_t lib_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4244

#line 4244
# Read the linker, shared library, and executable types.
#line 4244
allow sysadm_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244
allow sysadm_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244
allow sysadm_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 4244

#line 4244
# Read man directories and files.
#line 4244
allow sysadm_t man_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t man_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4244

#line 4244
# Read /usr/src.
#line 4244
allow sysadm_t src_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t src_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4244

#line 4244
# Read module-related files.
#line 4244
allow sysadm_t modules_object_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t modules_object_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244
allow sysadm_t modules_dep_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244
allow sysadm_t modules_conf_t:{ file lnk_file} { read getattr lock ioctl };
#line 4244

#line 4244
# Read /dev directories and any symbolic links.
#line 4244
allow sysadm_t device_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t device_t:lnk_file { read getattr lock ioctl };
#line 4244

#line 4244
# Read /dev/random and /dev/zero.
#line 4244
allow sysadm_t random_device_t:chr_file { read getattr lock ioctl };
#line 4244
allow sysadm_t zero_device_t:chr_file { read getattr lock ioctl };
#line 4244

#line 4244
# Read the root directory of a tmpfs filesytem and any symbolic links.
#line 4244
allow sysadm_t tmpfs_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t tmpfs_t:lnk_file { read getattr lock ioctl };
#line 4244

#line 4244
# Read any symbolic links on a devfs file system.
#line 4244
allow sysadm_t device_t:lnk_file { read getattr lock ioctl };
#line 4244

#line 4244
# Read the root directory of a usbdevfs filesystem, and
#line 4244
# the devices and drivers files.  Permit stating of the
#line 4244
# device nodes, but nothing else.
#line 4244
allow sysadm_t usbdevfs_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t usbdevfs_t:{ file lnk_file } { read getattr lock ioctl };
#line 4244
allow sysadm_t usbdevfs_device_t:file getattr;
#line 4244

#line 4244

#line 4244
# Grant write permissions to a small set of system file types.
#line 4244
# No permission to create files is granted here.  Use allow rules to grant 
#line 4244
# create permissions to a type or use file_type_auto_trans rules to set up
#line 4244
# new types for files.
#line 4244

#line 4244

#line 4244
# Read and write /dev/tty and /dev/null.
#line 4244
allow sysadm_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4244
allow sysadm_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 4244

#line 4244
# Do not audit write denials to /etc/ld.so.cache.
#line 4244
dontaudit sysadm_t ld_so_cache_t:file write;
#line 4244

#line 4244

#line 4244
# Execute from the system shared libraries.
#line 4244
# No permission to execute anything else is granted here.
#line 4244
# Use can_exec or can_exec_any to grant the ability to execute within a domain.
#line 4244
# Use domain_auto_trans for executing and changing domains.
#line 4244

#line 4244
allow sysadm_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t ld_so_t:file { read getattr lock execute ioctl };
#line 4244
allow sysadm_t ld_so_t:file execute_no_trans;
#line 4244
allow sysadm_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4244
allow sysadm_t shlib_t:file { read getattr lock execute ioctl };
#line 4244
allow sysadm_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4244
allow sysadm_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4244
allow sysadm_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4244

#line 4244

#line 4244
# read localization information
#line 4244
allow sysadm_t locale_t:dir { read getattr lock search ioctl };
#line 4244
allow sysadm_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 4244

#line 4244
# Obtain the context of any SID, the SID for any context, 
#line 4244
# and the list of active SIDs.
#line 4244
allow sysadm_t security_t:security { sid_to_context context_to_sid get_sids };
#line 4244

#line 4244

#line 4244

#line 4244
# Grant permissions needed to create TCP and UDP sockets and 
#line 4244
# to access the network.
#line 4244

#line 4244
#
#line 4244
# Allow the domain to create and use UDP and TCP sockets.
#line 4244
# Other kinds of sockets must be separately authorized for use.
#line 4244
allow sysadm_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4244
allow sysadm_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4244

#line 4244
#
#line 4244
# Allow the domain to send UDP packets.
#line 4244
# Since the destination sockets type is unknown, the generic
#line 4244
# any_socket_t type is used as a placeholder.
#line 4244
#
#line 4244
allow sysadm_t any_socket_t:udp_socket sendto;
#line 4244

#line 4244
#
#line 4244
# Allow the domain to send using any network interface.
#line 4244
# netif_type is a type attribute for all network interface types.
#line 4244
#
#line 4244
allow sysadm_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4244

#line 4244
#
#line 4244
# Allow packets sent by the domain to be received on any network interface.
#line 4244
#
#line 4244
allow sysadm_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4244

#line 4244
#
#line 4244
# Allow the domain to receive packets from any network interface.
#line 4244
# netmsg_type is a type attribute for all default message types.
#line 4244
#
#line 4244
allow sysadm_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4244

#line 4244
#
#line 4244
# Allow the domain to initiate or accept TCP connections 
#line 4244
# on any network interface.
#line 4244
#
#line 4244
allow sysadm_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4244

#line 4244
#
#line 4244
# Receive resets from the TCP reset socket.
#line 4244
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4244
#
#line 4244
allow sysadm_t tcp_socket_t:tcp_socket recvfrom;
#line 4244

#line 4244
dontaudit sysadm_t tcp_socket_t:tcp_socket connectto;
#line 4244

#line 4244
#
#line 4244
# Allow the domain to send to any node.
#line 4244
# node_type is a type attribute for all node types.
#line 4244
#
#line 4244
allow sysadm_t node_type:node { tcp_send udp_send rawip_send };
#line 4244

#line 4244
#
#line 4244
# Allow packets sent by the domain to be received from any node.
#line 4244
#
#line 4244
allow sysadm_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4244

#line 4244
#
#line 4244
# Allow the domain to send NFS client requests via the socket
#line 4244
# created by mount.
#line 4244
#
#line 4244
allow sysadm_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4244

#line 4244
#
#line 4244
# Bind to the default port type.
#line 4244
# Other port types must be separately authorized.
#line 4244
#
#line 4244
allow sysadm_t port_t:udp_socket name_bind;
#line 4244
allow sysadm_t port_t:tcp_socket name_bind;
#line 4244

#line 4244


# sysadm_t is also granted permissions specific to administrator domains.

#line 4247
# Inherit rules for ordinary users.
#line 4247

#line 4247
# Use capabilities
#line 4247
allow sysadm_t self:capability { setgid chown fowner };
#line 4247
dontaudit sysadm_t self:capability { sys_nice fsetid };
#line 4247

#line 4247
# Type for home directory.
#line 4247

#line 4247
type sysadm_home_dir_t, file_type, sysadmfile, home_dir_type, home_type;
#line 4247
type sysadm_home_t, file_type, sysadmfile, home_type;
#line 4247

#line 4247
type sysadm_tmp_t, file_type, sysadmfile, tmpfile ;
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to modify the directory.
#line 4247
#
#line 4247
allow sysadm_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4247

#line 4247
#
#line 4247
# Allow the process to create the file.
#line 4247
#
#line 4247

#line 4247
allow sysadm_t sysadm_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4247
allow sysadm_t sysadm_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4247

#line 4247

#line 4247

#line 4247
type_transition sysadm_t tmp_t:dir sysadm_tmp_t;
#line 4247
type_transition sysadm_t tmp_t:{ file lnk_file sock_file fifo_file } sysadm_tmp_t;
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
# Create, access, and remove files in home directory.
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to modify the directory.
#line 4247
#
#line 4247
allow sysadm_t sysadm_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4247

#line 4247
#
#line 4247
# Allow the process to create the file.
#line 4247
#
#line 4247

#line 4247
allow sysadm_t sysadm_home_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4247
allow sysadm_t sysadm_home_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4247

#line 4247

#line 4247

#line 4247
type_transition sysadm_t sysadm_home_dir_t:dir sysadm_home_t;
#line 4247
type_transition sysadm_t sysadm_home_dir_t:{ file lnk_file sock_file fifo_file } sysadm_home_t;
#line 4247

#line 4247

#line 4247

#line 4247
allow sysadm_t sysadm_home_t:{ dir file lnk_file sock_file fifo_file chr_file blk_file } { relabelfrom relabelto };
#line 4247

#line 4247
# Bind to a Unix domain socket in /tmp.
#line 4247
allow sysadm_t sysadm_tmp_t:unix_stream_socket name_bind;
#line 4247

#line 4247
# Type for tty devices.
#line 4247
type sysadm_tty_device_t, file_type, sysadmfile, ttyfile;
#line 4247
# Access ttys.
#line 4247
allow sysadm_t sysadm_tty_device_t:chr_file { setattr { ioctl read getattr lock write append } };
#line 4247
# Use the type when relabeling terminal devices.
#line 4247
type_change sysadm_t tty_device_t:chr_file sysadm_tty_device_t;
#line 4247

#line 4247

#line 4247
# Type and access for pty devices.
#line 4247

#line 4247

#line 4247

#line 4247
type sysadm_devpts_t, file_type, sysadmfile, ptyfile ;
#line 4247

#line 4247
# Allow the pty to be associated with the file system.
#line 4247
allow sysadm_devpts_t devpts_t:filesystem associate;
#line 4247

#line 4247
# Access the pty master multiplexer.
#line 4247
allow sysadm_t ptmx_t:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247
# Label pty files with a derived type.
#line 4247
type_transition sysadm_t devpts_t:chr_file sysadm_devpts_t;
#line 4247

#line 4247
# Read and write my pty files.
#line 4247
allow sysadm_t sysadm_devpts_t:chr_file { setattr { ioctl read getattr lock write append } };
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
# Use the type when relabeling pty devices.
#line 4247

#line 4247

#line 4247
type_change sysadm_t sshd_devpts_t:chr_file sysadm_devpts_t;
#line 4247

#line 4247
# Connect to sshd.
#line 4247

#line 4247
allow sysadm_t sshd_t:tcp_socket { connectto recvfrom };
#line 4247
allow sshd_t sysadm_t:tcp_socket { acceptfrom recvfrom };
#line 4247
allow sshd_t tcp_socket_t:tcp_socket { recvfrom };
#line 4247
allow sysadm_t tcp_socket_t:tcp_socket { recvfrom };
#line 4247

#line 4247

#line 4247
# Connect to ssh proxy.
#line 4247

#line 4247
allow sysadm_t sysadm_ssh_t:tcp_socket { connectto recvfrom };
#line 4247
allow sysadm_ssh_t sysadm_t:tcp_socket { acceptfrom recvfrom };
#line 4247
allow sysadm_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4247
allow sysadm_t tcp_socket_t:tcp_socket { recvfrom };
#line 4247

#line 4247

#line 4247
allow sysadm_t sshd_t:fd use;
#line 4247
allow sysadm_t sshd_t:tcp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4247
# Use a Unix stream socket inherited from sshd.
#line 4247
allow sysadm_t sshd_t:unix_stream_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4247

#line 4247
# Type for tmpfs/shm files.
#line 4247
type sysadm_tmpfs_t, file_type, sysadmfile, tmpfsfile;
#line 4247
# Use the type when creating files in tmpfs.
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to modify the directory.
#line 4247
#
#line 4247
allow sysadm_t tmpfs_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4247

#line 4247
#
#line 4247
# Allow the process to create the file.
#line 4247
#
#line 4247

#line 4247
allow sysadm_t sysadm_tmpfs_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4247
allow sysadm_t sysadm_tmpfs_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4247

#line 4247

#line 4247

#line 4247
type_transition sysadm_t tmpfs_t:dir sysadm_tmpfs_t;
#line 4247
type_transition sysadm_t tmpfs_t:{ file lnk_file sock_file fifo_file } sysadm_tmpfs_t;
#line 4247

#line 4247

#line 4247

#line 4247
allow sysadm_tmpfs_t tmpfs_t:filesystem associate;
#line 4247

#line 4247
# Read and write /var/catman.
#line 4247
allow sysadm_t catman_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4247
allow sysadm_t catman_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4247

#line 4247
# Modify mail spool file.
#line 4247
allow sysadm_t mail_spool_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_t mail_spool_t:file { ioctl read getattr lock write append };
#line 4247
allow sysadm_t mail_spool_t:lnk_file read;
#line 4247

#line 4247
#
#line 4247
# Allow the query of filesystem quotas
#line 4247
#
#line 4247
allow sysadm_t fs_type:filesystem quotaget;
#line 4247

#line 4247
# Run helper programs.
#line 4247

#line 4247
allow sysadm_t { bin_t sbin_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_t { bin_t sbin_t }:lnk_file read;
#line 4247

#line 4247
allow sysadm_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_t ld_so_t:file { read getattr lock execute ioctl };
#line 4247
allow sysadm_t ld_so_t:file execute_no_trans;
#line 4247
allow sysadm_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4247
allow sysadm_t shlib_t:file { read getattr lock execute ioctl };
#line 4247
allow sysadm_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4247
allow sysadm_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247

#line 4247
allow sysadm_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
allow sysadm_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
allow sysadm_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
allow sysadm_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
allow sysadm_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
# Run programs developed by other users in the same domain.
#line 4247

#line 4247
allow sysadm_t sysadm_home_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
allow sysadm_t sysadm_tmp_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
# Run user programs that require different permissions in their own domain.
#line 4247
# These rules were moved into the individual program domains.
#line 4247

#line 4247
# Instantiate derived domains for a number of programs.
#line 4247
# These derived domains encode both information about the calling
#line 4247
# user domain and the program, and allow us to maintain separation
#line 4247
# between different instances of the program being run by different
#line 4247
# user domains.
#line 4247

#line 4247

#line 4247

#line 4247
# Derived domain based on the calling user domain and the program.
#line 4247
type sysadm_su_t, domain, privlog, auth;
#line 4247

#line 4247
# Transition from the user domain to this domain.
#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to transition to the new domain.
#line 4247
#
#line 4247
allow sysadm_t sysadm_su_t:process transition;
#line 4247

#line 4247
#
#line 4247
# Allow the process to execute the program.
#line 4247
# 
#line 4247
allow sysadm_t su_exec_t:file { getattr execute };
#line 4247

#line 4247
#
#line 4247
# Allow the process to reap the new domain.
#line 4247
#
#line 4247
allow sysadm_su_t sysadm_t:process sigchld;
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to inherit and use file 
#line 4247
# descriptions from the creating process and vice versa.
#line 4247
#
#line 4247
allow sysadm_su_t sysadm_t:fd use;
#line 4247
allow sysadm_t sysadm_su_t:fd use;
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to write back to the old domain via a pipe.
#line 4247
#
#line 4247
allow sysadm_su_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to read and execute the program.
#line 4247
#
#line 4247
allow sysadm_su_t su_exec_t:file { read getattr lock execute ioctl };
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to be entered via the program.
#line 4247
#
#line 4247
allow sysadm_su_t su_exec_t:file entrypoint;
#line 4247

#line 4247
type_transition sysadm_t su_exec_t:process sysadm_su_t;
#line 4247

#line 4247

#line 4247
# This domain is granted permissions common to most domains.
#line 4247

#line 4247

#line 4247
# Grant the permissions common to the test domains.
#line 4247

#line 4247
# Grant permissions within the domain.
#line 4247

#line 4247
# Access other processes in the same domain.
#line 4247
allow sysadm_su_t self:process *;
#line 4247

#line 4247
# Access /proc/PID files for processes in the same domain.
#line 4247
allow sysadm_su_t self:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Access file descriptions, pipes, and sockets
#line 4247
# created by processes in the same domain.
#line 4247
allow sysadm_su_t self:fd *;
#line 4247
allow sysadm_su_t self:fifo_file { ioctl read getattr lock write append };
#line 4247
allow sysadm_su_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247
allow sysadm_su_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4247

#line 4247
# Allow the domain to communicate with other processes in the same domain.
#line 4247
allow sysadm_su_t self:unix_dgram_socket sendto;
#line 4247
allow sysadm_su_t self:unix_stream_socket connectto;
#line 4247

#line 4247
# Access System V IPC objects created by processes in the same domain.
#line 4247
allow sysadm_su_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4247
allow sysadm_su_t self:msg  { send receive };
#line 4247
allow sysadm_su_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4247
allow sysadm_su_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4247

#line 4247

#line 4247

#line 4247
# Grant read/search permissions to most of /proc.
#line 4247

#line 4247
# Read system information files in /proc.
#line 4247
allow sysadm_su_t proc_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Stat /proc/kmsg and /proc/kcore.
#line 4247
allow sysadm_su_t proc_kmsg_t:file { getattr };
#line 4247
allow sysadm_su_t proc_kcore_t:file { getattr };
#line 4247

#line 4247
# Read system variables in /proc/sys.
#line 4247
allow sysadm_su_t sysctl_modprobe_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_su_t sysctl_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_su_t sysctl_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t sysctl_fs_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_su_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t sysctl_kernel_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_su_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t sysctl_net_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_su_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t sysctl_vm_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_su_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t sysctl_dev_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_su_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 4247

#line 4247

#line 4247
# Grant read/search permissions to many system file types.
#line 4247

#line 4247

#line 4247
# Get attributes of file systems.
#line 4247
allow sysadm_su_t fs_type:filesystem getattr;
#line 4247

#line 4247

#line 4247
# Read /.
#line 4247
allow sysadm_su_t root_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /home.
#line 4247
allow sysadm_su_t home_root_t:dir { read getattr lock search ioctl };
#line 4247

#line 4247
# Read /usr.
#line 4247
allow sysadm_su_t usr_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read bin and sbin directories.
#line 4247
allow sysadm_su_t bin_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247
allow sysadm_su_t sbin_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247

#line 4247
# Read directories and files with the readable_t type.
#line 4247
# This type is a general type for "world"-readable files.
#line 4247
allow sysadm_su_t readable_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Stat /...security and lost+found.
#line 4247
allow sysadm_su_t file_labels_t:dir getattr;
#line 4247
allow sysadm_su_t lost_found_t:dir getattr;
#line 4247

#line 4247
# Read the devpts root directory.  
#line 4247
allow sysadm_su_t devpts_t:dir { read getattr lock search ioctl };
#line 4247

#line 4247

#line 4247
# Read the /tmp directory and any /tmp files with the base type.
#line 4247
# Temporary files created at runtime will typically use derived types.
#line 4247
allow sysadm_su_t tmp_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t tmp_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var.
#line 4247
allow sysadm_su_t var_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/catman.
#line 4247
allow sysadm_su_t catman_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t catman_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/lib.
#line 4247
allow sysadm_su_t var_lib_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t var_lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247
allow sysadm_su_t var_lib_nfs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t var_lib_nfs_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247

#line 4247
allow sysadm_su_t tetex_data_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t tetex_data_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247

#line 4247
# Read /var/yp.
#line 4247
allow sysadm_su_t var_yp_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t var_yp_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/spool.
#line 4247
allow sysadm_su_t var_spool_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/run, /var/lock, /var/log.
#line 4247
allow sysadm_su_t var_run_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_su_t var_log_t:dir { read getattr lock search ioctl };
#line 4247
#allow sysadm_su_t var_log_t:{ file lnk_file } r_file_perms;
#line 4247
allow sysadm_su_t var_log_sa_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t var_log_sa_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_su_t var_log_ksyms_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
allow sysadm_su_t var_lock_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t var_lock_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/run/utmp and /var/log/wtmp.
#line 4247
allow sysadm_su_t initrc_var_run_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_su_t wtmp_t:file { read getattr lock ioctl };
#line 4247

#line 4247
# Read /boot, /boot/System.map*, and /vmlinuz*
#line 4247
allow sysadm_su_t boot_t:dir { search getattr };
#line 4247
allow sysadm_su_t boot_t:file getattr;
#line 4247
allow sysadm_su_t system_map_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
allow sysadm_su_t boot_t:lnk_file read;
#line 4247

#line 4247
# Read /etc.
#line 4247
allow sysadm_su_t etc_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247
allow sysadm_su_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_su_t etc_aliases_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_su_t etc_mail_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t etc_mail_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_su_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_su_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4247

#line 4247
# Read /lib.
#line 4247
allow sysadm_su_t lib_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read the linker, shared library, and executable types.
#line 4247
allow sysadm_su_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_su_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_su_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read man directories and files.
#line 4247
allow sysadm_su_t man_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t man_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /usr/src.
#line 4247
allow sysadm_su_t src_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t src_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read module-related files.
#line 4247
allow sysadm_su_t modules_object_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t modules_object_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_su_t modules_dep_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_su_t modules_conf_t:{ file lnk_file} { read getattr lock ioctl };
#line 4247

#line 4247
# Read /dev directories and any symbolic links.
#line 4247
allow sysadm_su_t device_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t device_t:lnk_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read /dev/random and /dev/zero.
#line 4247
allow sysadm_su_t random_device_t:chr_file { read getattr lock ioctl };
#line 4247
allow sysadm_su_t zero_device_t:chr_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read the root directory of a tmpfs filesytem and any symbolic links.
#line 4247
allow sysadm_su_t tmpfs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t tmpfs_t:lnk_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read any symbolic links on a devfs file system.
#line 4247
allow sysadm_su_t device_t:lnk_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read the root directory of a usbdevfs filesystem, and
#line 4247
# the devices and drivers files.  Permit stating of the
#line 4247
# device nodes, but nothing else.
#line 4247
allow sysadm_su_t usbdevfs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t usbdevfs_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_su_t usbdevfs_device_t:file getattr;
#line 4247

#line 4247

#line 4247
# Grant write permissions to a small set of system file types.
#line 4247
# No permission to create files is granted here.  Use allow rules to grant 
#line 4247
# create permissions to a type or use file_type_auto_trans rules to set up
#line 4247
# new types for files.
#line 4247

#line 4247

#line 4247
# Read and write /dev/tty and /dev/null.
#line 4247
allow sysadm_su_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4247
allow sysadm_su_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247
# Do not audit write denials to /etc/ld.so.cache.
#line 4247
dontaudit sysadm_su_t ld_so_cache_t:file write;
#line 4247

#line 4247

#line 4247
# Execute from the system shared libraries.
#line 4247
# No permission to execute anything else is granted here.
#line 4247
# Use can_exec or can_exec_any to grant the ability to execute within a domain.
#line 4247
# Use domain_auto_trans for executing and changing domains.
#line 4247

#line 4247
allow sysadm_su_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t ld_so_t:file { read getattr lock execute ioctl };
#line 4247
allow sysadm_su_t ld_so_t:file execute_no_trans;
#line 4247
allow sysadm_su_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4247
allow sysadm_su_t shlib_t:file { read getattr lock execute ioctl };
#line 4247
allow sysadm_su_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4247
allow sysadm_su_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_su_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247

#line 4247
# read localization information
#line 4247
allow sysadm_su_t locale_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_su_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 4247

#line 4247
# Obtain the context of any SID, the SID for any context, 
#line 4247
# and the list of active SIDs.
#line 4247
allow sysadm_su_t security_t:security { sid_to_context context_to_sid get_sids };
#line 4247

#line 4247

#line 4247

#line 4247
# Grant permissions needed to create TCP and UDP sockets and 
#line 4247
# to access the network.
#line 4247

#line 4247
#
#line 4247
# Allow the domain to create and use UDP and TCP sockets.
#line 4247
# Other kinds of sockets must be separately authorized for use.
#line 4247
allow sysadm_su_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247
allow sysadm_su_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send UDP packets.
#line 4247
# Since the destination sockets type is unknown, the generic
#line 4247
# any_socket_t type is used as a placeholder.
#line 4247
#
#line 4247
allow sysadm_su_t any_socket_t:udp_socket sendto;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send using any network interface.
#line 4247
# netif_type is a type attribute for all network interface types.
#line 4247
#
#line 4247
allow sysadm_su_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4247

#line 4247
#
#line 4247
# Allow packets sent by the domain to be received on any network interface.
#line 4247
#
#line 4247
allow sysadm_su_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to receive packets from any network interface.
#line 4247
# netmsg_type is a type attribute for all default message types.
#line 4247
#
#line 4247
allow sysadm_su_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to initiate or accept TCP connections 
#line 4247
# on any network interface.
#line 4247
#
#line 4247
allow sysadm_su_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4247

#line 4247
#
#line 4247
# Receive resets from the TCP reset socket.
#line 4247
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4247
#
#line 4247
allow sysadm_su_t tcp_socket_t:tcp_socket recvfrom;
#line 4247

#line 4247
dontaudit sysadm_su_t tcp_socket_t:tcp_socket connectto;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send to any node.
#line 4247
# node_type is a type attribute for all node types.
#line 4247
#
#line 4247
allow sysadm_su_t node_type:node { tcp_send udp_send rawip_send };
#line 4247

#line 4247
#
#line 4247
# Allow packets sent by the domain to be received from any node.
#line 4247
#
#line 4247
allow sysadm_su_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send NFS client requests via the socket
#line 4247
# created by mount.
#line 4247
#
#line 4247
allow sysadm_su_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247

#line 4247
#
#line 4247
# Bind to the default port type.
#line 4247
# Other port types must be separately authorized.
#line 4247
#
#line 4247
allow sysadm_su_t port_t:udp_socket name_bind;
#line 4247
allow sysadm_su_t port_t:tcp_socket name_bind;
#line 4247

#line 4247

#line 4247

#line 4247
# Use capabilities.
#line 4247
allow sysadm_su_t self:capability { setuid setgid net_bind_service chown dac_override sys_nice sys_resource };
#line 4247

#line 4247
# Revert to the user domain when a shell is executed.
#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to transition to the new domain.
#line 4247
#
#line 4247
allow sysadm_su_t sysadm_t:process transition;
#line 4247

#line 4247
#
#line 4247
# Allow the process to execute the program.
#line 4247
# 
#line 4247
allow sysadm_su_t shell_exec_t:file { getattr execute };
#line 4247

#line 4247
#
#line 4247
# Allow the process to reap the new domain.
#line 4247
#
#line 4247
allow sysadm_t sysadm_su_t:process sigchld;
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to inherit and use file 
#line 4247
# descriptions from the creating process and vice versa.
#line 4247
#
#line 4247
allow sysadm_t sysadm_su_t:fd use;
#line 4247
allow sysadm_su_t sysadm_t:fd use;
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to write back to the old domain via a pipe.
#line 4247
#
#line 4247
allow sysadm_t sysadm_su_t:fifo_file { ioctl read getattr lock write append };
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to read and execute the program.
#line 4247
#
#line 4247
allow sysadm_t shell_exec_t:file { read getattr lock execute ioctl };
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to be entered via the program.
#line 4247
#
#line 4247
allow sysadm_t shell_exec_t:file entrypoint;
#line 4247

#line 4247
type_transition sysadm_su_t shell_exec_t:process sysadm_t;
#line 4247

#line 4247

#line 4247
allow sysadm_su_t privfd:fd use;
#line 4247

#line 4247
# Write to utmp.
#line 4247
allow sysadm_su_t initrc_var_run_t:file { ioctl read getattr lock write append };
#line 4247

#line 4247

#line 4247

#line 4247
# Run chkpwd.
#line 4247

#line 4247
allow sysadm_su_t chkpwd_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247

#line 4247
# Inherit and use descriptors from gnome-pty-helper.
#line 4247

#line 4247

#line 4247
# The user role is authorized for this domain.
#line 4247
role sysadm_r types sysadm_su_t;
#line 4247

#line 4247
# Write to the user domain tty.
#line 4247
allow sysadm_su_t sysadm_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4247
allow sysadm_su_t sysadm_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247
allow sysadm_su_t sysadm_home_dir_t:dir search;
#line 4247

#line 4247
# Modify .Xauthority file (via xauth program).
#line 4247

#line 4247

#line 4247
# Access sshd cookie files.
#line 4247
allow sysadm_su_t sshd_tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4247
allow sysadm_su_t sshd_tmp_t:file { ioctl read getattr lock write append };
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to modify the directory.
#line 4247
#
#line 4247
allow sysadm_su_t sshd_tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4247

#line 4247
#
#line 4247
# Allow the process to create the file.
#line 4247
#
#line 4247

#line 4247
allow sysadm_su_t sysadm_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4247
allow sysadm_su_t sysadm_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4247

#line 4247

#line 4247

#line 4247
type_transition sysadm_su_t sshd_tmp_t:dir sysadm_tmp_t;
#line 4247
type_transition sysadm_su_t sshd_tmp_t:{ file lnk_file sock_file fifo_file } sysadm_tmp_t;
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
# stop su complaining if you run it from a directory with restrictive perms
#line 4247
dontaudit sysadm_su_t file_type:dir search;
#line 4247

#line 4247

#line 4247
# Derived domain based on the calling user domain and the program.
#line 4247
type sysadm_chkpwd_t, domain, privlog, auth;
#line 4247

#line 4247
# Transition from the user domain to this domain.
#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to transition to the new domain.
#line 4247
#
#line 4247
allow sysadm_t sysadm_chkpwd_t:process transition;
#line 4247

#line 4247
#
#line 4247
# Allow the process to execute the program.
#line 4247
# 
#line 4247
allow sysadm_t chkpwd_exec_t:file { getattr execute };
#line 4247

#line 4247
#
#line 4247
# Allow the process to reap the new domain.
#line 4247
#
#line 4247
allow sysadm_chkpwd_t sysadm_t:process sigchld;
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to inherit and use file 
#line 4247
# descriptions from the creating process and vice versa.
#line 4247
#
#line 4247
allow sysadm_chkpwd_t sysadm_t:fd use;
#line 4247
allow sysadm_t sysadm_chkpwd_t:fd use;
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to write back to the old domain via a pipe.
#line 4247
#
#line 4247
allow sysadm_chkpwd_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to read and execute the program.
#line 4247
#
#line 4247
allow sysadm_chkpwd_t chkpwd_exec_t:file { read getattr lock execute ioctl };
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to be entered via the program.
#line 4247
#
#line 4247
allow sysadm_chkpwd_t chkpwd_exec_t:file entrypoint;
#line 4247

#line 4247
type_transition sysadm_t chkpwd_exec_t:process sysadm_chkpwd_t;
#line 4247

#line 4247

#line 4247
# The user role is authorized for this domain.
#line 4247
role sysadm_r types sysadm_chkpwd_t;
#line 4247

#line 4247
# This domain is granted permissions common to most domains (includes can_net)
#line 4247

#line 4247

#line 4247
# Grant the permissions common to the test domains.
#line 4247

#line 4247
# Grant permissions within the domain.
#line 4247

#line 4247
# Access other processes in the same domain.
#line 4247
allow sysadm_chkpwd_t self:process *;
#line 4247

#line 4247
# Access /proc/PID files for processes in the same domain.
#line 4247
allow sysadm_chkpwd_t self:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Access file descriptions, pipes, and sockets
#line 4247
# created by processes in the same domain.
#line 4247
allow sysadm_chkpwd_t self:fd *;
#line 4247
allow sysadm_chkpwd_t self:fifo_file { ioctl read getattr lock write append };
#line 4247
allow sysadm_chkpwd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247
allow sysadm_chkpwd_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4247

#line 4247
# Allow the domain to communicate with other processes in the same domain.
#line 4247
allow sysadm_chkpwd_t self:unix_dgram_socket sendto;
#line 4247
allow sysadm_chkpwd_t self:unix_stream_socket connectto;
#line 4247

#line 4247
# Access System V IPC objects created by processes in the same domain.
#line 4247
allow sysadm_chkpwd_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4247
allow sysadm_chkpwd_t self:msg  { send receive };
#line 4247
allow sysadm_chkpwd_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4247
allow sysadm_chkpwd_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4247

#line 4247

#line 4247

#line 4247
# Grant read/search permissions to most of /proc.
#line 4247

#line 4247
# Read system information files in /proc.
#line 4247
allow sysadm_chkpwd_t proc_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Stat /proc/kmsg and /proc/kcore.
#line 4247
allow sysadm_chkpwd_t proc_kmsg_t:file { getattr };
#line 4247
allow sysadm_chkpwd_t proc_kcore_t:file { getattr };
#line 4247

#line 4247
# Read system variables in /proc/sys.
#line 4247
allow sysadm_chkpwd_t sysctl_modprobe_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t sysctl_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t sysctl_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t sysctl_fs_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t sysctl_kernel_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t sysctl_net_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t sysctl_vm_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t sysctl_dev_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 4247

#line 4247

#line 4247
# Grant read/search permissions to many system file types.
#line 4247

#line 4247

#line 4247
# Get attributes of file systems.
#line 4247
allow sysadm_chkpwd_t fs_type:filesystem getattr;
#line 4247

#line 4247

#line 4247
# Read /.
#line 4247
allow sysadm_chkpwd_t root_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /home.
#line 4247
allow sysadm_chkpwd_t home_root_t:dir { read getattr lock search ioctl };
#line 4247

#line 4247
# Read /usr.
#line 4247
allow sysadm_chkpwd_t usr_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read bin and sbin directories.
#line 4247
allow sysadm_chkpwd_t bin_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t sbin_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247

#line 4247
# Read directories and files with the readable_t type.
#line 4247
# This type is a general type for "world"-readable files.
#line 4247
allow sysadm_chkpwd_t readable_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Stat /...security and lost+found.
#line 4247
allow sysadm_chkpwd_t file_labels_t:dir getattr;
#line 4247
allow sysadm_chkpwd_t lost_found_t:dir getattr;
#line 4247

#line 4247
# Read the devpts root directory.  
#line 4247
allow sysadm_chkpwd_t devpts_t:dir { read getattr lock search ioctl };
#line 4247

#line 4247

#line 4247
# Read the /tmp directory and any /tmp files with the base type.
#line 4247
# Temporary files created at runtime will typically use derived types.
#line 4247
allow sysadm_chkpwd_t tmp_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t tmp_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var.
#line 4247
allow sysadm_chkpwd_t var_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/catman.
#line 4247
allow sysadm_chkpwd_t catman_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t catman_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/lib.
#line 4247
allow sysadm_chkpwd_t var_lib_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t var_lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t var_lib_nfs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t var_lib_nfs_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247

#line 4247
allow sysadm_chkpwd_t tetex_data_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t tetex_data_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247

#line 4247
# Read /var/yp.
#line 4247
allow sysadm_chkpwd_t var_yp_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t var_yp_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/spool.
#line 4247
allow sysadm_chkpwd_t var_spool_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/run, /var/lock, /var/log.
#line 4247
allow sysadm_chkpwd_t var_run_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t var_log_t:dir { read getattr lock search ioctl };
#line 4247
#allow sysadm_chkpwd_t var_log_t:{ file lnk_file } r_file_perms;
#line 4247
allow sysadm_chkpwd_t var_log_sa_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t var_log_sa_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t var_log_ksyms_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
allow sysadm_chkpwd_t var_lock_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t var_lock_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/run/utmp and /var/log/wtmp.
#line 4247
allow sysadm_chkpwd_t initrc_var_run_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t wtmp_t:file { read getattr lock ioctl };
#line 4247

#line 4247
# Read /boot, /boot/System.map*, and /vmlinuz*
#line 4247
allow sysadm_chkpwd_t boot_t:dir { search getattr };
#line 4247
allow sysadm_chkpwd_t boot_t:file getattr;
#line 4247
allow sysadm_chkpwd_t system_map_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
allow sysadm_chkpwd_t boot_t:lnk_file read;
#line 4247

#line 4247
# Read /etc.
#line 4247
allow sysadm_chkpwd_t etc_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t etc_aliases_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t etc_mail_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t etc_mail_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4247

#line 4247
# Read /lib.
#line 4247
allow sysadm_chkpwd_t lib_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read the linker, shared library, and executable types.
#line 4247
allow sysadm_chkpwd_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read man directories and files.
#line 4247
allow sysadm_chkpwd_t man_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t man_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /usr/src.
#line 4247
allow sysadm_chkpwd_t src_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t src_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read module-related files.
#line 4247
allow sysadm_chkpwd_t modules_object_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t modules_object_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t modules_dep_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t modules_conf_t:{ file lnk_file} { read getattr lock ioctl };
#line 4247

#line 4247
# Read /dev directories and any symbolic links.
#line 4247
allow sysadm_chkpwd_t device_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t device_t:lnk_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read /dev/random and /dev/zero.
#line 4247
allow sysadm_chkpwd_t random_device_t:chr_file { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t zero_device_t:chr_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read the root directory of a tmpfs filesytem and any symbolic links.
#line 4247
allow sysadm_chkpwd_t tmpfs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t tmpfs_t:lnk_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read any symbolic links on a devfs file system.
#line 4247
allow sysadm_chkpwd_t device_t:lnk_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read the root directory of a usbdevfs filesystem, and
#line 4247
# the devices and drivers files.  Permit stating of the
#line 4247
# device nodes, but nothing else.
#line 4247
allow sysadm_chkpwd_t usbdevfs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t usbdevfs_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t usbdevfs_device_t:file getattr;
#line 4247

#line 4247

#line 4247
# Grant write permissions to a small set of system file types.
#line 4247
# No permission to create files is granted here.  Use allow rules to grant 
#line 4247
# create permissions to a type or use file_type_auto_trans rules to set up
#line 4247
# new types for files.
#line 4247

#line 4247

#line 4247
# Read and write /dev/tty and /dev/null.
#line 4247
allow sysadm_chkpwd_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4247
allow sysadm_chkpwd_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247
# Do not audit write denials to /etc/ld.so.cache.
#line 4247
dontaudit sysadm_chkpwd_t ld_so_cache_t:file write;
#line 4247

#line 4247

#line 4247
# Execute from the system shared libraries.
#line 4247
# No permission to execute anything else is granted here.
#line 4247
# Use can_exec or can_exec_any to grant the ability to execute within a domain.
#line 4247
# Use domain_auto_trans for executing and changing domains.
#line 4247

#line 4247
allow sysadm_chkpwd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t ld_so_t:file { read getattr lock execute ioctl };
#line 4247
allow sysadm_chkpwd_t ld_so_t:file execute_no_trans;
#line 4247
allow sysadm_chkpwd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t shlib_t:file { read getattr lock execute ioctl };
#line 4247
allow sysadm_chkpwd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_chkpwd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247

#line 4247
# read localization information
#line 4247
allow sysadm_chkpwd_t locale_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_chkpwd_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 4247

#line 4247
# Obtain the context of any SID, the SID for any context, 
#line 4247
# and the list of active SIDs.
#line 4247
allow sysadm_chkpwd_t security_t:security { sid_to_context context_to_sid get_sids };
#line 4247

#line 4247

#line 4247

#line 4247
# Grant permissions needed to create TCP and UDP sockets and 
#line 4247
# to access the network.
#line 4247

#line 4247
#
#line 4247
# Allow the domain to create and use UDP and TCP sockets.
#line 4247
# Other kinds of sockets must be separately authorized for use.
#line 4247
allow sysadm_chkpwd_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247
allow sysadm_chkpwd_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send UDP packets.
#line 4247
# Since the destination sockets type is unknown, the generic
#line 4247
# any_socket_t type is used as a placeholder.
#line 4247
#
#line 4247
allow sysadm_chkpwd_t any_socket_t:udp_socket sendto;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send using any network interface.
#line 4247
# netif_type is a type attribute for all network interface types.
#line 4247
#
#line 4247
allow sysadm_chkpwd_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4247

#line 4247
#
#line 4247
# Allow packets sent by the domain to be received on any network interface.
#line 4247
#
#line 4247
allow sysadm_chkpwd_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to receive packets from any network interface.
#line 4247
# netmsg_type is a type attribute for all default message types.
#line 4247
#
#line 4247
allow sysadm_chkpwd_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to initiate or accept TCP connections 
#line 4247
# on any network interface.
#line 4247
#
#line 4247
allow sysadm_chkpwd_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4247

#line 4247
#
#line 4247
# Receive resets from the TCP reset socket.
#line 4247
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4247
#
#line 4247
allow sysadm_chkpwd_t tcp_socket_t:tcp_socket recvfrom;
#line 4247

#line 4247
dontaudit sysadm_chkpwd_t tcp_socket_t:tcp_socket connectto;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send to any node.
#line 4247
# node_type is a type attribute for all node types.
#line 4247
#
#line 4247
allow sysadm_chkpwd_t node_type:node { tcp_send udp_send rawip_send };
#line 4247

#line 4247
#
#line 4247
# Allow packets sent by the domain to be received from any node.
#line 4247
#
#line 4247
allow sysadm_chkpwd_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send NFS client requests via the socket
#line 4247
# created by mount.
#line 4247
#
#line 4247
allow sysadm_chkpwd_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247

#line 4247
#
#line 4247
# Bind to the default port type.
#line 4247
# Other port types must be separately authorized.
#line 4247
#
#line 4247
allow sysadm_chkpwd_t port_t:udp_socket name_bind;
#line 4247
allow sysadm_chkpwd_t port_t:tcp_socket name_bind;
#line 4247

#line 4247

#line 4247

#line 4247
# Use capabilities.
#line 4247
allow sysadm_chkpwd_t self:capability setuid;
#line 4247

#line 4247
# Inherit and use descriptors from gnome-pty-helper.
#line 4247

#line 4247

#line 4247
# Inherit and use descriptors from newrole.
#line 4247
allow sysadm_chkpwd_t newrole_t:fd use;
#line 4247

#line 4247
# Write to the user domain tty.
#line 4247
allow sysadm_chkpwd_t sysadm_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4247
allow sysadm_chkpwd_t sysadm_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
# Derived domain based on the calling user domain and the program.
#line 4247
type sysadm_crontab_t, domain, privlog;
#line 4247

#line 4247
# Transition from the user domain to the derived domain.
#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to transition to the new domain.
#line 4247
#
#line 4247
allow sysadm_t sysadm_crontab_t:process transition;
#line 4247

#line 4247
#
#line 4247
# Allow the process to execute the program.
#line 4247
# 
#line 4247
allow sysadm_t crontab_exec_t:file { getattr execute };
#line 4247

#line 4247
#
#line 4247
# Allow the process to reap the new domain.
#line 4247
#
#line 4247
allow sysadm_crontab_t sysadm_t:process sigchld;
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to inherit and use file 
#line 4247
# descriptions from the creating process and vice versa.
#line 4247
#
#line 4247
allow sysadm_crontab_t sysadm_t:fd use;
#line 4247
allow sysadm_t sysadm_crontab_t:fd use;
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to write back to the old domain via a pipe.
#line 4247
#
#line 4247
allow sysadm_crontab_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to read and execute the program.
#line 4247
#
#line 4247
allow sysadm_crontab_t crontab_exec_t:file { read getattr lock execute ioctl };
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to be entered via the program.
#line 4247
#
#line 4247
allow sysadm_crontab_t crontab_exec_t:file entrypoint;
#line 4247

#line 4247
type_transition sysadm_t crontab_exec_t:process sysadm_crontab_t;
#line 4247

#line 4247

#line 4247
# The user role is authorized for this domain.
#line 4247
role sysadm_r types sysadm_crontab_t;
#line 4247

#line 4247
# This domain is granted permissions common to most domains (including can_net)
#line 4247

#line 4247

#line 4247
# Grant the permissions common to the test domains.
#line 4247

#line 4247
# Grant permissions within the domain.
#line 4247

#line 4247
# Access other processes in the same domain.
#line 4247
allow sysadm_crontab_t self:process *;
#line 4247

#line 4247
# Access /proc/PID files for processes in the same domain.
#line 4247
allow sysadm_crontab_t self:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Access file descriptions, pipes, and sockets
#line 4247
# created by processes in the same domain.
#line 4247
allow sysadm_crontab_t self:fd *;
#line 4247
allow sysadm_crontab_t self:fifo_file { ioctl read getattr lock write append };
#line 4247
allow sysadm_crontab_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247
allow sysadm_crontab_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4247

#line 4247
# Allow the domain to communicate with other processes in the same domain.
#line 4247
allow sysadm_crontab_t self:unix_dgram_socket sendto;
#line 4247
allow sysadm_crontab_t self:unix_stream_socket connectto;
#line 4247

#line 4247
# Access System V IPC objects created by processes in the same domain.
#line 4247
allow sysadm_crontab_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4247
allow sysadm_crontab_t self:msg  { send receive };
#line 4247
allow sysadm_crontab_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4247
allow sysadm_crontab_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4247

#line 4247

#line 4247

#line 4247
# Grant read/search permissions to most of /proc.
#line 4247

#line 4247
# Read system information files in /proc.
#line 4247
allow sysadm_crontab_t proc_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Stat /proc/kmsg and /proc/kcore.
#line 4247
allow sysadm_crontab_t proc_kmsg_t:file { getattr };
#line 4247
allow sysadm_crontab_t proc_kcore_t:file { getattr };
#line 4247

#line 4247
# Read system variables in /proc/sys.
#line 4247
allow sysadm_crontab_t sysctl_modprobe_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t sysctl_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t sysctl_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t sysctl_fs_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t sysctl_kernel_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t sysctl_net_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t sysctl_vm_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t sysctl_dev_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 4247

#line 4247

#line 4247
# Grant read/search permissions to many system file types.
#line 4247

#line 4247

#line 4247
# Get attributes of file systems.
#line 4247
allow sysadm_crontab_t fs_type:filesystem getattr;
#line 4247

#line 4247

#line 4247
# Read /.
#line 4247
allow sysadm_crontab_t root_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /home.
#line 4247
allow sysadm_crontab_t home_root_t:dir { read getattr lock search ioctl };
#line 4247

#line 4247
# Read /usr.
#line 4247
allow sysadm_crontab_t usr_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read bin and sbin directories.
#line 4247
allow sysadm_crontab_t bin_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t sbin_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247

#line 4247
# Read directories and files with the readable_t type.
#line 4247
# This type is a general type for "world"-readable files.
#line 4247
allow sysadm_crontab_t readable_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Stat /...security and lost+found.
#line 4247
allow sysadm_crontab_t file_labels_t:dir getattr;
#line 4247
allow sysadm_crontab_t lost_found_t:dir getattr;
#line 4247

#line 4247
# Read the devpts root directory.  
#line 4247
allow sysadm_crontab_t devpts_t:dir { read getattr lock search ioctl };
#line 4247

#line 4247

#line 4247
# Read the /tmp directory and any /tmp files with the base type.
#line 4247
# Temporary files created at runtime will typically use derived types.
#line 4247
allow sysadm_crontab_t tmp_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t tmp_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var.
#line 4247
allow sysadm_crontab_t var_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/catman.
#line 4247
allow sysadm_crontab_t catman_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t catman_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/lib.
#line 4247
allow sysadm_crontab_t var_lib_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t var_lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t var_lib_nfs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t var_lib_nfs_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247

#line 4247
allow sysadm_crontab_t tetex_data_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t tetex_data_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247

#line 4247
# Read /var/yp.
#line 4247
allow sysadm_crontab_t var_yp_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t var_yp_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/spool.
#line 4247
allow sysadm_crontab_t var_spool_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/run, /var/lock, /var/log.
#line 4247
allow sysadm_crontab_t var_run_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t var_log_t:dir { read getattr lock search ioctl };
#line 4247
#allow sysadm_crontab_t var_log_t:{ file lnk_file } r_file_perms;
#line 4247
allow sysadm_crontab_t var_log_sa_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t var_log_sa_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t var_log_ksyms_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
allow sysadm_crontab_t var_lock_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t var_lock_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/run/utmp and /var/log/wtmp.
#line 4247
allow sysadm_crontab_t initrc_var_run_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t wtmp_t:file { read getattr lock ioctl };
#line 4247

#line 4247
# Read /boot, /boot/System.map*, and /vmlinuz*
#line 4247
allow sysadm_crontab_t boot_t:dir { search getattr };
#line 4247
allow sysadm_crontab_t boot_t:file getattr;
#line 4247
allow sysadm_crontab_t system_map_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
allow sysadm_crontab_t boot_t:lnk_file read;
#line 4247

#line 4247
# Read /etc.
#line 4247
allow sysadm_crontab_t etc_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t etc_aliases_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t etc_mail_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t etc_mail_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4247

#line 4247
# Read /lib.
#line 4247
allow sysadm_crontab_t lib_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read the linker, shared library, and executable types.
#line 4247
allow sysadm_crontab_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read man directories and files.
#line 4247
allow sysadm_crontab_t man_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t man_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /usr/src.
#line 4247
allow sysadm_crontab_t src_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t src_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read module-related files.
#line 4247
allow sysadm_crontab_t modules_object_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t modules_object_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t modules_dep_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t modules_conf_t:{ file lnk_file} { read getattr lock ioctl };
#line 4247

#line 4247
# Read /dev directories and any symbolic links.
#line 4247
allow sysadm_crontab_t device_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t device_t:lnk_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read /dev/random and /dev/zero.
#line 4247
allow sysadm_crontab_t random_device_t:chr_file { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t zero_device_t:chr_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read the root directory of a tmpfs filesytem and any symbolic links.
#line 4247
allow sysadm_crontab_t tmpfs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t tmpfs_t:lnk_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read any symbolic links on a devfs file system.
#line 4247
allow sysadm_crontab_t device_t:lnk_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read the root directory of a usbdevfs filesystem, and
#line 4247
# the devices and drivers files.  Permit stating of the
#line 4247
# device nodes, but nothing else.
#line 4247
allow sysadm_crontab_t usbdevfs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t usbdevfs_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t usbdevfs_device_t:file getattr;
#line 4247

#line 4247

#line 4247
# Grant write permissions to a small set of system file types.
#line 4247
# No permission to create files is granted here.  Use allow rules to grant 
#line 4247
# create permissions to a type or use file_type_auto_trans rules to set up
#line 4247
# new types for files.
#line 4247

#line 4247

#line 4247
# Read and write /dev/tty and /dev/null.
#line 4247
allow sysadm_crontab_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4247
allow sysadm_crontab_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247
# Do not audit write denials to /etc/ld.so.cache.
#line 4247
dontaudit sysadm_crontab_t ld_so_cache_t:file write;
#line 4247

#line 4247

#line 4247
# Execute from the system shared libraries.
#line 4247
# No permission to execute anything else is granted here.
#line 4247
# Use can_exec or can_exec_any to grant the ability to execute within a domain.
#line 4247
# Use domain_auto_trans for executing and changing domains.
#line 4247

#line 4247
allow sysadm_crontab_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t ld_so_t:file { read getattr lock execute ioctl };
#line 4247
allow sysadm_crontab_t ld_so_t:file execute_no_trans;
#line 4247
allow sysadm_crontab_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t shlib_t:file { read getattr lock execute ioctl };
#line 4247
allow sysadm_crontab_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247

#line 4247
# read localization information
#line 4247
allow sysadm_crontab_t locale_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crontab_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 4247

#line 4247
# Obtain the context of any SID, the SID for any context, 
#line 4247
# and the list of active SIDs.
#line 4247
allow sysadm_crontab_t security_t:security { sid_to_context context_to_sid get_sids };
#line 4247

#line 4247

#line 4247

#line 4247
# Grant permissions needed to create TCP and UDP sockets and 
#line 4247
# to access the network.
#line 4247

#line 4247
#
#line 4247
# Allow the domain to create and use UDP and TCP sockets.
#line 4247
# Other kinds of sockets must be separately authorized for use.
#line 4247
allow sysadm_crontab_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247
allow sysadm_crontab_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send UDP packets.
#line 4247
# Since the destination sockets type is unknown, the generic
#line 4247
# any_socket_t type is used as a placeholder.
#line 4247
#
#line 4247
allow sysadm_crontab_t any_socket_t:udp_socket sendto;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send using any network interface.
#line 4247
# netif_type is a type attribute for all network interface types.
#line 4247
#
#line 4247
allow sysadm_crontab_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4247

#line 4247
#
#line 4247
# Allow packets sent by the domain to be received on any network interface.
#line 4247
#
#line 4247
allow sysadm_crontab_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to receive packets from any network interface.
#line 4247
# netmsg_type is a type attribute for all default message types.
#line 4247
#
#line 4247
allow sysadm_crontab_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to initiate or accept TCP connections 
#line 4247
# on any network interface.
#line 4247
#
#line 4247
allow sysadm_crontab_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4247

#line 4247
#
#line 4247
# Receive resets from the TCP reset socket.
#line 4247
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4247
#
#line 4247
allow sysadm_crontab_t tcp_socket_t:tcp_socket recvfrom;
#line 4247

#line 4247
dontaudit sysadm_crontab_t tcp_socket_t:tcp_socket connectto;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send to any node.
#line 4247
# node_type is a type attribute for all node types.
#line 4247
#
#line 4247
allow sysadm_crontab_t node_type:node { tcp_send udp_send rawip_send };
#line 4247

#line 4247
#
#line 4247
# Allow packets sent by the domain to be received from any node.
#line 4247
#
#line 4247
allow sysadm_crontab_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send NFS client requests via the socket
#line 4247
# created by mount.
#line 4247
#
#line 4247
allow sysadm_crontab_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247

#line 4247
#
#line 4247
# Bind to the default port type.
#line 4247
# Other port types must be separately authorized.
#line 4247
#
#line 4247
allow sysadm_crontab_t port_t:udp_socket name_bind;
#line 4247
allow sysadm_crontab_t port_t:tcp_socket name_bind;
#line 4247

#line 4247

#line 4247

#line 4247
# Use capabilities
#line 4247
allow sysadm_crontab_t sysadm_crontab_t:capability { setuid setgid chown };
#line 4247

#line 4247
# Type for temporary files.
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to modify the directory.
#line 4247
#
#line 4247
allow sysadm_crontab_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4247

#line 4247
#
#line 4247
# Allow the process to create the file.
#line 4247
#
#line 4247

#line 4247
allow sysadm_crontab_t sysadm_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4247
allow sysadm_crontab_t sysadm_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4247

#line 4247

#line 4247

#line 4247
type_transition sysadm_crontab_t tmp_t:dir sysadm_tmp_t;
#line 4247
type_transition sysadm_crontab_t tmp_t:{ file lnk_file sock_file fifo_file } sysadm_tmp_t;
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
# Type of user crontabs once moved to cron spool.
#line 4247
type sysadm_cron_spool_t, file_type, sysadmfile;
#line 4247
# Use the type when creating files in /var/spool/cron.
#line 4247
allow sysadm_crontab_t sysadm_cron_spool_t:file { getattr read };
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to modify the directory.
#line 4247
#
#line 4247
allow sysadm_crontab_t cron_spool_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4247

#line 4247
#
#line 4247
# Allow the process to create the file.
#line 4247
#
#line 4247

#line 4247
allow sysadm_crontab_t sysadm_cron_spool_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4247
allow sysadm_crontab_t sysadm_cron_spool_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4247

#line 4247

#line 4247

#line 4247
type_transition sysadm_crontab_t cron_spool_t:dir sysadm_cron_spool_t;
#line 4247
type_transition sysadm_crontab_t cron_spool_t:{ file lnk_file sock_file fifo_file } sysadm_cron_spool_t;
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
# crontab signals crond by updating the mtime on the spooldir
#line 4247
allow sysadm_crontab_t cron_spool_t:dir setattr;
#line 4247
# Allow crond to read those crontabs in cron spool.
#line 4247
allow crond_t sysadm_cron_spool_t:file { read getattr lock ioctl };
#line 4247

#line 4247
# Run helper programs as sysadm_t
#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to transition to the new domain.
#line 4247
#
#line 4247
allow sysadm_crontab_t sysadm_t:process transition;
#line 4247

#line 4247
#
#line 4247
# Allow the process to execute the program.
#line 4247
# 
#line 4247
allow sysadm_crontab_t { bin_t sbin_t exec_type }:file { getattr execute };
#line 4247

#line 4247
#
#line 4247
# Allow the process to reap the new domain.
#line 4247
#
#line 4247
allow sysadm_t sysadm_crontab_t:process sigchld;
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to inherit and use file 
#line 4247
# descriptions from the creating process and vice versa.
#line 4247
#
#line 4247
allow sysadm_t sysadm_crontab_t:fd use;
#line 4247
allow sysadm_crontab_t sysadm_t:fd use;
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to write back to the old domain via a pipe.
#line 4247
#
#line 4247
allow sysadm_t sysadm_crontab_t:fifo_file { ioctl read getattr lock write append };
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to read and execute the program.
#line 4247
#
#line 4247
allow sysadm_t { bin_t sbin_t exec_type }:file { read getattr lock execute ioctl };
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to be entered via the program.
#line 4247
#
#line 4247
allow sysadm_t { bin_t sbin_t exec_type }:file entrypoint;
#line 4247

#line 4247
type_transition sysadm_crontab_t { bin_t sbin_t exec_type }:process sysadm_t;
#line 4247

#line 4247

#line 4247
# Read user crontabs 
#line 4247
allow sysadm_crontab_t { sysadm_home_t sysadm_home_dir_t }:dir { read getattr lock search ioctl };  
#line 4247
allow sysadm_crontab_t sysadm_home_t:file { read getattr lock ioctl };  
#line 4247
dontaudit sysadm_crontab_t sysadm_home_dir_t:dir write;
#line 4247

#line 4247
# Access the cron log file.
#line 4247
allow sysadm_crontab_t cron_log_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crontab_t cron_log_t:file { append };
#line 4247

#line 4247
# Access terminals.
#line 4247
allow sysadm_crontab_t sysadm_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4247
allow sysadm_crontab_t sysadm_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247
# Inherit and use descriptors from gnome-pty-helper.
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
# Derived domain based on the calling user domain and the program.
#line 4247
type sysadm_ssh_t, domain, privlog;
#line 4247

#line 4247
# Transition from the user domain to the derived domain.
#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to transition to the new domain.
#line 4247
#
#line 4247
allow sysadm_t sysadm_ssh_t:process transition;
#line 4247

#line 4247
#
#line 4247
# Allow the process to execute the program.
#line 4247
# 
#line 4247
allow sysadm_t ssh_exec_t:file { getattr execute };
#line 4247

#line 4247
#
#line 4247
# Allow the process to reap the new domain.
#line 4247
#
#line 4247
allow sysadm_ssh_t sysadm_t:process sigchld;
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to inherit and use file 
#line 4247
# descriptions from the creating process and vice versa.
#line 4247
#
#line 4247
allow sysadm_ssh_t sysadm_t:fd use;
#line 4247
allow sysadm_t sysadm_ssh_t:fd use;
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to write back to the old domain via a pipe.
#line 4247
#
#line 4247
allow sysadm_ssh_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to read and execute the program.
#line 4247
#
#line 4247
allow sysadm_ssh_t ssh_exec_t:file { read getattr lock execute ioctl };
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to be entered via the program.
#line 4247
#
#line 4247
allow sysadm_ssh_t ssh_exec_t:file entrypoint;
#line 4247

#line 4247
type_transition sysadm_t ssh_exec_t:process sysadm_ssh_t;
#line 4247

#line 4247

#line 4247
# The user role is authorized for this domain.
#line 4247
role sysadm_r types sysadm_ssh_t;
#line 4247

#line 4247
# Grant permissions within the domain.
#line 4247

#line 4247
# Access other processes in the same domain.
#line 4247
allow sysadm_ssh_t self:process *;
#line 4247

#line 4247
# Access /proc/PID files for processes in the same domain.
#line 4247
allow sysadm_ssh_t self:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_ssh_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Access file descriptions, pipes, and sockets
#line 4247
# created by processes in the same domain.
#line 4247
allow sysadm_ssh_t self:fd *;
#line 4247
allow sysadm_ssh_t self:fifo_file { ioctl read getattr lock write append };
#line 4247
allow sysadm_ssh_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247
allow sysadm_ssh_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4247

#line 4247
# Allow the domain to communicate with other processes in the same domain.
#line 4247
allow sysadm_ssh_t self:unix_dgram_socket sendto;
#line 4247
allow sysadm_ssh_t self:unix_stream_socket connectto;
#line 4247

#line 4247
# Access System V IPC objects created by processes in the same domain.
#line 4247
allow sysadm_ssh_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4247
allow sysadm_ssh_t self:msg  { send receive };
#line 4247
allow sysadm_ssh_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4247
allow sysadm_ssh_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4247

#line 4247

#line 4247

#line 4247
# Use descriptors created by sshd
#line 4247
allow sysadm_ssh_t privfd:fd use;
#line 4247

#line 4247

#line 4247
allow sysadm_ssh_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_ssh_t ld_so_t:file { read getattr lock execute ioctl };
#line 4247
allow sysadm_ssh_t ld_so_t:file execute_no_trans;
#line 4247
allow sysadm_ssh_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4247
allow sysadm_ssh_t shlib_t:file { read getattr lock execute ioctl };
#line 4247
allow sysadm_ssh_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4247
allow sysadm_ssh_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_ssh_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247

#line 4247
# read localization information
#line 4247
allow sysadm_ssh_t locale_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_ssh_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 4247

#line 4247
# Get attributes of file systems.
#line 4247
allow sysadm_ssh_t fs_type:filesystem getattr;
#line 4247

#line 4247

#line 4247
# Read /.
#line 4247
allow sysadm_ssh_t root_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_ssh_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /home.
#line 4247
allow sysadm_ssh_t home_root_t:dir { read getattr lock search ioctl };
#line 4247

#line 4247
# Read /usr.
#line 4247
allow sysadm_ssh_t usr_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_ssh_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read bin and sbin directories.
#line 4247
allow sysadm_ssh_t bin_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_ssh_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247
allow sysadm_ssh_t sbin_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_ssh_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247

#line 4247
# Read the devpts root directory.
#line 4247
allow sysadm_ssh_t devpts_t:dir { read getattr lock search ioctl };
#line 4247

#line 4247
# Read /var.
#line 4247
allow sysadm_ssh_t var_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_ssh_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/run, /var/log.
#line 4247
allow sysadm_ssh_t var_run_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_ssh_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_ssh_t var_log_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_ssh_t var_log_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /etc.
#line 4247
allow sysadm_ssh_t etc_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_ssh_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247
allow sysadm_ssh_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_ssh_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read the linker, shared library, and executable types.
#line 4247
allow sysadm_ssh_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_ssh_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_ssh_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /dev directories and any symbolic links.
#line 4247
allow sysadm_ssh_t device_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_ssh_t device_t:lnk_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read /dev/random.
#line 4247
allow sysadm_ssh_t random_device_t:chr_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read and write /dev/tty and /dev/null.
#line 4247
allow sysadm_ssh_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4247
allow sysadm_ssh_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247
# Grant permissions needed to create TCP and UDP sockets and
#line 4247
# to access the network.
#line 4247

#line 4247
#
#line 4247
# Allow the domain to create and use UDP and TCP sockets.
#line 4247
# Other kinds of sockets must be separately authorized for use.
#line 4247
allow sysadm_ssh_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247
allow sysadm_ssh_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send UDP packets.
#line 4247
# Since the destination sockets type is unknown, the generic
#line 4247
# any_socket_t type is used as a placeholder.
#line 4247
#
#line 4247
allow sysadm_ssh_t any_socket_t:udp_socket sendto;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send using any network interface.
#line 4247
# netif_type is a type attribute for all network interface types.
#line 4247
#
#line 4247
allow sysadm_ssh_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4247

#line 4247
#
#line 4247
# Allow packets sent by the domain to be received on any network interface.
#line 4247
#
#line 4247
allow sysadm_ssh_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to receive packets from any network interface.
#line 4247
# netmsg_type is a type attribute for all default message types.
#line 4247
#
#line 4247
allow sysadm_ssh_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to initiate or accept TCP connections 
#line 4247
# on any network interface.
#line 4247
#
#line 4247
allow sysadm_ssh_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4247

#line 4247
#
#line 4247
# Receive resets from the TCP reset socket.
#line 4247
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4247
#
#line 4247
allow sysadm_ssh_t tcp_socket_t:tcp_socket recvfrom;
#line 4247

#line 4247
dontaudit sysadm_ssh_t tcp_socket_t:tcp_socket connectto;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send to any node.
#line 4247
# node_type is a type attribute for all node types.
#line 4247
#
#line 4247
allow sysadm_ssh_t node_type:node { tcp_send udp_send rawip_send };
#line 4247

#line 4247
#
#line 4247
# Allow packets sent by the domain to be received from any node.
#line 4247
#
#line 4247
allow sysadm_ssh_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send NFS client requests via the socket
#line 4247
# created by mount.
#line 4247
#
#line 4247
allow sysadm_ssh_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247

#line 4247
#
#line 4247
# Bind to the default port type.
#line 4247
# Other port types must be separately authorized.
#line 4247
#
#line 4247
allow sysadm_ssh_t port_t:udp_socket name_bind;
#line 4247
allow sysadm_ssh_t port_t:tcp_socket name_bind;
#line 4247

#line 4247

#line 4247
# for sshing to a ssh tunnel
#line 4247

#line 4247
allow sysadm_ssh_t sysadm_ssh_t:tcp_socket { connectto recvfrom };
#line 4247
allow sysadm_ssh_t sysadm_ssh_t:tcp_socket { acceptfrom recvfrom };
#line 4247
allow sysadm_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4247
allow sysadm_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4247

#line 4247

#line 4247
# Use capabilities.
#line 4247
allow sysadm_ssh_t self:capability { setuid setgid dac_override dac_read_search };
#line 4247

#line 4247
# Run helpers.
#line 4247

#line 4247
allow sysadm_ssh_t { bin_t sbin_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_ssh_t { bin_t sbin_t }:lnk_file read;
#line 4247

#line 4247
allow sysadm_ssh_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_ssh_t ld_so_t:file { read getattr lock execute ioctl };
#line 4247
allow sysadm_ssh_t ld_so_t:file execute_no_trans;
#line 4247
allow sysadm_ssh_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4247
allow sysadm_ssh_t shlib_t:file { read getattr lock execute ioctl };
#line 4247
allow sysadm_ssh_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4247
allow sysadm_ssh_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_ssh_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247

#line 4247
allow sysadm_ssh_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
allow sysadm_ssh_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
allow sysadm_ssh_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
allow sysadm_ssh_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
allow sysadm_ssh_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247

#line 4247
# Read the ssh key file.
#line 4247
allow sysadm_ssh_t sshd_key_t:file { read getattr lock ioctl };
#line 4247

#line 4247
# Access the ssh temporary files.
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to modify the directory.
#line 4247
#
#line 4247
allow sysadm_ssh_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4247

#line 4247
#
#line 4247
# Allow the process to create the file.
#line 4247
#
#line 4247

#line 4247
allow sysadm_ssh_t sshd_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4247
allow sysadm_ssh_t sshd_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4247

#line 4247

#line 4247

#line 4247
type_transition sysadm_ssh_t tmp_t:dir sshd_tmp_t;
#line 4247
type_transition sysadm_ssh_t tmp_t:{ file lnk_file sock_file fifo_file } sshd_tmp_t;
#line 4247

#line 4247

#line 4247

#line 4247
allow sysadm_ssh_t sysadm_tmp_t:dir { read getattr lock search ioctl };
#line 4247

#line 4247
# for rsync
#line 4247
allow sysadm_ssh_t sysadm_t:unix_stream_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247

#line 4247
# Access the users .ssh directory.
#line 4247
type sysadm_home_ssh_t, file_type, sysadmfile;
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to modify the directory.
#line 4247
#
#line 4247
allow { sysadm_ssh_t sysadm_ssh_t } sysadm_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4247

#line 4247
#
#line 4247
# Allow the process to create the file.
#line 4247
#
#line 4247

#line 4247
allow { sysadm_ssh_t sysadm_ssh_t } sysadm_home_ssh_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4247
allow { sysadm_ssh_t sysadm_ssh_t } sysadm_home_ssh_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4247

#line 4247

#line 4247

#line 4247
type_transition { sysadm_ssh_t sysadm_ssh_t } sysadm_home_dir_t:dir sysadm_home_ssh_t;
#line 4247
type_transition { sysadm_ssh_t sysadm_ssh_t } sysadm_home_dir_t:{ file lnk_file sock_file fifo_file } sysadm_home_ssh_t;
#line 4247

#line 4247

#line 4247

#line 4247
allow { sysadm_ssh_t sysadm_ssh_t } sysadm_home_ssh_t:lnk_file { getattr read };
#line 4247
dontaudit sysadm_ssh_t sysadm_home_t:dir search;
#line 4247

#line 4247
allow sshd_t sysadm_home_ssh_t:dir { read getattr lock search ioctl };
#line 4247
allow sshd_t sysadm_home_ssh_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247

#line 4247
allow sysadm_t sysadm_home_ssh_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4247
allow sysadm_t sysadm_home_ssh_t:{ file lnk_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4247

#line 4247

#line 4247
# Inherit and use descriptors from gnome-pty-helper.
#line 4247

#line 4247

#line 4247
# Connect to sshd.
#line 4247

#line 4247
allow sysadm_ssh_t sshd_t:tcp_socket { connectto recvfrom };
#line 4247
allow sshd_t sysadm_ssh_t:tcp_socket { acceptfrom recvfrom };
#line 4247
allow sshd_t tcp_socket_t:tcp_socket { recvfrom };
#line 4247
allow sysadm_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4247

#line 4247

#line 4247
# Write to the user domain tty.
#line 4247
allow sysadm_ssh_t sysadm_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4247
allow sysadm_ssh_t sysadm_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247
# Allow the user shell to signal the ssh program.
#line 4247
allow sysadm_t sysadm_ssh_t:process signal;
#line 4247
# allow ps to show ssh
#line 4247
allow sysadm_t sysadm_ssh_t:dir { search getattr read };
#line 4247
allow sysadm_t sysadm_ssh_t:{ file lnk_file } { read getattr };
#line 4247

#line 4247
# Allow the ssh program to communicate with ssh-agent.
#line 4247
allow sysadm_ssh_t sysadm_tmp_t:sock_file write;
#line 4247
allow sysadm_ssh_t sysadm_t:unix_stream_socket connectto;
#line 4247
allow sysadm_ssh_t sshd_t:unix_stream_socket connectto;
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
# Instantiate a derived domain for user cron jobs.
#line 4247

#line 4247
# Derived domain for user cron jobs, user user_crond_domain if not system
#line 4247

#line 4247
type sysadm_crond_t, domain, user_crond_domain;
#line 4247

#line 4247

#line 4247
# Permit a transition from the crond_t domain to this domain.
#line 4247
# The transition is requested explicitly by the modified crond 
#line 4247
# via execve_secure.  There is no way to set up an automatic
#line 4247
# transition, since crontabs are configuration files, not executables.
#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to transition to the new domain.
#line 4247
#
#line 4247
allow crond_t sysadm_crond_t:process transition;
#line 4247

#line 4247
#
#line 4247
# Allow the process to execute the program.
#line 4247
# 
#line 4247
allow crond_t shell_exec_t:file { getattr execute };
#line 4247

#line 4247
#
#line 4247
# Allow the process to reap the new domain.
#line 4247
#
#line 4247
allow sysadm_crond_t crond_t:process sigchld;
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to inherit and use file 
#line 4247
# descriptions from the creating process and vice versa.
#line 4247
#
#line 4247
allow sysadm_crond_t crond_t:fd use;
#line 4247
allow crond_t sysadm_crond_t:fd use;
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to write back to the old domain via a pipe.
#line 4247
#
#line 4247
allow sysadm_crond_t crond_t:fifo_file { ioctl read getattr lock write append };
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to read and execute the program.
#line 4247
#
#line 4247
allow sysadm_crond_t shell_exec_t:file { read getattr lock execute ioctl };
#line 4247

#line 4247
#
#line 4247
# Allow the new domain to be entered via the program.
#line 4247
#
#line 4247
allow sysadm_crond_t shell_exec_t:file entrypoint;
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
# The user role is authorized for this domain.
#line 4247
role sysadm_r types sysadm_crond_t;
#line 4247

#line 4247
# This domain is granted permissions common to most domains.
#line 4247

#line 4247

#line 4247
# Grant the permissions common to the test domains.
#line 4247

#line 4247
# Grant permissions within the domain.
#line 4247

#line 4247
# Access other processes in the same domain.
#line 4247
allow sysadm_crond_t self:process *;
#line 4247

#line 4247
# Access /proc/PID files for processes in the same domain.
#line 4247
allow sysadm_crond_t self:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Access file descriptions, pipes, and sockets
#line 4247
# created by processes in the same domain.
#line 4247
allow sysadm_crond_t self:fd *;
#line 4247
allow sysadm_crond_t self:fifo_file { ioctl read getattr lock write append };
#line 4247
allow sysadm_crond_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247
allow sysadm_crond_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4247

#line 4247
# Allow the domain to communicate with other processes in the same domain.
#line 4247
allow sysadm_crond_t self:unix_dgram_socket sendto;
#line 4247
allow sysadm_crond_t self:unix_stream_socket connectto;
#line 4247

#line 4247
# Access System V IPC objects created by processes in the same domain.
#line 4247
allow sysadm_crond_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4247
allow sysadm_crond_t self:msg  { send receive };
#line 4247
allow sysadm_crond_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4247
allow sysadm_crond_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4247

#line 4247

#line 4247

#line 4247
# Grant read/search permissions to most of /proc.
#line 4247

#line 4247
# Read system information files in /proc.
#line 4247
allow sysadm_crond_t proc_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Stat /proc/kmsg and /proc/kcore.
#line 4247
allow sysadm_crond_t proc_kmsg_t:file { getattr };
#line 4247
allow sysadm_crond_t proc_kcore_t:file { getattr };
#line 4247

#line 4247
# Read system variables in /proc/sys.
#line 4247
allow sysadm_crond_t sysctl_modprobe_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t sysctl_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t sysctl_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t sysctl_fs_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t sysctl_kernel_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t sysctl_net_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t sysctl_vm_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t sysctl_dev_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 4247

#line 4247

#line 4247
# Grant read/search permissions to many system file types.
#line 4247

#line 4247

#line 4247
# Get attributes of file systems.
#line 4247
allow sysadm_crond_t fs_type:filesystem getattr;
#line 4247

#line 4247

#line 4247
# Read /.
#line 4247
allow sysadm_crond_t root_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /home.
#line 4247
allow sysadm_crond_t home_root_t:dir { read getattr lock search ioctl };
#line 4247

#line 4247
# Read /usr.
#line 4247
allow sysadm_crond_t usr_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read bin and sbin directories.
#line 4247
allow sysadm_crond_t bin_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t sbin_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247

#line 4247
# Read directories and files with the readable_t type.
#line 4247
# This type is a general type for "world"-readable files.
#line 4247
allow sysadm_crond_t readable_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Stat /...security and lost+found.
#line 4247
allow sysadm_crond_t file_labels_t:dir getattr;
#line 4247
allow sysadm_crond_t lost_found_t:dir getattr;
#line 4247

#line 4247
# Read the devpts root directory.  
#line 4247
allow sysadm_crond_t devpts_t:dir { read getattr lock search ioctl };
#line 4247

#line 4247

#line 4247
# Read the /tmp directory and any /tmp files with the base type.
#line 4247
# Temporary files created at runtime will typically use derived types.
#line 4247
allow sysadm_crond_t tmp_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t tmp_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var.
#line 4247
allow sysadm_crond_t var_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/catman.
#line 4247
allow sysadm_crond_t catman_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t catman_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/lib.
#line 4247
allow sysadm_crond_t var_lib_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t var_lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t var_lib_nfs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t var_lib_nfs_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247

#line 4247
allow sysadm_crond_t tetex_data_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t tetex_data_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247

#line 4247
# Read /var/yp.
#line 4247
allow sysadm_crond_t var_yp_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t var_yp_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/spool.
#line 4247
allow sysadm_crond_t var_spool_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/run, /var/lock, /var/log.
#line 4247
allow sysadm_crond_t var_run_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t var_log_t:dir { read getattr lock search ioctl };
#line 4247
#allow sysadm_crond_t var_log_t:{ file lnk_file } r_file_perms;
#line 4247
allow sysadm_crond_t var_log_sa_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t var_log_sa_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t var_log_ksyms_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
allow sysadm_crond_t var_lock_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t var_lock_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /var/run/utmp and /var/log/wtmp.
#line 4247
allow sysadm_crond_t initrc_var_run_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t wtmp_t:file { read getattr lock ioctl };
#line 4247

#line 4247
# Read /boot, /boot/System.map*, and /vmlinuz*
#line 4247
allow sysadm_crond_t boot_t:dir { search getattr };
#line 4247
allow sysadm_crond_t boot_t:file getattr;
#line 4247
allow sysadm_crond_t system_map_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
allow sysadm_crond_t boot_t:lnk_file read;
#line 4247

#line 4247
# Read /etc.
#line 4247
allow sysadm_crond_t etc_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t etc_aliases_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t etc_mail_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t etc_mail_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4247

#line 4247
# Read /lib.
#line 4247
allow sysadm_crond_t lib_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read the linker, shared library, and executable types.
#line 4247
allow sysadm_crond_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read man directories and files.
#line 4247
allow sysadm_crond_t man_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t man_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read /usr/src.
#line 4247
allow sysadm_crond_t src_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t src_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Read module-related files.
#line 4247
allow sysadm_crond_t modules_object_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t modules_object_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t modules_dep_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t modules_conf_t:{ file lnk_file} { read getattr lock ioctl };
#line 4247

#line 4247
# Read /dev directories and any symbolic links.
#line 4247
allow sysadm_crond_t device_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t device_t:lnk_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read /dev/random and /dev/zero.
#line 4247
allow sysadm_crond_t random_device_t:chr_file { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t zero_device_t:chr_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read the root directory of a tmpfs filesytem and any symbolic links.
#line 4247
allow sysadm_crond_t tmpfs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t tmpfs_t:lnk_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read any symbolic links on a devfs file system.
#line 4247
allow sysadm_crond_t device_t:lnk_file { read getattr lock ioctl };
#line 4247

#line 4247
# Read the root directory of a usbdevfs filesystem, and
#line 4247
# the devices and drivers files.  Permit stating of the
#line 4247
# device nodes, but nothing else.
#line 4247
allow sysadm_crond_t usbdevfs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t usbdevfs_t:{ file lnk_file } { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t usbdevfs_device_t:file getattr;
#line 4247

#line 4247

#line 4247
# Grant write permissions to a small set of system file types.
#line 4247
# No permission to create files is granted here.  Use allow rules to grant 
#line 4247
# create permissions to a type or use file_type_auto_trans rules to set up
#line 4247
# new types for files.
#line 4247

#line 4247

#line 4247
# Read and write /dev/tty and /dev/null.
#line 4247
allow sysadm_crond_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4247
allow sysadm_crond_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247
# Do not audit write denials to /etc/ld.so.cache.
#line 4247
dontaudit sysadm_crond_t ld_so_cache_t:file write;
#line 4247

#line 4247

#line 4247
# Execute from the system shared libraries.
#line 4247
# No permission to execute anything else is granted here.
#line 4247
# Use can_exec or can_exec_any to grant the ability to execute within a domain.
#line 4247
# Use domain_auto_trans for executing and changing domains.
#line 4247

#line 4247
allow sysadm_crond_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t ld_so_t:file { read getattr lock execute ioctl };
#line 4247
allow sysadm_crond_t ld_so_t:file execute_no_trans;
#line 4247
allow sysadm_crond_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t shlib_t:file { read getattr lock execute ioctl };
#line 4247
allow sysadm_crond_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247

#line 4247
# read localization information
#line 4247
allow sysadm_crond_t locale_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 4247

#line 4247
# Obtain the context of any SID, the SID for any context, 
#line 4247
# and the list of active SIDs.
#line 4247
allow sysadm_crond_t security_t:security { sid_to_context context_to_sid get_sids };
#line 4247

#line 4247

#line 4247

#line 4247
# Grant permissions needed to create TCP and UDP sockets and 
#line 4247
# to access the network.
#line 4247

#line 4247
#
#line 4247
# Allow the domain to create and use UDP and TCP sockets.
#line 4247
# Other kinds of sockets must be separately authorized for use.
#line 4247
allow sysadm_crond_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247
allow sysadm_crond_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send UDP packets.
#line 4247
# Since the destination sockets type is unknown, the generic
#line 4247
# any_socket_t type is used as a placeholder.
#line 4247
#
#line 4247
allow sysadm_crond_t any_socket_t:udp_socket sendto;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send using any network interface.
#line 4247
# netif_type is a type attribute for all network interface types.
#line 4247
#
#line 4247
allow sysadm_crond_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4247

#line 4247
#
#line 4247
# Allow packets sent by the domain to be received on any network interface.
#line 4247
#
#line 4247
allow sysadm_crond_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to receive packets from any network interface.
#line 4247
# netmsg_type is a type attribute for all default message types.
#line 4247
#
#line 4247
allow sysadm_crond_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to initiate or accept TCP connections 
#line 4247
# on any network interface.
#line 4247
#
#line 4247
allow sysadm_crond_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4247

#line 4247
#
#line 4247
# Receive resets from the TCP reset socket.
#line 4247
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4247
#
#line 4247
allow sysadm_crond_t tcp_socket_t:tcp_socket recvfrom;
#line 4247

#line 4247
dontaudit sysadm_crond_t tcp_socket_t:tcp_socket connectto;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send to any node.
#line 4247
# node_type is a type attribute for all node types.
#line 4247
#
#line 4247
allow sysadm_crond_t node_type:node { tcp_send udp_send rawip_send };
#line 4247

#line 4247
#
#line 4247
# Allow packets sent by the domain to be received from any node.
#line 4247
#
#line 4247
allow sysadm_crond_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send NFS client requests via the socket
#line 4247
# created by mount.
#line 4247
#
#line 4247
allow sysadm_crond_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247

#line 4247
#
#line 4247
# Bind to the default port type.
#line 4247
# Other port types must be separately authorized.
#line 4247
#
#line 4247
allow sysadm_crond_t port_t:udp_socket name_bind;
#line 4247
allow sysadm_crond_t port_t:tcp_socket name_bind;
#line 4247

#line 4247

#line 4247

#line 4247
# Use capabilities.
#line 4247
allow sysadm_crond_t sysadm_crond_t:capability dac_override;
#line 4247

#line 4247
# Inherit and use descriptors from initrc.
#line 4247
allow sysadm_crond_t initrc_t:fd use;
#line 4247

#line 4247
# 
#line 4247
# Since crontab files are not directly executed,
#line 4247
# crond must ensure that the crontab file has
#line 4247
# a type that is appropriate for the domain of
#line 4247
# the user cron job.  It performs an entrypoint
#line 4247
# permission check for this purpose.
#line 4247
#
#line 4247
allow sysadm_crond_t sysadm_cron_spool_t:file entrypoint;
#line 4247

#line 4247
# Access user files and dirs.
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to modify the directory.
#line 4247
#
#line 4247
allow sysadm_crond_t sysadm_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4247

#line 4247
#
#line 4247
# Allow the process to create the file.
#line 4247
#
#line 4247

#line 4247
allow sysadm_crond_t sysadm_home_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4247
allow sysadm_crond_t sysadm_home_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4247

#line 4247

#line 4247

#line 4247
type_transition sysadm_crond_t sysadm_home_dir_t:dir sysadm_home_t;
#line 4247
type_transition sysadm_crond_t sysadm_home_dir_t:{ file lnk_file sock_file fifo_file } sysadm_home_t;
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to modify the directory.
#line 4247
#
#line 4247
allow sysadm_crond_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4247

#line 4247
#
#line 4247
# Allow the process to create the file.
#line 4247
#
#line 4247

#line 4247
allow sysadm_crond_t sysadm_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4247
allow sysadm_crond_t sysadm_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4247

#line 4247

#line 4247

#line 4247
type_transition sysadm_crond_t tmp_t:dir sysadm_tmp_t;
#line 4247
type_transition sysadm_crond_t tmp_t:{ file lnk_file sock_file fifo_file } sysadm_tmp_t;
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
# Run helper programs.
#line 4247

#line 4247
allow sysadm_crond_t { bin_t sbin_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t { bin_t sbin_t }:lnk_file read;
#line 4247

#line 4247
allow sysadm_crond_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_crond_t ld_so_t:file { read getattr lock execute ioctl };
#line 4247
allow sysadm_crond_t ld_so_t:file execute_no_trans;
#line 4247
allow sysadm_crond_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t shlib_t:file { read getattr lock execute ioctl };
#line 4247
allow sysadm_crond_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4247
allow sysadm_crond_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247

#line 4247
allow sysadm_crond_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
allow sysadm_crond_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
allow sysadm_crond_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
allow sysadm_crond_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
allow sysadm_crond_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247

#line 4247
# Run scripts in user home directory.
#line 4247

#line 4247
allow sysadm_crond_t sysadm_home_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
# Read the mouse.
#line 4247
allow sysadm_t mouse_device_t:chr_file { read getattr lock ioctl };
#line 4247
# Access other miscellaneous devices.
#line 4247
allow sysadm_t misc_device_t:{ file lnk_file sock_file fifo_file chr_file blk_file } { ioctl read getattr lock write append };
#line 4247

#line 4247
# Use the network.
#line 4247

#line 4247
#
#line 4247
# Allow the domain to create and use UDP and TCP sockets.
#line 4247
# Other kinds of sockets must be separately authorized for use.
#line 4247
allow sysadm_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247
allow sysadm_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send UDP packets.
#line 4247
# Since the destination sockets type is unknown, the generic
#line 4247
# any_socket_t type is used as a placeholder.
#line 4247
#
#line 4247
allow sysadm_t any_socket_t:udp_socket sendto;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send using any network interface.
#line 4247
# netif_type is a type attribute for all network interface types.
#line 4247
#
#line 4247
allow sysadm_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4247

#line 4247
#
#line 4247
# Allow packets sent by the domain to be received on any network interface.
#line 4247
#
#line 4247
allow sysadm_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to receive packets from any network interface.
#line 4247
# netmsg_type is a type attribute for all default message types.
#line 4247
#
#line 4247
allow sysadm_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to initiate or accept TCP connections 
#line 4247
# on any network interface.
#line 4247
#
#line 4247
allow sysadm_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4247

#line 4247
#
#line 4247
# Receive resets from the TCP reset socket.
#line 4247
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4247
#
#line 4247
allow sysadm_t tcp_socket_t:tcp_socket recvfrom;
#line 4247

#line 4247
dontaudit sysadm_t tcp_socket_t:tcp_socket connectto;
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send to any node.
#line 4247
# node_type is a type attribute for all node types.
#line 4247
#
#line 4247
allow sysadm_t node_type:node { tcp_send udp_send rawip_send };
#line 4247

#line 4247
#
#line 4247
# Allow packets sent by the domain to be received from any node.
#line 4247
#
#line 4247
allow sysadm_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4247

#line 4247
#
#line 4247
# Allow the domain to send NFS client requests via the socket
#line 4247
# created by mount.
#line 4247
#
#line 4247
allow sysadm_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4247

#line 4247
#
#line 4247
# Bind to the default port type.
#line 4247
# Other port types must be separately authorized.
#line 4247
#
#line 4247
allow sysadm_t port_t:udp_socket name_bind;
#line 4247
allow sysadm_t port_t:tcp_socket name_bind;
#line 4247

#line 4247

#line 4247
#
#line 4247
# connect_secure and sendmsg_secure calls with a 
#line 4247
# peer or destination socket SID can be enforced
#line 4247
# when using the loopback interface.  Enforcement
#line 4247
# for real network interfaces will be possible when
#line 4247
# a packet labeling mechanism is integrated.
#line 4247
#
#line 4247
allow sysadm_t node_lo_t:node enforce_dest;
#line 4247

#line 4247
# Communicate within the domain.
#line 4247

#line 4247
allow sysadm_t sysadm_t:udp_socket { sendto };
#line 4247
allow sysadm_t sysadm_t:udp_socket { recvfrom };
#line 4247

#line 4247

#line 4247
allow sysadm_t sysadm_t:tcp_socket { connectto recvfrom };
#line 4247
allow sysadm_t sysadm_t:tcp_socket { acceptfrom recvfrom };
#line 4247
allow sysadm_t tcp_socket_t:tcp_socket { recvfrom };
#line 4247
allow sysadm_t tcp_socket_t:tcp_socket { recvfrom };
#line 4247

#line 4247

#line 4247
# Connect to inetd.
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
# Connect data port to ftpd.
#line 4247

#line 4247

#line 4247
# Connect to portmap.
#line 4247

#line 4247

#line 4247
# Inherit and use sockets from inetd
#line 4247

#line 4247

#line 4247
# Allow system log read
#line 4247
#allow sysadm_t kernel_t:system syslog_read;
#line 4247
# else do not log it
#line 4247
dontaudit sysadm_t kernel_t:system syslog_read;
#line 4247

#line 4247
# Very permissive allowing every domain to see every type.
#line 4247
allow sysadm_t kernel_t:system { ipc_info };
#line 4247

#line 4247
# When the user domain runs ps, there will be a number of access
#line 4247
# denials when ps tries to search /proc.  Do not audit these denials.
#line 4247
dontaudit sysadm_t domain:dir { read getattr lock search ioctl };
#line 4247
dontaudit sysadm_t domain:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Some shells ask for w access to utmp, but will operate
#line 4247
# correctly without it.  Do not audit write denials to utmp.
#line 4247
dontaudit sysadm_t initrc_var_run_t:file { getattr read write };
#line 4247

#line 4247
# do not audit getattr on tmpfile, otherwise ls -l /tmp fills the logs
#line 4247
dontaudit sysadm_t tmpfile:{ dir file lnk_file sock_file fifo_file chr_file blk_file } getattr;
#line 4247

#line 4247
# do not audit getattr on disk devices, otherwise KDE fills the logs
#line 4247
dontaudit sysadm_t { removable_device_t fixed_disk_device_t }:blk_file getattr;
#line 4247

#line 4247

#line 4247
# Access the sound device.
#line 4247
allow sysadm_t sound_device_t:chr_file { getattr read write ioctl };
#line 4247

#line 4247
# Allow reading dpkg origins file
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
# Violates the goal of limiting write access to checkpolicy.
#line 4247
#rw_dir_create_file(sysadm_t, policy_config_t)
#line 4247

#line 4247

#line 4247
allow sysadm_crond_t var_log_t:file { read getattr lock ioctl };
#line 4247

#line 4247

#line 4247
# Allow system log read
#line 4247
allow sysadm_t kernel_t:system syslog_read;
#line 4247

#line 4247
# Use capabilities other than sys_module.
#line 4247
allow sysadm_t self:capability ~sys_module;
#line 4247

#line 4247
# Determine the set of legal user SIDs reachable from a given SID.
#line 4247
allow sysadm_t security_t:security { get_user_sids };
#line 4247

#line 4247
# Use system operations.
#line 4247
allow sysadm_t kernel_t:system *;
#line 4247

#line 4247
# Change system parameters.
#line 4247

#line 4247
allow sysadm_t sysctl_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_t sysctl_t:file { setattr { ioctl read getattr lock write append } };
#line 4247
allow sysadm_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_t sysctl_fs_t:file { setattr { ioctl read getattr lock write append } };
#line 4247
allow sysadm_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_t sysctl_kernel_t:file { setattr { ioctl read getattr lock write append } };
#line 4247
allow sysadm_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_t sysctl_net_t:file { setattr { ioctl read getattr lock write append } };
#line 4247
allow sysadm_t sysctl_net_unix_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_t sysctl_net_unix_t:file { setattr { ioctl read getattr lock write append } };
#line 4247
allow sysadm_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_t sysctl_vm_t:file { setattr { ioctl read getattr lock write append } };
#line 4247
allow sysadm_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_t sysctl_dev_t:file { setattr { ioctl read getattr lock write append } };
#line 4247
allow sysadm_t sysctl_modprobe_t:file { setattr { ioctl read getattr lock write append } };
#line 4247

#line 4247

#line 4247
# Create and use all files that have the sysadmfile attribute.
#line 4247
allow sysadm_t sysadmfile:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4247
allow sysadm_t sysadmfile:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4247

#line 4247
# Access removable devices.
#line 4247
allow sysadm_t removable_device_t:{ chr_file blk_file } { ioctl read getattr lock write append };
#line 4247

#line 4247
# Communicate with the init process.
#line 4247
allow sysadm_t initctl_t:fifo_file { ioctl read getattr lock write append };
#line 4247

#line 4247
# Examine all processes.
#line 4247
allow sysadm_t domain:dir { read getattr lock search ioctl };
#line 4247
allow sysadm_t domain:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4247

#line 4247
# Send signals to all processes.
#line 4247
allow sysadm_t { domain unlabeled_t }:process { sigchld sigkill sigstop signull signal };
#line 4247

#line 4247
# Access all user terminals.
#line 4247
allow sysadm_t tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4247
allow sysadm_t ttyfile:chr_file { ioctl read getattr lock write append };
#line 4247
allow sysadm_t ptyfile:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247
# allow setting up tunnels
#line 4247
allow sysadm_t tun_tap_device_t:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247
# Run init (telinit).
#line 4247

#line 4247
allow sysadm_t init_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
# Run programs from user home directories.
#line 4247
# Not ideal, but typical if users want to login as both sysadm_t or user_t.
#line 4247

#line 4247
allow sysadm_t user_home_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247
# Run programs from /usr/src.
#line 4247

#line 4247
allow sysadm_t src_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4247

#line 4247

#line 4247
# Run admin programs that require different permissions in their own domain.
#line 4247
# These rules were moved into the appropriate program domain file.
#line 4247

#line 4247
# added by mayerf@tresys.com
#line 4247
# The following rules are temporary until such time that a complete
#line 4247
# policy management infrastructure is in place so that an administrator
#line 4247
# cannot directly manipulate policy files with arbitrary programs.
#line 4247
#
#line 4247
allow sysadm_t policy_src_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4247
allow sysadm_t policy_src_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4247

#line 4247
# Remove the binary policy.
#line 4247
allow sysadm_t policy_config_t:file unlink;
#line 4247

#line 4247
# Relabel all files.
#line 4247
allow sysadm_t file_type:dir { getattr read search relabelfrom relabelto };
#line 4247
allow sysadm_t file_type:{ file lnk_file sock_file fifo_file chr_file blk_file } { getattr relabelfrom relabelto };
#line 4247

#line 4247
# Create files in /tmp/orbit-* and /tmp/.ICE-unix
#line 4247
# with our derived tmp type rather than user_tmp_t.
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# Allow the process to modify the directory.
#line 4247
#
#line 4247
allow sysadm_t user_tmpfile:dir { read getattr lock search ioctl add_name remove_name write };
#line 4247

#line 4247
#
#line 4247
# Allow the process to create the file.
#line 4247
#
#line 4247

#line 4247
allow sysadm_t sysadm_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4247
allow sysadm_t sysadm_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4247

#line 4247

#line 4247

#line 4247
type_transition sysadm_t user_tmpfile:dir sysadm_tmp_t;
#line 4247
type_transition sysadm_t user_tmpfile:{ file lnk_file sock_file fifo_file } sysadm_tmp_t;
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
#
#line 4247
# A user who is authorized for sysadm_t may nonetheless have
#line 4247
# a home directory labeled with user_home_t if the user is expected
#line 4247
# to login in either user_t or sysadm_t.  Hence, the derived domains
#line 4247
# for programs need to be able to access user_home_t.  
#line 4247
# 
#line 4247

#line 4247
# Allow our xauth domain to write to .Xauthority.
#line 4247

#line 4247

#line 4247
# Allow our gph domain to write to .xsession-errors.
#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247

#line 4247
# Allow our crontab domain to unlink a user cron spool file.
#line 4247
allow sysadm_crontab_t user_cron_spool_t:file unlink;
#line 4247

#line 4247
#
#line 4247
# Allow sysadm to execute quota commands against filesystems and files.
#line 4247
#
#line 4247
allow sysadm_t fs_type:filesystem { quotamod quotaget };
#line 4247
allow sysadm_t file_t:file quotaon;
#line 4247

#line 4247
# Grant read and write access to /dev/console.
#line 4247
allow sysadm_t console_device_t:chr_file { ioctl read getattr lock write append };
#line 4247

#line 4247
# for lsof
#line 4247
allow sysadm_t domain:{ tcp_socket udp_socket rawip_socket netlink_socket packet_socket unix_stream_socket unix_dgram_socket } getattr;
#line 4247


# Audit grantings of avc_toggle to the administrator domains.
# Due to its sensitivity, we always audit this permission.
auditallow admin kernel_t:system avc_toggle;





#DESC Httpd admin -  Domain for httpd administrators
########################################
# httpd_admin domain macro and rules for 
# httpd_admin_t
########################################

# Uses some types defined in apache.te, so conditionally defined this macro.
# The intent is to remove this file in the future.
#
#line 4404

#DESC User - Domains for ordinary users.
#
#################################

#line 4408

#line 4408
# user_t/user_t is an unprivileged users domain.
#line 4408
type user_t, domain, userdomain, unpriv_userdomain;
#line 4408

#line 4408
# user_r is authorized for user_t for the initial login domain.
#line 4408
role user_r types user_t;
#line 4408
allow system_r user_r;
#line 4408

#line 4408
# Grant permissions within the domain.
#line 4408

#line 4408
# Access other processes in the same domain.
#line 4408
allow user_t self:process *;
#line 4408

#line 4408
# Access /proc/PID files for processes in the same domain.
#line 4408
allow user_t self:dir { read getattr lock search ioctl };
#line 4408
allow user_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Access file descriptions, pipes, and sockets
#line 4408
# created by processes in the same domain.
#line 4408
allow user_t self:fd *;
#line 4408
allow user_t self:fifo_file { ioctl read getattr lock write append };
#line 4408
allow user_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408
allow user_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4408

#line 4408
# Allow the domain to communicate with other processes in the same domain.
#line 4408
allow user_t self:unix_dgram_socket sendto;
#line 4408
allow user_t self:unix_stream_socket connectto;
#line 4408

#line 4408
# Access System V IPC objects created by processes in the same domain.
#line 4408
allow user_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4408
allow user_t self:msg  { send receive };
#line 4408
allow user_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4408
allow user_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4408

#line 4408
;
#line 4408

#line 4408
# Grant read/search permissions to some of /proc.
#line 4408
allow user_t proc_t:dir { read getattr lock search ioctl };
#line 4408
allow user_t proc_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Grand read/search permissions to many system types.
#line 4408
#general_file_read_access(user_t);
#line 4408
# Get attributes of file systems.
#line 4408
allow user_t fs_type:filesystem getattr;
#line 4408

#line 4408

#line 4408
# Read /.
#line 4408
allow user_t root_t:dir { read getattr lock search ioctl };
#line 4408
allow user_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /home.
#line 4408
allow user_t home_root_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408
# Read /usr.
#line 4408
allow user_t usr_t:dir { read getattr lock search ioctl };
#line 4408
allow user_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read bin and sbin directories.
#line 4408
allow user_t bin_t:dir { read getattr lock search ioctl };
#line 4408
allow user_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_t sbin_t:dir { read getattr lock search ioctl };
#line 4408
allow user_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408

#line 4408
# Read directories and files with the readable_t type.
#line 4408
# This type is a general type for "world"-readable files.
#line 4408
allow user_t readable_t:dir { read getattr lock search ioctl };
#line 4408
allow user_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Stat /...security and lost+found.
#line 4408
allow user_t file_labels_t:dir getattr;
#line 4408
allow user_t lost_found_t:dir getattr;
#line 4408

#line 4408
# Read the devpts root directory.
#line 4408
allow user_t devpts_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408

#line 4408
# Read the /tmp directory and any /tmp files with the base type.
#line 4408
# Temporary files created at runtime will typically use derived types.
#line 4408
allow user_t tmp_t:dir { read getattr lock search ioctl };
#line 4408
allow user_t tmp_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var, /var/spool, /var/run.
#line 4408
allow user_t var_t:dir { read getattr lock search ioctl };
#line 4408
allow user_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_t var_spool_t:dir { read getattr lock search ioctl };
#line 4408
allow user_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_t var_run_t:dir { read getattr lock search ioctl };
#line 4408
allow user_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /etc.
#line 4408
allow user_t etc_t:dir { read getattr lock search ioctl };
#line 4408
allow user_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read man directories and files.
#line 4408
allow user_t man_t:dir { read getattr lock search ioctl };
#line 4408
allow user_t man_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /dev directories and any symbolic links.
#line 4408
allow user_t device_t:dir { read getattr lock search ioctl };
#line 4408
allow user_t device_t:lnk_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read and write /dev/tty and /dev/null.
#line 4408
allow user_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4408
allow user_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408
# Do not audit write denials to /etc/ld.so.cache.
#line 4408
dontaudit user_t ld_so_cache_t:file write;
#line 4408

#line 4408
# Execute from the system shared libraries.
#line 4408

#line 4408
allow user_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4408
allow user_t ld_so_t:file { read getattr lock execute ioctl };
#line 4408
allow user_t ld_so_t:file execute_no_trans;
#line 4408
allow user_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_t shlib_t:file { read getattr lock execute ioctl };
#line 4408
allow user_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4408
allow user_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4408
;
#line 4408

#line 4408
# Obtain the context of any SID, the SID for any context,
#line 4408
# and the list of active SIDs.
#line 4408
allow user_t security_t:security { sid_to_context context_to_sid get_sids };
#line 4408

#line 4408
# user_t is also granted permissions specific to user domains.
#line 4408

#line 4408
# Use capabilities
#line 4408
allow user_t self:capability { setgid chown fowner };
#line 4408
dontaudit user_t self:capability { sys_nice fsetid };
#line 4408

#line 4408
# Type for home directory.
#line 4408

#line 4408
type user_home_dir_t, file_type, sysadmfile, home_dir_type, user_home_dir_type, home_type, user_home_type;
#line 4408
type user_home_t, file_type, sysadmfile, home_type, user_home_type;
#line 4408
# do not allow privhome access to sysadm_home_dir_t
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to modify the directory.
#line 4408
#
#line 4408
allow privhome user_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4408

#line 4408
#
#line 4408
# Allow the process to create the file.
#line 4408
#
#line 4408

#line 4408
allow privhome user_home_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4408
allow privhome user_home_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4408

#line 4408

#line 4408

#line 4408
type_transition privhome user_home_dir_t:dir user_home_t;
#line 4408
type_transition privhome user_home_dir_t:{ file lnk_file sock_file fifo_file } user_home_t;
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
type user_tmp_t, file_type, sysadmfile, tmpfile , user_tmpfile;
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to modify the directory.
#line 4408
#
#line 4408
allow user_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4408

#line 4408
#
#line 4408
# Allow the process to create the file.
#line 4408
#
#line 4408

#line 4408
allow user_t user_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4408
allow user_t user_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4408

#line 4408

#line 4408

#line 4408
type_transition user_t tmp_t:dir user_tmp_t;
#line 4408
type_transition user_t tmp_t:{ file lnk_file sock_file fifo_file } user_tmp_t;
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
# Create, access, and remove files in home directory.
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to modify the directory.
#line 4408
#
#line 4408
allow user_t user_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4408

#line 4408
#
#line 4408
# Allow the process to create the file.
#line 4408
#
#line 4408

#line 4408
allow user_t user_home_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4408
allow user_t user_home_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4408

#line 4408

#line 4408

#line 4408
type_transition user_t user_home_dir_t:dir user_home_t;
#line 4408
type_transition user_t user_home_dir_t:{ file lnk_file sock_file fifo_file } user_home_t;
#line 4408

#line 4408

#line 4408

#line 4408
allow user_t user_home_t:{ dir file lnk_file sock_file fifo_file chr_file blk_file } { relabelfrom relabelto };
#line 4408

#line 4408
# Bind to a Unix domain socket in /tmp.
#line 4408
allow user_t user_tmp_t:unix_stream_socket name_bind;
#line 4408

#line 4408
# Type for tty devices.
#line 4408
type user_tty_device_t, file_type, sysadmfile, ttyfile;
#line 4408
# Access ttys.
#line 4408
allow user_t user_tty_device_t:chr_file { setattr { ioctl read getattr lock write append } };
#line 4408
# Use the type when relabeling terminal devices.
#line 4408
type_change user_t tty_device_t:chr_file user_tty_device_t;
#line 4408

#line 4408

#line 4408
# Type and access for pty devices.
#line 4408

#line 4408

#line 4408

#line 4408
type user_devpts_t, file_type, sysadmfile, ptyfile , userpty_type;
#line 4408

#line 4408
# Allow the pty to be associated with the file system.
#line 4408
allow user_devpts_t devpts_t:filesystem associate;
#line 4408

#line 4408
# Access the pty master multiplexer.
#line 4408
allow user_t ptmx_t:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408
# Label pty files with a derived type.
#line 4408
type_transition user_t devpts_t:chr_file user_devpts_t;
#line 4408

#line 4408
# Read and write my pty files.
#line 4408
allow user_t user_devpts_t:chr_file { setattr { ioctl read getattr lock write append } };
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
# Use the type when relabeling pty devices.
#line 4408

#line 4408

#line 4408
type_change user_t sshd_devpts_t:chr_file user_devpts_t;
#line 4408

#line 4408
# Connect to sshd.
#line 4408

#line 4408
allow user_t sshd_t:tcp_socket { connectto recvfrom };
#line 4408
allow sshd_t user_t:tcp_socket { acceptfrom recvfrom };
#line 4408
allow sshd_t tcp_socket_t:tcp_socket { recvfrom };
#line 4408
allow user_t tcp_socket_t:tcp_socket { recvfrom };
#line 4408

#line 4408

#line 4408
# Connect to ssh proxy.
#line 4408

#line 4408
allow user_t user_ssh_t:tcp_socket { connectto recvfrom };
#line 4408
allow user_ssh_t user_t:tcp_socket { acceptfrom recvfrom };
#line 4408
allow user_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4408
allow user_t tcp_socket_t:tcp_socket { recvfrom };
#line 4408

#line 4408

#line 4408
allow user_t sshd_t:fd use;
#line 4408
allow user_t sshd_t:tcp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4408
# Use a Unix stream socket inherited from sshd.
#line 4408
allow user_t sshd_t:unix_stream_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4408

#line 4408
# Type for tmpfs/shm files.
#line 4408
type user_tmpfs_t, file_type, sysadmfile, tmpfsfile;
#line 4408
# Use the type when creating files in tmpfs.
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to modify the directory.
#line 4408
#
#line 4408
allow user_t tmpfs_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4408

#line 4408
#
#line 4408
# Allow the process to create the file.
#line 4408
#
#line 4408

#line 4408
allow user_t user_tmpfs_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4408
allow user_t user_tmpfs_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4408

#line 4408

#line 4408

#line 4408
type_transition user_t tmpfs_t:dir user_tmpfs_t;
#line 4408
type_transition user_t tmpfs_t:{ file lnk_file sock_file fifo_file } user_tmpfs_t;
#line 4408

#line 4408

#line 4408

#line 4408
allow user_tmpfs_t tmpfs_t:filesystem associate;
#line 4408

#line 4408
# Read and write /var/catman.
#line 4408
allow user_t catman_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4408
allow user_t catman_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4408

#line 4408
# Modify mail spool file.
#line 4408
allow user_t mail_spool_t:dir { read getattr lock search ioctl };
#line 4408
allow user_t mail_spool_t:file { ioctl read getattr lock write append };
#line 4408
allow user_t mail_spool_t:lnk_file read;
#line 4408

#line 4408
#
#line 4408
# Allow the query of filesystem quotas
#line 4408
#
#line 4408
allow user_t fs_type:filesystem quotaget;
#line 4408

#line 4408
# Run helper programs.
#line 4408

#line 4408
allow user_t { bin_t sbin_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4408
allow user_t { bin_t sbin_t }:lnk_file read;
#line 4408

#line 4408
allow user_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4408
allow user_t ld_so_t:file { read getattr lock execute ioctl };
#line 4408
allow user_t ld_so_t:file execute_no_trans;
#line 4408
allow user_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_t shlib_t:file { read getattr lock execute ioctl };
#line 4408
allow user_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4408
allow user_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408

#line 4408
allow user_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408
allow user_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408
allow user_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408
allow user_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408
allow user_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408
# Run programs developed by other users in the same domain.
#line 4408

#line 4408
allow user_t user_home_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408
allow user_t user_tmp_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408
# Run user programs that require different permissions in their own domain.
#line 4408
# These rules were moved into the individual program domains.
#line 4408

#line 4408
# Instantiate derived domains for a number of programs.
#line 4408
# These derived domains encode both information about the calling
#line 4408
# user domain and the program, and allow us to maintain separation
#line 4408
# between different instances of the program being run by different
#line 4408
# user domains.
#line 4408

#line 4408

#line 4408

#line 4408
# Derived domain based on the calling user domain and the program.
#line 4408
type user_su_t, domain, privlog, auth;
#line 4408

#line 4408
# Transition from the user domain to this domain.
#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to transition to the new domain.
#line 4408
#
#line 4408
allow user_t user_su_t:process transition;
#line 4408

#line 4408
#
#line 4408
# Allow the process to execute the program.
#line 4408
# 
#line 4408
allow user_t su_exec_t:file { getattr execute };
#line 4408

#line 4408
#
#line 4408
# Allow the process to reap the new domain.
#line 4408
#
#line 4408
allow user_su_t user_t:process sigchld;
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to inherit and use file 
#line 4408
# descriptions from the creating process and vice versa.
#line 4408
#
#line 4408
allow user_su_t user_t:fd use;
#line 4408
allow user_t user_su_t:fd use;
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to write back to the old domain via a pipe.
#line 4408
#
#line 4408
allow user_su_t user_t:fifo_file { ioctl read getattr lock write append };
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to read and execute the program.
#line 4408
#
#line 4408
allow user_su_t su_exec_t:file { read getattr lock execute ioctl };
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to be entered via the program.
#line 4408
#
#line 4408
allow user_su_t su_exec_t:file entrypoint;
#line 4408

#line 4408
type_transition user_t su_exec_t:process user_su_t;
#line 4408

#line 4408

#line 4408
# This domain is granted permissions common to most domains.
#line 4408

#line 4408

#line 4408
# Grant the permissions common to the test domains.
#line 4408

#line 4408
# Grant permissions within the domain.
#line 4408

#line 4408
# Access other processes in the same domain.
#line 4408
allow user_su_t self:process *;
#line 4408

#line 4408
# Access /proc/PID files for processes in the same domain.
#line 4408
allow user_su_t self:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Access file descriptions, pipes, and sockets
#line 4408
# created by processes in the same domain.
#line 4408
allow user_su_t self:fd *;
#line 4408
allow user_su_t self:fifo_file { ioctl read getattr lock write append };
#line 4408
allow user_su_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408
allow user_su_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4408

#line 4408
# Allow the domain to communicate with other processes in the same domain.
#line 4408
allow user_su_t self:unix_dgram_socket sendto;
#line 4408
allow user_su_t self:unix_stream_socket connectto;
#line 4408

#line 4408
# Access System V IPC objects created by processes in the same domain.
#line 4408
allow user_su_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4408
allow user_su_t self:msg  { send receive };
#line 4408
allow user_su_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4408
allow user_su_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4408

#line 4408

#line 4408

#line 4408
# Grant read/search permissions to most of /proc.
#line 4408

#line 4408
# Read system information files in /proc.
#line 4408
allow user_su_t proc_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Stat /proc/kmsg and /proc/kcore.
#line 4408
allow user_su_t proc_kmsg_t:file { getattr };
#line 4408
allow user_su_t proc_kcore_t:file { getattr };
#line 4408

#line 4408
# Read system variables in /proc/sys.
#line 4408
allow user_su_t sysctl_modprobe_t:file { read getattr lock ioctl };
#line 4408
allow user_su_t sysctl_t:file { read getattr lock ioctl };
#line 4408
allow user_su_t sysctl_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t sysctl_fs_t:file { read getattr lock ioctl };
#line 4408
allow user_su_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t sysctl_kernel_t:file { read getattr lock ioctl };
#line 4408
allow user_su_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t sysctl_net_t:file { read getattr lock ioctl };
#line 4408
allow user_su_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t sysctl_vm_t:file { read getattr lock ioctl };
#line 4408
allow user_su_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t sysctl_dev_t:file { read getattr lock ioctl };
#line 4408
allow user_su_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408

#line 4408
# Grant read/search permissions to many system file types.
#line 4408

#line 4408

#line 4408
# Get attributes of file systems.
#line 4408
allow user_su_t fs_type:filesystem getattr;
#line 4408

#line 4408

#line 4408
# Read /.
#line 4408
allow user_su_t root_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /home.
#line 4408
allow user_su_t home_root_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408
# Read /usr.
#line 4408
allow user_su_t usr_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read bin and sbin directories.
#line 4408
allow user_su_t bin_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_su_t sbin_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408

#line 4408
# Read directories and files with the readable_t type.
#line 4408
# This type is a general type for "world"-readable files.
#line 4408
allow user_su_t readable_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Stat /...security and lost+found.
#line 4408
allow user_su_t file_labels_t:dir getattr;
#line 4408
allow user_su_t lost_found_t:dir getattr;
#line 4408

#line 4408
# Read the devpts root directory.  
#line 4408
allow user_su_t devpts_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408

#line 4408
# Read the /tmp directory and any /tmp files with the base type.
#line 4408
# Temporary files created at runtime will typically use derived types.
#line 4408
allow user_su_t tmp_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t tmp_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var.
#line 4408
allow user_su_t var_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/catman.
#line 4408
allow user_su_t catman_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t catman_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/lib.
#line 4408
allow user_su_t var_lib_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t var_lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_su_t var_lib_nfs_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t var_lib_nfs_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408

#line 4408
allow user_su_t tetex_data_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t tetex_data_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408

#line 4408
# Read /var/yp.
#line 4408
allow user_su_t var_yp_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t var_yp_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/spool.
#line 4408
allow user_su_t var_spool_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/run, /var/lock, /var/log.
#line 4408
allow user_su_t var_run_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_su_t var_log_t:dir { read getattr lock search ioctl };
#line 4408
#allow user_su_t var_log_t:{ file lnk_file } r_file_perms;
#line 4408
allow user_su_t var_log_sa_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t var_log_sa_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_su_t var_log_ksyms_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
allow user_su_t var_lock_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t var_lock_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/run/utmp and /var/log/wtmp.
#line 4408
allow user_su_t initrc_var_run_t:file { read getattr lock ioctl };
#line 4408
allow user_su_t wtmp_t:file { read getattr lock ioctl };
#line 4408

#line 4408
# Read /boot, /boot/System.map*, and /vmlinuz*
#line 4408
allow user_su_t boot_t:dir { search getattr };
#line 4408
allow user_su_t boot_t:file getattr;
#line 4408
allow user_su_t system_map_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
allow user_su_t boot_t:lnk_file read;
#line 4408

#line 4408
# Read /etc.
#line 4408
allow user_su_t etc_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_su_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_su_t etc_aliases_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_su_t etc_mail_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t etc_mail_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_su_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_su_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4408

#line 4408
# Read /lib.
#line 4408
allow user_su_t lib_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read the linker, shared library, and executable types.
#line 4408
allow user_su_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_su_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_su_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read man directories and files.
#line 4408
allow user_su_t man_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t man_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /usr/src.
#line 4408
allow user_su_t src_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t src_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read module-related files.
#line 4408
allow user_su_t modules_object_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t modules_object_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_su_t modules_dep_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_su_t modules_conf_t:{ file lnk_file} { read getattr lock ioctl };
#line 4408

#line 4408
# Read /dev directories and any symbolic links.
#line 4408
allow user_su_t device_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t device_t:lnk_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read /dev/random and /dev/zero.
#line 4408
allow user_su_t random_device_t:chr_file { read getattr lock ioctl };
#line 4408
allow user_su_t zero_device_t:chr_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read the root directory of a tmpfs filesytem and any symbolic links.
#line 4408
allow user_su_t tmpfs_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t tmpfs_t:lnk_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read any symbolic links on a devfs file system.
#line 4408
allow user_su_t device_t:lnk_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read the root directory of a usbdevfs filesystem, and
#line 4408
# the devices and drivers files.  Permit stating of the
#line 4408
# device nodes, but nothing else.
#line 4408
allow user_su_t usbdevfs_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t usbdevfs_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_su_t usbdevfs_device_t:file getattr;
#line 4408

#line 4408

#line 4408
# Grant write permissions to a small set of system file types.
#line 4408
# No permission to create files is granted here.  Use allow rules to grant 
#line 4408
# create permissions to a type or use file_type_auto_trans rules to set up
#line 4408
# new types for files.
#line 4408

#line 4408

#line 4408
# Read and write /dev/tty and /dev/null.
#line 4408
allow user_su_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4408
allow user_su_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408
# Do not audit write denials to /etc/ld.so.cache.
#line 4408
dontaudit user_su_t ld_so_cache_t:file write;
#line 4408

#line 4408

#line 4408
# Execute from the system shared libraries.
#line 4408
# No permission to execute anything else is granted here.
#line 4408
# Use can_exec or can_exec_any to grant the ability to execute within a domain.
#line 4408
# Use domain_auto_trans for executing and changing domains.
#line 4408

#line 4408
allow user_su_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t ld_so_t:file { read getattr lock execute ioctl };
#line 4408
allow user_su_t ld_so_t:file execute_no_trans;
#line 4408
allow user_su_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_su_t shlib_t:file { read getattr lock execute ioctl };
#line 4408
allow user_su_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_su_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4408
allow user_su_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408

#line 4408
# read localization information
#line 4408
allow user_su_t locale_t:dir { read getattr lock search ioctl };
#line 4408
allow user_su_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 4408

#line 4408
# Obtain the context of any SID, the SID for any context, 
#line 4408
# and the list of active SIDs.
#line 4408
allow user_su_t security_t:security { sid_to_context context_to_sid get_sids };
#line 4408

#line 4408

#line 4408

#line 4408
# Grant permissions needed to create TCP and UDP sockets and 
#line 4408
# to access the network.
#line 4408

#line 4408
#
#line 4408
# Allow the domain to create and use UDP and TCP sockets.
#line 4408
# Other kinds of sockets must be separately authorized for use.
#line 4408
allow user_su_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408
allow user_su_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send UDP packets.
#line 4408
# Since the destination sockets type is unknown, the generic
#line 4408
# any_socket_t type is used as a placeholder.
#line 4408
#
#line 4408
allow user_su_t any_socket_t:udp_socket sendto;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send using any network interface.
#line 4408
# netif_type is a type attribute for all network interface types.
#line 4408
#
#line 4408
allow user_su_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4408

#line 4408
#
#line 4408
# Allow packets sent by the domain to be received on any network interface.
#line 4408
#
#line 4408
allow user_su_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to receive packets from any network interface.
#line 4408
# netmsg_type is a type attribute for all default message types.
#line 4408
#
#line 4408
allow user_su_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to initiate or accept TCP connections 
#line 4408
# on any network interface.
#line 4408
#
#line 4408
allow user_su_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4408

#line 4408
#
#line 4408
# Receive resets from the TCP reset socket.
#line 4408
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4408
#
#line 4408
allow user_su_t tcp_socket_t:tcp_socket recvfrom;
#line 4408

#line 4408
dontaudit user_su_t tcp_socket_t:tcp_socket connectto;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send to any node.
#line 4408
# node_type is a type attribute for all node types.
#line 4408
#
#line 4408
allow user_su_t node_type:node { tcp_send udp_send rawip_send };
#line 4408

#line 4408
#
#line 4408
# Allow packets sent by the domain to be received from any node.
#line 4408
#
#line 4408
allow user_su_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send NFS client requests via the socket
#line 4408
# created by mount.
#line 4408
#
#line 4408
allow user_su_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408

#line 4408
#
#line 4408
# Bind to the default port type.
#line 4408
# Other port types must be separately authorized.
#line 4408
#
#line 4408
allow user_su_t port_t:udp_socket name_bind;
#line 4408
allow user_su_t port_t:tcp_socket name_bind;
#line 4408

#line 4408

#line 4408

#line 4408
# Use capabilities.
#line 4408
allow user_su_t self:capability { setuid setgid net_bind_service chown dac_override sys_nice sys_resource };
#line 4408

#line 4408
# Revert to the user domain when a shell is executed.
#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to transition to the new domain.
#line 4408
#
#line 4408
allow user_su_t user_t:process transition;
#line 4408

#line 4408
#
#line 4408
# Allow the process to execute the program.
#line 4408
# 
#line 4408
allow user_su_t shell_exec_t:file { getattr execute };
#line 4408

#line 4408
#
#line 4408
# Allow the process to reap the new domain.
#line 4408
#
#line 4408
allow user_t user_su_t:process sigchld;
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to inherit and use file 
#line 4408
# descriptions from the creating process and vice versa.
#line 4408
#
#line 4408
allow user_t user_su_t:fd use;
#line 4408
allow user_su_t user_t:fd use;
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to write back to the old domain via a pipe.
#line 4408
#
#line 4408
allow user_t user_su_t:fifo_file { ioctl read getattr lock write append };
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to read and execute the program.
#line 4408
#
#line 4408
allow user_t shell_exec_t:file { read getattr lock execute ioctl };
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to be entered via the program.
#line 4408
#
#line 4408
allow user_t shell_exec_t:file entrypoint;
#line 4408

#line 4408
type_transition user_su_t shell_exec_t:process user_t;
#line 4408

#line 4408

#line 4408
allow user_su_t privfd:fd use;
#line 4408

#line 4408
# Write to utmp.
#line 4408
allow user_su_t initrc_var_run_t:file { ioctl read getattr lock write append };
#line 4408

#line 4408

#line 4408

#line 4408
# Run chkpwd.
#line 4408

#line 4408
allow user_su_t chkpwd_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408

#line 4408
# Inherit and use descriptors from gnome-pty-helper.
#line 4408

#line 4408

#line 4408
# The user role is authorized for this domain.
#line 4408
role user_r types user_su_t;
#line 4408

#line 4408
# Write to the user domain tty.
#line 4408
allow user_su_t user_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4408
allow user_su_t user_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408
allow user_su_t user_home_dir_t:dir search;
#line 4408

#line 4408
# Modify .Xauthority file (via xauth program).
#line 4408

#line 4408

#line 4408
# Access sshd cookie files.
#line 4408
allow user_su_t sshd_tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4408
allow user_su_t sshd_tmp_t:file { ioctl read getattr lock write append };
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to modify the directory.
#line 4408
#
#line 4408
allow user_su_t sshd_tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4408

#line 4408
#
#line 4408
# Allow the process to create the file.
#line 4408
#
#line 4408

#line 4408
allow user_su_t user_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4408
allow user_su_t user_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4408

#line 4408

#line 4408

#line 4408
type_transition user_su_t sshd_tmp_t:dir user_tmp_t;
#line 4408
type_transition user_su_t sshd_tmp_t:{ file lnk_file sock_file fifo_file } user_tmp_t;
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
# stop su complaining if you run it from a directory with restrictive perms
#line 4408
dontaudit user_su_t file_type:dir search;
#line 4408

#line 4408

#line 4408
# Derived domain based on the calling user domain and the program.
#line 4408
type user_chkpwd_t, domain, privlog, auth;
#line 4408

#line 4408
# Transition from the user domain to this domain.
#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to transition to the new domain.
#line 4408
#
#line 4408
allow user_t user_chkpwd_t:process transition;
#line 4408

#line 4408
#
#line 4408
# Allow the process to execute the program.
#line 4408
# 
#line 4408
allow user_t chkpwd_exec_t:file { getattr execute };
#line 4408

#line 4408
#
#line 4408
# Allow the process to reap the new domain.
#line 4408
#
#line 4408
allow user_chkpwd_t user_t:process sigchld;
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to inherit and use file 
#line 4408
# descriptions from the creating process and vice versa.
#line 4408
#
#line 4408
allow user_chkpwd_t user_t:fd use;
#line 4408
allow user_t user_chkpwd_t:fd use;
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to write back to the old domain via a pipe.
#line 4408
#
#line 4408
allow user_chkpwd_t user_t:fifo_file { ioctl read getattr lock write append };
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to read and execute the program.
#line 4408
#
#line 4408
allow user_chkpwd_t chkpwd_exec_t:file { read getattr lock execute ioctl };
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to be entered via the program.
#line 4408
#
#line 4408
allow user_chkpwd_t chkpwd_exec_t:file entrypoint;
#line 4408

#line 4408
type_transition user_t chkpwd_exec_t:process user_chkpwd_t;
#line 4408

#line 4408

#line 4408
# The user role is authorized for this domain.
#line 4408
role user_r types user_chkpwd_t;
#line 4408

#line 4408
# This domain is granted permissions common to most domains (includes can_net)
#line 4408

#line 4408

#line 4408
# Grant the permissions common to the test domains.
#line 4408

#line 4408
# Grant permissions within the domain.
#line 4408

#line 4408
# Access other processes in the same domain.
#line 4408
allow user_chkpwd_t self:process *;
#line 4408

#line 4408
# Access /proc/PID files for processes in the same domain.
#line 4408
allow user_chkpwd_t self:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Access file descriptions, pipes, and sockets
#line 4408
# created by processes in the same domain.
#line 4408
allow user_chkpwd_t self:fd *;
#line 4408
allow user_chkpwd_t self:fifo_file { ioctl read getattr lock write append };
#line 4408
allow user_chkpwd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408
allow user_chkpwd_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4408

#line 4408
# Allow the domain to communicate with other processes in the same domain.
#line 4408
allow user_chkpwd_t self:unix_dgram_socket sendto;
#line 4408
allow user_chkpwd_t self:unix_stream_socket connectto;
#line 4408

#line 4408
# Access System V IPC objects created by processes in the same domain.
#line 4408
allow user_chkpwd_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4408
allow user_chkpwd_t self:msg  { send receive };
#line 4408
allow user_chkpwd_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4408
allow user_chkpwd_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4408

#line 4408

#line 4408

#line 4408
# Grant read/search permissions to most of /proc.
#line 4408

#line 4408
# Read system information files in /proc.
#line 4408
allow user_chkpwd_t proc_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Stat /proc/kmsg and /proc/kcore.
#line 4408
allow user_chkpwd_t proc_kmsg_t:file { getattr };
#line 4408
allow user_chkpwd_t proc_kcore_t:file { getattr };
#line 4408

#line 4408
# Read system variables in /proc/sys.
#line 4408
allow user_chkpwd_t sysctl_modprobe_t:file { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t sysctl_t:file { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t sysctl_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t sysctl_fs_t:file { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t sysctl_kernel_t:file { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t sysctl_net_t:file { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t sysctl_vm_t:file { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t sysctl_dev_t:file { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408

#line 4408
# Grant read/search permissions to many system file types.
#line 4408

#line 4408

#line 4408
# Get attributes of file systems.
#line 4408
allow user_chkpwd_t fs_type:filesystem getattr;
#line 4408

#line 4408

#line 4408
# Read /.
#line 4408
allow user_chkpwd_t root_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /home.
#line 4408
allow user_chkpwd_t home_root_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408
# Read /usr.
#line 4408
allow user_chkpwd_t usr_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read bin and sbin directories.
#line 4408
allow user_chkpwd_t bin_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t sbin_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408

#line 4408
# Read directories and files with the readable_t type.
#line 4408
# This type is a general type for "world"-readable files.
#line 4408
allow user_chkpwd_t readable_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Stat /...security and lost+found.
#line 4408
allow user_chkpwd_t file_labels_t:dir getattr;
#line 4408
allow user_chkpwd_t lost_found_t:dir getattr;
#line 4408

#line 4408
# Read the devpts root directory.  
#line 4408
allow user_chkpwd_t devpts_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408

#line 4408
# Read the /tmp directory and any /tmp files with the base type.
#line 4408
# Temporary files created at runtime will typically use derived types.
#line 4408
allow user_chkpwd_t tmp_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t tmp_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var.
#line 4408
allow user_chkpwd_t var_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/catman.
#line 4408
allow user_chkpwd_t catman_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t catman_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/lib.
#line 4408
allow user_chkpwd_t var_lib_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t var_lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t var_lib_nfs_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t var_lib_nfs_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408

#line 4408
allow user_chkpwd_t tetex_data_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t tetex_data_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408

#line 4408
# Read /var/yp.
#line 4408
allow user_chkpwd_t var_yp_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t var_yp_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/spool.
#line 4408
allow user_chkpwd_t var_spool_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/run, /var/lock, /var/log.
#line 4408
allow user_chkpwd_t var_run_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t var_log_t:dir { read getattr lock search ioctl };
#line 4408
#allow user_chkpwd_t var_log_t:{ file lnk_file } r_file_perms;
#line 4408
allow user_chkpwd_t var_log_sa_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t var_log_sa_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t var_log_ksyms_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
allow user_chkpwd_t var_lock_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t var_lock_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/run/utmp and /var/log/wtmp.
#line 4408
allow user_chkpwd_t initrc_var_run_t:file { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t wtmp_t:file { read getattr lock ioctl };
#line 4408

#line 4408
# Read /boot, /boot/System.map*, and /vmlinuz*
#line 4408
allow user_chkpwd_t boot_t:dir { search getattr };
#line 4408
allow user_chkpwd_t boot_t:file getattr;
#line 4408
allow user_chkpwd_t system_map_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
allow user_chkpwd_t boot_t:lnk_file read;
#line 4408

#line 4408
# Read /etc.
#line 4408
allow user_chkpwd_t etc_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t etc_aliases_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t etc_mail_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t etc_mail_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4408

#line 4408
# Read /lib.
#line 4408
allow user_chkpwd_t lib_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read the linker, shared library, and executable types.
#line 4408
allow user_chkpwd_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read man directories and files.
#line 4408
allow user_chkpwd_t man_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t man_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /usr/src.
#line 4408
allow user_chkpwd_t src_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t src_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read module-related files.
#line 4408
allow user_chkpwd_t modules_object_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t modules_object_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t modules_dep_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t modules_conf_t:{ file lnk_file} { read getattr lock ioctl };
#line 4408

#line 4408
# Read /dev directories and any symbolic links.
#line 4408
allow user_chkpwd_t device_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t device_t:lnk_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read /dev/random and /dev/zero.
#line 4408
allow user_chkpwd_t random_device_t:chr_file { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t zero_device_t:chr_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read the root directory of a tmpfs filesytem and any symbolic links.
#line 4408
allow user_chkpwd_t tmpfs_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t tmpfs_t:lnk_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read any symbolic links on a devfs file system.
#line 4408
allow user_chkpwd_t device_t:lnk_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read the root directory of a usbdevfs filesystem, and
#line 4408
# the devices and drivers files.  Permit stating of the
#line 4408
# device nodes, but nothing else.
#line 4408
allow user_chkpwd_t usbdevfs_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t usbdevfs_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t usbdevfs_device_t:file getattr;
#line 4408

#line 4408

#line 4408
# Grant write permissions to a small set of system file types.
#line 4408
# No permission to create files is granted here.  Use allow rules to grant 
#line 4408
# create permissions to a type or use file_type_auto_trans rules to set up
#line 4408
# new types for files.
#line 4408

#line 4408

#line 4408
# Read and write /dev/tty and /dev/null.
#line 4408
allow user_chkpwd_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4408
allow user_chkpwd_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408
# Do not audit write denials to /etc/ld.so.cache.
#line 4408
dontaudit user_chkpwd_t ld_so_cache_t:file write;
#line 4408

#line 4408

#line 4408
# Execute from the system shared libraries.
#line 4408
# No permission to execute anything else is granted here.
#line 4408
# Use can_exec or can_exec_any to grant the ability to execute within a domain.
#line 4408
# Use domain_auto_trans for executing and changing domains.
#line 4408

#line 4408
allow user_chkpwd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t ld_so_t:file { read getattr lock execute ioctl };
#line 4408
allow user_chkpwd_t ld_so_t:file execute_no_trans;
#line 4408
allow user_chkpwd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t shlib_t:file { read getattr lock execute ioctl };
#line 4408
allow user_chkpwd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4408
allow user_chkpwd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408

#line 4408
# read localization information
#line 4408
allow user_chkpwd_t locale_t:dir { read getattr lock search ioctl };
#line 4408
allow user_chkpwd_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 4408

#line 4408
# Obtain the context of any SID, the SID for any context, 
#line 4408
# and the list of active SIDs.
#line 4408
allow user_chkpwd_t security_t:security { sid_to_context context_to_sid get_sids };
#line 4408

#line 4408

#line 4408

#line 4408
# Grant permissions needed to create TCP and UDP sockets and 
#line 4408
# to access the network.
#line 4408

#line 4408
#
#line 4408
# Allow the domain to create and use UDP and TCP sockets.
#line 4408
# Other kinds of sockets must be separately authorized for use.
#line 4408
allow user_chkpwd_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408
allow user_chkpwd_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send UDP packets.
#line 4408
# Since the destination sockets type is unknown, the generic
#line 4408
# any_socket_t type is used as a placeholder.
#line 4408
#
#line 4408
allow user_chkpwd_t any_socket_t:udp_socket sendto;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send using any network interface.
#line 4408
# netif_type is a type attribute for all network interface types.
#line 4408
#
#line 4408
allow user_chkpwd_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4408

#line 4408
#
#line 4408
# Allow packets sent by the domain to be received on any network interface.
#line 4408
#
#line 4408
allow user_chkpwd_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to receive packets from any network interface.
#line 4408
# netmsg_type is a type attribute for all default message types.
#line 4408
#
#line 4408
allow user_chkpwd_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to initiate or accept TCP connections 
#line 4408
# on any network interface.
#line 4408
#
#line 4408
allow user_chkpwd_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4408

#line 4408
#
#line 4408
# Receive resets from the TCP reset socket.
#line 4408
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4408
#
#line 4408
allow user_chkpwd_t tcp_socket_t:tcp_socket recvfrom;
#line 4408

#line 4408
dontaudit user_chkpwd_t tcp_socket_t:tcp_socket connectto;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send to any node.
#line 4408
# node_type is a type attribute for all node types.
#line 4408
#
#line 4408
allow user_chkpwd_t node_type:node { tcp_send udp_send rawip_send };
#line 4408

#line 4408
#
#line 4408
# Allow packets sent by the domain to be received from any node.
#line 4408
#
#line 4408
allow user_chkpwd_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send NFS client requests via the socket
#line 4408
# created by mount.
#line 4408
#
#line 4408
allow user_chkpwd_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408

#line 4408
#
#line 4408
# Bind to the default port type.
#line 4408
# Other port types must be separately authorized.
#line 4408
#
#line 4408
allow user_chkpwd_t port_t:udp_socket name_bind;
#line 4408
allow user_chkpwd_t port_t:tcp_socket name_bind;
#line 4408

#line 4408

#line 4408

#line 4408
# Use capabilities.
#line 4408
allow user_chkpwd_t self:capability setuid;
#line 4408

#line 4408
# Inherit and use descriptors from gnome-pty-helper.
#line 4408

#line 4408

#line 4408
# Inherit and use descriptors from newrole.
#line 4408
allow user_chkpwd_t newrole_t:fd use;
#line 4408

#line 4408
# Write to the user domain tty.
#line 4408
allow user_chkpwd_t user_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4408
allow user_chkpwd_t user_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
# Derived domain based on the calling user domain and the program.
#line 4408
type user_crontab_t, domain, privlog;
#line 4408

#line 4408
# Transition from the user domain to the derived domain.
#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to transition to the new domain.
#line 4408
#
#line 4408
allow user_t user_crontab_t:process transition;
#line 4408

#line 4408
#
#line 4408
# Allow the process to execute the program.
#line 4408
# 
#line 4408
allow user_t crontab_exec_t:file { getattr execute };
#line 4408

#line 4408
#
#line 4408
# Allow the process to reap the new domain.
#line 4408
#
#line 4408
allow user_crontab_t user_t:process sigchld;
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to inherit and use file 
#line 4408
# descriptions from the creating process and vice versa.
#line 4408
#
#line 4408
allow user_crontab_t user_t:fd use;
#line 4408
allow user_t user_crontab_t:fd use;
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to write back to the old domain via a pipe.
#line 4408
#
#line 4408
allow user_crontab_t user_t:fifo_file { ioctl read getattr lock write append };
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to read and execute the program.
#line 4408
#
#line 4408
allow user_crontab_t crontab_exec_t:file { read getattr lock execute ioctl };
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to be entered via the program.
#line 4408
#
#line 4408
allow user_crontab_t crontab_exec_t:file entrypoint;
#line 4408

#line 4408
type_transition user_t crontab_exec_t:process user_crontab_t;
#line 4408

#line 4408

#line 4408
# The user role is authorized for this domain.
#line 4408
role user_r types user_crontab_t;
#line 4408

#line 4408
# This domain is granted permissions common to most domains (including can_net)
#line 4408

#line 4408

#line 4408
# Grant the permissions common to the test domains.
#line 4408

#line 4408
# Grant permissions within the domain.
#line 4408

#line 4408
# Access other processes in the same domain.
#line 4408
allow user_crontab_t self:process *;
#line 4408

#line 4408
# Access /proc/PID files for processes in the same domain.
#line 4408
allow user_crontab_t self:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Access file descriptions, pipes, and sockets
#line 4408
# created by processes in the same domain.
#line 4408
allow user_crontab_t self:fd *;
#line 4408
allow user_crontab_t self:fifo_file { ioctl read getattr lock write append };
#line 4408
allow user_crontab_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408
allow user_crontab_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4408

#line 4408
# Allow the domain to communicate with other processes in the same domain.
#line 4408
allow user_crontab_t self:unix_dgram_socket sendto;
#line 4408
allow user_crontab_t self:unix_stream_socket connectto;
#line 4408

#line 4408
# Access System V IPC objects created by processes in the same domain.
#line 4408
allow user_crontab_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4408
allow user_crontab_t self:msg  { send receive };
#line 4408
allow user_crontab_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4408
allow user_crontab_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4408

#line 4408

#line 4408

#line 4408
# Grant read/search permissions to most of /proc.
#line 4408

#line 4408
# Read system information files in /proc.
#line 4408
allow user_crontab_t proc_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Stat /proc/kmsg and /proc/kcore.
#line 4408
allow user_crontab_t proc_kmsg_t:file { getattr };
#line 4408
allow user_crontab_t proc_kcore_t:file { getattr };
#line 4408

#line 4408
# Read system variables in /proc/sys.
#line 4408
allow user_crontab_t sysctl_modprobe_t:file { read getattr lock ioctl };
#line 4408
allow user_crontab_t sysctl_t:file { read getattr lock ioctl };
#line 4408
allow user_crontab_t sysctl_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t sysctl_fs_t:file { read getattr lock ioctl };
#line 4408
allow user_crontab_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t sysctl_kernel_t:file { read getattr lock ioctl };
#line 4408
allow user_crontab_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t sysctl_net_t:file { read getattr lock ioctl };
#line 4408
allow user_crontab_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t sysctl_vm_t:file { read getattr lock ioctl };
#line 4408
allow user_crontab_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t sysctl_dev_t:file { read getattr lock ioctl };
#line 4408
allow user_crontab_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408

#line 4408
# Grant read/search permissions to many system file types.
#line 4408

#line 4408

#line 4408
# Get attributes of file systems.
#line 4408
allow user_crontab_t fs_type:filesystem getattr;
#line 4408

#line 4408

#line 4408
# Read /.
#line 4408
allow user_crontab_t root_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /home.
#line 4408
allow user_crontab_t home_root_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408
# Read /usr.
#line 4408
allow user_crontab_t usr_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read bin and sbin directories.
#line 4408
allow user_crontab_t bin_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_crontab_t sbin_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408

#line 4408
# Read directories and files with the readable_t type.
#line 4408
# This type is a general type for "world"-readable files.
#line 4408
allow user_crontab_t readable_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Stat /...security and lost+found.
#line 4408
allow user_crontab_t file_labels_t:dir getattr;
#line 4408
allow user_crontab_t lost_found_t:dir getattr;
#line 4408

#line 4408
# Read the devpts root directory.  
#line 4408
allow user_crontab_t devpts_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408

#line 4408
# Read the /tmp directory and any /tmp files with the base type.
#line 4408
# Temporary files created at runtime will typically use derived types.
#line 4408
allow user_crontab_t tmp_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t tmp_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var.
#line 4408
allow user_crontab_t var_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/catman.
#line 4408
allow user_crontab_t catman_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t catman_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/lib.
#line 4408
allow user_crontab_t var_lib_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t var_lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_crontab_t var_lib_nfs_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t var_lib_nfs_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408

#line 4408
allow user_crontab_t tetex_data_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t tetex_data_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408

#line 4408
# Read /var/yp.
#line 4408
allow user_crontab_t var_yp_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t var_yp_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/spool.
#line 4408
allow user_crontab_t var_spool_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/run, /var/lock, /var/log.
#line 4408
allow user_crontab_t var_run_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crontab_t var_log_t:dir { read getattr lock search ioctl };
#line 4408
#allow user_crontab_t var_log_t:{ file lnk_file } r_file_perms;
#line 4408
allow user_crontab_t var_log_sa_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t var_log_sa_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crontab_t var_log_ksyms_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
allow user_crontab_t var_lock_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t var_lock_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/run/utmp and /var/log/wtmp.
#line 4408
allow user_crontab_t initrc_var_run_t:file { read getattr lock ioctl };
#line 4408
allow user_crontab_t wtmp_t:file { read getattr lock ioctl };
#line 4408

#line 4408
# Read /boot, /boot/System.map*, and /vmlinuz*
#line 4408
allow user_crontab_t boot_t:dir { search getattr };
#line 4408
allow user_crontab_t boot_t:file getattr;
#line 4408
allow user_crontab_t system_map_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
allow user_crontab_t boot_t:lnk_file read;
#line 4408

#line 4408
# Read /etc.
#line 4408
allow user_crontab_t etc_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_crontab_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crontab_t etc_aliases_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crontab_t etc_mail_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t etc_mail_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crontab_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crontab_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4408

#line 4408
# Read /lib.
#line 4408
allow user_crontab_t lib_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read the linker, shared library, and executable types.
#line 4408
allow user_crontab_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crontab_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crontab_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read man directories and files.
#line 4408
allow user_crontab_t man_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t man_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /usr/src.
#line 4408
allow user_crontab_t src_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t src_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read module-related files.
#line 4408
allow user_crontab_t modules_object_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t modules_object_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crontab_t modules_dep_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crontab_t modules_conf_t:{ file lnk_file} { read getattr lock ioctl };
#line 4408

#line 4408
# Read /dev directories and any symbolic links.
#line 4408
allow user_crontab_t device_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t device_t:lnk_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read /dev/random and /dev/zero.
#line 4408
allow user_crontab_t random_device_t:chr_file { read getattr lock ioctl };
#line 4408
allow user_crontab_t zero_device_t:chr_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read the root directory of a tmpfs filesytem and any symbolic links.
#line 4408
allow user_crontab_t tmpfs_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t tmpfs_t:lnk_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read any symbolic links on a devfs file system.
#line 4408
allow user_crontab_t device_t:lnk_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read the root directory of a usbdevfs filesystem, and
#line 4408
# the devices and drivers files.  Permit stating of the
#line 4408
# device nodes, but nothing else.
#line 4408
allow user_crontab_t usbdevfs_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t usbdevfs_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crontab_t usbdevfs_device_t:file getattr;
#line 4408

#line 4408

#line 4408
# Grant write permissions to a small set of system file types.
#line 4408
# No permission to create files is granted here.  Use allow rules to grant 
#line 4408
# create permissions to a type or use file_type_auto_trans rules to set up
#line 4408
# new types for files.
#line 4408

#line 4408

#line 4408
# Read and write /dev/tty and /dev/null.
#line 4408
allow user_crontab_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4408
allow user_crontab_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408
# Do not audit write denials to /etc/ld.so.cache.
#line 4408
dontaudit user_crontab_t ld_so_cache_t:file write;
#line 4408

#line 4408

#line 4408
# Execute from the system shared libraries.
#line 4408
# No permission to execute anything else is granted here.
#line 4408
# Use can_exec or can_exec_any to grant the ability to execute within a domain.
#line 4408
# Use domain_auto_trans for executing and changing domains.
#line 4408

#line 4408
allow user_crontab_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t ld_so_t:file { read getattr lock execute ioctl };
#line 4408
allow user_crontab_t ld_so_t:file execute_no_trans;
#line 4408
allow user_crontab_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_crontab_t shlib_t:file { read getattr lock execute ioctl };
#line 4408
allow user_crontab_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_crontab_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4408
allow user_crontab_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408

#line 4408
# read localization information
#line 4408
allow user_crontab_t locale_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crontab_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 4408

#line 4408
# Obtain the context of any SID, the SID for any context, 
#line 4408
# and the list of active SIDs.
#line 4408
allow user_crontab_t security_t:security { sid_to_context context_to_sid get_sids };
#line 4408

#line 4408

#line 4408

#line 4408
# Grant permissions needed to create TCP and UDP sockets and 
#line 4408
# to access the network.
#line 4408

#line 4408
#
#line 4408
# Allow the domain to create and use UDP and TCP sockets.
#line 4408
# Other kinds of sockets must be separately authorized for use.
#line 4408
allow user_crontab_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408
allow user_crontab_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send UDP packets.
#line 4408
# Since the destination sockets type is unknown, the generic
#line 4408
# any_socket_t type is used as a placeholder.
#line 4408
#
#line 4408
allow user_crontab_t any_socket_t:udp_socket sendto;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send using any network interface.
#line 4408
# netif_type is a type attribute for all network interface types.
#line 4408
#
#line 4408
allow user_crontab_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4408

#line 4408
#
#line 4408
# Allow packets sent by the domain to be received on any network interface.
#line 4408
#
#line 4408
allow user_crontab_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to receive packets from any network interface.
#line 4408
# netmsg_type is a type attribute for all default message types.
#line 4408
#
#line 4408
allow user_crontab_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to initiate or accept TCP connections 
#line 4408
# on any network interface.
#line 4408
#
#line 4408
allow user_crontab_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4408

#line 4408
#
#line 4408
# Receive resets from the TCP reset socket.
#line 4408
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4408
#
#line 4408
allow user_crontab_t tcp_socket_t:tcp_socket recvfrom;
#line 4408

#line 4408
dontaudit user_crontab_t tcp_socket_t:tcp_socket connectto;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send to any node.
#line 4408
# node_type is a type attribute for all node types.
#line 4408
#
#line 4408
allow user_crontab_t node_type:node { tcp_send udp_send rawip_send };
#line 4408

#line 4408
#
#line 4408
# Allow packets sent by the domain to be received from any node.
#line 4408
#
#line 4408
allow user_crontab_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send NFS client requests via the socket
#line 4408
# created by mount.
#line 4408
#
#line 4408
allow user_crontab_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408

#line 4408
#
#line 4408
# Bind to the default port type.
#line 4408
# Other port types must be separately authorized.
#line 4408
#
#line 4408
allow user_crontab_t port_t:udp_socket name_bind;
#line 4408
allow user_crontab_t port_t:tcp_socket name_bind;
#line 4408

#line 4408

#line 4408

#line 4408
# Use capabilities
#line 4408
allow user_crontab_t user_crontab_t:capability { setuid setgid chown };
#line 4408

#line 4408
# Type for temporary files.
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to modify the directory.
#line 4408
#
#line 4408
allow user_crontab_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4408

#line 4408
#
#line 4408
# Allow the process to create the file.
#line 4408
#
#line 4408

#line 4408
allow user_crontab_t user_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4408
allow user_crontab_t user_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4408

#line 4408

#line 4408

#line 4408
type_transition user_crontab_t tmp_t:dir user_tmp_t;
#line 4408
type_transition user_crontab_t tmp_t:{ file lnk_file sock_file fifo_file } user_tmp_t;
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
# Type of user crontabs once moved to cron spool.
#line 4408
type user_cron_spool_t, file_type, sysadmfile;
#line 4408
# Use the type when creating files in /var/spool/cron.
#line 4408
allow sysadm_crontab_t user_cron_spool_t:file { getattr read };
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to modify the directory.
#line 4408
#
#line 4408
allow user_crontab_t cron_spool_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4408

#line 4408
#
#line 4408
# Allow the process to create the file.
#line 4408
#
#line 4408

#line 4408
allow user_crontab_t user_cron_spool_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4408
allow user_crontab_t user_cron_spool_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4408

#line 4408

#line 4408

#line 4408
type_transition user_crontab_t cron_spool_t:dir user_cron_spool_t;
#line 4408
type_transition user_crontab_t cron_spool_t:{ file lnk_file sock_file fifo_file } user_cron_spool_t;
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
# crontab signals crond by updating the mtime on the spooldir
#line 4408
allow user_crontab_t cron_spool_t:dir setattr;
#line 4408
# Allow crond to read those crontabs in cron spool.
#line 4408
allow crond_t user_cron_spool_t:file { read getattr lock ioctl };
#line 4408

#line 4408
# Run helper programs as user_t
#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to transition to the new domain.
#line 4408
#
#line 4408
allow user_crontab_t user_t:process transition;
#line 4408

#line 4408
#
#line 4408
# Allow the process to execute the program.
#line 4408
# 
#line 4408
allow user_crontab_t { bin_t sbin_t exec_type }:file { getattr execute };
#line 4408

#line 4408
#
#line 4408
# Allow the process to reap the new domain.
#line 4408
#
#line 4408
allow user_t user_crontab_t:process sigchld;
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to inherit and use file 
#line 4408
# descriptions from the creating process and vice versa.
#line 4408
#
#line 4408
allow user_t user_crontab_t:fd use;
#line 4408
allow user_crontab_t user_t:fd use;
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to write back to the old domain via a pipe.
#line 4408
#
#line 4408
allow user_t user_crontab_t:fifo_file { ioctl read getattr lock write append };
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to read and execute the program.
#line 4408
#
#line 4408
allow user_t { bin_t sbin_t exec_type }:file { read getattr lock execute ioctl };
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to be entered via the program.
#line 4408
#
#line 4408
allow user_t { bin_t sbin_t exec_type }:file entrypoint;
#line 4408

#line 4408
type_transition user_crontab_t { bin_t sbin_t exec_type }:process user_t;
#line 4408

#line 4408

#line 4408
# Read user crontabs 
#line 4408
allow user_crontab_t { user_home_t user_home_dir_t }:dir { read getattr lock search ioctl };  
#line 4408
allow user_crontab_t user_home_t:file { read getattr lock ioctl };  
#line 4408
dontaudit user_crontab_t user_home_dir_t:dir write;
#line 4408

#line 4408
# Access the cron log file.
#line 4408
allow user_crontab_t cron_log_t:file { read getattr lock ioctl };
#line 4408
allow user_crontab_t cron_log_t:file { append };
#line 4408

#line 4408
# Access terminals.
#line 4408
allow user_crontab_t user_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4408
allow user_crontab_t user_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408
# Inherit and use descriptors from gnome-pty-helper.
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
# Derived domain based on the calling user domain and the program.
#line 4408
type user_ssh_t, domain, privlog;
#line 4408

#line 4408
# Transition from the user domain to the derived domain.
#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to transition to the new domain.
#line 4408
#
#line 4408
allow user_t user_ssh_t:process transition;
#line 4408

#line 4408
#
#line 4408
# Allow the process to execute the program.
#line 4408
# 
#line 4408
allow user_t ssh_exec_t:file { getattr execute };
#line 4408

#line 4408
#
#line 4408
# Allow the process to reap the new domain.
#line 4408
#
#line 4408
allow user_ssh_t user_t:process sigchld;
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to inherit and use file 
#line 4408
# descriptions from the creating process and vice versa.
#line 4408
#
#line 4408
allow user_ssh_t user_t:fd use;
#line 4408
allow user_t user_ssh_t:fd use;
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to write back to the old domain via a pipe.
#line 4408
#
#line 4408
allow user_ssh_t user_t:fifo_file { ioctl read getattr lock write append };
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to read and execute the program.
#line 4408
#
#line 4408
allow user_ssh_t ssh_exec_t:file { read getattr lock execute ioctl };
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to be entered via the program.
#line 4408
#
#line 4408
allow user_ssh_t ssh_exec_t:file entrypoint;
#line 4408

#line 4408
type_transition user_t ssh_exec_t:process user_ssh_t;
#line 4408

#line 4408

#line 4408
# The user role is authorized for this domain.
#line 4408
role user_r types user_ssh_t;
#line 4408

#line 4408
# Grant permissions within the domain.
#line 4408

#line 4408
# Access other processes in the same domain.
#line 4408
allow user_ssh_t self:process *;
#line 4408

#line 4408
# Access /proc/PID files for processes in the same domain.
#line 4408
allow user_ssh_t self:dir { read getattr lock search ioctl };
#line 4408
allow user_ssh_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Access file descriptions, pipes, and sockets
#line 4408
# created by processes in the same domain.
#line 4408
allow user_ssh_t self:fd *;
#line 4408
allow user_ssh_t self:fifo_file { ioctl read getattr lock write append };
#line 4408
allow user_ssh_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408
allow user_ssh_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4408

#line 4408
# Allow the domain to communicate with other processes in the same domain.
#line 4408
allow user_ssh_t self:unix_dgram_socket sendto;
#line 4408
allow user_ssh_t self:unix_stream_socket connectto;
#line 4408

#line 4408
# Access System V IPC objects created by processes in the same domain.
#line 4408
allow user_ssh_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4408
allow user_ssh_t self:msg  { send receive };
#line 4408
allow user_ssh_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4408
allow user_ssh_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4408

#line 4408

#line 4408

#line 4408
# Use descriptors created by sshd
#line 4408
allow user_ssh_t privfd:fd use;
#line 4408

#line 4408

#line 4408
allow user_ssh_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4408
allow user_ssh_t ld_so_t:file { read getattr lock execute ioctl };
#line 4408
allow user_ssh_t ld_so_t:file execute_no_trans;
#line 4408
allow user_ssh_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_ssh_t shlib_t:file { read getattr lock execute ioctl };
#line 4408
allow user_ssh_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_ssh_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4408
allow user_ssh_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408

#line 4408
# read localization information
#line 4408
allow user_ssh_t locale_t:dir { read getattr lock search ioctl };
#line 4408
allow user_ssh_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 4408

#line 4408
# Get attributes of file systems.
#line 4408
allow user_ssh_t fs_type:filesystem getattr;
#line 4408

#line 4408

#line 4408
# Read /.
#line 4408
allow user_ssh_t root_t:dir { read getattr lock search ioctl };
#line 4408
allow user_ssh_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /home.
#line 4408
allow user_ssh_t home_root_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408
# Read /usr.
#line 4408
allow user_ssh_t usr_t:dir { read getattr lock search ioctl };
#line 4408
allow user_ssh_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read bin and sbin directories.
#line 4408
allow user_ssh_t bin_t:dir { read getattr lock search ioctl };
#line 4408
allow user_ssh_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_ssh_t sbin_t:dir { read getattr lock search ioctl };
#line 4408
allow user_ssh_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408

#line 4408
# Read the devpts root directory.
#line 4408
allow user_ssh_t devpts_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408
# Read /var.
#line 4408
allow user_ssh_t var_t:dir { read getattr lock search ioctl };
#line 4408
allow user_ssh_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/run, /var/log.
#line 4408
allow user_ssh_t var_run_t:dir { read getattr lock search ioctl };
#line 4408
allow user_ssh_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_ssh_t var_log_t:dir { read getattr lock search ioctl };
#line 4408
allow user_ssh_t var_log_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /etc.
#line 4408
allow user_ssh_t etc_t:dir { read getattr lock search ioctl };
#line 4408
allow user_ssh_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_ssh_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_ssh_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read the linker, shared library, and executable types.
#line 4408
allow user_ssh_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_ssh_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_ssh_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /dev directories and any symbolic links.
#line 4408
allow user_ssh_t device_t:dir { read getattr lock search ioctl };
#line 4408
allow user_ssh_t device_t:lnk_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read /dev/random.
#line 4408
allow user_ssh_t random_device_t:chr_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read and write /dev/tty and /dev/null.
#line 4408
allow user_ssh_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4408
allow user_ssh_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408
# Grant permissions needed to create TCP and UDP sockets and
#line 4408
# to access the network.
#line 4408

#line 4408
#
#line 4408
# Allow the domain to create and use UDP and TCP sockets.
#line 4408
# Other kinds of sockets must be separately authorized for use.
#line 4408
allow user_ssh_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408
allow user_ssh_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send UDP packets.
#line 4408
# Since the destination sockets type is unknown, the generic
#line 4408
# any_socket_t type is used as a placeholder.
#line 4408
#
#line 4408
allow user_ssh_t any_socket_t:udp_socket sendto;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send using any network interface.
#line 4408
# netif_type is a type attribute for all network interface types.
#line 4408
#
#line 4408
allow user_ssh_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4408

#line 4408
#
#line 4408
# Allow packets sent by the domain to be received on any network interface.
#line 4408
#
#line 4408
allow user_ssh_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to receive packets from any network interface.
#line 4408
# netmsg_type is a type attribute for all default message types.
#line 4408
#
#line 4408
allow user_ssh_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to initiate or accept TCP connections 
#line 4408
# on any network interface.
#line 4408
#
#line 4408
allow user_ssh_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4408

#line 4408
#
#line 4408
# Receive resets from the TCP reset socket.
#line 4408
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4408
#
#line 4408
allow user_ssh_t tcp_socket_t:tcp_socket recvfrom;
#line 4408

#line 4408
dontaudit user_ssh_t tcp_socket_t:tcp_socket connectto;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send to any node.
#line 4408
# node_type is a type attribute for all node types.
#line 4408
#
#line 4408
allow user_ssh_t node_type:node { tcp_send udp_send rawip_send };
#line 4408

#line 4408
#
#line 4408
# Allow packets sent by the domain to be received from any node.
#line 4408
#
#line 4408
allow user_ssh_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send NFS client requests via the socket
#line 4408
# created by mount.
#line 4408
#
#line 4408
allow user_ssh_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408

#line 4408
#
#line 4408
# Bind to the default port type.
#line 4408
# Other port types must be separately authorized.
#line 4408
#
#line 4408
allow user_ssh_t port_t:udp_socket name_bind;
#line 4408
allow user_ssh_t port_t:tcp_socket name_bind;
#line 4408

#line 4408

#line 4408
# for sshing to a ssh tunnel
#line 4408

#line 4408
allow user_ssh_t user_ssh_t:tcp_socket { connectto recvfrom };
#line 4408
allow user_ssh_t user_ssh_t:tcp_socket { acceptfrom recvfrom };
#line 4408
allow user_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4408
allow user_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4408

#line 4408

#line 4408
# Use capabilities.
#line 4408
allow user_ssh_t self:capability { setuid setgid dac_override dac_read_search };
#line 4408

#line 4408
# Run helpers.
#line 4408

#line 4408
allow user_ssh_t { bin_t sbin_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4408
allow user_ssh_t { bin_t sbin_t }:lnk_file read;
#line 4408

#line 4408
allow user_ssh_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4408
allow user_ssh_t ld_so_t:file { read getattr lock execute ioctl };
#line 4408
allow user_ssh_t ld_so_t:file execute_no_trans;
#line 4408
allow user_ssh_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_ssh_t shlib_t:file { read getattr lock execute ioctl };
#line 4408
allow user_ssh_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_ssh_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4408
allow user_ssh_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408

#line 4408
allow user_ssh_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408
allow user_ssh_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408
allow user_ssh_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408
allow user_ssh_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408
allow user_ssh_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408

#line 4408
# Read the ssh key file.
#line 4408
allow user_ssh_t sshd_key_t:file { read getattr lock ioctl };
#line 4408

#line 4408
# Access the ssh temporary files.
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to modify the directory.
#line 4408
#
#line 4408
allow user_ssh_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4408

#line 4408
#
#line 4408
# Allow the process to create the file.
#line 4408
#
#line 4408

#line 4408
allow user_ssh_t sshd_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4408
allow user_ssh_t sshd_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4408

#line 4408

#line 4408

#line 4408
type_transition user_ssh_t tmp_t:dir sshd_tmp_t;
#line 4408
type_transition user_ssh_t tmp_t:{ file lnk_file sock_file fifo_file } sshd_tmp_t;
#line 4408

#line 4408

#line 4408

#line 4408
allow user_ssh_t user_tmp_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408
# for rsync
#line 4408
allow user_ssh_t user_t:unix_stream_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408

#line 4408
# Access the users .ssh directory.
#line 4408
type user_home_ssh_t, file_type, sysadmfile;
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to modify the directory.
#line 4408
#
#line 4408
allow { sysadm_ssh_t user_ssh_t } user_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4408

#line 4408
#
#line 4408
# Allow the process to create the file.
#line 4408
#
#line 4408

#line 4408
allow { sysadm_ssh_t user_ssh_t } user_home_ssh_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4408
allow { sysadm_ssh_t user_ssh_t } user_home_ssh_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4408

#line 4408

#line 4408

#line 4408
type_transition { sysadm_ssh_t user_ssh_t } user_home_dir_t:dir user_home_ssh_t;
#line 4408
type_transition { sysadm_ssh_t user_ssh_t } user_home_dir_t:{ file lnk_file sock_file fifo_file } user_home_ssh_t;
#line 4408

#line 4408

#line 4408

#line 4408
allow { sysadm_ssh_t user_ssh_t } user_home_ssh_t:lnk_file { getattr read };
#line 4408
dontaudit user_ssh_t user_home_t:dir search;
#line 4408

#line 4408
allow sshd_t user_home_ssh_t:dir { read getattr lock search ioctl };
#line 4408
allow sshd_t user_home_ssh_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408

#line 4408
allow user_t user_home_ssh_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4408
allow user_t user_home_ssh_t:{ file lnk_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4408

#line 4408

#line 4408
# Inherit and use descriptors from gnome-pty-helper.
#line 4408

#line 4408

#line 4408
# Connect to sshd.
#line 4408

#line 4408
allow user_ssh_t sshd_t:tcp_socket { connectto recvfrom };
#line 4408
allow sshd_t user_ssh_t:tcp_socket { acceptfrom recvfrom };
#line 4408
allow sshd_t tcp_socket_t:tcp_socket { recvfrom };
#line 4408
allow user_ssh_t tcp_socket_t:tcp_socket { recvfrom };
#line 4408

#line 4408

#line 4408
# Write to the user domain tty.
#line 4408
allow user_ssh_t user_tty_device_t:chr_file { ioctl read getattr lock write append };
#line 4408
allow user_ssh_t user_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408
# Allow the user shell to signal the ssh program.
#line 4408
allow user_t user_ssh_t:process signal;
#line 4408
# allow ps to show ssh
#line 4408
allow user_t user_ssh_t:dir { search getattr read };
#line 4408
allow user_t user_ssh_t:{ file lnk_file } { read getattr };
#line 4408

#line 4408
# Allow the ssh program to communicate with ssh-agent.
#line 4408
allow user_ssh_t user_tmp_t:sock_file write;
#line 4408
allow user_ssh_t user_t:unix_stream_socket connectto;
#line 4408
allow user_ssh_t sshd_t:unix_stream_socket connectto;
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
# Instantiate a derived domain for user cron jobs.
#line 4408

#line 4408
# Derived domain for user cron jobs, user user_crond_domain if not system
#line 4408

#line 4408
type user_crond_t, domain, user_crond_domain;
#line 4408

#line 4408

#line 4408
# Permit a transition from the crond_t domain to this domain.
#line 4408
# The transition is requested explicitly by the modified crond 
#line 4408
# via execve_secure.  There is no way to set up an automatic
#line 4408
# transition, since crontabs are configuration files, not executables.
#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to transition to the new domain.
#line 4408
#
#line 4408
allow crond_t user_crond_t:process transition;
#line 4408

#line 4408
#
#line 4408
# Allow the process to execute the program.
#line 4408
# 
#line 4408
allow crond_t shell_exec_t:file { getattr execute };
#line 4408

#line 4408
#
#line 4408
# Allow the process to reap the new domain.
#line 4408
#
#line 4408
allow user_crond_t crond_t:process sigchld;
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to inherit and use file 
#line 4408
# descriptions from the creating process and vice versa.
#line 4408
#
#line 4408
allow user_crond_t crond_t:fd use;
#line 4408
allow crond_t user_crond_t:fd use;
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to write back to the old domain via a pipe.
#line 4408
#
#line 4408
allow user_crond_t crond_t:fifo_file { ioctl read getattr lock write append };
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to read and execute the program.
#line 4408
#
#line 4408
allow user_crond_t shell_exec_t:file { read getattr lock execute ioctl };
#line 4408

#line 4408
#
#line 4408
# Allow the new domain to be entered via the program.
#line 4408
#
#line 4408
allow user_crond_t shell_exec_t:file entrypoint;
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
# The user role is authorized for this domain.
#line 4408
role user_r types user_crond_t;
#line 4408

#line 4408
# This domain is granted permissions common to most domains.
#line 4408

#line 4408

#line 4408
# Grant the permissions common to the test domains.
#line 4408

#line 4408
# Grant permissions within the domain.
#line 4408

#line 4408
# Access other processes in the same domain.
#line 4408
allow user_crond_t self:process *;
#line 4408

#line 4408
# Access /proc/PID files for processes in the same domain.
#line 4408
allow user_crond_t self:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Access file descriptions, pipes, and sockets
#line 4408
# created by processes in the same domain.
#line 4408
allow user_crond_t self:fd *;
#line 4408
allow user_crond_t self:fifo_file { ioctl read getattr lock write append };
#line 4408
allow user_crond_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408
allow user_crond_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4408

#line 4408
# Allow the domain to communicate with other processes in the same domain.
#line 4408
allow user_crond_t self:unix_dgram_socket sendto;
#line 4408
allow user_crond_t self:unix_stream_socket connectto;
#line 4408

#line 4408
# Access System V IPC objects created by processes in the same domain.
#line 4408
allow user_crond_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4408
allow user_crond_t self:msg  { send receive };
#line 4408
allow user_crond_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4408
allow user_crond_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4408

#line 4408

#line 4408

#line 4408
# Grant read/search permissions to most of /proc.
#line 4408

#line 4408
# Read system information files in /proc.
#line 4408
allow user_crond_t proc_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Stat /proc/kmsg and /proc/kcore.
#line 4408
allow user_crond_t proc_kmsg_t:file { getattr };
#line 4408
allow user_crond_t proc_kcore_t:file { getattr };
#line 4408

#line 4408
# Read system variables in /proc/sys.
#line 4408
allow user_crond_t sysctl_modprobe_t:file { read getattr lock ioctl };
#line 4408
allow user_crond_t sysctl_t:file { read getattr lock ioctl };
#line 4408
allow user_crond_t sysctl_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t sysctl_fs_t:file { read getattr lock ioctl };
#line 4408
allow user_crond_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t sysctl_kernel_t:file { read getattr lock ioctl };
#line 4408
allow user_crond_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t sysctl_net_t:file { read getattr lock ioctl };
#line 4408
allow user_crond_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t sysctl_vm_t:file { read getattr lock ioctl };
#line 4408
allow user_crond_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t sysctl_dev_t:file { read getattr lock ioctl };
#line 4408
allow user_crond_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408

#line 4408
# Grant read/search permissions to many system file types.
#line 4408

#line 4408

#line 4408
# Get attributes of file systems.
#line 4408
allow user_crond_t fs_type:filesystem getattr;
#line 4408

#line 4408

#line 4408
# Read /.
#line 4408
allow user_crond_t root_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /home.
#line 4408
allow user_crond_t home_root_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408
# Read /usr.
#line 4408
allow user_crond_t usr_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read bin and sbin directories.
#line 4408
allow user_crond_t bin_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_crond_t sbin_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408

#line 4408
# Read directories and files with the readable_t type.
#line 4408
# This type is a general type for "world"-readable files.
#line 4408
allow user_crond_t readable_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Stat /...security and lost+found.
#line 4408
allow user_crond_t file_labels_t:dir getattr;
#line 4408
allow user_crond_t lost_found_t:dir getattr;
#line 4408

#line 4408
# Read the devpts root directory.  
#line 4408
allow user_crond_t devpts_t:dir { read getattr lock search ioctl };
#line 4408

#line 4408

#line 4408
# Read the /tmp directory and any /tmp files with the base type.
#line 4408
# Temporary files created at runtime will typically use derived types.
#line 4408
allow user_crond_t tmp_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t tmp_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var.
#line 4408
allow user_crond_t var_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/catman.
#line 4408
allow user_crond_t catman_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t catman_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/lib.
#line 4408
allow user_crond_t var_lib_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t var_lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_crond_t var_lib_nfs_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t var_lib_nfs_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408

#line 4408
allow user_crond_t tetex_data_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t tetex_data_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408

#line 4408
# Read /var/yp.
#line 4408
allow user_crond_t var_yp_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t var_yp_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/spool.
#line 4408
allow user_crond_t var_spool_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/run, /var/lock, /var/log.
#line 4408
allow user_crond_t var_run_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crond_t var_log_t:dir { read getattr lock search ioctl };
#line 4408
#allow user_crond_t var_log_t:{ file lnk_file } r_file_perms;
#line 4408
allow user_crond_t var_log_sa_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t var_log_sa_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crond_t var_log_ksyms_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
allow user_crond_t var_lock_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t var_lock_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /var/run/utmp and /var/log/wtmp.
#line 4408
allow user_crond_t initrc_var_run_t:file { read getattr lock ioctl };
#line 4408
allow user_crond_t wtmp_t:file { read getattr lock ioctl };
#line 4408

#line 4408
# Read /boot, /boot/System.map*, and /vmlinuz*
#line 4408
allow user_crond_t boot_t:dir { search getattr };
#line 4408
allow user_crond_t boot_t:file getattr;
#line 4408
allow user_crond_t system_map_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
allow user_crond_t boot_t:lnk_file read;
#line 4408

#line 4408
# Read /etc.
#line 4408
allow user_crond_t etc_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408
allow user_crond_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crond_t etc_aliases_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crond_t etc_mail_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t etc_mail_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crond_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crond_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4408

#line 4408
# Read /lib.
#line 4408
allow user_crond_t lib_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read the linker, shared library, and executable types.
#line 4408
allow user_crond_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crond_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crond_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read man directories and files.
#line 4408
allow user_crond_t man_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t man_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read /usr/src.
#line 4408
allow user_crond_t src_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t src_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Read module-related files.
#line 4408
allow user_crond_t modules_object_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t modules_object_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crond_t modules_dep_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crond_t modules_conf_t:{ file lnk_file} { read getattr lock ioctl };
#line 4408

#line 4408
# Read /dev directories and any symbolic links.
#line 4408
allow user_crond_t device_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t device_t:lnk_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read /dev/random and /dev/zero.
#line 4408
allow user_crond_t random_device_t:chr_file { read getattr lock ioctl };
#line 4408
allow user_crond_t zero_device_t:chr_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read the root directory of a tmpfs filesytem and any symbolic links.
#line 4408
allow user_crond_t tmpfs_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t tmpfs_t:lnk_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read any symbolic links on a devfs file system.
#line 4408
allow user_crond_t device_t:lnk_file { read getattr lock ioctl };
#line 4408

#line 4408
# Read the root directory of a usbdevfs filesystem, and
#line 4408
# the devices and drivers files.  Permit stating of the
#line 4408
# device nodes, but nothing else.
#line 4408
allow user_crond_t usbdevfs_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t usbdevfs_t:{ file lnk_file } { read getattr lock ioctl };
#line 4408
allow user_crond_t usbdevfs_device_t:file getattr;
#line 4408

#line 4408

#line 4408
# Grant write permissions to a small set of system file types.
#line 4408
# No permission to create files is granted here.  Use allow rules to grant 
#line 4408
# create permissions to a type or use file_type_auto_trans rules to set up
#line 4408
# new types for files.
#line 4408

#line 4408

#line 4408
# Read and write /dev/tty and /dev/null.
#line 4408
allow user_crond_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4408
allow user_crond_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408
# Do not audit write denials to /etc/ld.so.cache.
#line 4408
dontaudit user_crond_t ld_so_cache_t:file write;
#line 4408

#line 4408

#line 4408
# Execute from the system shared libraries.
#line 4408
# No permission to execute anything else is granted here.
#line 4408
# Use can_exec or can_exec_any to grant the ability to execute within a domain.
#line 4408
# Use domain_auto_trans for executing and changing domains.
#line 4408

#line 4408
allow user_crond_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t ld_so_t:file { read getattr lock execute ioctl };
#line 4408
allow user_crond_t ld_so_t:file execute_no_trans;
#line 4408
allow user_crond_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_crond_t shlib_t:file { read getattr lock execute ioctl };
#line 4408
allow user_crond_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_crond_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4408
allow user_crond_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408

#line 4408
# read localization information
#line 4408
allow user_crond_t locale_t:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 4408

#line 4408
# Obtain the context of any SID, the SID for any context, 
#line 4408
# and the list of active SIDs.
#line 4408
allow user_crond_t security_t:security { sid_to_context context_to_sid get_sids };
#line 4408

#line 4408

#line 4408

#line 4408
# Grant permissions needed to create TCP and UDP sockets and 
#line 4408
# to access the network.
#line 4408

#line 4408
#
#line 4408
# Allow the domain to create and use UDP and TCP sockets.
#line 4408
# Other kinds of sockets must be separately authorized for use.
#line 4408
allow user_crond_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408
allow user_crond_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send UDP packets.
#line 4408
# Since the destination sockets type is unknown, the generic
#line 4408
# any_socket_t type is used as a placeholder.
#line 4408
#
#line 4408
allow user_crond_t any_socket_t:udp_socket sendto;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send using any network interface.
#line 4408
# netif_type is a type attribute for all network interface types.
#line 4408
#
#line 4408
allow user_crond_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4408

#line 4408
#
#line 4408
# Allow packets sent by the domain to be received on any network interface.
#line 4408
#
#line 4408
allow user_crond_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to receive packets from any network interface.
#line 4408
# netmsg_type is a type attribute for all default message types.
#line 4408
#
#line 4408
allow user_crond_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to initiate or accept TCP connections 
#line 4408
# on any network interface.
#line 4408
#
#line 4408
allow user_crond_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4408

#line 4408
#
#line 4408
# Receive resets from the TCP reset socket.
#line 4408
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4408
#
#line 4408
allow user_crond_t tcp_socket_t:tcp_socket recvfrom;
#line 4408

#line 4408
dontaudit user_crond_t tcp_socket_t:tcp_socket connectto;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send to any node.
#line 4408
# node_type is a type attribute for all node types.
#line 4408
#
#line 4408
allow user_crond_t node_type:node { tcp_send udp_send rawip_send };
#line 4408

#line 4408
#
#line 4408
# Allow packets sent by the domain to be received from any node.
#line 4408
#
#line 4408
allow user_crond_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send NFS client requests via the socket
#line 4408
# created by mount.
#line 4408
#
#line 4408
allow user_crond_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408

#line 4408
#
#line 4408
# Bind to the default port type.
#line 4408
# Other port types must be separately authorized.
#line 4408
#
#line 4408
allow user_crond_t port_t:udp_socket name_bind;
#line 4408
allow user_crond_t port_t:tcp_socket name_bind;
#line 4408

#line 4408

#line 4408

#line 4408
# Use capabilities.
#line 4408
allow user_crond_t user_crond_t:capability dac_override;
#line 4408

#line 4408
# Inherit and use descriptors from initrc.
#line 4408
allow user_crond_t initrc_t:fd use;
#line 4408

#line 4408
# 
#line 4408
# Since crontab files are not directly executed,
#line 4408
# crond must ensure that the crontab file has
#line 4408
# a type that is appropriate for the domain of
#line 4408
# the user cron job.  It performs an entrypoint
#line 4408
# permission check for this purpose.
#line 4408
#
#line 4408
allow user_crond_t user_cron_spool_t:file entrypoint;
#line 4408

#line 4408
# Access user files and dirs.
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to modify the directory.
#line 4408
#
#line 4408
allow user_crond_t user_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4408

#line 4408
#
#line 4408
# Allow the process to create the file.
#line 4408
#
#line 4408

#line 4408
allow user_crond_t user_home_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4408
allow user_crond_t user_home_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4408

#line 4408

#line 4408

#line 4408
type_transition user_crond_t user_home_dir_t:dir user_home_t;
#line 4408
type_transition user_crond_t user_home_dir_t:{ file lnk_file sock_file fifo_file } user_home_t;
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
#
#line 4408
# Allow the process to modify the directory.
#line 4408
#
#line 4408
allow user_crond_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4408

#line 4408
#
#line 4408
# Allow the process to create the file.
#line 4408
#
#line 4408

#line 4408
allow user_crond_t user_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4408
allow user_crond_t user_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4408

#line 4408

#line 4408

#line 4408
type_transition user_crond_t tmp_t:dir user_tmp_t;
#line 4408
type_transition user_crond_t tmp_t:{ file lnk_file sock_file fifo_file } user_tmp_t;
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
# Run helper programs.
#line 4408

#line 4408
allow user_crond_t { bin_t sbin_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t { bin_t sbin_t }:lnk_file read;
#line 4408

#line 4408
allow user_crond_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4408
allow user_crond_t ld_so_t:file { read getattr lock execute ioctl };
#line 4408
allow user_crond_t ld_so_t:file execute_no_trans;
#line 4408
allow user_crond_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_crond_t shlib_t:file { read getattr lock execute ioctl };
#line 4408
allow user_crond_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4408
allow user_crond_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4408
allow user_crond_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4408

#line 4408

#line 4408
allow user_crond_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408
allow user_crond_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408
allow user_crond_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408
allow user_crond_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408
allow user_crond_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408

#line 4408
# Run scripts in user home directory.
#line 4408

#line 4408
allow user_crond_t user_home_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
# Read the mouse.
#line 4408
allow user_t mouse_device_t:chr_file { read getattr lock ioctl };
#line 4408
# Access other miscellaneous devices.
#line 4408
allow user_t misc_device_t:{ file lnk_file sock_file fifo_file chr_file blk_file } { ioctl read getattr lock write append };
#line 4408

#line 4408
# Use the network.
#line 4408

#line 4408
#
#line 4408
# Allow the domain to create and use UDP and TCP sockets.
#line 4408
# Other kinds of sockets must be separately authorized for use.
#line 4408
allow user_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408
allow user_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send UDP packets.
#line 4408
# Since the destination sockets type is unknown, the generic
#line 4408
# any_socket_t type is used as a placeholder.
#line 4408
#
#line 4408
allow user_t any_socket_t:udp_socket sendto;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send using any network interface.
#line 4408
# netif_type is a type attribute for all network interface types.
#line 4408
#
#line 4408
allow user_t netif_type:netif { tcp_send udp_send rawip_send };
#line 4408

#line 4408
#
#line 4408
# Allow packets sent by the domain to be received on any network interface.
#line 4408
#
#line 4408
allow user_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to receive packets from any network interface.
#line 4408
# netmsg_type is a type attribute for all default message types.
#line 4408
#
#line 4408
allow user_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to initiate or accept TCP connections 
#line 4408
# on any network interface.
#line 4408
#
#line 4408
allow user_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 4408

#line 4408
#
#line 4408
# Receive resets from the TCP reset socket.
#line 4408
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 4408
#
#line 4408
allow user_t tcp_socket_t:tcp_socket recvfrom;
#line 4408

#line 4408
dontaudit user_t tcp_socket_t:tcp_socket connectto;
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send to any node.
#line 4408
# node_type is a type attribute for all node types.
#line 4408
#
#line 4408
allow user_t node_type:node { tcp_send udp_send rawip_send };
#line 4408

#line 4408
#
#line 4408
# Allow packets sent by the domain to be received from any node.
#line 4408
#
#line 4408
allow user_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 4408

#line 4408
#
#line 4408
# Allow the domain to send NFS client requests via the socket
#line 4408
# created by mount.
#line 4408
#
#line 4408
allow user_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4408

#line 4408
#
#line 4408
# Bind to the default port type.
#line 4408
# Other port types must be separately authorized.
#line 4408
#
#line 4408
allow user_t port_t:udp_socket name_bind;
#line 4408
allow user_t port_t:tcp_socket name_bind;
#line 4408

#line 4408

#line 4408
#
#line 4408
# connect_secure and sendmsg_secure calls with a 
#line 4408
# peer or destination socket SID can be enforced
#line 4408
# when using the loopback interface.  Enforcement
#line 4408
# for real network interfaces will be possible when
#line 4408
# a packet labeling mechanism is integrated.
#line 4408
#
#line 4408
allow user_t node_lo_t:node enforce_dest;
#line 4408

#line 4408
# Communicate within the domain.
#line 4408

#line 4408
allow user_t user_t:udp_socket { sendto };
#line 4408
allow user_t user_t:udp_socket { recvfrom };
#line 4408

#line 4408

#line 4408
allow user_t user_t:tcp_socket { connectto recvfrom };
#line 4408
allow user_t user_t:tcp_socket { acceptfrom recvfrom };
#line 4408
allow user_t tcp_socket_t:tcp_socket { recvfrom };
#line 4408
allow user_t tcp_socket_t:tcp_socket { recvfrom };
#line 4408

#line 4408

#line 4408
# Connect to inetd.
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
# Connect data port to ftpd.
#line 4408

#line 4408

#line 4408
# Connect to portmap.
#line 4408

#line 4408

#line 4408
# Inherit and use sockets from inetd
#line 4408

#line 4408

#line 4408
# Allow system log read
#line 4408
#allow user_t kernel_t:system syslog_read;
#line 4408
# else do not log it
#line 4408
dontaudit user_t kernel_t:system syslog_read;
#line 4408

#line 4408
# Very permissive allowing every domain to see every type.
#line 4408
allow user_t kernel_t:system { ipc_info };
#line 4408

#line 4408
# When the user domain runs ps, there will be a number of access
#line 4408
# denials when ps tries to search /proc.  Do not audit these denials.
#line 4408
dontaudit user_t domain:dir { read getattr lock search ioctl };
#line 4408
dontaudit user_t domain:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4408

#line 4408
# Some shells ask for w access to utmp, but will operate
#line 4408
# correctly without it.  Do not audit write denials to utmp.
#line 4408
dontaudit user_t initrc_var_run_t:file { getattr read write };
#line 4408

#line 4408
# do not audit getattr on tmpfile, otherwise ls -l /tmp fills the logs
#line 4408
dontaudit user_t tmpfile:{ dir file lnk_file sock_file fifo_file chr_file blk_file } getattr;
#line 4408

#line 4408
# do not audit getattr on disk devices, otherwise KDE fills the logs
#line 4408
dontaudit user_t { removable_device_t fixed_disk_device_t }:blk_file getattr;
#line 4408

#line 4408

#line 4408
# Access the sound device.
#line 4408
allow user_t sound_device_t:chr_file { getattr read write ioctl };
#line 4408

#line 4408
# Allow reading dpkg origins file
#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408

#line 4408
# When an ordinary user domain runs su, su may try to
#line 4408
# update the /root/.Xauthority file, and the user shell may
#line 4408
# try to update the shell history. This isnt allowed, but 
#line 4408
# we dont need to audit it.
#line 4408

#line 4408
dontaudit user_su_t sysadm_home_t:dir  { read getattr search write add_name remove_name };
#line 4408
dontaudit user_su_t sysadm_home_t:file { read getattr create write link unlink };
#line 4408
dontaudit user_t    sysadm_home_t:dir { read search getattr };
#line 4408
dontaudit user_t    sysadm_home_t:file { read getattr append };
#line 4408

#line 4408

#line 4408
# Some programs that are left in user_t will try to connect
#line 4408
# to syslogd, but we do not want to let them generate log messages.
#line 4408
# Do not audit.
#line 4408
dontaudit user_t devlog_t:sock_file { read write };
#line 4408
dontaudit user_t syslogd_t:unix_dgram_socket sendto;
#line 4408

#line 4408

#line 4408
# stop warnings about "ls -l" on directories with unlabelled files
#line 4408
dontaudit user_t file_t:{ dir file lnk_file } getattr;
#line 4408


# a role for staff that allows seeing all domains and control over the user_t
# domain
#full_user_role(staff)
#allow staff_t user_t:process signal_perms;
#r_dir_file(staff_t, domain)
#file_type_auto_trans(staff_t, user_home_dir_t, user_home_t)

# read localization information
allow user_t locale_t:dir { read getattr lock search ioctl };
allow user_t locale_t:{file lnk_file} { read getattr lock ioctl };

# if adding new user roles make sure you edit the in_user_role macro in
# macros/user_macros.te to match

# lots of user programs accidentally search /root, and also the admin often
# logs in as UID=0 domain=user_t...
dontaudit unpriv_userdomain sysadm_home_dir_t:dir { getattr search };

# system_r is authorized for user_t as a fallback for unmodified daemons.
role system_r types user_t;

# change from role $1_r to $2_r and relabel tty appropriately
#line 4436


#line 4446

#line 4446
#
#line 4446
# Allow the user roles to transition
#line 4446
# into each other.
#line 4446

#line 4446
allow sysadm_r user_r;
#line 4446
type_change user_t sysadm_devpts_t:chr_file user_devpts_t;
#line 4446
type_change user_t sysadm_tty_device_t:chr_file user_tty_device_t;
#line 4446

#line 4446

#line 4446
allow user_r sysadm_r;
#line 4446
type_change sysadm_t user_devpts_t:chr_file sysadm_devpts_t;
#line 4446
type_change sysadm_t user_tty_device_t:chr_file sysadm_tty_device_t;
#line 4446

#line 4446
#role_tty_type_change(staff, sysadm)
#line 4446
#role_tty_type_change(sysadm, staff)
#line 4446


# "ps aux" and "ls -l /dev/pts" make too much noise without this
dontaudit unpriv_userdomain ptyfile:chr_file getattr;
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

#################################
#
# Rules for the kernel_t domain.
#

#
# kernel_t is the domain of kernel threads.
# It is also the target type when checking permissions in the system class.
# 
type kernel_t, domain;
role system_r types kernel_t;

#line 4465
# Access other processes in the same domain.
#line 4465
allow kernel_t self:process *;
#line 4465

#line 4465
# Access /proc/PID files for processes in the same domain.
#line 4465
allow kernel_t self:dir { read getattr lock search ioctl };
#line 4465
allow kernel_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4465

#line 4465
# Access file descriptions, pipes, and sockets
#line 4465
# created by processes in the same domain.
#line 4465
allow kernel_t self:fd *;
#line 4465
allow kernel_t self:fifo_file { ioctl read getattr lock write append };
#line 4465
allow kernel_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4465
allow kernel_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4465

#line 4465
# Allow the domain to communicate with other processes in the same domain.
#line 4465
allow kernel_t self:unix_dgram_socket sendto;
#line 4465
allow kernel_t self:unix_stream_socket connectto;
#line 4465

#line 4465
# Access System V IPC objects created by processes in the same domain.
#line 4465
allow kernel_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4465
allow kernel_t self:msg  { send receive };
#line 4465
allow kernel_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4465
allow kernel_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4465

#line 4465


#line 4466
# Read system information files in /proc.
#line 4466
allow kernel_t proc_t:dir { read getattr lock search ioctl };
#line 4466
allow kernel_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4466

#line 4466
# Stat /proc/kmsg and /proc/kcore.
#line 4466
allow kernel_t proc_kmsg_t:file { getattr };
#line 4466
allow kernel_t proc_kcore_t:file { getattr };
#line 4466

#line 4466
# Read system variables in /proc/sys.
#line 4466
allow kernel_t sysctl_modprobe_t:file { read getattr lock ioctl };
#line 4466
allow kernel_t sysctl_t:file { read getattr lock ioctl };
#line 4466
allow kernel_t sysctl_t:dir { read getattr lock search ioctl };
#line 4466
allow kernel_t sysctl_fs_t:file { read getattr lock ioctl };
#line 4466
allow kernel_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 4466
allow kernel_t sysctl_kernel_t:file { read getattr lock ioctl };
#line 4466
allow kernel_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 4466
allow kernel_t sysctl_net_t:file { read getattr lock ioctl };
#line 4466
allow kernel_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 4466
allow kernel_t sysctl_vm_t:file { read getattr lock ioctl };
#line 4466
allow kernel_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 4466
allow kernel_t sysctl_dev_t:file { read getattr lock ioctl };
#line 4466
allow kernel_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 4466


#line 4467
# Read /.
#line 4467
allow kernel_t root_t:dir { read getattr lock search ioctl };
#line 4467
allow kernel_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4467

#line 4467
# Read /home.
#line 4467
allow kernel_t home_root_t:dir { read getattr lock search ioctl };
#line 4467

#line 4467
# Read /usr.
#line 4467
allow kernel_t usr_t:dir { read getattr lock search ioctl };
#line 4467
allow kernel_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4467

#line 4467
# Read bin and sbin directories.
#line 4467
allow kernel_t bin_t:dir { read getattr lock search ioctl };
#line 4467
allow kernel_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4467
allow kernel_t sbin_t:dir { read getattr lock search ioctl };
#line 4467
allow kernel_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4467


#line 4468
allow kernel_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4468
allow kernel_t ld_so_t:file { read getattr lock execute ioctl };
#line 4468
allow kernel_t ld_so_t:file execute_no_trans;
#line 4468
allow kernel_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4468
allow kernel_t shlib_t:file { read getattr lock execute ioctl };
#line 4468
allow kernel_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4468
allow kernel_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4468
allow kernel_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4468


# Use capabilities.
allow kernel_t self:capability *;

# Run init in the init_t domain.

#line 4474

#line 4474

#line 4474

#line 4474
#
#line 4474
# Allow the process to transition to the new domain.
#line 4474
#
#line 4474
allow kernel_t init_t:process transition;
#line 4474

#line 4474
#
#line 4474
# Allow the process to execute the program.
#line 4474
# 
#line 4474
allow kernel_t init_exec_t:file { getattr execute };
#line 4474

#line 4474
#
#line 4474
# Allow the process to reap the new domain.
#line 4474
#
#line 4474
allow init_t kernel_t:process sigchld;
#line 4474

#line 4474
#
#line 4474
# Allow the new domain to inherit and use file 
#line 4474
# descriptions from the creating process and vice versa.
#line 4474
#
#line 4474
allow init_t kernel_t:fd use;
#line 4474
allow kernel_t init_t:fd use;
#line 4474

#line 4474
#
#line 4474
# Allow the new domain to write back to the old domain via a pipe.
#line 4474
#
#line 4474
allow init_t kernel_t:fifo_file { ioctl read getattr lock write append };
#line 4474

#line 4474
#
#line 4474
# Allow the new domain to read and execute the program.
#line 4474
#
#line 4474
allow init_t init_exec_t:file { read getattr lock execute ioctl };
#line 4474

#line 4474
#
#line 4474
# Allow the new domain to be entered via the program.
#line 4474
#
#line 4474
allow init_t init_exec_t:file entrypoint;
#line 4474

#line 4474
type_transition kernel_t init_exec_t:process init_t;
#line 4474

#line 4474
allow kernel_t init_exec_t:file read;
#line 4474


# Share state with the init process.
allow kernel_t init_t:process share;

# Mount and unmount file systems.
allow kernel_t fs_type:filesystem { mount remount unmount getattr };

# Search the persistent label mapping.
allow kernel_t file_labels_t:dir search;

# Send signal to any process.
allow kernel_t domain:process signal;

# Access the console.
allow kernel_t device_t:dir search;
allow kernel_t console_device_t:chr_file { ioctl read getattr lock write append };

# Access the initrd filesystem.
allow kernel_t file_t:chr_file { ioctl read getattr lock write append };

#line 4494
allow kernel_t file_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4494

#line 4497

allow kernel_t self:capability sys_chroot;

allow kernel_t file_t:dir mounton;
allow kernel_t file_t:dir { read getattr lock search ioctl add_name remove_name write };
allow kernel_t file_t:blk_file { create ioctl read getattr lock write setattr append link unlink rename };
allow kernel_t { sysctl_t sysctl_kernel_t }:file { setattr { ioctl read getattr lock write append } };

# Lookup the policy.
allow kernel_t policy_config_t:dir { read getattr lock search ioctl };

# Reload the policy from the real root.
allow kernel_t security_t:security load_policy;

#line 4515

#line 4515
# Run insmod (for kernel module loader).
#line 4515

#line 4515

#line 4515

#line 4515

#line 4515
#
#line 4515
# Allow the process to transition to the new domain.
#line 4515
#
#line 4515
allow kernel_t insmod_t:process transition;
#line 4515

#line 4515
#
#line 4515
# Allow the process to execute the program.
#line 4515
# 
#line 4515
allow kernel_t insmod_exec_t:file { getattr execute };
#line 4515

#line 4515
#
#line 4515
# Allow the process to reap the new domain.
#line 4515
#
#line 4515
allow insmod_t kernel_t:process sigchld;
#line 4515

#line 4515
#
#line 4515
# Allow the new domain to inherit and use file 
#line 4515
# descriptions from the creating process and vice versa.
#line 4515
#
#line 4515
allow insmod_t kernel_t:fd use;
#line 4515
allow kernel_t insmod_t:fd use;
#line 4515

#line 4515
#
#line 4515
# Allow the new domain to write back to the old domain via a pipe.
#line 4515
#
#line 4515
allow insmod_t kernel_t:fifo_file { ioctl read getattr lock write append };
#line 4515

#line 4515
#
#line 4515
# Allow the new domain to read and execute the program.
#line 4515
#
#line 4515
allow insmod_t insmod_exec_t:file { read getattr lock execute ioctl };
#line 4515

#line 4515
#
#line 4515
# Allow the new domain to be entered via the program.
#line 4515
#
#line 4515
allow insmod_t insmod_exec_t:file entrypoint;
#line 4515

#line 4515
type_transition kernel_t insmod_exec_t:process insmod_t;
#line 4515

#line 4515
allow kernel_t insmod_exec_t:file read;
#line 4515

#line 4515
allow kernel_t insmod_exec_t:lnk_file read;
#line 4515


# /proc/sys/kernel/modprobe is set to /bin/true if not using modules.

#line 4518
allow kernel_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4518



#DESC Checkpolicy - SELinux policy compliler
#
# Authors:  Frank Mayer, mayerf@tresys.com
#

###########################
# 
# checkpolicy_t is the domain type for checkpolicy
# checkpolicy_exec_t if file type for the executable

type checkpolicy_t, domain;
role sysadm_r types checkpolicy_t;

type checkpolicy_exec_t, file_type, exec_type, sysadmfile;

##########################
# 
# Rules


#line 4540

#line 4540

#line 4540
#
#line 4540
# Allow the process to transition to the new domain.
#line 4540
#
#line 4540
allow sysadm_t checkpolicy_t:process transition;
#line 4540

#line 4540
#
#line 4540
# Allow the process to execute the program.
#line 4540
# 
#line 4540
allow sysadm_t checkpolicy_exec_t:file { getattr execute };
#line 4540

#line 4540
#
#line 4540
# Allow the process to reap the new domain.
#line 4540
#
#line 4540
allow checkpolicy_t sysadm_t:process sigchld;
#line 4540

#line 4540
#
#line 4540
# Allow the new domain to inherit and use file 
#line 4540
# descriptions from the creating process and vice versa.
#line 4540
#
#line 4540
allow checkpolicy_t sysadm_t:fd use;
#line 4540
allow sysadm_t checkpolicy_t:fd use;
#line 4540

#line 4540
#
#line 4540
# Allow the new domain to write back to the old domain via a pipe.
#line 4540
#
#line 4540
allow checkpolicy_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 4540

#line 4540
#
#line 4540
# Allow the new domain to read and execute the program.
#line 4540
#
#line 4540
allow checkpolicy_t checkpolicy_exec_t:file { read getattr lock execute ioctl };
#line 4540

#line 4540
#
#line 4540
# Allow the new domain to be entered via the program.
#line 4540
#
#line 4540
allow checkpolicy_t checkpolicy_exec_t:file entrypoint;
#line 4540

#line 4540
type_transition sysadm_t checkpolicy_exec_t:process checkpolicy_t;
#line 4540


# able to create and modify binary policy files
allow checkpolicy_t policy_config_t:dir { read getattr lock search ioctl add_name remove_name write };
allow checkpolicy_t policy_config_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };

###########################
# constrain what checkpolicy can use as source files
#

# only allow read of policy source files
allow checkpolicy_t policy_src_t:dir { read getattr lock search ioctl };
allow checkpolicy_t policy_src_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };

# allow test policies to be created in src directories

#line 4555

#line 4555

#line 4555

#line 4555
#
#line 4555
# Allow the process to modify the directory.
#line 4555
#
#line 4555
allow checkpolicy_t policy_src_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4555

#line 4555
#
#line 4555
# Allow the process to create the file.
#line 4555
#
#line 4555

#line 4555
allow checkpolicy_t policy_config_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4555
allow checkpolicy_t policy_config_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4555

#line 4555

#line 4555

#line 4555
type_transition checkpolicy_t policy_src_t:dir policy_config_t;
#line 4555
type_transition checkpolicy_t policy_src_t:{ file lnk_file sock_file fifo_file } policy_config_t;
#line 4555

#line 4555

#line 4555


# directory search permissions for path to source and binary policy files
allow checkpolicy_t root_t:dir search;
allow checkpolicy_t etc_t:dir search;

# Read the devpts root directory.  
allow checkpolicy_t devpts_t:dir { read getattr lock search ioctl };
#line 4564


# Other access
allow checkpolicy_t { sysadm_tty_device_t sysadm_devpts_t }:chr_file { read write ioctl getattr };

#line 4568
allow checkpolicy_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4568
allow checkpolicy_t ld_so_t:file { read getattr lock execute ioctl };
#line 4568
allow checkpolicy_t ld_so_t:file execute_no_trans;
#line 4568
allow checkpolicy_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4568
allow checkpolicy_t shlib_t:file { read getattr lock execute ioctl };
#line 4568
allow checkpolicy_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4568
allow checkpolicy_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4568
allow checkpolicy_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4568

allow checkpolicy_t self:capability dac_override;

allow checkpolicy_t sysadm_tmp_t:file { getattr write } ;

##########################
# Allow users to execute checkpolicy without a domain transition
# so it can be used without privilege to write real binary policy file

#line 4576
allow user_t checkpolicy_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4576


allow checkpolicy_t privfd:fd use;

#DESC Chkpwd - PAM password checking programs
#
# Domains for the /sbin/.*_chkpwd utilities.
#

#
# chkpwd_exec_t is the type of the /sbin/.*_chkpwd executables.
#
type chkpwd_exec_t, file_type, sysadmfile, exec_type;

# Everything else is in the chkpwd_domain macro in
# macros/program/chkpwd_macros.te.
#DESC Crond - Crond daemon
#
# Domains for the top-level crond daemon process and
# for system cron jobs.  The domains for user cron jobs
# are in macros/program/crond_macros.te.
#

#
# Authors:  Jonathan Crowley (MITRE) <jonathan@mitre.org>,
#	    Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser
#

# Domain for crond.  It needs auth to check for locked accounts.

#line 4605

#line 4605
type crond_t, domain, privlog , privrole, privmail, auth, privfd;
#line 4605
type crond_exec_t, file_type, sysadmfile, exec_type;
#line 4605

#line 4605
role system_r types crond_t;
#line 4605

#line 4605

#line 4605

#line 4605

#line 4605
#
#line 4605
# Allow the process to transition to the new domain.
#line 4605
#
#line 4605
allow initrc_t crond_t:process transition;
#line 4605

#line 4605
#
#line 4605
# Allow the process to execute the program.
#line 4605
# 
#line 4605
allow initrc_t crond_exec_t:file { getattr execute };
#line 4605

#line 4605
#
#line 4605
# Allow the process to reap the new domain.
#line 4605
#
#line 4605
allow crond_t initrc_t:process sigchld;
#line 4605

#line 4605
#
#line 4605
# Allow the new domain to inherit and use file 
#line 4605
# descriptions from the creating process and vice versa.
#line 4605
#
#line 4605
allow crond_t initrc_t:fd use;
#line 4605
allow initrc_t crond_t:fd use;
#line 4605

#line 4605
#
#line 4605
# Allow the new domain to write back to the old domain via a pipe.
#line 4605
#
#line 4605
allow crond_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 4605

#line 4605
#
#line 4605
# Allow the new domain to read and execute the program.
#line 4605
#
#line 4605
allow crond_t crond_exec_t:file { read getattr lock execute ioctl };
#line 4605

#line 4605
#
#line 4605
# Allow the new domain to be entered via the program.
#line 4605
#
#line 4605
allow crond_t crond_exec_t:file entrypoint;
#line 4605

#line 4605
type_transition initrc_t crond_exec_t:process crond_t;
#line 4605

#line 4605

#line 4605
# Inherit and use descriptors from init.
#line 4605
allow crond_t init_t:fd use;
#line 4605
allow crond_t init_t:process sigchld;
#line 4605
allow crond_t privfd:fd use;
#line 4605
allow crond_t newrole_t:process sigchld;
#line 4605
allow crond_t self:process { { sigchld sigkill sigstop signull signal } fork };
#line 4605

#line 4605

#line 4605
allow crond_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4605
allow crond_t ld_so_t:file { read getattr lock execute ioctl };
#line 4605
allow crond_t ld_so_t:file execute_no_trans;
#line 4605
allow crond_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4605
allow crond_t shlib_t:file { read getattr lock execute ioctl };
#line 4605
allow crond_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4605
allow crond_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4605
allow crond_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4605

#line 4605

#line 4605
allow crond_t { self proc_t }:dir { read getattr lock search ioctl };
#line 4605
allow crond_t { self proc_t }:lnk_file read;
#line 4605

#line 4605
allow crond_t device_t:dir { getattr search };
#line 4605
allow crond_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4605
allow crond_t console_device_t:chr_file { ioctl read getattr lock write append };
#line 4605
allow crond_t initrc_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4605

#line 4605
# Create pid file.
#line 4605
allow crond_t var_t:dir { getattr search };
#line 4605
type var_run_crond_t, file_type, sysadmfile, pidfile;
#line 4605

#line 4605

#line 4605

#line 4605

#line 4605
#
#line 4605
# Allow the process to modify the directory.
#line 4605
#
#line 4605
allow crond_t var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4605

#line 4605
#
#line 4605
# Allow the process to create the file.
#line 4605
#
#line 4605

#line 4605
allow crond_t var_run_crond_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4605
allow crond_t var_run_crond_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4605

#line 4605

#line 4605

#line 4605
type_transition crond_t var_run_t:dir var_run_crond_t;
#line 4605
type_transition crond_t var_run_t:{ file lnk_file sock_file fifo_file } var_run_crond_t;
#line 4605

#line 4605

#line 4605

#line 4605

#line 4605
allow crond_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4605

#line 4605
# for daemons that look at /root on startup
#line 4605
dontaudit crond_t sysadm_home_dir_t:dir search;
#line 4605

#line 4605
# for df
#line 4605
allow crond_t fs_type:filesystem getattr;
#line 4605


# This domain is granted permissions common to most domains (including can_net)

#line 4608
# Access other processes in the same domain.
#line 4608
allow crond_t self:process *;
#line 4608

#line 4608
# Access /proc/PID files for processes in the same domain.
#line 4608
allow crond_t self:dir { read getattr lock search ioctl };
#line 4608
allow crond_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4608

#line 4608
# Access file descriptions, pipes, and sockets
#line 4608
# created by processes in the same domain.
#line 4608
allow crond_t self:fd *;
#line 4608
allow crond_t self:fifo_file { ioctl read getattr lock write append };
#line 4608
allow crond_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4608
allow crond_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4608

#line 4608
# Allow the domain to communicate with other processes in the same domain.
#line 4608
allow crond_t self:unix_dgram_socket sendto;
#line 4608
allow crond_t self:unix_stream_socket connectto;
#line 4608

#line 4608
# Access System V IPC objects created by processes in the same domain.
#line 4608
allow crond_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4608
allow crond_t self:msg  { send receive };
#line 4608
allow crond_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4608
allow crond_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4608

#line 4608


# Type for the anacron executable.
type anacron_exec_t, file_type, sysadmfile, exec_type;

# Type for temporary files.

#line 4614
type crond_tmp_t, file_type, sysadmfile, tmpfile ;
#line 4614

#line 4614

#line 4614

#line 4614

#line 4614
#
#line 4614
# Allow the process to modify the directory.
#line 4614
#
#line 4614
allow crond_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4614

#line 4614
#
#line 4614
# Allow the process to create the file.
#line 4614
#
#line 4614

#line 4614
allow crond_t crond_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4614
allow crond_t crond_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4614

#line 4614

#line 4614

#line 4614
type_transition crond_t tmp_t:dir crond_tmp_t;
#line 4614
type_transition crond_t tmp_t:{ file lnk_file sock_file fifo_file } crond_tmp_t;
#line 4614

#line 4614

#line 4614

#line 4614


# Domain for system cron jobs.
type system_crond_t, domain, privlog, privmail;

# Read and write console and ttys.
allow system_crond_t devtty_t:chr_file { ioctl read getattr lock write append };

# Read system information files in /proc.
allow system_crond_t proc_t:dir { read getattr lock search ioctl };
allow system_crond_t proc_t:file { read getattr lock ioctl };

#line 4628


# to stop killall type operations from filling our logs
dontaudit system_crond_t domain:dir search;

# read files in /etc (anacrontab)  execute /etc/cron.hourly/*, etc.
allow system_crond_t etc_t:file read;
allow system_crond_t etc_runtime_t:file read;

# read localization information
allow crond_t locale_t:dir { read getattr lock search ioctl };
allow crond_t locale_t:{file lnk_file} { read getattr lock ioctl };
allow system_crond_t locale_t:dir { read getattr lock search ioctl };
allow system_crond_t locale_t:{file lnk_file} { read getattr lock ioctl };

# Type for log files.
type cron_log_t, file_type, sysadmfile, logfile;
# Use this type when creating files in /var/log.

#line 4646

#line 4646

#line 4646

#line 4646
#
#line 4646
# Allow the process to modify the directory.
#line 4646
#
#line 4646
allow crond_t var_log_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4646

#line 4646
#
#line 4646
# Allow the process to create the file.
#line 4646
#
#line 4646

#line 4646
allow crond_t cron_log_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4646
allow crond_t cron_log_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4646

#line 4646

#line 4646

#line 4646
type_transition crond_t var_log_t:dir cron_log_t;
#line 4646
type_transition crond_t var_log_t:{ file lnk_file sock_file fifo_file } cron_log_t;
#line 4646

#line 4646

#line 4646


# Use capabilities.
allow crond_t crond_t:capability { setgid setuid net_bind_service };

# Check entrypoint permission on crontab files.
allow crond_t security_t:security compute_av;

# for finding binaries and /bin/sh
allow crond_t { bin_t sbin_t }:dir search;
allow crond_t bin_t:lnk_file read;

# Read from /var/spool/cron.
allow crond_t var_lib_t:dir search;
allow crond_t var_spool_t:dir { read getattr lock search ioctl };
allow crond_t cron_spool_t:dir { read getattr lock search ioctl };
allow crond_t cron_spool_t:file { read getattr lock ioctl };

# Read system crontabs
allow crond_t system_crond_script_t:file { read getattr lock ioctl };
allow crond_t system_crond_script_t:dir { read getattr lock search ioctl };

# Read /etc/security/default_contexts.
allow crond_t default_context_t:file { read getattr lock ioctl };

allow crond_t etc_t:file { getattr read };
allow crond_t etc_t:lnk_file read;

# crond tries to search /root.  Not sure why.
allow crond_t sysadm_home_dir_t:dir { read getattr lock search ioctl };

# to search /home
allow crond_t home_root_t:dir { getattr search };
allow crond_t user_home_dir_type:dir { read getattr lock search ioctl };

# Run a shell.

#line 4682
allow crond_t shell_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4682


#line 4691


# This system_r role is authorized for this domain.
role system_r types system_crond_t;


#line 4696
allow system_crond_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4696
allow system_crond_t ld_so_t:file { read getattr lock execute ioctl };
#line 4696
allow system_crond_t ld_so_t:file execute_no_trans;
#line 4696
allow system_crond_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4696
allow system_crond_t shlib_t:file { read getattr lock execute ioctl };
#line 4696
allow system_crond_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4696
allow system_crond_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4696
allow system_crond_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4696
;

#line 4697
# Access other processes in the same domain.
#line 4697
allow system_crond_t self:process *;
#line 4697

#line 4697
# Access /proc/PID files for processes in the same domain.
#line 4697
allow system_crond_t self:dir { read getattr lock search ioctl };
#line 4697
allow system_crond_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4697

#line 4697
# Access file descriptions, pipes, and sockets
#line 4697
# created by processes in the same domain.
#line 4697
allow system_crond_t self:fd *;
#line 4697
allow system_crond_t self:fifo_file { ioctl read getattr lock write append };
#line 4697
allow system_crond_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4697
allow system_crond_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4697

#line 4697
# Allow the domain to communicate with other processes in the same domain.
#line 4697
allow system_crond_t self:unix_dgram_socket sendto;
#line 4697
allow system_crond_t self:unix_stream_socket connectto;
#line 4697

#line 4697
# Access System V IPC objects created by processes in the same domain.
#line 4697
allow system_crond_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4697
allow system_crond_t self:msg  { send receive };
#line 4697
allow system_crond_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4697
allow system_crond_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4697

#line 4697
;
allow system_crond_t var_log_t:file { read getattr lock ioctl };

# Type for system crontab files.
type system_crond_script_t, file_type, sysadmfile;

# Permit crond_t to transition to this domain.
# The transition is requested explicitly by the modified crond 
# via execve_secure.  There is no way to set up an automatic
# transition, since crontabs are configuration files, not executables.

#line 4707

#line 4707
#
#line 4707
# Allow the process to transition to the new domain.
#line 4707
#
#line 4707
allow crond_t system_crond_t:process transition;
#line 4707

#line 4707
#
#line 4707
# Allow the process to execute the program.
#line 4707
# 
#line 4707
allow crond_t shell_exec_t:file { getattr execute };
#line 4707

#line 4707
#
#line 4707
# Allow the process to reap the new domain.
#line 4707
#
#line 4707
allow system_crond_t crond_t:process sigchld;
#line 4707

#line 4707
#
#line 4707
# Allow the new domain to inherit and use file 
#line 4707
# descriptions from the creating process and vice versa.
#line 4707
#
#line 4707
allow system_crond_t crond_t:fd use;
#line 4707
allow crond_t system_crond_t:fd use;
#line 4707

#line 4707
#
#line 4707
# Allow the new domain to write back to the old domain via a pipe.
#line 4707
#
#line 4707
allow system_crond_t crond_t:fifo_file { ioctl read getattr lock write append };
#line 4707

#line 4707
#
#line 4707
# Allow the new domain to read and execute the program.
#line 4707
#
#line 4707
allow system_crond_t shell_exec_t:file { read getattr lock execute ioctl };
#line 4707

#line 4707
#
#line 4707
# Allow the new domain to be entered via the program.
#line 4707
#
#line 4707
allow system_crond_t shell_exec_t:file entrypoint;
#line 4707


# Transition to this domain for anacron as well.
# Still need to study anacron.

#line 4711

#line 4711

#line 4711
#
#line 4711
# Allow the process to transition to the new domain.
#line 4711
#
#line 4711
allow initrc_t system_crond_t:process transition;
#line 4711

#line 4711
#
#line 4711
# Allow the process to execute the program.
#line 4711
# 
#line 4711
allow initrc_t anacron_exec_t:file { getattr execute };
#line 4711

#line 4711
#
#line 4711
# Allow the process to reap the new domain.
#line 4711
#
#line 4711
allow system_crond_t initrc_t:process sigchld;
#line 4711

#line 4711
#
#line 4711
# Allow the new domain to inherit and use file 
#line 4711
# descriptions from the creating process and vice versa.
#line 4711
#
#line 4711
allow system_crond_t initrc_t:fd use;
#line 4711
allow initrc_t system_crond_t:fd use;
#line 4711

#line 4711
#
#line 4711
# Allow the new domain to write back to the old domain via a pipe.
#line 4711
#
#line 4711
allow system_crond_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 4711

#line 4711
#
#line 4711
# Allow the new domain to read and execute the program.
#line 4711
#
#line 4711
allow system_crond_t anacron_exec_t:file { read getattr lock execute ioctl };
#line 4711

#line 4711
#
#line 4711
# Allow the new domain to be entered via the program.
#line 4711
#
#line 4711
allow system_crond_t anacron_exec_t:file entrypoint;
#line 4711

#line 4711
type_transition initrc_t anacron_exec_t:process system_crond_t;
#line 4711


# Access log files

#line 4714

#line 4714

#line 4714

#line 4714
#
#line 4714
# Allow the process to modify the directory.
#line 4714
#
#line 4714
allow system_crond_t var_log_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4714

#line 4714
#
#line 4714
# Allow the process to create the file.
#line 4714
#
#line 4714

#line 4714
allow system_crond_t cron_log_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4714
allow system_crond_t cron_log_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4714

#line 4714

#line 4714

#line 4714
type_transition system_crond_t var_log_t:dir cron_log_t;
#line 4714
type_transition system_crond_t var_log_t:{ file lnk_file sock_file fifo_file } cron_log_t;
#line 4714

#line 4714

#line 4714


# Inherit and use descriptors from init.
allow system_crond_t init_t:fd use;

# Inherit and use descriptors from initrc.
allow system_crond_t initrc_t:fd use;

# Write to a socket from initrc.
allow system_crond_t initrc_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# Use capabilities.
allow system_crond_t system_crond_t:capability { setgid setuid dac_override fowner net_bind_service fsetid };

# Read the system crontabs.
allow system_crond_t system_crond_script_t:file { read getattr lock ioctl };

# 
# Since crontab files are not directly executed,
# crond must ensure that the crontab file has
# a type that is appropriate for the domain of
# the system cron job.  It performs an entrypoint
# permission check for this purpose.
#
allow system_crond_t system_crond_script_t:file entrypoint;
#line 4741


# Run helper programs in the system_crond_t domain.
allow system_crond_t { bin_t sbin_t }:dir { read getattr lock search ioctl };
allow system_crond_t { bin_t sbin_t }:lnk_file read;

#line 4746
allow system_crond_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4746


#line 4747
allow system_crond_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4747


#line 4748
allow system_crond_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4748


#line 4749
allow system_crond_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4749



# Read from /var/spool/cron.
allow system_crond_t cron_spool_t:dir { read getattr lock search ioctl };
allow system_crond_t cron_spool_t:file { read getattr lock ioctl };

# Write to /var/lib/slocate.db.
allow system_crond_t var_lib_t:dir { read getattr lock search ioctl add_name remove_name write };
allow system_crond_t var_lib_t:file { create ioctl read getattr lock write setattr append link unlink rename };

# Update whatis files.
allow system_crond_t catman_t:dir { read getattr lock search ioctl add_name remove_name write };
allow system_crond_t catman_t:file { create ioctl read getattr lock write setattr append link unlink rename };

# Write /var/lock/makewhatis.lock.
allow system_crond_t var_lock_t:dir { read getattr lock search ioctl add_name remove_name write };
allow system_crond_t var_lock_t:file { create ioctl read getattr lock write setattr append link unlink rename };

# Modutils are now combined, so we can no longer distinguish them.
# Let crond run the insmod executable in the insmod_t domain.
#line 4772

#line 4772

#line 4772

#line 4772

#line 4772

#line 4772
#
#line 4772
# Allow the process to transition to the new domain.
#line 4772
#
#line 4772
allow system_crond_t insmod_t:process transition;
#line 4772

#line 4772
#
#line 4772
# Allow the process to execute the program.
#line 4772
# 
#line 4772
allow system_crond_t insmod_exec_t:file { getattr execute };
#line 4772

#line 4772
#
#line 4772
# Allow the process to reap the new domain.
#line 4772
#
#line 4772
allow insmod_t system_crond_t:process sigchld;
#line 4772

#line 4772
#
#line 4772
# Allow the new domain to inherit and use file 
#line 4772
# descriptions from the creating process and vice versa.
#line 4772
#
#line 4772
allow insmod_t system_crond_t:fd use;
#line 4772
allow system_crond_t insmod_t:fd use;
#line 4772

#line 4772
#
#line 4772
# Allow the new domain to write back to the old domain via a pipe.
#line 4772
#
#line 4772
allow insmod_t system_crond_t:fifo_file { ioctl read getattr lock write append };
#line 4772

#line 4772
#
#line 4772
# Allow the new domain to read and execute the program.
#line 4772
#
#line 4772
allow insmod_t insmod_exec_t:file { read getattr lock execute ioctl };
#line 4772

#line 4772
#
#line 4772
# Allow the new domain to be entered via the program.
#line 4772
#
#line 4772
allow insmod_t insmod_exec_t:file entrypoint;
#line 4772

#line 4772
type_transition system_crond_t insmod_exec_t:process insmod_t;
#line 4772

#line 4772
allow insmod_t crond_t:fifo_file { getattr read write ioctl };
#line 4772
# a rule for privfd may make this obsolete
#line 4772
allow insmod_t crond_t:fd use;
#line 4772
allow insmod_t crond_t:process sigchld;
#line 4772

#line 4772


# for if /var/mail is a symlink
allow crond_t mail_spool_t:lnk_file read;

# Run logrotate in the logrotate_t domain.
#line 4780

#line 4780

#line 4780

#line 4780

#line 4780

#line 4780
#
#line 4780
# Allow the process to transition to the new domain.
#line 4780
#
#line 4780
allow system_crond_t logrotate_t:process transition;
#line 4780

#line 4780
#
#line 4780
# Allow the process to execute the program.
#line 4780
# 
#line 4780
allow system_crond_t logrotate_exec_t:file { getattr execute };
#line 4780

#line 4780
#
#line 4780
# Allow the process to reap the new domain.
#line 4780
#
#line 4780
allow logrotate_t system_crond_t:process sigchld;
#line 4780

#line 4780
#
#line 4780
# Allow the new domain to inherit and use file 
#line 4780
# descriptions from the creating process and vice versa.
#line 4780
#
#line 4780
allow logrotate_t system_crond_t:fd use;
#line 4780
allow system_crond_t logrotate_t:fd use;
#line 4780

#line 4780
#
#line 4780
# Allow the new domain to write back to the old domain via a pipe.
#line 4780
#
#line 4780
allow logrotate_t system_crond_t:fifo_file { ioctl read getattr lock write append };
#line 4780

#line 4780
#
#line 4780
# Allow the new domain to read and execute the program.
#line 4780
#
#line 4780
allow logrotate_t logrotate_exec_t:file { read getattr lock execute ioctl };
#line 4780

#line 4780
#
#line 4780
# Allow the new domain to be entered via the program.
#line 4780
#
#line 4780
allow logrotate_t logrotate_exec_t:file entrypoint;
#line 4780

#line 4780
type_transition system_crond_t logrotate_exec_t:process logrotate_t;
#line 4780

#line 4780
allow logrotate_t crond_t:fifo_file { getattr read write ioctl };
#line 4780
# a rule for privfd may make this obsolete
#line 4780
allow logrotate_t crond_t:fd use;
#line 4780
allow logrotate_t crond_t:process sigchld;
#line 4780

#line 4780


#line 4784


# Stat any file and search any directory for find.
allow system_crond_t file_type:{ file lnk_file sock_file fifo_file chr_file blk_file } getattr;
allow system_crond_t file_type:dir { read search getattr };

# Create temporary files.
type system_crond_tmp_t, file_type, sysadmfile, tmpfile;

#line 4792

#line 4792

#line 4792

#line 4792
#
#line 4792
# Allow the process to modify the directory.
#line 4792
#
#line 4792
allow system_crond_t { tmp_t crond_tmp_t }:dir { read getattr lock search ioctl add_name remove_name write };
#line 4792

#line 4792
#
#line 4792
# Allow the process to create the file.
#line 4792
#
#line 4792

#line 4792
allow system_crond_t system_crond_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4792
allow system_crond_t system_crond_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4792

#line 4792

#line 4792

#line 4792
type_transition system_crond_t { tmp_t crond_tmp_t }:dir system_crond_tmp_t;
#line 4792
type_transition system_crond_t { tmp_t crond_tmp_t }:{ file lnk_file sock_file fifo_file } system_crond_tmp_t;
#line 4792

#line 4792

#line 4792


# /sbin/runlevel ask for w access to utmp, but will operate
# correctly without it.  Do not audit write denials to utmp.
dontaudit system_crond_t initrc_var_run_t:file { read write };

# Access accounting summary files.
allow system_crond_t var_log_sa_t:file { create ioctl read getattr lock write setattr append link unlink rename };
allow system_crond_t var_log_sa_t:dir { read getattr lock search ioctl add_name remove_name write };

# Access other spool directories like
# /var/spool/anacron and /var/spool/slrnpull.
allow system_crond_t var_spool_t:file { create ioctl read getattr lock write setattr append link unlink rename };
allow system_crond_t var_spool_t:dir { read getattr lock search ioctl add_name remove_name write };

# Do not audit attempts to search unlabeled directories (e.g. slocate).
dontaudit system_crond_t unlabeled_t:dir { read getattr lock search ioctl };
dontaudit system_crond_t unlabeled_t:file { read getattr lock ioctl };

# Determine the set of legal user SIDs that can be reached.
allow crond_t security_t:security { sid_to_context context_to_sid get_user_sids };
#DESC Crontab - Crontab manipulation programs
#
# Domains for the crontab program.
#

# Type for the crontab executable.
type crontab_exec_t, file_type, sysadmfile, exec_type;

# Everything else is in the crontab_domain macro in
# macros/program/crontab_macros.te.
#DESC Fsadm - Disk and file system administration
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

#################################
#
# Rules for the fsadm_t domain.
#
# fsadm_t is the domain for disk and file system
# administration.
# fsadm_exec_t is the type of the corresponding programs.
#
type fsadm_t, domain, privlog;
role system_r types fsadm_t;
role sysadm_r types fsadm_t;


#line 4840
# Access other processes in the same domain.
#line 4840
allow fsadm_t self:process *;
#line 4840

#line 4840
# Access /proc/PID files for processes in the same domain.
#line 4840
allow fsadm_t self:dir { read getattr lock search ioctl };
#line 4840
allow fsadm_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4840

#line 4840
# Access file descriptions, pipes, and sockets
#line 4840
# created by processes in the same domain.
#line 4840
allow fsadm_t self:fd *;
#line 4840
allow fsadm_t self:fifo_file { ioctl read getattr lock write append };
#line 4840
allow fsadm_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4840
allow fsadm_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4840

#line 4840
# Allow the domain to communicate with other processes in the same domain.
#line 4840
allow fsadm_t self:unix_dgram_socket sendto;
#line 4840
allow fsadm_t self:unix_stream_socket connectto;
#line 4840

#line 4840
# Access System V IPC objects created by processes in the same domain.
#line 4840
allow fsadm_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4840
allow fsadm_t self:msg  { send receive };
#line 4840
allow fsadm_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4840
allow fsadm_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4840

#line 4840


# Read system information files in /proc.
allow fsadm_t proc_t:dir { read getattr lock search ioctl };
allow fsadm_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };

# Read system variables in /proc/sys
allow fsadm_t sysctl_kernel_t:file { read getattr lock ioctl };
allow fsadm_t sysctl_kernel_t:dir { read getattr lock search ioctl };


#line 4850
# Read /.
#line 4850
allow fsadm_t root_t:dir { read getattr lock search ioctl };
#line 4850
allow fsadm_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4850

#line 4850
# Read /home.
#line 4850
allow fsadm_t home_root_t:dir { read getattr lock search ioctl };
#line 4850

#line 4850
# Read /usr.
#line 4850
allow fsadm_t usr_t:dir { read getattr lock search ioctl };
#line 4850
allow fsadm_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4850

#line 4850
# Read bin and sbin directories.
#line 4850
allow fsadm_t bin_t:dir { read getattr lock search ioctl };
#line 4850
allow fsadm_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4850
allow fsadm_t sbin_t:dir { read getattr lock search ioctl };
#line 4850
allow fsadm_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4850


# Read /etc.
allow fsadm_t etc_t:dir { read getattr lock search ioctl };
allow fsadm_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };

# Read module-related files.
allow fsadm_t modules_conf_t:{ file lnk_file } { read getattr lock ioctl };

# Read /dev directories and any symbolic links.
allow fsadm_t device_t:dir { read getattr lock search ioctl };
allow fsadm_t device_t:lnk_file { read getattr lock ioctl };


#line 4863
allow fsadm_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4863
allow fsadm_t ld_so_t:file { read getattr lock execute ioctl };
#line 4863
allow fsadm_t ld_so_t:file execute_no_trans;
#line 4863
allow fsadm_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4863
allow fsadm_t shlib_t:file { read getattr lock execute ioctl };
#line 4863
allow fsadm_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4863
allow fsadm_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4863
allow fsadm_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4863


type fsadm_exec_t, file_type, sysadmfile, exec_type;

#line 4866

#line 4866

#line 4866
#
#line 4866
# Allow the process to transition to the new domain.
#line 4866
#
#line 4866
allow initrc_t fsadm_t:process transition;
#line 4866

#line 4866
#
#line 4866
# Allow the process to execute the program.
#line 4866
# 
#line 4866
allow initrc_t fsadm_exec_t:file { getattr execute };
#line 4866

#line 4866
#
#line 4866
# Allow the process to reap the new domain.
#line 4866
#
#line 4866
allow fsadm_t initrc_t:process sigchld;
#line 4866

#line 4866
#
#line 4866
# Allow the new domain to inherit and use file 
#line 4866
# descriptions from the creating process and vice versa.
#line 4866
#
#line 4866
allow fsadm_t initrc_t:fd use;
#line 4866
allow initrc_t fsadm_t:fd use;
#line 4866

#line 4866
#
#line 4866
# Allow the new domain to write back to the old domain via a pipe.
#line 4866
#
#line 4866
allow fsadm_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 4866

#line 4866
#
#line 4866
# Allow the new domain to read and execute the program.
#line 4866
#
#line 4866
allow fsadm_t fsadm_exec_t:file { read getattr lock execute ioctl };
#line 4866

#line 4866
#
#line 4866
# Allow the new domain to be entered via the program.
#line 4866
#
#line 4866
allow fsadm_t fsadm_exec_t:file entrypoint;
#line 4866

#line 4866
type_transition initrc_t fsadm_exec_t:process fsadm_t;
#line 4866


#line 4867

#line 4867

#line 4867
#
#line 4867
# Allow the process to transition to the new domain.
#line 4867
#
#line 4867
allow sysadm_t fsadm_t:process transition;
#line 4867

#line 4867
#
#line 4867
# Allow the process to execute the program.
#line 4867
# 
#line 4867
allow sysadm_t fsadm_exec_t:file { getattr execute };
#line 4867

#line 4867
#
#line 4867
# Allow the process to reap the new domain.
#line 4867
#
#line 4867
allow fsadm_t sysadm_t:process sigchld;
#line 4867

#line 4867
#
#line 4867
# Allow the new domain to inherit and use file 
#line 4867
# descriptions from the creating process and vice versa.
#line 4867
#
#line 4867
allow fsadm_t sysadm_t:fd use;
#line 4867
allow sysadm_t fsadm_t:fd use;
#line 4867

#line 4867
#
#line 4867
# Allow the new domain to write back to the old domain via a pipe.
#line 4867
#
#line 4867
allow fsadm_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 4867

#line 4867
#
#line 4867
# Allow the new domain to read and execute the program.
#line 4867
#
#line 4867
allow fsadm_t fsadm_exec_t:file { read getattr lock execute ioctl };
#line 4867

#line 4867
#
#line 4867
# Allow the new domain to be entered via the program.
#line 4867
#
#line 4867
allow fsadm_t fsadm_exec_t:file entrypoint;
#line 4867

#line 4867
type_transition sysadm_t fsadm_exec_t:process fsadm_t;
#line 4867


type fsadm_tmp_t, file_type, sysadmfile, tmpfile;

#line 4870

#line 4870

#line 4870

#line 4870
#
#line 4870
# Allow the process to modify the directory.
#line 4870
#
#line 4870
allow fsadm_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4870

#line 4870
#
#line 4870
# Allow the process to create the file.
#line 4870
#
#line 4870

#line 4870
allow fsadm_t fsadm_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4870
allow fsadm_t fsadm_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4870

#line 4870

#line 4870

#line 4870
type_transition fsadm_t tmp_t:dir fsadm_tmp_t;
#line 4870
type_transition fsadm_t tmp_t:{ file lnk_file sock_file fifo_file } fsadm_tmp_t;
#line 4870

#line 4870

#line 4870


# remount file system to apply changes
allow fsadm_t fs_t:filesystem remount;

# Use capabilities.  ipc_lock is for losetup
allow fsadm_t self:capability { ipc_lock sys_rawio sys_admin };

# Write to /etc/mtab.

#line 4879

#line 4879

#line 4879

#line 4879
#
#line 4879
# Allow the process to modify the directory.
#line 4879
#
#line 4879
allow fsadm_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4879

#line 4879
#
#line 4879
# Allow the process to create the file.
#line 4879
#
#line 4879

#line 4879
allow fsadm_t etc_runtime_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 4879

#line 4879

#line 4879

#line 4879
type_transition fsadm_t etc_t:file etc_runtime_t;
#line 4879

#line 4879

#line 4879


# Inherit and use descriptors from init.
allow fsadm_t init_t:fd use;

# Run other fs admin programs in the fsadm_t domain.

#line 4885
allow fsadm_t fsadm_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 4885


# Access disk devices.
allow fsadm_t fixed_disk_device_t:{ chr_file blk_file } { ioctl read getattr lock write append };
allow fsadm_t removable_device_t:{ chr_file blk_file } { ioctl read getattr lock write append };

# Access lost+found.
allow fsadm_t lost_found_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
allow fsadm_t lost_found_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };

# Recreate /mnt/cdrom. 
allow fsadm_t file_t:dir { search read getattr rmdir create };

# Recreate /dev/cdrom.
allow fsadm_t device_t:dir { read getattr lock search ioctl add_name remove_name write };
allow fsadm_t device_t:lnk_file { unlink create };

# Enable swapping to devices and files
allow fsadm_t swapfile_t:file { getattr swapon };
allow fsadm_t fixed_disk_device_t:blk_file { getattr swapon };

# XXX Why does updfstab run insmod?

#line 4907

#line 4907

#line 4907
#
#line 4907
# Allow the process to transition to the new domain.
#line 4907
#
#line 4907
allow fsadm_t insmod_t:process transition;
#line 4907

#line 4907
#
#line 4907
# Allow the process to execute the program.
#line 4907
# 
#line 4907
allow fsadm_t insmod_exec_t:file { getattr execute };
#line 4907

#line 4907
#
#line 4907
# Allow the process to reap the new domain.
#line 4907
#
#line 4907
allow insmod_t fsadm_t:process sigchld;
#line 4907

#line 4907
#
#line 4907
# Allow the new domain to inherit and use file 
#line 4907
# descriptions from the creating process and vice versa.
#line 4907
#
#line 4907
allow insmod_t fsadm_t:fd use;
#line 4907
allow fsadm_t insmod_t:fd use;
#line 4907

#line 4907
#
#line 4907
# Allow the new domain to write back to the old domain via a pipe.
#line 4907
#
#line 4907
allow insmod_t fsadm_t:fifo_file { ioctl read getattr lock write append };
#line 4907

#line 4907
#
#line 4907
# Allow the new domain to read and execute the program.
#line 4907
#
#line 4907
allow insmod_t insmod_exec_t:file { read getattr lock execute ioctl };
#line 4907

#line 4907
#
#line 4907
# Allow the new domain to be entered via the program.
#line 4907
#
#line 4907
allow insmod_t insmod_exec_t:file entrypoint;
#line 4907

#line 4907
type_transition fsadm_t insmod_exec_t:process insmod_t;
#line 4907


# Allow console log change (updfstab)
allow fsadm_t kernel_t:system syslog_console;

# Access terminals.
allow fsadm_t { sysadm_tty_device_t sysadm_devpts_t }:chr_file { ioctl read getattr lock write append };


# read localization information
allow fsadm_t locale_t:dir { read getattr lock search ioctl };
allow fsadm_t locale_t:{file lnk_file} { read getattr lock ioctl };
#DESC Getty - Manage ttys
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

#################################
#
# Rules for the getty_t domain.
#

#line 4928

#line 4928
type getty_t, domain, privlog , mlstrustedwriter, privfd;
#line 4928
type getty_exec_t, file_type, sysadmfile, exec_type;
#line 4928

#line 4928
role system_r types getty_t;
#line 4928

#line 4928

#line 4928

#line 4928

#line 4928
#
#line 4928
# Allow the process to transition to the new domain.
#line 4928
#
#line 4928
allow initrc_t getty_t:process transition;
#line 4928

#line 4928
#
#line 4928
# Allow the process to execute the program.
#line 4928
# 
#line 4928
allow initrc_t getty_exec_t:file { getattr execute };
#line 4928

#line 4928
#
#line 4928
# Allow the process to reap the new domain.
#line 4928
#
#line 4928
allow getty_t initrc_t:process sigchld;
#line 4928

#line 4928
#
#line 4928
# Allow the new domain to inherit and use file 
#line 4928
# descriptions from the creating process and vice versa.
#line 4928
#
#line 4928
allow getty_t initrc_t:fd use;
#line 4928
allow initrc_t getty_t:fd use;
#line 4928

#line 4928
#
#line 4928
# Allow the new domain to write back to the old domain via a pipe.
#line 4928
#
#line 4928
allow getty_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 4928

#line 4928
#
#line 4928
# Allow the new domain to read and execute the program.
#line 4928
#
#line 4928
allow getty_t getty_exec_t:file { read getattr lock execute ioctl };
#line 4928

#line 4928
#
#line 4928
# Allow the new domain to be entered via the program.
#line 4928
#
#line 4928
allow getty_t getty_exec_t:file entrypoint;
#line 4928

#line 4928
type_transition initrc_t getty_exec_t:process getty_t;
#line 4928

#line 4928

#line 4928
# Inherit and use descriptors from init.
#line 4928
allow getty_t init_t:fd use;
#line 4928
allow getty_t init_t:process sigchld;
#line 4928
allow getty_t privfd:fd use;
#line 4928
allow getty_t newrole_t:process sigchld;
#line 4928
allow getty_t self:process { { sigchld sigkill sigstop signull signal } fork };
#line 4928

#line 4928

#line 4928
allow getty_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4928
allow getty_t ld_so_t:file { read getattr lock execute ioctl };
#line 4928
allow getty_t ld_so_t:file execute_no_trans;
#line 4928
allow getty_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4928
allow getty_t shlib_t:file { read getattr lock execute ioctl };
#line 4928
allow getty_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4928
allow getty_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4928
allow getty_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4928

#line 4928

#line 4928
allow getty_t { self proc_t }:dir { read getattr lock search ioctl };
#line 4928
allow getty_t { self proc_t }:lnk_file read;
#line 4928

#line 4928
allow getty_t device_t:dir { getattr search };
#line 4928
allow getty_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4928
allow getty_t console_device_t:chr_file { ioctl read getattr lock write append };
#line 4928
allow getty_t initrc_devpts_t:chr_file { ioctl read getattr lock write append };
#line 4928

#line 4928
# Create pid file.
#line 4928
allow getty_t var_t:dir { getattr search };
#line 4928
type var_run_getty_t, file_type, sysadmfile, pidfile;
#line 4928

#line 4928

#line 4928

#line 4928

#line 4928
#
#line 4928
# Allow the process to modify the directory.
#line 4928
#
#line 4928
allow getty_t var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4928

#line 4928
#
#line 4928
# Allow the process to create the file.
#line 4928
#
#line 4928

#line 4928
allow getty_t var_run_getty_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4928
allow getty_t var_run_getty_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4928

#line 4928

#line 4928

#line 4928
type_transition getty_t var_run_t:dir var_run_getty_t;
#line 4928
type_transition getty_t var_run_t:{ file lnk_file sock_file fifo_file } var_run_getty_t;
#line 4928

#line 4928

#line 4928

#line 4928

#line 4928
allow getty_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 4928

#line 4928
# for daemons that look at /root on startup
#line 4928
dontaudit getty_t sysadm_home_dir_t:dir search;
#line 4928

#line 4928
# for df
#line 4928
allow getty_t fs_type:filesystem getattr;
#line 4928


type etc_getty_t, file_type, sysadmfile;

#line 4931
allow getty_t etc_getty_t:dir { read getattr lock search ioctl };
#line 4931
allow getty_t etc_getty_t:{ file lnk_file } { read getattr lock ioctl };
#line 4931


allow getty_t console_device_t:chr_file setattr;


#line 4935
type getty_tmp_t, file_type, sysadmfile, tmpfile ;
#line 4935

#line 4935

#line 4935

#line 4935

#line 4935
#
#line 4935
# Allow the process to modify the directory.
#line 4935
#
#line 4935
allow getty_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4935

#line 4935
#
#line 4935
# Allow the process to create the file.
#line 4935
#
#line 4935

#line 4935
allow getty_t getty_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4935
allow getty_t getty_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4935

#line 4935

#line 4935

#line 4935
type_transition getty_t tmp_t:dir getty_tmp_t;
#line 4935
type_transition getty_t tmp_t:{ file lnk_file sock_file fifo_file } getty_tmp_t;
#line 4935

#line 4935

#line 4935

#line 4935


#line 4936
type getty_log_t, file_type, sysadmfile, logfile;
#line 4936

#line 4936

#line 4936

#line 4936

#line 4936
#
#line 4936
# Allow the process to modify the directory.
#line 4936
#
#line 4936
allow getty_t var_log_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4936

#line 4936
#
#line 4936
# Allow the process to create the file.
#line 4936
#
#line 4936

#line 4936
allow getty_t getty_log_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4936
allow getty_t getty_log_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 4936

#line 4936

#line 4936

#line 4936
type_transition getty_t var_log_t:dir getty_log_t;
#line 4936
type_transition getty_t var_log_t:{ file lnk_file sock_file fifo_file } getty_log_t;
#line 4936

#line 4936

#line 4936

#line 4936


allow getty_t { etc_t etc_runtime_t }:file { getattr read };
allow getty_t etc_t:lnk_file read;
allow getty_t self:process { getpgid getsession };
allow getty_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
allow getty_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# for ldap and other authentication services
allow getty_t resolv_conf_t:file { getattr read };

# to allow w to display everyone...
#allow userdomain ttyfile:chr_file getattr;

# Use capabilities.
allow getty_t getty_t:capability { dac_override chown sys_tty_config };

# fbgetty needs fsetid for some reason
allow getty_t getty_t:capability fsetid;

# Run getty in its own domain.

#line 4957

#line 4957

#line 4957
#
#line 4957
# Allow the process to transition to the new domain.
#line 4957
#
#line 4957
allow init_t getty_t:process transition;
#line 4957

#line 4957
#
#line 4957
# Allow the process to execute the program.
#line 4957
# 
#line 4957
allow init_t getty_exec_t:file { getattr execute };
#line 4957

#line 4957
#
#line 4957
# Allow the process to reap the new domain.
#line 4957
#
#line 4957
allow getty_t init_t:process sigchld;
#line 4957

#line 4957
#
#line 4957
# Allow the new domain to inherit and use file 
#line 4957
# descriptions from the creating process and vice versa.
#line 4957
#
#line 4957
allow getty_t init_t:fd use;
#line 4957
allow init_t getty_t:fd use;
#line 4957

#line 4957
#
#line 4957
# Allow the new domain to write back to the old domain via a pipe.
#line 4957
#
#line 4957
allow getty_t init_t:fifo_file { ioctl read getattr lock write append };
#line 4957

#line 4957
#
#line 4957
# Allow the new domain to read and execute the program.
#line 4957
#
#line 4957
allow getty_t getty_exec_t:file { read getattr lock execute ioctl };
#line 4957

#line 4957
#
#line 4957
# Allow the new domain to be entered via the program.
#line 4957
#
#line 4957
allow getty_t getty_exec_t:file entrypoint;
#line 4957

#line 4957
type_transition init_t getty_exec_t:process getty_t;
#line 4957


# Inherit and use descriptors from init.
allow getty_t init_t:fd use;

# Run login in local_login_t domain.
allow getty_t bin_t:dir search;

#line 4964

#line 4964

#line 4964

#line 4964
#
#line 4964
# Allow the process to transition to the new domain.
#line 4964
#
#line 4964
allow getty_t local_login_t:process transition;
#line 4964

#line 4964
#
#line 4964
# Allow the process to execute the program.
#line 4964
# 
#line 4964
allow getty_t login_exec_t:file { getattr execute };
#line 4964

#line 4964
#
#line 4964
# Allow the process to reap the new domain.
#line 4964
#
#line 4964
allow local_login_t getty_t:process sigchld;
#line 4964

#line 4964
#
#line 4964
# Allow the new domain to inherit and use file 
#line 4964
# descriptions from the creating process and vice versa.
#line 4964
#
#line 4964
allow local_login_t getty_t:fd use;
#line 4964
allow getty_t local_login_t:fd use;
#line 4964

#line 4964
#
#line 4964
# Allow the new domain to write back to the old domain via a pipe.
#line 4964
#
#line 4964
allow local_login_t getty_t:fifo_file { ioctl read getattr lock write append };
#line 4964

#line 4964
#
#line 4964
# Allow the new domain to read and execute the program.
#line 4964
#
#line 4964
allow local_login_t login_exec_t:file { read getattr lock execute ioctl };
#line 4964

#line 4964
#
#line 4964
# Allow the new domain to be entered via the program.
#line 4964
#
#line 4964
allow local_login_t login_exec_t:file entrypoint;
#line 4964

#line 4964
type_transition getty_t login_exec_t:process local_login_t;
#line 4964

#line 4964
allow getty_t login_exec_t:file read;
#line 4964


# Write to /var/run/utmp.
allow getty_t initrc_var_run_t:file { ioctl read getattr lock write append };

# Write to /var/log/wtmp.
allow getty_t wtmp_t:file { ioctl read getattr lock write append };

# Chown, chmod, read and write ttys.
allow getty_t tty_device_t:chr_file { setattr { ioctl read getattr lock write append } };
allow getty_t ttyfile:chr_file { setattr { ioctl read getattr lock write append } };



#line 4977
allow getty_t var_lock_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 4977
allow getty_t var_lock_t:{ file lnk_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 4977

#DESC Groupadd - Manage system groups
#
# Authors:  David Caplan, dac@tresys.com
#	    (Based on useradd.te by Chris Vance <cvance@tislabs.com>)
#

#################################
#
# Rules for the groupadd_t domain.
#
# groupadd_t is the domain of the groupadd/mod/del programs when
# executed through the sgroupadd/mod/del wrapper.
type groupadd_t, domain, privlog, auth, privowner;
role sysadm_r types groupadd_t;


#line 4993
# Access other processes in the same domain.
#line 4993
allow groupadd_t self:process *;
#line 4993

#line 4993
# Access /proc/PID files for processes in the same domain.
#line 4993
allow groupadd_t self:dir { read getattr lock search ioctl };
#line 4993
allow groupadd_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 4993

#line 4993
# Access file descriptions, pipes, and sockets
#line 4993
# created by processes in the same domain.
#line 4993
allow groupadd_t self:fd *;
#line 4993
allow groupadd_t self:fifo_file { ioctl read getattr lock write append };
#line 4993
allow groupadd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 4993
allow groupadd_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 4993

#line 4993
# Allow the domain to communicate with other processes in the same domain.
#line 4993
allow groupadd_t self:unix_dgram_socket sendto;
#line 4993
allow groupadd_t self:unix_stream_socket connectto;
#line 4993

#line 4993
# Access System V IPC objects created by processes in the same domain.
#line 4993
allow groupadd_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 4993
allow groupadd_t self:msg  { send receive };
#line 4993
allow groupadd_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 4993
allow groupadd_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 4993

#line 4993


#line 4994
allow groupadd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 4994
allow groupadd_t ld_so_t:file { read getattr lock execute ioctl };
#line 4994
allow groupadd_t ld_so_t:file execute_no_trans;
#line 4994
allow groupadd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 4994
allow groupadd_t shlib_t:file { read getattr lock execute ioctl };
#line 4994
allow groupadd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 4994
allow groupadd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 4994
allow groupadd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 4994


type groupadd_exec_t, file_type, sysadmfile, exec_type;

#line 4997

#line 4997

#line 4997
#
#line 4997
# Allow the process to transition to the new domain.
#line 4997
#
#line 4997
allow sysadm_t groupadd_t :process transition;
#line 4997

#line 4997
#
#line 4997
# Allow the process to execute the program.
#line 4997
# 
#line 4997
allow sysadm_t groupadd_exec_t:file { getattr execute };
#line 4997

#line 4997
#
#line 4997
# Allow the process to reap the new domain.
#line 4997
#
#line 4997
allow groupadd_t  sysadm_t:process sigchld;
#line 4997

#line 4997
#
#line 4997
# Allow the new domain to inherit and use file 
#line 4997
# descriptions from the creating process and vice versa.
#line 4997
#
#line 4997
allow groupadd_t  sysadm_t:fd use;
#line 4997
allow sysadm_t groupadd_t :fd use;
#line 4997

#line 4997
#
#line 4997
# Allow the new domain to write back to the old domain via a pipe.
#line 4997
#
#line 4997
allow groupadd_t  sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 4997

#line 4997
#
#line 4997
# Allow the new domain to read and execute the program.
#line 4997
#
#line 4997
allow groupadd_t  groupadd_exec_t:file { read getattr lock execute ioctl };
#line 4997

#line 4997
#
#line 4997
# Allow the new domain to be entered via the program.
#line 4997
#
#line 4997
allow groupadd_t  groupadd_exec_t:file entrypoint;
#line 4997

#line 4997
type_transition sysadm_t groupadd_exec_t:process groupadd_t ;
#line 4997


# Use capabilities.
# need more if users can run gpasswd
allow groupadd_t groupadd_t:capability { dac_override };

# Allow access to context for shadow file
allow groupadd_t security_t:security { context_to_sid };

# Inherit and use descriptors from login.
allow groupadd_t privfd:fd use;

# Execute /usr/sbin/{groupadd,groupdel,groupmod}, /usr/bin/gpasswd.
allow groupadd_t { bin_t sbin_t }:dir { read getattr lock search ioctl };

#line 5011
allow groupadd_t { sbin_t bin_t }:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5011


# Update /etc/shadow and /etc/passwd

#line 5014

#line 5014

#line 5014

#line 5014
#
#line 5014
# Allow the process to modify the directory.
#line 5014
#
#line 5014
allow groupadd_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5014

#line 5014
#
#line 5014
# Allow the process to create the file.
#line 5014
#
#line 5014

#line 5014
allow groupadd_t shadow_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5014
allow groupadd_t shadow_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5014

#line 5014

#line 5014

#line 5014
type_transition groupadd_t etc_t:dir shadow_t;
#line 5014
type_transition groupadd_t etc_t:{ file lnk_file sock_file fifo_file } shadow_t;
#line 5014

#line 5014

#line 5014

allow groupadd_t etc_t:file { create ioctl read getattr lock write setattr append link unlink rename };

allow groupadd_t { etc_t shadow_t }:file { relabelfrom relabelto };

# some apps ask for these accesses, but seems to work regardless
dontaudit groupadd_t initrc_var_run_t:file { write };
dontaudit groupadd_t { var_run_t device_t var_t }:dir { search };

# Access terminals.
allow groupadd_t ttyfile:chr_file { ioctl read getattr lock write append };
allow groupadd_t ptyfile:chr_file { ioctl read getattr lock write append };












#DESC Ifconfig - Configure network interfaces
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

#################################
#
# Rules for the ifconfig_t domain.
#
# ifconfig_t is the domain for the ifconfig program.
# ifconfig_exec_t is the type of the corresponding program.
#
type ifconfig_t, domain, privlog;
type ifconfig_exec_t, file_type, sysadmfile, exec_type;

role system_r types ifconfig_t;
role sysadm_r types ifconfig_t;


#line 5056
allow ifconfig_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5056
allow ifconfig_t ld_so_t:file { read getattr lock execute ioctl };
#line 5056
allow ifconfig_t ld_so_t:file execute_no_trans;
#line 5056
allow ifconfig_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5056
allow ifconfig_t shlib_t:file { read getattr lock execute ioctl };
#line 5056
allow ifconfig_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5056
allow ifconfig_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5056
allow ifconfig_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5056


#line 5057
# Access other processes in the same domain.
#line 5057
allow ifconfig_t self:process *;
#line 5057

#line 5057
# Access /proc/PID files for processes in the same domain.
#line 5057
allow ifconfig_t self:dir { read getattr lock search ioctl };
#line 5057
allow ifconfig_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5057

#line 5057
# Access file descriptions, pipes, and sockets
#line 5057
# created by processes in the same domain.
#line 5057
allow ifconfig_t self:fd *;
#line 5057
allow ifconfig_t self:fifo_file { ioctl read getattr lock write append };
#line 5057
allow ifconfig_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 5057
allow ifconfig_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 5057

#line 5057
# Allow the domain to communicate with other processes in the same domain.
#line 5057
allow ifconfig_t self:unix_dgram_socket sendto;
#line 5057
allow ifconfig_t self:unix_stream_socket connectto;
#line 5057

#line 5057
# Access System V IPC objects created by processes in the same domain.
#line 5057
allow ifconfig_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 5057
allow ifconfig_t self:msg  { send receive };
#line 5057
allow ifconfig_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 5057
allow ifconfig_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 5057

#line 5057



#line 5059

#line 5059

#line 5059
#
#line 5059
# Allow the process to transition to the new domain.
#line 5059
#
#line 5059
allow initrc_t ifconfig_t:process transition;
#line 5059

#line 5059
#
#line 5059
# Allow the process to execute the program.
#line 5059
# 
#line 5059
allow initrc_t ifconfig_exec_t:file { getattr execute };
#line 5059

#line 5059
#
#line 5059
# Allow the process to reap the new domain.
#line 5059
#
#line 5059
allow ifconfig_t initrc_t:process sigchld;
#line 5059

#line 5059
#
#line 5059
# Allow the new domain to inherit and use file 
#line 5059
# descriptions from the creating process and vice versa.
#line 5059
#
#line 5059
allow ifconfig_t initrc_t:fd use;
#line 5059
allow initrc_t ifconfig_t:fd use;
#line 5059

#line 5059
#
#line 5059
# Allow the new domain to write back to the old domain via a pipe.
#line 5059
#
#line 5059
allow ifconfig_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 5059

#line 5059
#
#line 5059
# Allow the new domain to read and execute the program.
#line 5059
#
#line 5059
allow ifconfig_t ifconfig_exec_t:file { read getattr lock execute ioctl };
#line 5059

#line 5059
#
#line 5059
# Allow the new domain to be entered via the program.
#line 5059
#
#line 5059
allow ifconfig_t ifconfig_exec_t:file entrypoint;
#line 5059

#line 5059
type_transition initrc_t ifconfig_exec_t:process ifconfig_t;
#line 5059


#line 5060

#line 5060

#line 5060
#
#line 5060
# Allow the process to transition to the new domain.
#line 5060
#
#line 5060
allow sysadm_t ifconfig_t:process transition;
#line 5060

#line 5060
#
#line 5060
# Allow the process to execute the program.
#line 5060
# 
#line 5060
allow sysadm_t ifconfig_exec_t:file { getattr execute };
#line 5060

#line 5060
#
#line 5060
# Allow the process to reap the new domain.
#line 5060
#
#line 5060
allow ifconfig_t sysadm_t:process sigchld;
#line 5060

#line 5060
#
#line 5060
# Allow the new domain to inherit and use file 
#line 5060
# descriptions from the creating process and vice versa.
#line 5060
#
#line 5060
allow ifconfig_t sysadm_t:fd use;
#line 5060
allow sysadm_t ifconfig_t:fd use;
#line 5060

#line 5060
#
#line 5060
# Allow the new domain to write back to the old domain via a pipe.
#line 5060
#
#line 5060
allow ifconfig_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 5060

#line 5060
#
#line 5060
# Allow the new domain to read and execute the program.
#line 5060
#
#line 5060
allow ifconfig_t ifconfig_exec_t:file { read getattr lock execute ioctl };
#line 5060

#line 5060
#
#line 5060
# Allow the new domain to be entered via the program.
#line 5060
#
#line 5060
allow ifconfig_t ifconfig_exec_t:file entrypoint;
#line 5060

#line 5060
type_transition sysadm_t ifconfig_exec_t:process ifconfig_t;
#line 5060


# Use capabilities.
allow ifconfig_t ifconfig_t:capability { sys_module net_admin };

# Inherit and use descriptors from init.
allow ifconfig_t init_t:fd use;

# Execute insmod.

#line 5069

#line 5069

#line 5069
#
#line 5069
# Allow the process to transition to the new domain.
#line 5069
#
#line 5069
allow ifconfig_t insmod_t:process transition;
#line 5069

#line 5069
#
#line 5069
# Allow the process to execute the program.
#line 5069
# 
#line 5069
allow ifconfig_t insmod_exec_t:file { getattr execute };
#line 5069

#line 5069
#
#line 5069
# Allow the process to reap the new domain.
#line 5069
#
#line 5069
allow insmod_t ifconfig_t:process sigchld;
#line 5069

#line 5069
#
#line 5069
# Allow the new domain to inherit and use file 
#line 5069
# descriptions from the creating process and vice versa.
#line 5069
#
#line 5069
allow insmod_t ifconfig_t:fd use;
#line 5069
allow ifconfig_t insmod_t:fd use;
#line 5069

#line 5069
#
#line 5069
# Allow the new domain to write back to the old domain via a pipe.
#line 5069
#
#line 5069
allow insmod_t ifconfig_t:fifo_file { ioctl read getattr lock write append };
#line 5069

#line 5069
#
#line 5069
# Allow the new domain to read and execute the program.
#line 5069
#
#line 5069
allow insmod_t insmod_exec_t:file { read getattr lock execute ioctl };
#line 5069

#line 5069
#
#line 5069
# Allow the new domain to be entered via the program.
#line 5069
#
#line 5069
allow insmod_t insmod_exec_t:file entrypoint;
#line 5069

#line 5069
type_transition ifconfig_t insmod_exec_t:process insmod_t;
#line 5069


#line 5073


# Access /proc
allow ifconfig_t proc_t:dir { read getattr lock search ioctl };
allow ifconfig_t proc_t:file { read getattr lock ioctl };

allow ifconfig_t privfd:fd use;

# Create UDP sockets, necessary when called from dhcpc
allow ifconfig_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# Access terminals.
allow ifconfig_t { initrc_devpts_t { sysadm_tty_device_t sysadm_devpts_t } }:chr_file { ioctl read getattr lock write append };


allow ifconfig_t tun_tap_device_t:chr_file { read write };

# ifconfig attempts to create to search some sysctl entries.
# Don't audit those attempts; comment out these rules if it is desired to
# see the denials.
dontaudit ifconfig_t sysctl_t:dir search;
#DESC Initrc - System initialization scripts
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

#################################
#
# Rules for the initrc_t domain.
#
# initrc_t is the domain of the init rc scripts.
# initrc_exec_t is the type of the init program.
#
#line 5111

#line 5111
type initrc_t, domain, privlog, privowner, privmail;
#line 5111

role system_r types initrc_t;

#line 5113
allow initrc_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5113
allow initrc_t ld_so_t:file { read getattr lock execute ioctl };
#line 5113
allow initrc_t ld_so_t:file execute_no_trans;
#line 5113
allow initrc_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5113
allow initrc_t shlib_t:file { read getattr lock execute ioctl };
#line 5113
allow initrc_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5113
allow initrc_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5113
allow initrc_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5113
;
type initrc_exec_t, file_type, sysadmfile, exec_type;

# read files in /etc/init.d
allow initrc_t etc_t:lnk_file { read getattr lock ioctl };

# read localization information
allow initrc_t locale_t:dir { read getattr lock search ioctl };
allow initrc_t locale_t:{file lnk_file} { read getattr lock ioctl };

# Read system information files in /proc.
allow initrc_t proc_t:dir { read getattr lock search ioctl };
allow initrc_t proc_t:{ file lnk_file } { read getattr lock ioctl };

# Allow IPC with self
allow initrc_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
allow initrc_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
allow initrc_t self:fifo_file { ioctl read getattr lock write append };

# Read the root directory of a usbdevfs filesystem, and
# the devices and drivers files.  Permit stating of the
# device nodes, but nothing else.
allow initrc_t usbdevfs_t:dir { read getattr lock search ioctl };
allow initrc_t usbdevfs_t:{ file lnk_file } { read getattr lock ioctl };
allow initrc_t usbdevfs_device_t:file getattr;

# allow initrc to fork and renice itself
allow initrc_t self:process { fork sigchld setsched };

# Can create ptys for open_init_pty

#line 5143

#line 5143
type initrc_devpts_t, file_type, sysadmfile, ptyfile ;
#line 5143

#line 5143
# Allow the pty to be associated with the file system.
#line 5143
allow initrc_devpts_t devpts_t:filesystem associate;
#line 5143

#line 5143
# Access the pty master multiplexer.
#line 5143
allow initrc_t ptmx_t:chr_file { ioctl read getattr lock write append };
#line 5143

#line 5143
# Label pty files with a derived type.
#line 5143
type_transition initrc_t devpts_t:chr_file initrc_devpts_t;
#line 5143

#line 5143
# Read and write my pty files.
#line 5143
allow initrc_t initrc_devpts_t:chr_file { setattr { ioctl read getattr lock write append } };
#line 5143

#line 5143

#line 5143

#line 5143


type initrc_tmp_t, file_type, sysadmfile, tmpfile;

#line 5146

#line 5146

#line 5146

#line 5146
#
#line 5146
# Allow the process to modify the directory.
#line 5146
#
#line 5146
allow initrc_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5146

#line 5146
#
#line 5146
# Allow the process to create the file.
#line 5146
#
#line 5146

#line 5146
allow initrc_t initrc_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5146
allow initrc_t initrc_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5146

#line 5146

#line 5146

#line 5146
type_transition initrc_t tmp_t:dir initrc_tmp_t;
#line 5146
type_transition initrc_t tmp_t:{ file lnk_file sock_file fifo_file } initrc_tmp_t;
#line 5146

#line 5146

#line 5146


type initrc_var_run_t, file_type, sysadmfile, pidfile;

#line 5149

#line 5149

#line 5149

#line 5149
#
#line 5149
# Allow the process to modify the directory.
#line 5149
#
#line 5149
allow initrc_t var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5149

#line 5149
#
#line 5149
# Allow the process to create the file.
#line 5149
#
#line 5149

#line 5149
allow initrc_t initrc_var_run_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5149
allow initrc_t initrc_var_run_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5149

#line 5149

#line 5149

#line 5149
type_transition initrc_t var_run_t:dir initrc_var_run_t;
#line 5149
type_transition initrc_t var_run_t:{ file lnk_file sock_file fifo_file } initrc_var_run_t;
#line 5149

#line 5149

#line 5149

allow initrc_t var_run_t:{ file sock_file lnk_file } unlink;

allow initrc_t framebuf_device_t:chr_file { read getattr lock ioctl };

# Use capabilities.
allow initrc_t initrc_t:capability ~sys_module;

# Use system operations.
allow initrc_t kernel_t:system *;

# Audit grantings of the avc_toggle permission to initrc_t.
# The initrc_t domain is granted this permission for 
# people who want to use a development kernel and toggle
# into enforcing mode from an /etc/rc.d script.
# Due to its sensitivity, we always audit it.
auditallow initrc_t kernel_t:system avc_toggle;

# Set values in /proc/sys.

#line 5168
allow initrc_t sysctl_t:dir { read getattr lock search ioctl };
#line 5168
allow initrc_t sysctl_t:file { setattr { ioctl read getattr lock write append } };
#line 5168
allow initrc_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 5168
allow initrc_t sysctl_fs_t:file { setattr { ioctl read getattr lock write append } };
#line 5168
allow initrc_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 5168
allow initrc_t sysctl_kernel_t:file { setattr { ioctl read getattr lock write append } };
#line 5168
allow initrc_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 5168
allow initrc_t sysctl_net_t:file { setattr { ioctl read getattr lock write append } };
#line 5168
allow initrc_t sysctl_net_unix_t:dir { read getattr lock search ioctl };
#line 5168
allow initrc_t sysctl_net_unix_t:file { setattr { ioctl read getattr lock write append } };
#line 5168
allow initrc_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 5168
allow initrc_t sysctl_vm_t:file { setattr { ioctl read getattr lock write append } };
#line 5168
allow initrc_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 5168
allow initrc_t sysctl_dev_t:file { setattr { ioctl read getattr lock write append } };
#line 5168
allow initrc_t sysctl_modprobe_t:file { setattr { ioctl read getattr lock write append } };
#line 5168


# Run helper programs in the initrc_t domain.
allow initrc_t {bin_t sbin_t }:dir { read getattr lock search ioctl };
allow initrc_t {bin_t sbin_t }:lnk_file read;

#line 5173
allow initrc_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5173


#line 5174
allow initrc_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5174


#line 5175
allow initrc_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5175


#line 5176
allow initrc_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5176


#line 5177
allow initrc_t exec_type:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5177



# Read conf.modules.
allow initrc_t modules_conf_t:file { read getattr lock ioctl };

# Run other rc scripts in the initrc_t domain.

#line 5184
allow initrc_t initrc_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5184


# Run init (telinit) in the initrc_t domain.

#line 5187
allow initrc_t init_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5187


# Communicate with the init process.
allow initrc_t initctl_t:fifo_file { ioctl read getattr lock write append };

# Send messages to portmap and ypbind.



# Search persistent label mappings.
allow initrc_t file_labels_t:dir { read getattr lock search ioctl };
allow initrc_t file_labels_t:file { getattr };

# Read /proc/PID directories for all domains.
allow initrc_t domain:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
allow initrc_t domain:dir { read getattr lock search ioctl };

# Mount and unmount file systems.
allow initrc_t fs_type:filesystem { mount remount unmount getattr };
allow initrc_t file_t:dir { read search getattr mounton };

# Create runtime files in /etc, e.g. /etc/mtab, /etc/HOSTNAME.

#line 5209

#line 5209

#line 5209

#line 5209
#
#line 5209
# Allow the process to modify the directory.
#line 5209
#
#line 5209
allow initrc_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5209

#line 5209
#
#line 5209
# Allow the process to create the file.
#line 5209
#
#line 5209

#line 5209
allow initrc_t etc_runtime_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 5209

#line 5209

#line 5209

#line 5209
type_transition initrc_t etc_t:file etc_runtime_t;
#line 5209

#line 5209

#line 5209


# Update /etc/ld.so.cache.
allow initrc_t ld_so_cache_t:file { ioctl read getattr lock write append };

#line 5217


#line 5223


# Update /var/log/wtmp and /var/log/dmesg.
allow initrc_t wtmp_t:file { setattr { ioctl read getattr lock write append } };
allow initrc_t var_log_t:file { setattr { ioctl read getattr lock write append } };
allow initrc_t lastlog_t:file { setattr { ioctl read getattr lock write append } };

# remove old locks
allow initrc_t lockfile:dir { read getattr lock search ioctl add_name remove_name write };
allow initrc_t lockfile:file { getattr unlink };

# Access /var/lib/random-seed.
allow initrc_t var_lib_t:file { ioctl read getattr lock write append };
allow initrc_t var_lib_t:file unlink;

# Create lock file.
allow initrc_t var_lock_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
allow initrc_t var_lock_t:file { create ioctl read getattr lock write setattr append link unlink rename };

# Set the clock.
allow initrc_t clock_device_t:{ chr_file blk_file } { ioctl read getattr lock write append };

# Kill all processes.
allow initrc_t domain:process { sigchld sigkill sigstop signull signal };

# Read and unlink /var/run/*.pid files.
allow initrc_t pidfile:file { getattr read unlink };

# Write to /dev/urandom.
allow initrc_t random_device_t:chr_file { ioctl read getattr lock write append };

# Access /dev/psaux (for kudzu).
allow initrc_t psaux_t:chr_file { ioctl read getattr lock write append };

# Set device ownerships/modes.
allow initrc_t framebuf_device_t:lnk_file read;
allow initrc_t framebuf_device_t:{ chr_file blk_file } setattr;
allow initrc_t misc_device_t:{ chr_file blk_file } setattr;
allow initrc_t device_t:{ chr_file blk_file } setattr;
allow initrc_t fixed_disk_device_t:{ chr_file blk_file } setattr;
allow initrc_t removable_device_t:{ chr_file blk_file } setattr;

# Stat any file.
allow initrc_t file_type:{ file lnk_file sock_file fifo_file chr_file blk_file } getattr;
allow initrc_t file_type:dir { search getattr };

# Read and write console and ttys.
allow initrc_t devtty_t:chr_file { ioctl read getattr lock write append };
allow initrc_t console_device_t:chr_file { ioctl read getattr lock write append };
allow initrc_t tty_device_t:chr_file { ioctl read getattr lock write append };
allow initrc_t ttyfile:chr_file { ioctl read getattr lock write append };
allow initrc_t ptyfile:chr_file { ioctl read getattr lock write append };

# Reset tty labels.
allow initrc_t ttyfile:chr_file relabelfrom;
allow initrc_t tty_device_t:chr_file relabelto;

# Create and read /boot/kernel.h.
# Redhat systems typically create this file at boot time.
allow initrc_t boot_t:lnk_file { read getattr lock ioctl };

#line 5283

#line 5283

#line 5283

#line 5283
#
#line 5283
# Allow the process to modify the directory.
#line 5283
#
#line 5283
allow initrc_t boot_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5283

#line 5283
#
#line 5283
# Allow the process to create the file.
#line 5283
#
#line 5283

#line 5283
allow initrc_t boot_runtime_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5283
allow initrc_t boot_runtime_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5283

#line 5283

#line 5283

#line 5283
type_transition initrc_t boot_t:dir boot_runtime_t;
#line 5283
type_transition initrc_t boot_t:{ file lnk_file sock_file fifo_file } boot_runtime_t;
#line 5283

#line 5283

#line 5283


# Delete and re-create /boot/System.map.
allow initrc_t boot_t:dir { read getattr write remove_name add_name };
allow initrc_t boot_t:lnk_file { read unlink create };
allow initrc_t system_map_t:{ file lnk_file } { read getattr lock ioctl };

# Unlink /halt.
allow initrc_t root_t:dir { search write remove_name };
allow initrc_t root_t:file { unlink write };



allow initrc_t var_spool_t:file { ioctl read getattr lock write append };



#
# quota control
#
allow initrc_t fs_type:filesystem { quotamod quotaget };

# Access the mouse (for kudzu).
allow initrc_t mouse_device_t:chr_file { ioctl read getattr lock write append };

# Allow access to the sysadm TTYs. Note that this will give access to the 
# TTYs to any process in the initrc_t domain. Therefore, daemons and such
# started from init should be placed in their own domain.
allow initrc_t { sysadm_tty_device_t sysadm_devpts_t }:chr_file { ioctl read getattr lock write append };

# Access sound device and files.
allow initrc_t sound_device_t:chr_file { setattr ioctl read write };


#line 5320


# Update /var/log/ksyms.*.

#line 5323

#line 5323

#line 5323

#line 5323
#
#line 5323
# Allow the process to modify the directory.
#line 5323
#
#line 5323
allow initrc_t var_log_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5323

#line 5323
#
#line 5323
# Allow the process to create the file.
#line 5323
#
#line 5323

#line 5323
allow initrc_t var_log_ksyms_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5323
allow initrc_t var_log_ksyms_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5323

#line 5323

#line 5323

#line 5323
type_transition initrc_t var_log_t:dir var_log_ksyms_t;
#line 5323
type_transition initrc_t var_log_t:{ file lnk_file sock_file fifo_file } var_log_ksyms_t;
#line 5323

#line 5323

#line 5323


#line 5327


# Access /dev/fd0 (for kudzu). Need a separate domain for kudzu?
allow initrc_t removable_device_t:blk_file { ioctl read getattr lock write append };

#line 5335


# Create and delete /.autofsck
allow initrc_t root_t:dir { search write add_name };
allow initrc_t root_t:file { create setattr unlink getattr };
allow initrc_t file_t:file { unlink getattr };

# Read user home directories.
allow initrc_t { home_root_t home_type }:dir { read getattr lock search ioctl };
allow initrc_t home_type:file { read getattr lock ioctl };

# for system start scripts
allow initrc_t pidfile:dir { read getattr lock search ioctl add_name remove_name write };
allow initrc_t pidfile:sock_file unlink;
allow initrc_t tmpfile:sock_file unlink;

#line 5350
allow initrc_t var_lib_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5350
allow initrc_t var_lib_t:{ file lnk_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5350


# allow start scripts to clean /tmp
allow initrc_t tmpfile:dir { { read getattr lock search ioctl add_name remove_name write } rmdir };
allow initrc_t tmpfile:{ file lnk_file sock_file fifo_file } { getattr unlink };

#################################
#
# Rules for the run_init_t domain.
#

#line 5360
type run_init_exec_t, file_type, exec_type, sysadmfile;
#line 5360

#line 5360
# domain for program to run in, needs to change role (privrole), change
#line 5360
# identity to system_u (privuser), log failures to syslog (privlog) and
#line 5360
# authenticate users (auth)
#line 5360
type run_init_t, domain, privrole, privuser, privlog, auth;
#line 5360

#line 5360

#line 5360

#line 5360
#
#line 5360
# Allow the process to transition to the new domain.
#line 5360
#
#line 5360
allow sysadm_t run_init_t:process transition;
#line 5360

#line 5360
#
#line 5360
# Allow the process to execute the program.
#line 5360
# 
#line 5360
allow sysadm_t run_init_exec_t:file { getattr execute };
#line 5360

#line 5360
#
#line 5360
# Allow the process to reap the new domain.
#line 5360
#
#line 5360
allow run_init_t sysadm_t:process sigchld;
#line 5360

#line 5360
#
#line 5360
# Allow the new domain to inherit and use file 
#line 5360
# descriptions from the creating process and vice versa.
#line 5360
#
#line 5360
allow run_init_t sysadm_t:fd use;
#line 5360
allow sysadm_t run_init_t:fd use;
#line 5360

#line 5360
#
#line 5360
# Allow the new domain to write back to the old domain via a pipe.
#line 5360
#
#line 5360
allow run_init_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 5360

#line 5360
#
#line 5360
# Allow the new domain to read and execute the program.
#line 5360
#
#line 5360
allow run_init_t run_init_exec_t:file { read getattr lock execute ioctl };
#line 5360

#line 5360
#
#line 5360
# Allow the new domain to be entered via the program.
#line 5360
#
#line 5360
allow run_init_t run_init_exec_t:file entrypoint;
#line 5360

#line 5360
type_transition sysadm_t run_init_exec_t:process run_init_t;
#line 5360

#line 5360
role sysadm_r types run_init_t;
#line 5360

#line 5360
# for utmp
#line 5360
allow run_init_t initrc_var_run_t:file { ioctl read getattr lock write append };
#line 5360
allow run_init_t { sysadm_tty_device_t sysadm_devpts_t }:chr_file { ioctl read getattr lock write append };
#line 5360

#line 5360
# often the administrator runs such programs from a directory that is owned
#line 5360
# by a different user or has restrictive SE permissions, do not want to audit
#line 5360
# the failed access to the current directory
#line 5360
dontaudit run_init_t file_type:dir search;
#line 5360
dontaudit run_init_t self:capability { dac_override dac_read_search };
#line 5360

#line 5360

#line 5360
allow run_init_t { bin_t chkpwd_exec_t shell_exec_t }:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5360

#line 5360

#line 5360

#line 5360

#line 5360
#
#line 5360
# Allow the process to transition to the new domain.
#line 5360
#
#line 5360
allow run_init_t initrc_t:process transition;
#line 5360

#line 5360
#
#line 5360
# Allow the process to execute the program.
#line 5360
# 
#line 5360
allow run_init_t initrc_exec_t:file { getattr execute };
#line 5360

#line 5360
#
#line 5360
# Allow the process to reap the new domain.
#line 5360
#
#line 5360
allow initrc_t run_init_t:process sigchld;
#line 5360

#line 5360
#
#line 5360
# Allow the new domain to inherit and use file 
#line 5360
# descriptions from the creating process and vice versa.
#line 5360
#
#line 5360
allow initrc_t run_init_t:fd use;
#line 5360
allow run_init_t initrc_t:fd use;
#line 5360

#line 5360
#
#line 5360
# Allow the new domain to write back to the old domain via a pipe.
#line 5360
#
#line 5360
allow initrc_t run_init_t:fifo_file { ioctl read getattr lock write append };
#line 5360

#line 5360
#
#line 5360
# Allow the new domain to read and execute the program.
#line 5360
#
#line 5360
allow initrc_t initrc_exec_t:file { read getattr lock execute ioctl };
#line 5360

#line 5360
#
#line 5360
# Allow the new domain to be entered via the program.
#line 5360
#
#line 5360
allow initrc_t initrc_exec_t:file entrypoint;
#line 5360

#line 5360

#line 5360
# hmm, do we REALLY need this?
#line 5360

#line 5360

#line 5360
# Grant the permissions common to the test domains.
#line 5360

#line 5360
# Grant permissions within the domain.
#line 5360

#line 5360
# Access other processes in the same domain.
#line 5360
allow run_init_t self:process *;
#line 5360

#line 5360
# Access /proc/PID files for processes in the same domain.
#line 5360
allow run_init_t self:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5360

#line 5360
# Access file descriptions, pipes, and sockets
#line 5360
# created by processes in the same domain.
#line 5360
allow run_init_t self:fd *;
#line 5360
allow run_init_t self:fifo_file { ioctl read getattr lock write append };
#line 5360
allow run_init_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 5360
allow run_init_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 5360

#line 5360
# Allow the domain to communicate with other processes in the same domain.
#line 5360
allow run_init_t self:unix_dgram_socket sendto;
#line 5360
allow run_init_t self:unix_stream_socket connectto;
#line 5360

#line 5360
# Access System V IPC objects created by processes in the same domain.
#line 5360
allow run_init_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 5360
allow run_init_t self:msg  { send receive };
#line 5360
allow run_init_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 5360
allow run_init_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 5360

#line 5360

#line 5360

#line 5360
# Grant read/search permissions to most of /proc.
#line 5360

#line 5360
# Read system information files in /proc.
#line 5360
allow run_init_t proc_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5360

#line 5360
# Stat /proc/kmsg and /proc/kcore.
#line 5360
allow run_init_t proc_kmsg_t:file { getattr };
#line 5360
allow run_init_t proc_kcore_t:file { getattr };
#line 5360

#line 5360
# Read system variables in /proc/sys.
#line 5360
allow run_init_t sysctl_modprobe_t:file { read getattr lock ioctl };
#line 5360
allow run_init_t sysctl_t:file { read getattr lock ioctl };
#line 5360
allow run_init_t sysctl_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t sysctl_fs_t:file { read getattr lock ioctl };
#line 5360
allow run_init_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t sysctl_kernel_t:file { read getattr lock ioctl };
#line 5360
allow run_init_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t sysctl_net_t:file { read getattr lock ioctl };
#line 5360
allow run_init_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t sysctl_vm_t:file { read getattr lock ioctl };
#line 5360
allow run_init_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t sysctl_dev_t:file { read getattr lock ioctl };
#line 5360
allow run_init_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 5360

#line 5360

#line 5360
# Grant read/search permissions to many system file types.
#line 5360

#line 5360

#line 5360
# Get attributes of file systems.
#line 5360
allow run_init_t fs_type:filesystem getattr;
#line 5360

#line 5360

#line 5360
# Read /.
#line 5360
allow run_init_t root_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5360

#line 5360
# Read /home.
#line 5360
allow run_init_t home_root_t:dir { read getattr lock search ioctl };
#line 5360

#line 5360
# Read /usr.
#line 5360
allow run_init_t usr_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5360

#line 5360
# Read bin and sbin directories.
#line 5360
allow run_init_t bin_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5360
allow run_init_t sbin_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5360

#line 5360

#line 5360
# Read directories and files with the readable_t type.
#line 5360
# This type is a general type for "world"-readable files.
#line 5360
allow run_init_t readable_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5360

#line 5360
# Stat /...security and lost+found.
#line 5360
allow run_init_t file_labels_t:dir getattr;
#line 5360
allow run_init_t lost_found_t:dir getattr;
#line 5360

#line 5360
# Read the devpts root directory.  
#line 5360
allow run_init_t devpts_t:dir { read getattr lock search ioctl };
#line 5360

#line 5360

#line 5360
# Read the /tmp directory and any /tmp files with the base type.
#line 5360
# Temporary files created at runtime will typically use derived types.
#line 5360
allow run_init_t tmp_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t tmp_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360

#line 5360
# Read /var.
#line 5360
allow run_init_t var_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5360

#line 5360
# Read /var/catman.
#line 5360
allow run_init_t catman_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t catman_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360

#line 5360
# Read /var/lib.
#line 5360
allow run_init_t var_lib_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t var_lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5360
allow run_init_t var_lib_nfs_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t var_lib_nfs_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5360

#line 5360

#line 5360
allow run_init_t tetex_data_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t tetex_data_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360

#line 5360

#line 5360
# Read /var/yp.
#line 5360
allow run_init_t var_yp_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t var_yp_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5360

#line 5360
# Read /var/spool.
#line 5360
allow run_init_t var_spool_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5360

#line 5360
# Read /var/run, /var/lock, /var/log.
#line 5360
allow run_init_t var_run_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360
allow run_init_t var_log_t:dir { read getattr lock search ioctl };
#line 5360
#allow run_init_t var_log_t:{ file lnk_file } r_file_perms;
#line 5360
allow run_init_t var_log_sa_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t var_log_sa_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360
allow run_init_t var_log_ksyms_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360

#line 5360
allow run_init_t var_lock_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t var_lock_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360

#line 5360
# Read /var/run/utmp and /var/log/wtmp.
#line 5360
allow run_init_t initrc_var_run_t:file { read getattr lock ioctl };
#line 5360
allow run_init_t wtmp_t:file { read getattr lock ioctl };
#line 5360

#line 5360
# Read /boot, /boot/System.map*, and /vmlinuz*
#line 5360
allow run_init_t boot_t:dir { search getattr };
#line 5360
allow run_init_t boot_t:file getattr;
#line 5360
allow run_init_t system_map_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360

#line 5360
allow run_init_t boot_t:lnk_file read;
#line 5360

#line 5360
# Read /etc.
#line 5360
allow run_init_t etc_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5360
allow run_init_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360
allow run_init_t etc_aliases_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360
allow run_init_t etc_mail_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t etc_mail_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360
allow run_init_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360
allow run_init_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5360

#line 5360
# Read /lib.
#line 5360
allow run_init_t lib_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5360

#line 5360
# Read the linker, shared library, and executable types.
#line 5360
allow run_init_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360
allow run_init_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360
allow run_init_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 5360

#line 5360
# Read man directories and files.
#line 5360
allow run_init_t man_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t man_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5360

#line 5360
# Read /usr/src.
#line 5360
allow run_init_t src_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t src_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5360

#line 5360
# Read module-related files.
#line 5360
allow run_init_t modules_object_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t modules_object_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360
allow run_init_t modules_dep_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360
allow run_init_t modules_conf_t:{ file lnk_file} { read getattr lock ioctl };
#line 5360

#line 5360
# Read /dev directories and any symbolic links.
#line 5360
allow run_init_t device_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t device_t:lnk_file { read getattr lock ioctl };
#line 5360

#line 5360
# Read /dev/random and /dev/zero.
#line 5360
allow run_init_t random_device_t:chr_file { read getattr lock ioctl };
#line 5360
allow run_init_t zero_device_t:chr_file { read getattr lock ioctl };
#line 5360

#line 5360
# Read the root directory of a tmpfs filesytem and any symbolic links.
#line 5360
allow run_init_t tmpfs_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t tmpfs_t:lnk_file { read getattr lock ioctl };
#line 5360

#line 5360
# Read any symbolic links on a devfs file system.
#line 5360
allow run_init_t device_t:lnk_file { read getattr lock ioctl };
#line 5360

#line 5360
# Read the root directory of a usbdevfs filesystem, and
#line 5360
# the devices and drivers files.  Permit stating of the
#line 5360
# device nodes, but nothing else.
#line 5360
allow run_init_t usbdevfs_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t usbdevfs_t:{ file lnk_file } { read getattr lock ioctl };
#line 5360
allow run_init_t usbdevfs_device_t:file getattr;
#line 5360

#line 5360

#line 5360
# Grant write permissions to a small set of system file types.
#line 5360
# No permission to create files is granted here.  Use allow rules to grant 
#line 5360
# create permissions to a type or use file_type_auto_trans rules to set up
#line 5360
# new types for files.
#line 5360

#line 5360

#line 5360
# Read and write /dev/tty and /dev/null.
#line 5360
allow run_init_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 5360
allow run_init_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 5360

#line 5360
# Do not audit write denials to /etc/ld.so.cache.
#line 5360
dontaudit run_init_t ld_so_cache_t:file write;
#line 5360

#line 5360

#line 5360
# Execute from the system shared libraries.
#line 5360
# No permission to execute anything else is granted here.
#line 5360
# Use can_exec or can_exec_any to grant the ability to execute within a domain.
#line 5360
# Use domain_auto_trans for executing and changing domains.
#line 5360

#line 5360
allow run_init_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t ld_so_t:file { read getattr lock execute ioctl };
#line 5360
allow run_init_t ld_so_t:file execute_no_trans;
#line 5360
allow run_init_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5360
allow run_init_t shlib_t:file { read getattr lock execute ioctl };
#line 5360
allow run_init_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5360
allow run_init_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5360
allow run_init_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5360

#line 5360

#line 5360
# read localization information
#line 5360
allow run_init_t locale_t:dir { read getattr lock search ioctl };
#line 5360
allow run_init_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 5360

#line 5360
# Obtain the context of any SID, the SID for any context, 
#line 5360
# and the list of active SIDs.
#line 5360
allow run_init_t security_t:security { sid_to_context context_to_sid get_sids };
#line 5360

#line 5360

#line 5360

#line 5360
# Grant permissions needed to create TCP and UDP sockets and 
#line 5360
# to access the network.
#line 5360

#line 5360
#
#line 5360
# Allow the domain to create and use UDP and TCP sockets.
#line 5360
# Other kinds of sockets must be separately authorized for use.
#line 5360
allow run_init_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 5360
allow run_init_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 5360

#line 5360
#
#line 5360
# Allow the domain to send UDP packets.
#line 5360
# Since the destination sockets type is unknown, the generic
#line 5360
# any_socket_t type is used as a placeholder.
#line 5360
#
#line 5360
allow run_init_t any_socket_t:udp_socket sendto;
#line 5360

#line 5360
#
#line 5360
# Allow the domain to send using any network interface.
#line 5360
# netif_type is a type attribute for all network interface types.
#line 5360
#
#line 5360
allow run_init_t netif_type:netif { tcp_send udp_send rawip_send };
#line 5360

#line 5360
#
#line 5360
# Allow packets sent by the domain to be received on any network interface.
#line 5360
#
#line 5360
allow run_init_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 5360

#line 5360
#
#line 5360
# Allow the domain to receive packets from any network interface.
#line 5360
# netmsg_type is a type attribute for all default message types.
#line 5360
#
#line 5360
allow run_init_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 5360

#line 5360
#
#line 5360
# Allow the domain to initiate or accept TCP connections 
#line 5360
# on any network interface.
#line 5360
#
#line 5360
allow run_init_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 5360

#line 5360
#
#line 5360
# Receive resets from the TCP reset socket.
#line 5360
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 5360
#
#line 5360
allow run_init_t tcp_socket_t:tcp_socket recvfrom;
#line 5360

#line 5360
dontaudit run_init_t tcp_socket_t:tcp_socket connectto;
#line 5360

#line 5360
#
#line 5360
# Allow the domain to send to any node.
#line 5360
# node_type is a type attribute for all node types.
#line 5360
#
#line 5360
allow run_init_t node_type:node { tcp_send udp_send rawip_send };
#line 5360

#line 5360
#
#line 5360
# Allow packets sent by the domain to be received from any node.
#line 5360
#
#line 5360
allow run_init_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 5360

#line 5360
#
#line 5360
# Allow the domain to send NFS client requests via the socket
#line 5360
# created by mount.
#line 5360
#
#line 5360
allow run_init_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 5360

#line 5360
#
#line 5360
# Bind to the default port type.
#line 5360
# Other port types must be separately authorized.
#line 5360
#
#line 5360
allow run_init_t port_t:udp_socket name_bind;
#line 5360
allow run_init_t port_t:tcp_socket name_bind;
#line 5360

#line 5360

#line 5360

#DESC Init - Process initialization
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

#################################
#
# Rules for the init_t domain.
#
# init_t is the domain of the init process.
# init_exec_t is the type of the init program.
# initctl_t is the type of the named pipe created 
# by init during initialization.  This pipe is used
# to communicate with init.
# sulogin_exec_t is the type of sulogin.
#
type init_t, domain, privlog, mlstrustedreader, mlstrustedwriter;
role system_r types init_t;

#line 5379
allow init_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5379
allow init_t ld_so_t:file { read getattr lock execute ioctl };
#line 5379
allow init_t ld_so_t:file execute_no_trans;
#line 5379
allow init_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5379
allow init_t shlib_t:file { read getattr lock execute ioctl };
#line 5379
allow init_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5379
allow init_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5379
allow init_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5379
;
type init_exec_t, file_type, sysadmfile, exec_type;
type initctl_t, file_type, sysadmfile;
type sulogin_exec_t, file_type, exec_type, sysadmfile;

# Use capabilities.
allow init_t init_t:capability ~sys_module;

# Run /etc/rc.sysinit, /etc/rc, /etc/rc.local in the initrc_t domain.

#line 5388

#line 5388

#line 5388
#
#line 5388
# Allow the process to transition to the new domain.
#line 5388
#
#line 5388
allow init_t initrc_t:process transition;
#line 5388

#line 5388
#
#line 5388
# Allow the process to execute the program.
#line 5388
# 
#line 5388
allow init_t initrc_exec_t:file { getattr execute };
#line 5388

#line 5388
#
#line 5388
# Allow the process to reap the new domain.
#line 5388
#
#line 5388
allow initrc_t init_t:process sigchld;
#line 5388

#line 5388
#
#line 5388
# Allow the new domain to inherit and use file 
#line 5388
# descriptions from the creating process and vice versa.
#line 5388
#
#line 5388
allow initrc_t init_t:fd use;
#line 5388
allow init_t initrc_t:fd use;
#line 5388

#line 5388
#
#line 5388
# Allow the new domain to write back to the old domain via a pipe.
#line 5388
#
#line 5388
allow initrc_t init_t:fifo_file { ioctl read getattr lock write append };
#line 5388

#line 5388
#
#line 5388
# Allow the new domain to read and execute the program.
#line 5388
#
#line 5388
allow initrc_t initrc_exec_t:file { read getattr lock execute ioctl };
#line 5388

#line 5388
#
#line 5388
# Allow the new domain to be entered via the program.
#line 5388
#
#line 5388
allow initrc_t initrc_exec_t:file entrypoint;
#line 5388

#line 5388
type_transition init_t initrc_exec_t:process initrc_t;
#line 5388


# Run the shell or sulogin in the sysadm_t domain for single-user mode.

#line 5391

#line 5391

#line 5391
#
#line 5391
# Allow the process to transition to the new domain.
#line 5391
#
#line 5391
allow init_t sysadm_t:process transition;
#line 5391

#line 5391
#
#line 5391
# Allow the process to execute the program.
#line 5391
# 
#line 5391
allow init_t shell_exec_t:file { getattr execute };
#line 5391

#line 5391
#
#line 5391
# Allow the process to reap the new domain.
#line 5391
#
#line 5391
allow sysadm_t init_t:process sigchld;
#line 5391

#line 5391
#
#line 5391
# Allow the new domain to inherit and use file 
#line 5391
# descriptions from the creating process and vice versa.
#line 5391
#
#line 5391
allow sysadm_t init_t:fd use;
#line 5391
allow init_t sysadm_t:fd use;
#line 5391

#line 5391
#
#line 5391
# Allow the new domain to write back to the old domain via a pipe.
#line 5391
#
#line 5391
allow sysadm_t init_t:fifo_file { ioctl read getattr lock write append };
#line 5391

#line 5391
#
#line 5391
# Allow the new domain to read and execute the program.
#line 5391
#
#line 5391
allow sysadm_t shell_exec_t:file { read getattr lock execute ioctl };
#line 5391

#line 5391
#
#line 5391
# Allow the new domain to be entered via the program.
#line 5391
#
#line 5391
allow sysadm_t shell_exec_t:file entrypoint;
#line 5391

#line 5391
type_transition init_t shell_exec_t:process sysadm_t;
#line 5391


#line 5392

#line 5392

#line 5392
#
#line 5392
# Allow the process to transition to the new domain.
#line 5392
#
#line 5392
allow init_t sysadm_t:process transition;
#line 5392

#line 5392
#
#line 5392
# Allow the process to execute the program.
#line 5392
# 
#line 5392
allow init_t sulogin_exec_t:file { getattr execute };
#line 5392

#line 5392
#
#line 5392
# Allow the process to reap the new domain.
#line 5392
#
#line 5392
allow sysadm_t init_t:process sigchld;
#line 5392

#line 5392
#
#line 5392
# Allow the new domain to inherit and use file 
#line 5392
# descriptions from the creating process and vice versa.
#line 5392
#
#line 5392
allow sysadm_t init_t:fd use;
#line 5392
allow init_t sysadm_t:fd use;
#line 5392

#line 5392
#
#line 5392
# Allow the new domain to write back to the old domain via a pipe.
#line 5392
#
#line 5392
allow sysadm_t init_t:fifo_file { ioctl read getattr lock write append };
#line 5392

#line 5392
#
#line 5392
# Allow the new domain to read and execute the program.
#line 5392
#
#line 5392
allow sysadm_t sulogin_exec_t:file { read getattr lock execute ioctl };
#line 5392

#line 5392
#
#line 5392
# Allow the new domain to be entered via the program.
#line 5392
#
#line 5392
allow sysadm_t sulogin_exec_t:file entrypoint;
#line 5392

#line 5392
type_transition init_t sulogin_exec_t:process sysadm_t;
#line 5392


# Run /sbin/update in the init_t domain.

#line 5395
allow init_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5395


# Run init.

#line 5398
allow init_t init_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5398


# Run chroot from initrd scripts.
#line 5403


# Create /dev/initctl.

#line 5406

#line 5406

#line 5406

#line 5406
#
#line 5406
# Allow the process to modify the directory.
#line 5406
#
#line 5406
allow init_t device_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5406

#line 5406
#
#line 5406
# Allow the process to create the file.
#line 5406
#
#line 5406

#line 5406
allow init_t initctl_t:fifo_file { create ioctl read getattr lock write setattr append link unlink rename };
#line 5406

#line 5406

#line 5406

#line 5406
type_transition init_t device_t:fifo_file initctl_t;
#line 5406

#line 5406

#line 5406


# Create ioctl.save.

#line 5409

#line 5409

#line 5409

#line 5409
#
#line 5409
# Allow the process to modify the directory.
#line 5409
#
#line 5409
allow init_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5409

#line 5409
#
#line 5409
# Allow the process to create the file.
#line 5409
#
#line 5409

#line 5409
allow init_t etc_runtime_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 5409

#line 5409

#line 5409

#line 5409
type_transition init_t etc_t:file etc_runtime_t;
#line 5409

#line 5409

#line 5409


# Update /etc/ld.so.cache
allow init_t ld_so_cache_t:file { ioctl read getattr lock write append };

# Allow access to log files
allow init_t var_t:dir search;
allow init_t var_log_t:dir search;

# read /etc/localtime
allow init_t locale_t:dir { read getattr lock search ioctl };
allow init_t locale_t:{file lnk_file} { read getattr lock ioctl };

# Create unix sockets
allow init_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
allow init_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# Permissions required for system startup
allow init_t bin_t:dir { read getattr lock search ioctl };
allow init_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
allow init_t exec_type:{ file lnk_file } { read getattr lock ioctl };
allow init_t sbin_t:dir { read getattr lock search ioctl };
allow init_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };

# allow init to fork
allow init_t self:process { fork sigchld };

# Modify utmp.
allow init_t var_run_t:file { ioctl read getattr lock write append };
allow init_t initrc_var_run_t:file { ioctl read getattr lock write append };

# For /var/run/shutdown.pid.
type init_var_run_t, file_type, sysadmfile, pidfile;

#line 5442

#line 5442

#line 5442

#line 5442
#
#line 5442
# Allow the process to modify the directory.
#line 5442
#
#line 5442
allow init_t var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5442

#line 5442
#
#line 5442
# Allow the process to create the file.
#line 5442
#
#line 5442

#line 5442
allow init_t init_var_run_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5442
allow init_t init_var_run_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5442

#line 5442

#line 5442

#line 5442
type_transition init_t var_run_t:dir init_var_run_t;
#line 5442
type_transition init_t var_run_t:{ file lnk_file sock_file fifo_file } init_var_run_t;
#line 5442

#line 5442

#line 5442


# Shutdown permissions
allow init_t proc_t:dir { read getattr lock search ioctl };
allow init_t proc_t:lnk_file { read getattr lock ioctl };
allow init_t self:dir { read getattr lock search ioctl };
allow init_t self:lnk_file { read getattr lock ioctl };
allow init_t devpts_t:dir { read getattr lock ioctl };

# Modify wtmp.
allow init_t wtmp_t:file { ioctl read getattr lock write append };

# Kill all processes.
allow init_t domain:process { sigchld sigkill sigstop signull signal };

# Allow all processes to send SIGCHLD to init.
allow domain init_t:process { sigchld signull };

# If you load a new policy that removes active domains, processes can
# get stuck if you don't allow unlabeled policies to signal init
# If you load an incompatible policy, you should probably reboot,
# since you may have compromised system security.
# allow unlabeled_t init_t:process sigchld;

# Read and write the console and ttys.
allow init_t console_device_t:chr_file { ioctl read getattr lock write append };
allow init_t tty_device_t:chr_file { ioctl read getattr lock write append };
allow init_t ttyfile:chr_file { ioctl read getattr lock write append };
allow init_t ptyfile:chr_file { ioctl read getattr lock write append };

# Flush the system buffers (/sbin/update)
allow init_t kernel_t:system bdflush;

# Run system executables.

#line 5476
allow init_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5476


# Run /etc/X11/prefdm.

#line 5479
allow init_t etc_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5479


# for initrd pivot_root seems to access this
dontaudit init_t file_labels_t:dir { search };
#DESC Klogd - Kernel log daemon
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

#################################
#
# Rules for the klogd_t domain.
#
type klogd_t, domain, privlog, privmem;
role system_r types klogd_t;

#line 5494
allow klogd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5494
allow klogd_t ld_so_t:file { read getattr lock execute ioctl };
#line 5494
allow klogd_t ld_so_t:file execute_no_trans;
#line 5494
allow klogd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5494
allow klogd_t shlib_t:file { read getattr lock execute ioctl };
#line 5494
allow klogd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5494
allow klogd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5494
allow klogd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5494

type klogd_exec_t, file_type, sysadmfile, exec_type;

#line 5496

#line 5496

#line 5496
#
#line 5496
# Allow the process to transition to the new domain.
#line 5496
#
#line 5496
allow initrc_t klogd_t:process transition;
#line 5496

#line 5496
#
#line 5496
# Allow the process to execute the program.
#line 5496
# 
#line 5496
allow initrc_t klogd_exec_t:file { getattr execute };
#line 5496

#line 5496
#
#line 5496
# Allow the process to reap the new domain.
#line 5496
#
#line 5496
allow klogd_t initrc_t:process sigchld;
#line 5496

#line 5496
#
#line 5496
# Allow the new domain to inherit and use file 
#line 5496
# descriptions from the creating process and vice versa.
#line 5496
#
#line 5496
allow klogd_t initrc_t:fd use;
#line 5496
allow initrc_t klogd_t:fd use;
#line 5496

#line 5496
#
#line 5496
# Allow the new domain to write back to the old domain via a pipe.
#line 5496
#
#line 5496
allow klogd_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 5496

#line 5496
#
#line 5496
# Allow the new domain to read and execute the program.
#line 5496
#
#line 5496
allow klogd_t klogd_exec_t:file { read getattr lock execute ioctl };
#line 5496

#line 5496
#
#line 5496
# Allow the new domain to be entered via the program.
#line 5496
#
#line 5496
allow klogd_t klogd_exec_t:file entrypoint;
#line 5496

#line 5496
type_transition initrc_t klogd_exec_t:process klogd_t;
#line 5496

allow klogd_t self:process { fork signal };

type klogd_tmp_t, file_type, sysadmfile, tmpfile;

#line 5500

#line 5500

#line 5500

#line 5500
#
#line 5500
# Allow the process to modify the directory.
#line 5500
#
#line 5500
allow klogd_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5500

#line 5500
#
#line 5500
# Allow the process to create the file.
#line 5500
#
#line 5500

#line 5500
allow klogd_t klogd_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5500
allow klogd_t klogd_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5500

#line 5500

#line 5500

#line 5500
type_transition klogd_t tmp_t:dir klogd_tmp_t;
#line 5500
type_transition klogd_t tmp_t:{ file lnk_file sock_file fifo_file } klogd_tmp_t;
#line 5500

#line 5500

#line 5500

allow klogd_t var_t:dir { read getattr lock search ioctl };
type klogd_var_run_t, file_type, sysadmfile, pidfile;

#line 5503

#line 5503

#line 5503

#line 5503
#
#line 5503
# Allow the process to modify the directory.
#line 5503
#
#line 5503
allow klogd_t var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5503

#line 5503
#
#line 5503
# Allow the process to create the file.
#line 5503
#
#line 5503

#line 5503
allow klogd_t klogd_var_run_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5503
allow klogd_t klogd_var_run_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5503

#line 5503

#line 5503

#line 5503
type_transition klogd_t var_run_t:dir klogd_var_run_t;
#line 5503
type_transition klogd_t var_run_t:{ file lnk_file sock_file fifo_file } klogd_var_run_t;
#line 5503

#line 5503

#line 5503

allow klogd_t proc_t:dir { read getattr lock search ioctl };
allow klogd_t proc_t:lnk_file { read getattr lock ioctl };
allow klogd_t self:dir { read getattr lock search ioctl };
allow klogd_t self:lnk_file { read getattr lock ioctl };

# read /etc/nsswitch.conf
allow klogd_t etc_t:file { read getattr lock ioctl };

# read localization information
allow klogd_t locale_t:dir { read getattr lock search ioctl };
allow klogd_t locale_t:{file lnk_file} { read getattr lock ioctl };

# Create unix sockets
allow klogd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# Use the sys_admin and sys_rawio capabilities.
allow klogd_t klogd_t:capability { sys_admin sys_rawio };

# Inherit and use descriptors from init.
allow klogd_t init_t:fd use;

# Read /proc/kmsg and /dev/mem.
allow klogd_t device_t:dir { read getattr lock search ioctl };
allow klogd_t proc_kmsg_t:file { read getattr lock ioctl };
allow klogd_t memory_device_t:chr_file { read getattr lock ioctl };

# Write to the console.
allow klogd_t { initrc_devpts_t console_device_t }:chr_file { ioctl read getattr lock write append };

# Control syslog and console logging
allow klogd_t kernel_t:system { syslog_mod syslog_console };

# Read /boot/System.map*
allow klogd_t system_map_t:file { read getattr lock ioctl };
allow klogd_t boot_t:dir { read getattr lock search ioctl };
allow klogd_t boot_t:{ file lnk_file } { read getattr lock ioctl };
#DESC Ldconfig - Configure dynamic linker bindings
#
# Author:  Russell Coker <russell@coker.com.au>
#

#################################
#
# Rules for the ldconfig_t domain.
#
type ldconfig_t, domain, privlog;
type ldconfig_exec_t, file_type, sysadmfile, exec_type;

role sysadm_r types ldconfig_t;
role system_r types ldconfig_t;


#line 5555

#line 5555

#line 5555
#
#line 5555
# Allow the process to transition to the new domain.
#line 5555
#
#line 5555
allow { sysadm_t initrc_t  } ldconfig_t:process transition;
#line 5555

#line 5555
#
#line 5555
# Allow the process to execute the program.
#line 5555
# 
#line 5555
allow { sysadm_t initrc_t  } ldconfig_exec_t:file { getattr execute };
#line 5555

#line 5555
#
#line 5555
# Allow the process to reap the new domain.
#line 5555
#
#line 5555
allow ldconfig_t { sysadm_t initrc_t  }:process sigchld;
#line 5555

#line 5555
#
#line 5555
# Allow the new domain to inherit and use file 
#line 5555
# descriptions from the creating process and vice versa.
#line 5555
#
#line 5555
allow ldconfig_t { sysadm_t initrc_t  }:fd use;
#line 5555
allow { sysadm_t initrc_t  } ldconfig_t:fd use;
#line 5555

#line 5555
#
#line 5555
# Allow the new domain to write back to the old domain via a pipe.
#line 5555
#
#line 5555
allow ldconfig_t { sysadm_t initrc_t  }:fifo_file { ioctl read getattr lock write append };
#line 5555

#line 5555
#
#line 5555
# Allow the new domain to read and execute the program.
#line 5555
#
#line 5555
allow ldconfig_t ldconfig_exec_t:file { read getattr lock execute ioctl };
#line 5555

#line 5555
#
#line 5555
# Allow the new domain to be entered via the program.
#line 5555
#
#line 5555
allow ldconfig_t ldconfig_exec_t:file entrypoint;
#line 5555

#line 5555
type_transition { sysadm_t initrc_t  } ldconfig_exec_t:process ldconfig_t;
#line 5555

dontaudit ldconfig_t device_t:dir search;
allow ldconfig_t { initrc_devpts_t { sysadm_tty_device_t sysadm_devpts_t } }:chr_file { ioctl read getattr lock write append };
allow ldconfig_t privfd:fd use;


#line 5560
allow ldconfig_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5560
allow ldconfig_t ld_so_t:file { read getattr lock execute ioctl };
#line 5560
allow ldconfig_t ld_so_t:file execute_no_trans;
#line 5560
allow ldconfig_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5560
allow ldconfig_t shlib_t:file { read getattr lock execute ioctl };
#line 5560
allow ldconfig_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5560
allow ldconfig_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5560
allow ldconfig_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5560



#line 5562

#line 5562

#line 5562

#line 5562
#
#line 5562
# Allow the process to modify the directory.
#line 5562
#
#line 5562
allow ldconfig_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5562

#line 5562
#
#line 5562
# Allow the process to create the file.
#line 5562
#
#line 5562

#line 5562
allow ldconfig_t ld_so_cache_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5562
allow ldconfig_t ld_so_cache_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5562

#line 5562

#line 5562

#line 5562
type_transition ldconfig_t etc_t:dir ld_so_cache_t;
#line 5562
type_transition ldconfig_t etc_t:{ file lnk_file sock_file fifo_file } ld_so_cache_t;
#line 5562

#line 5562

#line 5562


#line 5563

#line 5563

#line 5563

#line 5563
#
#line 5563
# Allow the process to modify the directory.
#line 5563
#
#line 5563
allow ldconfig_t lib_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5563

#line 5563
#
#line 5563
# Allow the process to create the file.
#line 5563
#
#line 5563

#line 5563
allow ldconfig_t shlib_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5563
allow ldconfig_t shlib_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5563

#line 5563

#line 5563

#line 5563
type_transition ldconfig_t lib_t:dir shlib_t;
#line 5563
type_transition ldconfig_t lib_t:{ file lnk_file sock_file fifo_file } shlib_t;
#line 5563

#line 5563

#line 5563

# allow removing mis-labelled links
allow ldconfig_t lib_t:lnk_file unlink;

allow ldconfig_t userdomain:fd use;
allow ldconfig_t etc_t:file { getattr read };
allow ldconfig_t etc_t:lnk_file read;

allow ldconfig_t fs_t:filesystem getattr;
#DESC LoadPolicy - SELinux policy loading utilities
#
# Authors:  Frank Mayer, mayerf@tresys.com
#

###########################
# load_policy_t is the domain type for load_policy 
# load_policy_exec_t is the file type for the executable


type load_policy_t, domain;
role sysadm_r types load_policy_t;

type load_policy_exec_t, file_type, exec_type, sysadmfile;

##########################
# 
# Rules


#line 5591

#line 5591

#line 5591
#
#line 5591
# Allow the process to transition to the new domain.
#line 5591
#
#line 5591
allow sysadm_t load_policy_t:process transition;
#line 5591

#line 5591
#
#line 5591
# Allow the process to execute the program.
#line 5591
# 
#line 5591
allow sysadm_t load_policy_exec_t:file { getattr execute };
#line 5591

#line 5591
#
#line 5591
# Allow the process to reap the new domain.
#line 5591
#
#line 5591
allow load_policy_t sysadm_t:process sigchld;
#line 5591

#line 5591
#
#line 5591
# Allow the new domain to inherit and use file 
#line 5591
# descriptions from the creating process and vice versa.
#line 5591
#
#line 5591
allow load_policy_t sysadm_t:fd use;
#line 5591
allow sysadm_t load_policy_t:fd use;
#line 5591

#line 5591
#
#line 5591
# Allow the new domain to write back to the old domain via a pipe.
#line 5591
#
#line 5591
allow load_policy_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 5591

#line 5591
#
#line 5591
# Allow the new domain to read and execute the program.
#line 5591
#
#line 5591
allow load_policy_t load_policy_exec_t:file { read getattr lock execute ioctl };
#line 5591

#line 5591
#
#line 5591
# Allow the new domain to be entered via the program.
#line 5591
#
#line 5591
allow load_policy_t load_policy_exec_t:file entrypoint;
#line 5591

#line 5591
type_transition sysadm_t load_policy_exec_t:process load_policy_t;
#line 5591

#line 5595


# Reload the policy configuration (sysadm_t no longer has this ability)
allow load_policy_t security_t:security load_policy;


###########################
# constrain from where load_policy can load a policy, specifically 
# policy_config_t files 
#

# only allow read of policy config files
allow load_policy_t policy_config_t:dir { read getattr lock search ioctl };
allow load_policy_t policy_config_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };

# directory search permissions for path to binary policy files
allow load_policy_t root_t:dir search;
allow load_policy_t etc_t:dir search;

# Read the devpts root directory (needed?)  
allow load_policy_t devpts_t:dir { read getattr lock search ioctl };

# Other access
allow load_policy_t { initrc_devpts_t { sysadm_tty_device_t sysadm_devpts_t } }:chr_file { read write ioctl getattr };

#line 5619
allow load_policy_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5619
allow load_policy_t ld_so_t:file { read getattr lock execute ioctl };
#line 5619
allow load_policy_t ld_so_t:file execute_no_trans;
#line 5619
allow load_policy_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5619
allow load_policy_t shlib_t:file { read getattr lock execute ioctl };
#line 5619
allow load_policy_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5619
allow load_policy_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5619
allow load_policy_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5619

allow load_policy_t self:capability dac_override;

allow load_policy_t { initrc_t privfd }:fd use;

allow load_policy_t fs_t:filesystem getattr;

allow load_policy_t sysadm_tmp_t:file { getattr write } ;

#DESC Login - Local/remote login utilities
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
# Macroised by Russell Coker <russell@coker.com.au>
#

#################################
# 
# Rules for the local_login_t domain
# and the remote_login_t domain.
#

# $1 is the name of the domain (local or remote)
# I added "mlstrustedreader, mlstrustedwriter, mlstrustedobject" to
# remote_login_t, not sure if this is right
#line 5721


#################################
#
# Rules for the local_login_t domain.
#
# local_login_t is the domain of a login process 
# spawned by getty.
#
# remote_login_t is the domain of a login process 
# spawned by rlogind.
#
# login_exec_t is the type of the login program
#
type login_exec_t, file_type, sysadmfile, exec_type;


#line 5737
type local_login_t, domain, privuser, privrole, privlog, auth, privowner, mlstrustedreader, mlstrustedwriter, mlstrustedobject, privfd;
#line 5737
role system_r types local_login_t;
#line 5737

#line 5737

#line 5737
# Access other processes in the same domain.
#line 5737
allow local_login_t self:process *;
#line 5737

#line 5737
# Access /proc/PID files for processes in the same domain.
#line 5737
allow local_login_t self:dir { read getattr lock search ioctl };
#line 5737
allow local_login_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5737

#line 5737
# Access file descriptions, pipes, and sockets
#line 5737
# created by processes in the same domain.
#line 5737
allow local_login_t self:fd *;
#line 5737
allow local_login_t self:fifo_file { ioctl read getattr lock write append };
#line 5737
allow local_login_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 5737
allow local_login_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 5737

#line 5737
# Allow the domain to communicate with other processes in the same domain.
#line 5737
allow local_login_t self:unix_dgram_socket sendto;
#line 5737
allow local_login_t self:unix_stream_socket connectto;
#line 5737

#line 5737
# Access System V IPC objects created by processes in the same domain.
#line 5737
allow local_login_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 5737
allow local_login_t self:msg  { send receive };
#line 5737
allow local_login_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 5737
allow local_login_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 5737

#line 5737
;
#line 5737

#line 5737
# Read system information files in /proc.
#line 5737
allow local_login_t proc_t:dir { read getattr lock search ioctl };
#line 5737
allow local_login_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5737

#line 5737

#line 5737
# Read /.
#line 5737
allow local_login_t root_t:dir { read getattr lock search ioctl };
#line 5737
allow local_login_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5737

#line 5737
# Read /home.
#line 5737
allow local_login_t home_root_t:dir { read getattr lock search ioctl };
#line 5737

#line 5737
# Read /usr.
#line 5737
allow local_login_t usr_t:dir { read getattr lock search ioctl };
#line 5737
allow local_login_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5737

#line 5737
# Read bin and sbin directories.
#line 5737
allow local_login_t bin_t:dir { read getattr lock search ioctl };
#line 5737
allow local_login_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5737
allow local_login_t sbin_t:dir { read getattr lock search ioctl };
#line 5737
allow local_login_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5737

#line 5737

#line 5737
# Read directories and files with the readable_t type.
#line 5737
# This type is a general type for "world"-readable files.
#line 5737
allow local_login_t readable_t:dir { read getattr lock search ioctl };
#line 5737
allow local_login_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5737

#line 5737
# Read /var, /var/spool, /var/log.
#line 5737
allow local_login_t var_t:dir { read getattr lock search ioctl };
#line 5737
allow local_login_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5737
allow local_login_t var_spool_t:dir { read getattr lock search ioctl };
#line 5737
allow local_login_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5737
allow local_login_t var_log_t:dir { read getattr lock search ioctl };
#line 5737
allow local_login_t var_log_t:{ file lnk_file } { read getattr lock ioctl };
#line 5737

#line 5737
# Read /etc.
#line 5737
allow local_login_t etc_t:dir { read getattr lock search ioctl };
#line 5737
allow local_login_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5737
allow local_login_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 5737

#line 5737
# Read executable types.
#line 5737
allow local_login_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 5737

#line 5737
# Read /dev directories and any symbolic links.
#line 5737
allow local_login_t device_t:dir { read getattr lock search ioctl };
#line 5737
allow local_login_t device_t:lnk_file { read getattr lock ioctl };
#line 5737

#line 5737

#line 5737
allow local_login_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5737
allow local_login_t ld_so_t:file { read getattr lock execute ioctl };
#line 5737
allow local_login_t ld_so_t:file execute_no_trans;
#line 5737
allow local_login_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5737
allow local_login_t shlib_t:file { read getattr lock execute ioctl };
#line 5737
allow local_login_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5737
allow local_login_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5737
allow local_login_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5737
;
#line 5737
allow local_login_t security_t:security {sid_to_context context_to_sid };
#line 5737

#line 5737

#line 5737
type local_login_tmp_t, file_type, sysadmfile, tmpfile ;
#line 5737

#line 5737

#line 5737

#line 5737

#line 5737
#
#line 5737
# Allow the process to modify the directory.
#line 5737
#
#line 5737
allow local_login_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5737

#line 5737
#
#line 5737
# Allow the process to create the file.
#line 5737
#
#line 5737

#line 5737
allow local_login_t local_login_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5737
allow local_login_t local_login_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5737

#line 5737

#line 5737

#line 5737
type_transition local_login_t tmp_t:dir local_login_tmp_t;
#line 5737
type_transition local_login_t tmp_t:{ file lnk_file sock_file fifo_file } local_login_tmp_t;
#line 5737

#line 5737

#line 5737

#line 5737

#line 5737

#line 5737
# Use capabilities
#line 5737
allow local_login_t self:capability { setuid setgid chown fowner fsetid net_bind_service sys_tty_config dac_override sys_nice sys_resource };
#line 5737

#line 5737
# Run shells in user_t by default.
#line 5737

#line 5737

#line 5737

#line 5737
#
#line 5737
# Allow the process to transition to the new domain.
#line 5737
#
#line 5737
allow local_login_t user_t:process transition;
#line 5737

#line 5737
#
#line 5737
# Allow the process to execute the program.
#line 5737
# 
#line 5737
allow local_login_t shell_exec_t:file { getattr execute };
#line 5737

#line 5737
#
#line 5737
# Allow the process to reap the new domain.
#line 5737
#
#line 5737
allow user_t local_login_t:process sigchld;
#line 5737

#line 5737
#
#line 5737
# Allow the new domain to inherit and use file 
#line 5737
# descriptions from the creating process and vice versa.
#line 5737
#
#line 5737
allow user_t local_login_t:fd use;
#line 5737
allow local_login_t user_t:fd use;
#line 5737

#line 5737
#
#line 5737
# Allow the new domain to write back to the old domain via a pipe.
#line 5737
#
#line 5737
allow user_t local_login_t:fifo_file { ioctl read getattr lock write append };
#line 5737

#line 5737
#
#line 5737
# Allow the new domain to read and execute the program.
#line 5737
#
#line 5737
allow user_t shell_exec_t:file { read getattr lock execute ioctl };
#line 5737

#line 5737
#
#line 5737
# Allow the new domain to be entered via the program.
#line 5737
#
#line 5737
allow user_t shell_exec_t:file entrypoint;
#line 5737

#line 5737
type_transition local_login_t shell_exec_t:process user_t;
#line 5737

#line 5737

#line 5737
# Permit login to search the user home directories.
#line 5737
allow local_login_t home_root_t:dir search;
#line 5737
allow local_login_t home_dir_type:dir search;
#line 5737

#line 5737
# Write to /var/run/utmp.
#line 5737
allow local_login_t initrc_var_run_t:file { ioctl read getattr lock write append };
#line 5737

#line 5737
# Write to /var/log/wtmp.
#line 5737
allow local_login_t wtmp_t:file { ioctl read getattr lock write append };
#line 5737

#line 5737
# Write to /var/log/lastlog.
#line 5737
allow local_login_t lastlog_t:file { ioctl read getattr lock write append };
#line 5737

#line 5737
# Write to /var/log/btmp
#line 5737
allow local_login_t faillog_t:file { append read write };
#line 5737

#line 5737
# Search for mail spool file.
#line 5737
allow local_login_t mail_spool_t:dir { read getattr lock search ioctl };
#line 5737
allow local_login_t mail_spool_t:file getattr;
#line 5737
allow local_login_t mail_spool_t:lnk_file read;
#line 5737

#line 5737
# Determine the set of legal user SIDs that can be reached.
#line 5737
allow local_login_t security_t:security get_user_sids;
#line 5737

#line 5737
# Obtain the SID to use for relabeling terminals.
#line 5737
allow local_login_t security_t:security change_sid;
#line 5737

#line 5737
# allow read access to default_contexts in /etc/security
#line 5737
allow local_login_t default_context_t:file { read getattr lock ioctl };
#line 5737

#line 5737


# But also permit other user domains to be entered by login.

#line 5740

#line 5740
#
#line 5740
# Allow the process to transition to the new domain.
#line 5740
#
#line 5740
allow local_login_t userdomain:process transition;
#line 5740

#line 5740
#
#line 5740
# Allow the process to execute the program.
#line 5740
# 
#line 5740
allow local_login_t shell_exec_t:file { getattr execute };
#line 5740

#line 5740
#
#line 5740
# Allow the process to reap the new domain.
#line 5740
#
#line 5740
allow userdomain local_login_t:process sigchld;
#line 5740

#line 5740
#
#line 5740
# Allow the new domain to inherit and use file 
#line 5740
# descriptions from the creating process and vice versa.
#line 5740
#
#line 5740
allow userdomain local_login_t:fd use;
#line 5740
allow local_login_t userdomain:fd use;
#line 5740

#line 5740
#
#line 5740
# Allow the new domain to write back to the old domain via a pipe.
#line 5740
#
#line 5740
allow userdomain local_login_t:fifo_file { ioctl read getattr lock write append };
#line 5740

#line 5740
#
#line 5740
# Allow the new domain to read and execute the program.
#line 5740
#
#line 5740
allow userdomain shell_exec_t:file { read getattr lock execute ioctl };
#line 5740

#line 5740
#
#line 5740
# Allow the new domain to be entered via the program.
#line 5740
#
#line 5740
allow userdomain shell_exec_t:file entrypoint;
#line 5740


# read localization information
allow local_login_t locale_t:dir { read getattr lock search ioctl };
allow local_login_t locale_t:{file lnk_file} { read getattr lock ioctl };

# Do not audit denied attempts to access devices.
dontaudit local_login_t fixed_disk_device_t:blk_file { getattr setattr };
dontaudit local_login_t removable_device_t:blk_file { getattr setattr };
dontaudit local_login_t device_t:{ chr_file blk_file lnk_file } { getattr setattr };
dontaudit local_login_t misc_device_t:{ chr_file blk_file lnk_file } { getattr setattr };
dontaudit local_login_t framebuf_device_t:{ chr_file blk_file lnk_file } { getattr setattr read };
dontaudit local_login_t apm_bios_t:chr_file { getattr setattr };
dontaudit local_login_t v4l_device_t:{ chr_file blk_file lnk_file } { getattr setattr read };
dontaudit local_login_t v4l_device_t:dir { read search getattr };

# Do not audit denied attempts to access /mnt.
dontaudit local_login_t file_t:dir { read getattr lock search ioctl };


# Create lock file.
allow local_login_t var_lock_t:dir { read getattr lock search ioctl add_name remove_name write };
allow local_login_t var_lock_t:file { create ioctl read getattr lock write setattr append link unlink rename };


# Read and write ttys.
allow local_login_t tty_device_t:chr_file { setattr { ioctl read getattr lock write append } };
allow local_login_t ttyfile:chr_file { setattr { ioctl read getattr lock write append } };

# Relabel ttys.
allow local_login_t tty_device_t:chr_file { getattr relabelfrom relabelto };
allow local_login_t ttyfile:chr_file { getattr relabelfrom relabelto };

#line 5774


# Allow setting of attributes on sound devices.
allow local_login_t sound_device_t:chr_file { getattr setattr };

# Allow access to /var/run/console and /var/run/console.lock.  Need a separate type?
allow local_login_t var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
allow local_login_t var_run_t:file { create ioctl read getattr lock write setattr append link unlink rename };

#################################
#
# Rules for the remote_login_t domain.
#


#line 5788
type remote_login_t, domain, privuser, privrole, privlog, auth, privowner, mlstrustedreader, mlstrustedwriter, mlstrustedobject, privfd;
#line 5788
role system_r types remote_login_t;
#line 5788

#line 5788

#line 5788
# Access other processes in the same domain.
#line 5788
allow remote_login_t self:process *;
#line 5788

#line 5788
# Access /proc/PID files for processes in the same domain.
#line 5788
allow remote_login_t self:dir { read getattr lock search ioctl };
#line 5788
allow remote_login_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5788

#line 5788
# Access file descriptions, pipes, and sockets
#line 5788
# created by processes in the same domain.
#line 5788
allow remote_login_t self:fd *;
#line 5788
allow remote_login_t self:fifo_file { ioctl read getattr lock write append };
#line 5788
allow remote_login_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 5788
allow remote_login_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 5788

#line 5788
# Allow the domain to communicate with other processes in the same domain.
#line 5788
allow remote_login_t self:unix_dgram_socket sendto;
#line 5788
allow remote_login_t self:unix_stream_socket connectto;
#line 5788

#line 5788
# Access System V IPC objects created by processes in the same domain.
#line 5788
allow remote_login_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 5788
allow remote_login_t self:msg  { send receive };
#line 5788
allow remote_login_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 5788
allow remote_login_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 5788

#line 5788
;
#line 5788

#line 5788
# Read system information files in /proc.
#line 5788
allow remote_login_t proc_t:dir { read getattr lock search ioctl };
#line 5788
allow remote_login_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5788

#line 5788

#line 5788
# Read /.
#line 5788
allow remote_login_t root_t:dir { read getattr lock search ioctl };
#line 5788
allow remote_login_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5788

#line 5788
# Read /home.
#line 5788
allow remote_login_t home_root_t:dir { read getattr lock search ioctl };
#line 5788

#line 5788
# Read /usr.
#line 5788
allow remote_login_t usr_t:dir { read getattr lock search ioctl };
#line 5788
allow remote_login_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5788

#line 5788
# Read bin and sbin directories.
#line 5788
allow remote_login_t bin_t:dir { read getattr lock search ioctl };
#line 5788
allow remote_login_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5788
allow remote_login_t sbin_t:dir { read getattr lock search ioctl };
#line 5788
allow remote_login_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5788

#line 5788

#line 5788
# Read directories and files with the readable_t type.
#line 5788
# This type is a general type for "world"-readable files.
#line 5788
allow remote_login_t readable_t:dir { read getattr lock search ioctl };
#line 5788
allow remote_login_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5788

#line 5788
# Read /var, /var/spool, /var/log.
#line 5788
allow remote_login_t var_t:dir { read getattr lock search ioctl };
#line 5788
allow remote_login_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5788
allow remote_login_t var_spool_t:dir { read getattr lock search ioctl };
#line 5788
allow remote_login_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5788
allow remote_login_t var_log_t:dir { read getattr lock search ioctl };
#line 5788
allow remote_login_t var_log_t:{ file lnk_file } { read getattr lock ioctl };
#line 5788

#line 5788
# Read /etc.
#line 5788
allow remote_login_t etc_t:dir { read getattr lock search ioctl };
#line 5788
allow remote_login_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5788
allow remote_login_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 5788

#line 5788
# Read executable types.
#line 5788
allow remote_login_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 5788

#line 5788
# Read /dev directories and any symbolic links.
#line 5788
allow remote_login_t device_t:dir { read getattr lock search ioctl };
#line 5788
allow remote_login_t device_t:lnk_file { read getattr lock ioctl };
#line 5788

#line 5788

#line 5788
allow remote_login_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5788
allow remote_login_t ld_so_t:file { read getattr lock execute ioctl };
#line 5788
allow remote_login_t ld_so_t:file execute_no_trans;
#line 5788
allow remote_login_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5788
allow remote_login_t shlib_t:file { read getattr lock execute ioctl };
#line 5788
allow remote_login_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5788
allow remote_login_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5788
allow remote_login_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5788
;
#line 5788
allow remote_login_t security_t:security {sid_to_context context_to_sid };
#line 5788

#line 5788

#line 5788
type remote_login_tmp_t, file_type, sysadmfile, tmpfile ;
#line 5788

#line 5788

#line 5788

#line 5788

#line 5788
#
#line 5788
# Allow the process to modify the directory.
#line 5788
#
#line 5788
allow remote_login_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5788

#line 5788
#
#line 5788
# Allow the process to create the file.
#line 5788
#
#line 5788

#line 5788
allow remote_login_t remote_login_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5788
allow remote_login_t remote_login_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5788

#line 5788

#line 5788

#line 5788
type_transition remote_login_t tmp_t:dir remote_login_tmp_t;
#line 5788
type_transition remote_login_t tmp_t:{ file lnk_file sock_file fifo_file } remote_login_tmp_t;
#line 5788

#line 5788

#line 5788

#line 5788

#line 5788

#line 5788
# Use capabilities
#line 5788
allow remote_login_t self:capability { setuid setgid chown fowner fsetid net_bind_service sys_tty_config dac_override sys_nice sys_resource };
#line 5788

#line 5788
# Run shells in user_t by default.
#line 5788

#line 5788

#line 5788

#line 5788
#
#line 5788
# Allow the process to transition to the new domain.
#line 5788
#
#line 5788
allow remote_login_t user_t:process transition;
#line 5788

#line 5788
#
#line 5788
# Allow the process to execute the program.
#line 5788
# 
#line 5788
allow remote_login_t shell_exec_t:file { getattr execute };
#line 5788

#line 5788
#
#line 5788
# Allow the process to reap the new domain.
#line 5788
#
#line 5788
allow user_t remote_login_t:process sigchld;
#line 5788

#line 5788
#
#line 5788
# Allow the new domain to inherit and use file 
#line 5788
# descriptions from the creating process and vice versa.
#line 5788
#
#line 5788
allow user_t remote_login_t:fd use;
#line 5788
allow remote_login_t user_t:fd use;
#line 5788

#line 5788
#
#line 5788
# Allow the new domain to write back to the old domain via a pipe.
#line 5788
#
#line 5788
allow user_t remote_login_t:fifo_file { ioctl read getattr lock write append };
#line 5788

#line 5788
#
#line 5788
# Allow the new domain to read and execute the program.
#line 5788
#
#line 5788
allow user_t shell_exec_t:file { read getattr lock execute ioctl };
#line 5788

#line 5788
#
#line 5788
# Allow the new domain to be entered via the program.
#line 5788
#
#line 5788
allow user_t shell_exec_t:file entrypoint;
#line 5788

#line 5788
type_transition remote_login_t shell_exec_t:process user_t;
#line 5788

#line 5788

#line 5788
# Permit login to search the user home directories.
#line 5788
allow remote_login_t home_root_t:dir search;
#line 5788
allow remote_login_t home_dir_type:dir search;
#line 5788

#line 5788
# Write to /var/run/utmp.
#line 5788
allow remote_login_t initrc_var_run_t:file { ioctl read getattr lock write append };
#line 5788

#line 5788
# Write to /var/log/wtmp.
#line 5788
allow remote_login_t wtmp_t:file { ioctl read getattr lock write append };
#line 5788

#line 5788
# Write to /var/log/lastlog.
#line 5788
allow remote_login_t lastlog_t:file { ioctl read getattr lock write append };
#line 5788

#line 5788
# Write to /var/log/btmp
#line 5788
allow remote_login_t faillog_t:file { append read write };
#line 5788

#line 5788
# Search for mail spool file.
#line 5788
allow remote_login_t mail_spool_t:dir { read getattr lock search ioctl };
#line 5788
allow remote_login_t mail_spool_t:file getattr;
#line 5788
allow remote_login_t mail_spool_t:lnk_file read;
#line 5788

#line 5788
# Determine the set of legal user SIDs that can be reached.
#line 5788
allow remote_login_t security_t:security get_user_sids;
#line 5788

#line 5788
# Obtain the SID to use for relabeling terminals.
#line 5788
allow remote_login_t security_t:security change_sid;
#line 5788

#line 5788
# allow read access to default_contexts in /etc/security
#line 5788
allow remote_login_t default_context_t:file { read getattr lock ioctl };
#line 5788

#line 5788


# Only permit unprivileged user domains to be entered via rlogin,
# since very weak authentication is used.

#line 5792

#line 5792
#
#line 5792
# Allow the process to transition to the new domain.
#line 5792
#
#line 5792
allow remote_login_t unpriv_userdomain:process transition;
#line 5792

#line 5792
#
#line 5792
# Allow the process to execute the program.
#line 5792
# 
#line 5792
allow remote_login_t shell_exec_t:file { getattr execute };
#line 5792

#line 5792
#
#line 5792
# Allow the process to reap the new domain.
#line 5792
#
#line 5792
allow unpriv_userdomain remote_login_t:process sigchld;
#line 5792

#line 5792
#
#line 5792
# Allow the new domain to inherit and use file 
#line 5792
# descriptions from the creating process and vice versa.
#line 5792
#
#line 5792
allow unpriv_userdomain remote_login_t:fd use;
#line 5792
allow remote_login_t unpriv_userdomain:fd use;
#line 5792

#line 5792
#
#line 5792
# Allow the new domain to write back to the old domain via a pipe.
#line 5792
#
#line 5792
allow unpriv_userdomain remote_login_t:fifo_file { ioctl read getattr lock write append };
#line 5792

#line 5792
#
#line 5792
# Allow the new domain to read and execute the program.
#line 5792
#
#line 5792
allow unpriv_userdomain shell_exec_t:file { read getattr lock execute ioctl };
#line 5792

#line 5792
#
#line 5792
# Allow the new domain to be entered via the program.
#line 5792
#
#line 5792
allow unpriv_userdomain shell_exec_t:file entrypoint;
#line 5792


# Use the pty created by rlogind.
#line 5797


# Relabel ptys created by rlogind.
#line 5801

allow remote_login_t ptyfile:chr_file { getattr relabelfrom relabelto };

#DESC Logrotate - Rotate log files
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

#################################
#
# Rules for the logrotate_t domain.
#
# logrotate_t is the domain for the logrotate program.
# logrotate_exec_t is the type of the corresponding program.
#
type logrotate_t, domain, privowner, privmail;
role system_r types logrotate_t;
role sysadm_r types logrotate_t;

#line 5819
allow logrotate_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5819
allow logrotate_t ld_so_t:file { read getattr lock execute ioctl };
#line 5819
allow logrotate_t ld_so_t:file execute_no_trans;
#line 5819
allow logrotate_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5819
allow logrotate_t shlib_t:file { read getattr lock execute ioctl };
#line 5819
allow logrotate_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5819
allow logrotate_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5819
allow logrotate_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5819
;

#line 5820
# Access other processes in the same domain.
#line 5820
allow logrotate_t self:process *;
#line 5820

#line 5820
# Access /proc/PID files for processes in the same domain.
#line 5820
allow logrotate_t self:dir { read getattr lock search ioctl };
#line 5820
allow logrotate_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 5820

#line 5820
# Access file descriptions, pipes, and sockets
#line 5820
# created by processes in the same domain.
#line 5820
allow logrotate_t self:fd *;
#line 5820
allow logrotate_t self:fifo_file { ioctl read getattr lock write append };
#line 5820
allow logrotate_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 5820
allow logrotate_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 5820

#line 5820
# Allow the domain to communicate with other processes in the same domain.
#line 5820
allow logrotate_t self:unix_dgram_socket sendto;
#line 5820
allow logrotate_t self:unix_stream_socket connectto;
#line 5820

#line 5820
# Access System V IPC objects created by processes in the same domain.
#line 5820
allow logrotate_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 5820
allow logrotate_t self:msg  { send receive };
#line 5820
allow logrotate_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 5820
allow logrotate_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 5820

#line 5820
;
type logrotate_exec_t, file_type, sysadmfile, exec_type;

#line 5822

#line 5822

#line 5822
#
#line 5822
# Allow the process to transition to the new domain.
#line 5822
#
#line 5822
allow system_crond_t logrotate_t:process transition;
#line 5822

#line 5822
#
#line 5822
# Allow the process to execute the program.
#line 5822
# 
#line 5822
allow system_crond_t logrotate_exec_t:file { getattr execute };
#line 5822

#line 5822
#
#line 5822
# Allow the process to reap the new domain.
#line 5822
#
#line 5822
allow logrotate_t system_crond_t:process sigchld;
#line 5822

#line 5822
#
#line 5822
# Allow the new domain to inherit and use file 
#line 5822
# descriptions from the creating process and vice versa.
#line 5822
#
#line 5822
allow logrotate_t system_crond_t:fd use;
#line 5822
allow system_crond_t logrotate_t:fd use;
#line 5822

#line 5822
#
#line 5822
# Allow the new domain to write back to the old domain via a pipe.
#line 5822
#
#line 5822
allow logrotate_t system_crond_t:fifo_file { ioctl read getattr lock write append };
#line 5822

#line 5822
#
#line 5822
# Allow the new domain to read and execute the program.
#line 5822
#
#line 5822
allow logrotate_t logrotate_exec_t:file { read getattr lock execute ioctl };
#line 5822

#line 5822
#
#line 5822
# Allow the new domain to be entered via the program.
#line 5822
#
#line 5822
allow logrotate_t logrotate_exec_t:file entrypoint;
#line 5822

#line 5822
type_transition system_crond_t logrotate_exec_t:process logrotate_t;
#line 5822

allow logrotate_t crond_t:fifo_file write;

#line 5824

#line 5824

#line 5824
#
#line 5824
# Allow the process to transition to the new domain.
#line 5824
#
#line 5824
allow sysadm_t logrotate_t:process transition;
#line 5824

#line 5824
#
#line 5824
# Allow the process to execute the program.
#line 5824
# 
#line 5824
allow sysadm_t logrotate_exec_t:file { getattr execute };
#line 5824

#line 5824
#
#line 5824
# Allow the process to reap the new domain.
#line 5824
#
#line 5824
allow logrotate_t sysadm_t:process sigchld;
#line 5824

#line 5824
#
#line 5824
# Allow the new domain to inherit and use file 
#line 5824
# descriptions from the creating process and vice versa.
#line 5824
#
#line 5824
allow logrotate_t sysadm_t:fd use;
#line 5824
allow sysadm_t logrotate_t:fd use;
#line 5824

#line 5824
#
#line 5824
# Allow the new domain to write back to the old domain via a pipe.
#line 5824
#
#line 5824
allow logrotate_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 5824

#line 5824
#
#line 5824
# Allow the new domain to read and execute the program.
#line 5824
#
#line 5824
allow logrotate_t logrotate_exec_t:file { read getattr lock execute ioctl };
#line 5824

#line 5824
#
#line 5824
# Allow the new domain to be entered via the program.
#line 5824
#
#line 5824
allow logrotate_t logrotate_exec_t:file entrypoint;
#line 5824

#line 5824
type_transition sysadm_t logrotate_exec_t:process logrotate_t;
#line 5824

allow logrotate_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
allow logrotate_t devtty_t:chr_file { ioctl read getattr lock write append };

# access files in /etc
allow logrotate_t etc_t:file { getattr read };
allow logrotate_t etc_t:lnk_file read;
allow logrotate_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };

# it should not require this
allow logrotate_t sysadm_home_dir_t:dir { read getattr search };

# create lock files

#line 5837
allow logrotate_t var_lock_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5837
allow logrotate_t var_lock_t:{ file lnk_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5837


# Create temporary files.

#line 5840
type logrotate_tmp_t, file_type, sysadmfile, tmpfile ;
#line 5840

#line 5840

#line 5840

#line 5840

#line 5840
#
#line 5840
# Allow the process to modify the directory.
#line 5840
#
#line 5840
allow logrotate_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5840

#line 5840
#
#line 5840
# Allow the process to create the file.
#line 5840
#
#line 5840

#line 5840
allow logrotate_t logrotate_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5840
allow logrotate_t logrotate_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5840

#line 5840

#line 5840

#line 5840
type_transition logrotate_t tmp_t:dir logrotate_tmp_t;
#line 5840
type_transition logrotate_t tmp_t:{ file lnk_file sock_file fifo_file } logrotate_tmp_t;
#line 5840

#line 5840

#line 5840

#line 5840


# Run helper programs.
allow logrotate_t { bin_t sbin_t }:dir { read getattr lock search ioctl };
allow logrotate_t { bin_t sbin_t }:lnk_file read;

#line 5845
allow logrotate_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5845
;

#line 5846
allow logrotate_t sbin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5846
;

#line 5847
allow logrotate_t shell_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5847
;

# Read PID files.
allow logrotate_t pidfile:file { read getattr lock ioctl };

# Read /proc/PID directories for all domains.
allow logrotate_t proc_t:dir { read getattr lock search ioctl };
allow logrotate_t proc_t:{ file lnk_file } { read getattr lock ioctl };
allow logrotate_t domain:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
allow logrotate_t domain:dir { read getattr lock search ioctl };

# Read /dev directories and any symbolic links.
allow logrotate_t device_t:dir { read getattr lock search ioctl };
allow logrotate_t device_t:lnk_file { read getattr lock ioctl };

# Signal processes.
allow logrotate_t domain:process signal;

# Modify /var/log and other log dirs.
allow logrotate_t var_t:dir { read getattr lock search ioctl };
allow logrotate_t logfile:dir { read getattr lock search ioctl add_name remove_name write };
allow logrotate_t logfile:lnk_file read;

# Create, rename, and truncate log files.
allow logrotate_t logfile:file { create ioctl read getattr lock write setattr append link unlink rename };
allow logrotate_t wtmp_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 5878


# Change ownership on log files.
allow logrotate_t self:capability { chown dac_override kill fsetid fowner };
# for mailx
dontaudit logrotate_t self:capability { setuid setgid };

#line 5887


# Access /var/run
allow logrotate_t var_run_t:dir { read getattr lock search ioctl };

# Write to /var/lib/logrotate.status - should be moved into its own type.
allow logrotate_t var_lib_t:dir { read getattr lock search ioctl add_name remove_name write };
allow logrotate_t var_lib_t:file { create ioctl read getattr lock write setattr append link unlink rename };

# Write to /var/spool/slrnpull - should be moved into its own type.
allow logrotate_t var_spool_t:dir { search write add_name remove_name };
allow logrotate_t var_spool_t:file { rename create setattr unlink };

# Access terminals.
allow logrotate_t { sysadm_tty_device_t sysadm_devpts_t }:chr_file { ioctl read getattr lock write append };


# for /var/backups on Debian
#line 5907


# read localization information
allow logrotate_t locale_t:dir { read getattr lock search ioctl };
allow logrotate_t locale_t:{file lnk_file} { read getattr lock ioctl };
#DESC Modutil - Dynamic module utilities
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

#################################
#
# Rules for the module utility domains.
#
type modules_dep_t, file_type, sysadmfile;
type modules_conf_t, file_type, sysadmfile;
type modules_object_t, file_type, sysadmfile;


#################################
#
# Rules for the depmod_t domain.
#
type depmod_t, domain;
role system_r types depmod_t;
role sysadm_r types depmod_t;


#line 5934
allow depmod_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5934
allow depmod_t ld_so_t:file { read getattr lock execute ioctl };
#line 5934
allow depmod_t ld_so_t:file execute_no_trans;
#line 5934
allow depmod_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5934
allow depmod_t shlib_t:file { read getattr lock execute ioctl };
#line 5934
allow depmod_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5934
allow depmod_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5934
allow depmod_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5934


type depmod_exec_t, file_type, exec_type, sysadmfile;

#line 5937

#line 5937

#line 5937
#
#line 5937
# Allow the process to transition to the new domain.
#line 5937
#
#line 5937
allow initrc_t depmod_t:process transition;
#line 5937

#line 5937
#
#line 5937
# Allow the process to execute the program.
#line 5937
# 
#line 5937
allow initrc_t depmod_exec_t:file { getattr execute };
#line 5937

#line 5937
#
#line 5937
# Allow the process to reap the new domain.
#line 5937
#
#line 5937
allow depmod_t initrc_t:process sigchld;
#line 5937

#line 5937
#
#line 5937
# Allow the new domain to inherit and use file 
#line 5937
# descriptions from the creating process and vice versa.
#line 5937
#
#line 5937
allow depmod_t initrc_t:fd use;
#line 5937
allow initrc_t depmod_t:fd use;
#line 5937

#line 5937
#
#line 5937
# Allow the new domain to write back to the old domain via a pipe.
#line 5937
#
#line 5937
allow depmod_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 5937

#line 5937
#
#line 5937
# Allow the new domain to read and execute the program.
#line 5937
#
#line 5937
allow depmod_t depmod_exec_t:file { read getattr lock execute ioctl };
#line 5937

#line 5937
#
#line 5937
# Allow the new domain to be entered via the program.
#line 5937
#
#line 5937
allow depmod_t depmod_exec_t:file entrypoint;
#line 5937

#line 5937
type_transition initrc_t depmod_exec_t:process depmod_t;
#line 5937


#line 5938
allow depmod_t depmod_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5938


#line 5939

#line 5939

#line 5939
#
#line 5939
# Allow the process to transition to the new domain.
#line 5939
#
#line 5939
allow sysadm_t depmod_t:process transition;
#line 5939

#line 5939
#
#line 5939
# Allow the process to execute the program.
#line 5939
# 
#line 5939
allow sysadm_t depmod_exec_t:file { getattr execute };
#line 5939

#line 5939
#
#line 5939
# Allow the process to reap the new domain.
#line 5939
#
#line 5939
allow depmod_t sysadm_t:process sigchld;
#line 5939

#line 5939
#
#line 5939
# Allow the new domain to inherit and use file 
#line 5939
# descriptions from the creating process and vice versa.
#line 5939
#
#line 5939
allow depmod_t sysadm_t:fd use;
#line 5939
allow sysadm_t depmod_t:fd use;
#line 5939

#line 5939
#
#line 5939
# Allow the new domain to write back to the old domain via a pipe.
#line 5939
#
#line 5939
allow depmod_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 5939

#line 5939
#
#line 5939
# Allow the new domain to read and execute the program.
#line 5939
#
#line 5939
allow depmod_t depmod_exec_t:file { read getattr lock execute ioctl };
#line 5939

#line 5939
#
#line 5939
# Allow the new domain to be entered via the program.
#line 5939
#
#line 5939
allow depmod_t depmod_exec_t:file entrypoint;
#line 5939

#line 5939
type_transition sysadm_t depmod_exec_t:process depmod_t;
#line 5939


# Inherit and use descriptors from init.
allow depmod_t init_t:fd use;

# Read conf.modules.
allow depmod_t modules_conf_t:file { read getattr lock ioctl };

# Create modules.dep.

#line 5948

#line 5948

#line 5948

#line 5948
#
#line 5948
# Allow the process to modify the directory.
#line 5948
#
#line 5948
allow depmod_t modules_object_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 5948

#line 5948
#
#line 5948
# Allow the process to create the file.
#line 5948
#
#line 5948

#line 5948
allow depmod_t modules_dep_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 5948
allow depmod_t modules_dep_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 5948

#line 5948

#line 5948

#line 5948
type_transition depmod_t modules_object_t:dir modules_dep_t;
#line 5948
type_transition depmod_t modules_object_t:{ file lnk_file sock_file fifo_file } modules_dep_t;
#line 5948

#line 5948

#line 5948


# Read module objects.
allow depmod_t modules_object_t:dir { read getattr lock search ioctl };
allow depmod_t modules_object_t:{ file lnk_file } { read getattr lock ioctl };

# Access terminals.
allow depmod_t { console_device_t initrc_devpts_t { sysadm_tty_device_t sysadm_devpts_t } }:chr_file { ioctl read getattr lock write append };


# Read System.map from home directories.
allow depmod_t { home_root_t user_home_dir_type sysadm_home_dir_t }:dir { read getattr lock search ioctl };

#line 5960
allow depmod_t { user_home_type sysadm_home_t }:dir { read getattr lock search ioctl };
#line 5960
allow depmod_t { user_home_type sysadm_home_t }:{ file lnk_file } { read getattr lock ioctl };
#line 5960


#################################
#
# Rules for the insmod_t domain.
#

type insmod_t, domain, privlog;
role system_r types insmod_t;
role sysadm_r types insmod_t;

allow insmod_t self:process { fork { sigchld sigkill sigstop signull signal } };


#line 5973
allow insmod_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 5973
allow insmod_t ld_so_t:file { read getattr lock execute ioctl };
#line 5973
allow insmod_t ld_so_t:file execute_no_trans;
#line 5973
allow insmod_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 5973
allow insmod_t shlib_t:file { read getattr lock execute ioctl };
#line 5973
allow insmod_t shlib_t:lnk_file { read getattr lock ioctl };
#line 5973
allow insmod_t ld_so_cache_t:file { read getattr lock ioctl };
#line 5973
allow insmod_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 5973


type insmod_exec_t, file_type, exec_type, sysadmfile;

#line 5976

#line 5976

#line 5976
#
#line 5976
# Allow the process to transition to the new domain.
#line 5976
#
#line 5976
allow { initrc_t kernel_t } insmod_t:process transition;
#line 5976

#line 5976
#
#line 5976
# Allow the process to execute the program.
#line 5976
# 
#line 5976
allow { initrc_t kernel_t } insmod_exec_t:file { getattr execute };
#line 5976

#line 5976
#
#line 5976
# Allow the process to reap the new domain.
#line 5976
#
#line 5976
allow insmod_t { initrc_t kernel_t }:process sigchld;
#line 5976

#line 5976
#
#line 5976
# Allow the new domain to inherit and use file 
#line 5976
# descriptions from the creating process and vice versa.
#line 5976
#
#line 5976
allow insmod_t { initrc_t kernel_t }:fd use;
#line 5976
allow { initrc_t kernel_t } insmod_t:fd use;
#line 5976

#line 5976
#
#line 5976
# Allow the new domain to write back to the old domain via a pipe.
#line 5976
#
#line 5976
allow insmod_t { initrc_t kernel_t }:fifo_file { ioctl read getattr lock write append };
#line 5976

#line 5976
#
#line 5976
# Allow the new domain to read and execute the program.
#line 5976
#
#line 5976
allow insmod_t insmod_exec_t:file { read getattr lock execute ioctl };
#line 5976

#line 5976
#
#line 5976
# Allow the new domain to be entered via the program.
#line 5976
#
#line 5976
allow insmod_t insmod_exec_t:file entrypoint;
#line 5976

#line 5976
type_transition { initrc_t kernel_t } insmod_exec_t:process insmod_t;
#line 5976

allow initrc_t insmod_exec_t:lnk_file read;

#line 5978
allow insmod_t insmod_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 5978

allow insmod_t init_t:fd use;

#line 5980

#line 5980

#line 5980
#
#line 5980
# Allow the process to transition to the new domain.
#line 5980
#
#line 5980
allow sysadm_t insmod_t:process transition;
#line 5980

#line 5980
#
#line 5980
# Allow the process to execute the program.
#line 5980
# 
#line 5980
allow sysadm_t insmod_exec_t:file { getattr execute };
#line 5980

#line 5980
#
#line 5980
# Allow the process to reap the new domain.
#line 5980
#
#line 5980
allow insmod_t sysadm_t:process sigchld;
#line 5980

#line 5980
#
#line 5980
# Allow the new domain to inherit and use file 
#line 5980
# descriptions from the creating process and vice versa.
#line 5980
#
#line 5980
allow insmod_t sysadm_t:fd use;
#line 5980
allow sysadm_t insmod_t:fd use;
#line 5980

#line 5980
#
#line 5980
# Allow the new domain to write back to the old domain via a pipe.
#line 5980
#
#line 5980
allow insmod_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 5980

#line 5980
#
#line 5980
# Allow the new domain to read and execute the program.
#line 5980
#
#line 5980
allow insmod_t insmod_exec_t:file { read getattr lock execute ioctl };
#line 5980

#line 5980
#
#line 5980
# Allow the new domain to be entered via the program.
#line 5980
#
#line 5980
allow insmod_t insmod_exec_t:file entrypoint;
#line 5980

#line 5980
type_transition sysadm_t insmod_exec_t:process insmod_t;
#line 5980


# Read module objects.
allow insmod_t modules_object_t:dir { read getattr lock search ioctl };
allow insmod_t modules_object_t:{ file lnk_file } { read getattr lock ioctl };

# Read module config and dependency files.
allow insmod_t modules_conf_t:file { read getattr lock ioctl };
allow insmod_t modules_dep_t:file { read getattr lock ioctl };

# read localization information
allow insmod_t locale_t:dir { read getattr lock search ioctl };
allow insmod_t locale_t:{file lnk_file} { read getattr lock ioctl };

# Use the sys_module capability.
allow insmod_t self:capability { sys_module kill };

# for ipv6
allow insmod_t self:capability net_raw;

# Inherit and use descriptors from init.
allow insmod_t privfd:fd use;

# I do not know why insmod sends signals or what signals it sends
allow insmod_t domain:process signal;

# Update /proc/sys/kernel/tainted.
allow insmod_t { proc_t sysctl_t sysctl_kernel_t }:dir search;
allow insmod_t sysctl_kernel_t:file { setattr { ioctl read getattr lock write append } };

# /var/log/ksymoops/*
allow insmod_t var_t:dir { read getattr lock search ioctl };
allow insmod_t var_log_t:dir { read getattr lock search ioctl };
allow insmod_t var_log_ksyms_t:file { create ioctl read getattr lock write setattr append link unlink rename };
allow insmod_t var_log_ksyms_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };

#line 6018

#line 6018

#line 6018
allow system_crond_t var_log_ksyms_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6018
allow system_crond_t var_log_ksyms_t:{ file lnk_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6018

#line 6018

#line 6021


# Access terminals.
allow insmod_t { initrc_devpts_t { sysadm_tty_device_t sysadm_devpts_t } }:chr_file { ioctl read getattr lock write append };



#line 6027
allow insmod_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6027
allow insmod_t ld_so_t:file { read getattr lock execute ioctl };
#line 6027
allow insmod_t ld_so_t:file execute_no_trans;
#line 6027
allow insmod_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6027
allow insmod_t shlib_t:file { read getattr lock execute ioctl };
#line 6027
allow insmod_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6027
allow insmod_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6027
allow insmod_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6027


allow insmod_t initctl_t:fifo_file { ioctl read getattr lock write append };

#################################
#
# Rules for the update_modules_t domain.
#
type update_modules_t, domain, privlog;
type update_modules_exec_t, file_type, exec_type, sysadmfile;

role system_r types update_modules_t;
role sysadm_r types update_modules_t;


#line 6041

#line 6041

#line 6041
#
#line 6041
# Allow the process to transition to the new domain.
#line 6041
#
#line 6041
allow { initrc_t sysadm_t } update_modules_t:process transition;
#line 6041

#line 6041
#
#line 6041
# Allow the process to execute the program.
#line 6041
# 
#line 6041
allow { initrc_t sysadm_t } update_modules_exec_t:file { getattr execute };
#line 6041

#line 6041
#
#line 6041
# Allow the process to reap the new domain.
#line 6041
#
#line 6041
allow update_modules_t { initrc_t sysadm_t }:process sigchld;
#line 6041

#line 6041
#
#line 6041
# Allow the new domain to inherit and use file 
#line 6041
# descriptions from the creating process and vice versa.
#line 6041
#
#line 6041
allow update_modules_t { initrc_t sysadm_t }:fd use;
#line 6041
allow { initrc_t sysadm_t } update_modules_t:fd use;
#line 6041

#line 6041
#
#line 6041
# Allow the new domain to write back to the old domain via a pipe.
#line 6041
#
#line 6041
allow update_modules_t { initrc_t sysadm_t }:fifo_file { ioctl read getattr lock write append };
#line 6041

#line 6041
#
#line 6041
# Allow the new domain to read and execute the program.
#line 6041
#
#line 6041
allow update_modules_t update_modules_exec_t:file { read getattr lock execute ioctl };
#line 6041

#line 6041
#
#line 6041
# Allow the new domain to be entered via the program.
#line 6041
#
#line 6041
allow update_modules_t update_modules_exec_t:file entrypoint;
#line 6041

#line 6041
type_transition { initrc_t sysadm_t } update_modules_exec_t:process update_modules_t;
#line 6041

allow update_modules_t privfd:fd use;
allow update_modules_t init_t:fd use;

allow update_modules_t device_t:dir { getattr search };
allow update_modules_t { console_device_t devtty_t }:chr_file { ioctl read getattr lock write append };
allow update_modules_t { initrc_devpts_t { sysadm_tty_device_t sysadm_devpts_t } }:chr_file { ioctl read getattr lock write append };

dontaudit update_modules_t sysadm_home_dir_t:dir search;


#line 6051
allow update_modules_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6051
allow update_modules_t ld_so_t:file { read getattr lock execute ioctl };
#line 6051
allow update_modules_t ld_so_t:file execute_no_trans;
#line 6051
allow update_modules_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6051
allow update_modules_t shlib_t:file { read getattr lock execute ioctl };
#line 6051
allow update_modules_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6051
allow update_modules_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6051
allow update_modules_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6051

allow update_modules_t self:process { fork sigchld };
allow update_modules_t self:fifo_file { ioctl read getattr lock write append };
allow update_modules_t modules_dep_t:file { ioctl read getattr lock write append };


#line 6056

#line 6056

#line 6056

#line 6056
#
#line 6056
# Allow the process to modify the directory.
#line 6056
#
#line 6056
allow update_modules_t modules_object_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6056

#line 6056
#
#line 6056
# Allow the process to create the file.
#line 6056
#
#line 6056

#line 6056
allow update_modules_t modules_conf_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6056
allow update_modules_t modules_conf_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6056

#line 6056

#line 6056

#line 6056
type_transition update_modules_t modules_object_t:dir modules_conf_t;
#line 6056
type_transition update_modules_t modules_object_t:{ file lnk_file sock_file fifo_file } modules_conf_t;
#line 6056

#line 6056

#line 6056


#line 6057

#line 6057

#line 6057

#line 6057
#
#line 6057
# Allow the process to transition to the new domain.
#line 6057
#
#line 6057
allow update_modules_t depmod_t:process transition;
#line 6057

#line 6057
#
#line 6057
# Allow the process to execute the program.
#line 6057
# 
#line 6057
allow update_modules_t depmod_exec_t:file { getattr execute };
#line 6057

#line 6057
#
#line 6057
# Allow the process to reap the new domain.
#line 6057
#
#line 6057
allow depmod_t update_modules_t:process sigchld;
#line 6057

#line 6057
#
#line 6057
# Allow the new domain to inherit and use file 
#line 6057
# descriptions from the creating process and vice versa.
#line 6057
#
#line 6057
allow depmod_t update_modules_t:fd use;
#line 6057
allow update_modules_t depmod_t:fd use;
#line 6057

#line 6057
#
#line 6057
# Allow the new domain to write back to the old domain via a pipe.
#line 6057
#
#line 6057
allow depmod_t update_modules_t:fifo_file { ioctl read getattr lock write append };
#line 6057

#line 6057
#
#line 6057
# Allow the new domain to read and execute the program.
#line 6057
#
#line 6057
allow depmod_t depmod_exec_t:file { read getattr lock execute ioctl };
#line 6057

#line 6057
#
#line 6057
# Allow the new domain to be entered via the program.
#line 6057
#
#line 6057
allow depmod_t depmod_exec_t:file entrypoint;
#line 6057

#line 6057
type_transition update_modules_t depmod_exec_t:process depmod_t;
#line 6057

#line 6057
allow update_modules_t depmod_exec_t:file read;
#line 6057


#line 6058
allow update_modules_t { shell_exec_t bin_t sbin_t update_modules_exec_t etc_t }:file { { read getattr lock execute ioctl } execute_no_trans };
#line 6058


allow update_modules_t bin_t:lnk_file read;
allow update_modules_t { sbin_t bin_t }:dir search;
allow update_modules_t { etc_t etc_runtime_t }:file { read getattr lock ioctl };
allow update_modules_t etc_t:lnk_file read;
allow update_modules_t fs_t:filesystem getattr;

allow update_modules_t proc_t:dir search;
allow update_modules_t proc_t:file { read getattr lock ioctl };
allow update_modules_t { self proc_t }:lnk_file read;
allow update_modules_t sysctl_kernel_t:dir search;
allow update_modules_t sysctl_kernel_t:file { getattr read };
allow update_modules_t self:dir search;
allow update_modules_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

allow update_modules_t security_t:security sid_to_context;


#line 6076

#line 6076

#line 6076

#line 6076
#
#line 6076
# Allow the process to modify the directory.
#line 6076
#
#line 6076
allow update_modules_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6076

#line 6076
#
#line 6076
# Allow the process to create the file.
#line 6076
#
#line 6076

#line 6076
allow update_modules_t modules_conf_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6076
allow update_modules_t modules_conf_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6076

#line 6076

#line 6076

#line 6076
type_transition update_modules_t etc_t:dir modules_conf_t;
#line 6076
type_transition update_modules_t etc_t:{ file lnk_file sock_file fifo_file } modules_conf_t;
#line 6076

#line 6076

#line 6076


# for when /etc/modules.conf gets the wrong type
allow update_modules_t etc_t:file unlink;


#line 6081
type update_modules_tmp_t, file_type, sysadmfile, tmpfile ;
#line 6081

#line 6081

#line 6081

#line 6081

#line 6081
#
#line 6081
# Allow the process to modify the directory.
#line 6081
#
#line 6081
allow update_modules_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6081

#line 6081
#
#line 6081
# Allow the process to create the file.
#line 6081
#
#line 6081

#line 6081
allow update_modules_t update_modules_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6081
allow update_modules_t update_modules_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6081

#line 6081

#line 6081

#line 6081
type_transition update_modules_t tmp_t:dir update_modules_tmp_t;
#line 6081
type_transition update_modules_t tmp_t:{ file lnk_file sock_file fifo_file } update_modules_tmp_t;
#line 6081

#line 6081

#line 6081

#line 6081

#DESC Mount - Filesystem mount utilities
#
# Macros for mount
#
# Author:  Brian May <bam@snoopy.apana.org.au>
#
# based on the work of:
#          Mark Westerman mark.westerman@csoconline.com
#

type mount_exec_t, file_type, sysadmfile, exec_type;


#line 6094
#
#line 6094
# Rules for the mount_t domain, used by the sysadm_t domain.
#line 6094
#
#line 6094
# mount_t is the domain for the mount process.
#line 6094
#
#line 6094
# This macro will not be included by all users and it may be included twice if
#line 6094
# called from other macros, so we need protection for this do not call this
#line 6094
# macro if mount_def is defined
#line 6094

#line 6094
#
#line 6094
type mount_t, domain, privlog;
#line 6094

#line 6094

#line 6094

#line 6094
# Grant the permissions common to the test domains.
#line 6094

#line 6094
# Grant permissions within the domain.
#line 6094

#line 6094
# Access other processes in the same domain.
#line 6094
allow mount_t self:process *;
#line 6094

#line 6094
# Access /proc/PID files for processes in the same domain.
#line 6094
allow mount_t self:dir { read getattr lock search ioctl };
#line 6094
allow mount_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6094

#line 6094
# Access file descriptions, pipes, and sockets
#line 6094
# created by processes in the same domain.
#line 6094
allow mount_t self:fd *;
#line 6094
allow mount_t self:fifo_file { ioctl read getattr lock write append };
#line 6094
allow mount_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6094
allow mount_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6094

#line 6094
# Allow the domain to communicate with other processes in the same domain.
#line 6094
allow mount_t self:unix_dgram_socket sendto;
#line 6094
allow mount_t self:unix_stream_socket connectto;
#line 6094

#line 6094
# Access System V IPC objects created by processes in the same domain.
#line 6094
allow mount_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 6094
allow mount_t self:msg  { send receive };
#line 6094
allow mount_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 6094
allow mount_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 6094

#line 6094

#line 6094

#line 6094
# Grant read/search permissions to most of /proc.
#line 6094

#line 6094
# Read system information files in /proc.
#line 6094
allow mount_t proc_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6094

#line 6094
# Stat /proc/kmsg and /proc/kcore.
#line 6094
allow mount_t proc_kmsg_t:file { getattr };
#line 6094
allow mount_t proc_kcore_t:file { getattr };
#line 6094

#line 6094
# Read system variables in /proc/sys.
#line 6094
allow mount_t sysctl_modprobe_t:file { read getattr lock ioctl };
#line 6094
allow mount_t sysctl_t:file { read getattr lock ioctl };
#line 6094
allow mount_t sysctl_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t sysctl_fs_t:file { read getattr lock ioctl };
#line 6094
allow mount_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t sysctl_kernel_t:file { read getattr lock ioctl };
#line 6094
allow mount_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t sysctl_net_t:file { read getattr lock ioctl };
#line 6094
allow mount_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t sysctl_vm_t:file { read getattr lock ioctl };
#line 6094
allow mount_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t sysctl_dev_t:file { read getattr lock ioctl };
#line 6094
allow mount_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 6094

#line 6094

#line 6094
# Grant read/search permissions to many system file types.
#line 6094

#line 6094

#line 6094
# Get attributes of file systems.
#line 6094
allow mount_t fs_type:filesystem getattr;
#line 6094

#line 6094

#line 6094
# Read /.
#line 6094
allow mount_t root_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6094

#line 6094
# Read /home.
#line 6094
allow mount_t home_root_t:dir { read getattr lock search ioctl };
#line 6094

#line 6094
# Read /usr.
#line 6094
allow mount_t usr_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6094

#line 6094
# Read bin and sbin directories.
#line 6094
allow mount_t bin_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6094
allow mount_t sbin_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6094

#line 6094

#line 6094
# Read directories and files with the readable_t type.
#line 6094
# This type is a general type for "world"-readable files.
#line 6094
allow mount_t readable_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6094

#line 6094
# Stat /...security and lost+found.
#line 6094
allow mount_t file_labels_t:dir getattr;
#line 6094
allow mount_t lost_found_t:dir getattr;
#line 6094

#line 6094
# Read the devpts root directory.  
#line 6094
allow mount_t devpts_t:dir { read getattr lock search ioctl };
#line 6094

#line 6094

#line 6094
# Read the /tmp directory and any /tmp files with the base type.
#line 6094
# Temporary files created at runtime will typically use derived types.
#line 6094
allow mount_t tmp_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t tmp_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094

#line 6094
# Read /var.
#line 6094
allow mount_t var_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6094

#line 6094
# Read /var/catman.
#line 6094
allow mount_t catman_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t catman_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094

#line 6094
# Read /var/lib.
#line 6094
allow mount_t var_lib_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t var_lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6094
allow mount_t var_lib_nfs_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t var_lib_nfs_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6094

#line 6094

#line 6094
allow mount_t tetex_data_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t tetex_data_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094

#line 6094

#line 6094
# Read /var/yp.
#line 6094
allow mount_t var_yp_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t var_yp_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6094

#line 6094
# Read /var/spool.
#line 6094
allow mount_t var_spool_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6094

#line 6094
# Read /var/run, /var/lock, /var/log.
#line 6094
allow mount_t var_run_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094
allow mount_t var_log_t:dir { read getattr lock search ioctl };
#line 6094
#allow mount_t var_log_t:{ file lnk_file } r_file_perms;
#line 6094
allow mount_t var_log_sa_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t var_log_sa_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094
allow mount_t var_log_ksyms_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094

#line 6094
allow mount_t var_lock_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t var_lock_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094

#line 6094
# Read /var/run/utmp and /var/log/wtmp.
#line 6094
allow mount_t initrc_var_run_t:file { read getattr lock ioctl };
#line 6094
allow mount_t wtmp_t:file { read getattr lock ioctl };
#line 6094

#line 6094
# Read /boot, /boot/System.map*, and /vmlinuz*
#line 6094
allow mount_t boot_t:dir { search getattr };
#line 6094
allow mount_t boot_t:file getattr;
#line 6094
allow mount_t system_map_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094

#line 6094
allow mount_t boot_t:lnk_file read;
#line 6094

#line 6094
# Read /etc.
#line 6094
allow mount_t etc_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6094
allow mount_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094
allow mount_t etc_aliases_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094
allow mount_t etc_mail_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t etc_mail_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094
allow mount_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094
allow mount_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6094

#line 6094
# Read /lib.
#line 6094
allow mount_t lib_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6094

#line 6094
# Read the linker, shared library, and executable types.
#line 6094
allow mount_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094
allow mount_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094
allow mount_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 6094

#line 6094
# Read man directories and files.
#line 6094
allow mount_t man_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t man_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6094

#line 6094
# Read /usr/src.
#line 6094
allow mount_t src_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t src_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6094

#line 6094
# Read module-related files.
#line 6094
allow mount_t modules_object_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t modules_object_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094
allow mount_t modules_dep_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094
allow mount_t modules_conf_t:{ file lnk_file} { read getattr lock ioctl };
#line 6094

#line 6094
# Read /dev directories and any symbolic links.
#line 6094
allow mount_t device_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t device_t:lnk_file { read getattr lock ioctl };
#line 6094

#line 6094
# Read /dev/random and /dev/zero.
#line 6094
allow mount_t random_device_t:chr_file { read getattr lock ioctl };
#line 6094
allow mount_t zero_device_t:chr_file { read getattr lock ioctl };
#line 6094

#line 6094
# Read the root directory of a tmpfs filesytem and any symbolic links.
#line 6094
allow mount_t tmpfs_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t tmpfs_t:lnk_file { read getattr lock ioctl };
#line 6094

#line 6094
# Read any symbolic links on a devfs file system.
#line 6094
allow mount_t device_t:lnk_file { read getattr lock ioctl };
#line 6094

#line 6094
# Read the root directory of a usbdevfs filesystem, and
#line 6094
# the devices and drivers files.  Permit stating of the
#line 6094
# device nodes, but nothing else.
#line 6094
allow mount_t usbdevfs_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t usbdevfs_t:{ file lnk_file } { read getattr lock ioctl };
#line 6094
allow mount_t usbdevfs_device_t:file getattr;
#line 6094

#line 6094

#line 6094
# Grant write permissions to a small set of system file types.
#line 6094
# No permission to create files is granted here.  Use allow rules to grant 
#line 6094
# create permissions to a type or use file_type_auto_trans rules to set up
#line 6094
# new types for files.
#line 6094

#line 6094

#line 6094
# Read and write /dev/tty and /dev/null.
#line 6094
allow mount_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 6094
allow mount_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 6094

#line 6094
# Do not audit write denials to /etc/ld.so.cache.
#line 6094
dontaudit mount_t ld_so_cache_t:file write;
#line 6094

#line 6094

#line 6094
# Execute from the system shared libraries.
#line 6094
# No permission to execute anything else is granted here.
#line 6094
# Use can_exec or can_exec_any to grant the ability to execute within a domain.
#line 6094
# Use domain_auto_trans for executing and changing domains.
#line 6094

#line 6094
allow mount_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6094
allow mount_t ld_so_t:file { read getattr lock execute ioctl };
#line 6094
allow mount_t ld_so_t:file execute_no_trans;
#line 6094
allow mount_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6094
allow mount_t shlib_t:file { read getattr lock execute ioctl };
#line 6094
allow mount_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6094
allow mount_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6094
allow mount_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6094

#line 6094

#line 6094
# read localization information
#line 6094
allow mount_t locale_t:dir { read getattr lock search ioctl };
#line 6094
allow mount_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 6094

#line 6094
# Obtain the context of any SID, the SID for any context, 
#line 6094
# and the list of active SIDs.
#line 6094
allow mount_t security_t:security { sid_to_context context_to_sid get_sids };
#line 6094

#line 6094

#line 6094

#line 6094
# Grant permissions needed to create TCP and UDP sockets and 
#line 6094
# to access the network.
#line 6094

#line 6094
#
#line 6094
# Allow the domain to create and use UDP and TCP sockets.
#line 6094
# Other kinds of sockets must be separately authorized for use.
#line 6094
allow mount_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6094
allow mount_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6094

#line 6094
#
#line 6094
# Allow the domain to send UDP packets.
#line 6094
# Since the destination sockets type is unknown, the generic
#line 6094
# any_socket_t type is used as a placeholder.
#line 6094
#
#line 6094
allow mount_t any_socket_t:udp_socket sendto;
#line 6094

#line 6094
#
#line 6094
# Allow the domain to send using any network interface.
#line 6094
# netif_type is a type attribute for all network interface types.
#line 6094
#
#line 6094
allow mount_t netif_type:netif { tcp_send udp_send rawip_send };
#line 6094

#line 6094
#
#line 6094
# Allow packets sent by the domain to be received on any network interface.
#line 6094
#
#line 6094
allow mount_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 6094

#line 6094
#
#line 6094
# Allow the domain to receive packets from any network interface.
#line 6094
# netmsg_type is a type attribute for all default message types.
#line 6094
#
#line 6094
allow mount_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 6094

#line 6094
#
#line 6094
# Allow the domain to initiate or accept TCP connections 
#line 6094
# on any network interface.
#line 6094
#
#line 6094
allow mount_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 6094

#line 6094
#
#line 6094
# Receive resets from the TCP reset socket.
#line 6094
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 6094
#
#line 6094
allow mount_t tcp_socket_t:tcp_socket recvfrom;
#line 6094

#line 6094
dontaudit mount_t tcp_socket_t:tcp_socket connectto;
#line 6094

#line 6094
#
#line 6094
# Allow the domain to send to any node.
#line 6094
# node_type is a type attribute for all node types.
#line 6094
#
#line 6094
allow mount_t node_type:node { tcp_send udp_send rawip_send };
#line 6094

#line 6094
#
#line 6094
# Allow packets sent by the domain to be received from any node.
#line 6094
#
#line 6094
allow mount_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 6094

#line 6094
#
#line 6094
# Allow the domain to send NFS client requests via the socket
#line 6094
# created by mount.
#line 6094
#
#line 6094
allow mount_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6094

#line 6094
#
#line 6094
# Bind to the default port type.
#line 6094
# Other port types must be separately authorized.
#line 6094
#
#line 6094
allow mount_t port_t:udp_socket name_bind;
#line 6094
allow mount_t port_t:tcp_socket name_bind;
#line 6094

#line 6094

#line 6094
# when mount is run by sysadm goto mount_t domain
#line 6094

#line 6094

#line 6094

#line 6094
#
#line 6094
# Allow the process to transition to the new domain.
#line 6094
#
#line 6094
allow sysadm_t mount_t:process transition;
#line 6094

#line 6094
#
#line 6094
# Allow the process to execute the program.
#line 6094
# 
#line 6094
allow sysadm_t mount_exec_t:file { getattr execute };
#line 6094

#line 6094
#
#line 6094
# Allow the process to reap the new domain.
#line 6094
#
#line 6094
allow mount_t sysadm_t:process sigchld;
#line 6094

#line 6094
#
#line 6094
# Allow the new domain to inherit and use file 
#line 6094
# descriptions from the creating process and vice versa.
#line 6094
#
#line 6094
allow mount_t sysadm_t:fd use;
#line 6094
allow sysadm_t mount_t:fd use;
#line 6094

#line 6094
#
#line 6094
# Allow the new domain to write back to the old domain via a pipe.
#line 6094
#
#line 6094
allow mount_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 6094

#line 6094
#
#line 6094
# Allow the new domain to read and execute the program.
#line 6094
#
#line 6094
allow mount_t mount_exec_t:file { read getattr lock execute ioctl };
#line 6094

#line 6094
#
#line 6094
# Allow the new domain to be entered via the program.
#line 6094
#
#line 6094
allow mount_t mount_exec_t:file entrypoint;
#line 6094

#line 6094
type_transition sysadm_t mount_exec_t:process mount_t;
#line 6094

#line 6094

#line 6094

#line 6094
type mount_tmp_t, file_type, sysadmfile, tmpfile ;
#line 6094

#line 6094

#line 6094

#line 6094

#line 6094
#
#line 6094
# Allow the process to modify the directory.
#line 6094
#
#line 6094
allow mount_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6094

#line 6094
#
#line 6094
# Allow the process to create the file.
#line 6094
#
#line 6094

#line 6094
allow mount_t mount_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6094
allow mount_t mount_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6094

#line 6094

#line 6094

#line 6094
type_transition mount_t tmp_t:dir mount_tmp_t;
#line 6094
type_transition mount_t tmp_t:{ file lnk_file sock_file fifo_file } mount_tmp_t;
#line 6094

#line 6094

#line 6094

#line 6094

#line 6094

#line 6094
# Use capabilities.
#line 6094
allow mount_t self:capability { net_bind_service sys_rawio sys_admin };
#line 6094

#line 6094
# Create and modify /etc/mtab.
#line 6094

#line 6094

#line 6094

#line 6094

#line 6094
#
#line 6094
# Allow the process to modify the directory.
#line 6094
#
#line 6094
allow mount_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6094

#line 6094
#
#line 6094
# Allow the process to create the file.
#line 6094
#
#line 6094

#line 6094
allow mount_t etc_runtime_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 6094

#line 6094

#line 6094

#line 6094
type_transition mount_t etc_t:file etc_runtime_t;
#line 6094

#line 6094

#line 6094

#line 6094

#line 6094
# Access the terminal.
#line 6094
allow mount_t sysadm_tty_device_t:chr_file { getattr read write ioctl };
#line 6094
allow mount_t sysadm_devpts_t:chr_file { getattr read write };
#line 6094

#line 6094

role sysadm_r types mount_t;
role system_r types mount_t;


#line 6098

#line 6098

#line 6098
#
#line 6098
# Allow the process to transition to the new domain.
#line 6098
#
#line 6098
allow initrc_t mount_t:process transition;
#line 6098

#line 6098
#
#line 6098
# Allow the process to execute the program.
#line 6098
# 
#line 6098
allow initrc_t mount_exec_t:file { getattr execute };
#line 6098

#line 6098
#
#line 6098
# Allow the process to reap the new domain.
#line 6098
#
#line 6098
allow mount_t initrc_t:process sigchld;
#line 6098

#line 6098
#
#line 6098
# Allow the new domain to inherit and use file 
#line 6098
# descriptions from the creating process and vice versa.
#line 6098
#
#line 6098
allow mount_t initrc_t:fd use;
#line 6098
allow initrc_t mount_t:fd use;
#line 6098

#line 6098
#
#line 6098
# Allow the new domain to write back to the old domain via a pipe.
#line 6098
#
#line 6098
allow mount_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 6098

#line 6098
#
#line 6098
# Allow the new domain to read and execute the program.
#line 6098
#
#line 6098
allow mount_t mount_exec_t:file { read getattr lock execute ioctl };
#line 6098

#line 6098
#
#line 6098
# Allow the new domain to be entered via the program.
#line 6098
#
#line 6098
allow mount_t mount_exec_t:file entrypoint;
#line 6098

#line 6098
type_transition initrc_t mount_exec_t:process mount_t;
#line 6098

allow mount_t init_t:fd use;
allow mount_t privfd:fd use;

allow mount_t self:capability { ipc_lock dac_override };

# Create and modify /etc/mtab.

#line 6105

#line 6105

#line 6105

#line 6105
#
#line 6105
# Allow the process to modify the directory.
#line 6105
#
#line 6105
allow mount_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6105

#line 6105
#
#line 6105
# Allow the process to create the file.
#line 6105
#
#line 6105

#line 6105
allow mount_t etc_runtime_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 6105

#line 6105

#line 6105

#line 6105
type_transition mount_t etc_t:file etc_runtime_t;
#line 6105

#line 6105

#line 6105


allow mount_t file_type:dir search;

# Access disk devices.
allow mount_t fixed_disk_device_t:{ chr_file blk_file } { ioctl read getattr lock write append };
allow mount_t removable_device_t:{ chr_file blk_file } { ioctl read getattr lock write append };

# Mount, remount and unmount file systems.
allow mount_t fs_type:filesystem { mount remount unmount getattr };
allow mount_t file_t:dir mounton;
allow mount_t usr_t:dir mounton;
allow mount_t proc_t:dir mounton;
allow mount_t root_t:dir mounton;
# On some RedHat systems, /boot is a mount point
allow mount_t boot_t:dir mounton;
allow mount_t device_t:dir mounton;
#line 6124

allow mount_t root_t:filesystem unmount;


#DESC Netutils - Network utilities
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil>
#

#
# Rules for the netutils_t domain.
# This domain is for network utilities that require access to
# special protocol families.
#
type netutils_t, domain, privlog;
type netutils_exec_t, file_type, sysadmfile, exec_type;
role system_r types netutils_t;
role sysadm_r types netutils_t;


#line 6143
allow netutils_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6143
allow netutils_t ld_so_t:file { read getattr lock execute ioctl };
#line 6143
allow netutils_t ld_so_t:file execute_no_trans;
#line 6143
allow netutils_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6143
allow netutils_t shlib_t:file { read getattr lock execute ioctl };
#line 6143
allow netutils_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6143
allow netutils_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6143
allow netutils_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6143



#line 6145

#line 6145

#line 6145
#
#line 6145
# Allow the process to transition to the new domain.
#line 6145
#
#line 6145
allow initrc_t netutils_t:process transition;
#line 6145

#line 6145
#
#line 6145
# Allow the process to execute the program.
#line 6145
# 
#line 6145
allow initrc_t netutils_exec_t:file { getattr execute };
#line 6145

#line 6145
#
#line 6145
# Allow the process to reap the new domain.
#line 6145
#
#line 6145
allow netutils_t initrc_t:process sigchld;
#line 6145

#line 6145
#
#line 6145
# Allow the new domain to inherit and use file 
#line 6145
# descriptions from the creating process and vice versa.
#line 6145
#
#line 6145
allow netutils_t initrc_t:fd use;
#line 6145
allow initrc_t netutils_t:fd use;
#line 6145

#line 6145
#
#line 6145
# Allow the new domain to write back to the old domain via a pipe.
#line 6145
#
#line 6145
allow netutils_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 6145

#line 6145
#
#line 6145
# Allow the new domain to read and execute the program.
#line 6145
#
#line 6145
allow netutils_t netutils_exec_t:file { read getattr lock execute ioctl };
#line 6145

#line 6145
#
#line 6145
# Allow the new domain to be entered via the program.
#line 6145
#
#line 6145
allow netutils_t netutils_exec_t:file entrypoint;
#line 6145

#line 6145
type_transition initrc_t netutils_exec_t:process netutils_t;
#line 6145


#line 6146

#line 6146

#line 6146
#
#line 6146
# Allow the process to transition to the new domain.
#line 6146
#
#line 6146
allow sysadm_t netutils_t:process transition;
#line 6146

#line 6146
#
#line 6146
# Allow the process to execute the program.
#line 6146
# 
#line 6146
allow sysadm_t netutils_exec_t:file { getattr execute };
#line 6146

#line 6146
#
#line 6146
# Allow the process to reap the new domain.
#line 6146
#
#line 6146
allow netutils_t sysadm_t:process sigchld;
#line 6146

#line 6146
#
#line 6146
# Allow the new domain to inherit and use file 
#line 6146
# descriptions from the creating process and vice versa.
#line 6146
#
#line 6146
allow netutils_t sysadm_t:fd use;
#line 6146
allow sysadm_t netutils_t:fd use;
#line 6146

#line 6146
#
#line 6146
# Allow the new domain to write back to the old domain via a pipe.
#line 6146
#
#line 6146
allow netutils_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 6146

#line 6146
#
#line 6146
# Allow the new domain to read and execute the program.
#line 6146
#
#line 6146
allow netutils_t netutils_exec_t:file { read getattr lock execute ioctl };
#line 6146

#line 6146
#
#line 6146
# Allow the new domain to be entered via the program.
#line 6146
#
#line 6146
allow netutils_t netutils_exec_t:file entrypoint;
#line 6146

#line 6146
type_transition sysadm_t netutils_exec_t:process netutils_t;
#line 6146


# Inherit and use descriptors from init.
allow netutils_t init_t:fd use;

# Perform network administration operations and have raw access to the network.
allow netutils_t self:capability { net_admin net_raw setuid setgid };

# Create and use netlink sockets.
allow netutils_t self:netlink_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# Create and use packet sockets.
allow netutils_t self:packet_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# Create and use UDP sockets.
allow netutils_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# Create and use TCP sockets.
allow netutils_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };

# Read certain files in /etc
allow netutils_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
allow netutils_t resolv_conf_t:file { read getattr lock ioctl };

# Access terminals.
allow netutils_t privfd:fd use;
allow netutils_t { sysadm_tty_device_t sysadm_devpts_t }:chr_file { ioctl read getattr lock write append };

#DESC Newrole - SELinux utility to run a shell with a new role
#
# Authors:  Anthony Colatrella (NSA) 
# Maintained by Stephen Smalley <sds@epoch.ncsc.mil>
#

#################################
#
# Rules for the newrole_t domain.
#
# newrole_t is the domain for the newrole program.
# newrole_exec_t is the type of the newrole executable.
#
type newrole_t, domain, privrole, privowner, privlog, auth, privfd;

#line 6188
role user_r types newrole_t;
#line 6188
#role staff_r types newrole_t;
#line 6188

role sysadm_r types newrole_t;


#line 6191
# Access other processes in the same domain.
#line 6191
allow newrole_t self:process *;
#line 6191

#line 6191
# Access /proc/PID files for processes in the same domain.
#line 6191
allow newrole_t self:dir { read getattr lock search ioctl };
#line 6191
allow newrole_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6191

#line 6191
# Access file descriptions, pipes, and sockets
#line 6191
# created by processes in the same domain.
#line 6191
allow newrole_t self:fd *;
#line 6191
allow newrole_t self:fifo_file { ioctl read getattr lock write append };
#line 6191
allow newrole_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6191
allow newrole_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6191

#line 6191
# Allow the domain to communicate with other processes in the same domain.
#line 6191
allow newrole_t self:unix_dgram_socket sendto;
#line 6191
allow newrole_t self:unix_stream_socket connectto;
#line 6191

#line 6191
# Access System V IPC objects created by processes in the same domain.
#line 6191
allow newrole_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 6191
allow newrole_t self:msg  { send receive };
#line 6191
allow newrole_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 6191
allow newrole_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 6191

#line 6191
;
allow newrole_t proc_t:{file lnk_file} { read getattr lock ioctl };


#line 6194
allow newrole_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6194
allow newrole_t ld_so_t:file { read getattr lock execute ioctl };
#line 6194
allow newrole_t ld_so_t:file execute_no_trans;
#line 6194
allow newrole_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6194
allow newrole_t shlib_t:file { read getattr lock execute ioctl };
#line 6194
allow newrole_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6194
allow newrole_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6194
allow newrole_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6194


# read localization information
allow newrole_t locale_t:dir { read getattr lock search ioctl };
allow newrole_t locale_t:{file lnk_file} { read getattr lock ioctl };

type newrole_exec_t, file_type, exec_type, sysadmfile;

#line 6201

#line 6201

#line 6201
#
#line 6201
# Allow the process to transition to the new domain.
#line 6201
#
#line 6201
allow userdomain newrole_t:process transition;
#line 6201

#line 6201
#
#line 6201
# Allow the process to execute the program.
#line 6201
# 
#line 6201
allow userdomain newrole_exec_t:file { getattr execute };
#line 6201

#line 6201
#
#line 6201
# Allow the process to reap the new domain.
#line 6201
#
#line 6201
allow newrole_t userdomain:process sigchld;
#line 6201

#line 6201
#
#line 6201
# Allow the new domain to inherit and use file 
#line 6201
# descriptions from the creating process and vice versa.
#line 6201
#
#line 6201
allow newrole_t userdomain:fd use;
#line 6201
allow userdomain newrole_t:fd use;
#line 6201

#line 6201
#
#line 6201
# Allow the new domain to write back to the old domain via a pipe.
#line 6201
#
#line 6201
allow newrole_t userdomain:fifo_file { ioctl read getattr lock write append };
#line 6201

#line 6201
#
#line 6201
# Allow the new domain to read and execute the program.
#line 6201
#
#line 6201
allow newrole_t newrole_exec_t:file { read getattr lock execute ioctl };
#line 6201

#line 6201
#
#line 6201
# Allow the new domain to be entered via the program.
#line 6201
#
#line 6201
allow newrole_t newrole_exec_t:file entrypoint;
#line 6201

#line 6201
type_transition userdomain newrole_exec_t:process newrole_t;
#line 6201


allow newrole_t shadow_t:file { read getattr };

# Inherit descriptors from the current session.
allow newrole_t privfd:fd use;

# Execute /sbin/pwdb_chkpwd to check the password.
allow newrole_t sbin_t:dir { read getattr lock search ioctl };

#line 6210
allow newrole_t chkpwd_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 6210


# Execute shells
allow newrole_t bin_t:dir { read getattr lock search ioctl };
allow newrole_t shell_exec_t:file { read getattr lock ioctl };

# Allow newrole_t to transition to user domains.

#line 6217

#line 6217
#
#line 6217
# Allow the process to transition to the new domain.
#line 6217
#
#line 6217
allow newrole_t userdomain:process transition;
#line 6217

#line 6217
#
#line 6217
# Allow the process to execute the program.
#line 6217
# 
#line 6217
allow newrole_t shell_exec_t:file { getattr execute };
#line 6217

#line 6217
#
#line 6217
# Allow the process to reap the new domain.
#line 6217
#
#line 6217
allow userdomain newrole_t:process sigchld;
#line 6217

#line 6217
#
#line 6217
# Allow the new domain to inherit and use file 
#line 6217
# descriptions from the creating process and vice versa.
#line 6217
#
#line 6217
allow userdomain newrole_t:fd use;
#line 6217
allow newrole_t userdomain:fd use;
#line 6217

#line 6217
#
#line 6217
# Allow the new domain to write back to the old domain via a pipe.
#line 6217
#
#line 6217
allow userdomain newrole_t:fifo_file { ioctl read getattr lock write append };
#line 6217

#line 6217
#
#line 6217
# Allow the new domain to read and execute the program.
#line 6217
#
#line 6217
allow userdomain shell_exec_t:file { read getattr lock execute ioctl };
#line 6217

#line 6217
#
#line 6217
# Allow the new domain to be entered via the program.
#line 6217
#
#line 6217
allow userdomain shell_exec_t:file entrypoint;
#line 6217


# Use capabilities.
allow newrole_t self:capability { setuid setgid net_bind_service dac_override };

# Write to utmp.
allow newrole_t var_run_t:dir { read getattr lock search ioctl };
allow newrole_t initrc_var_run_t:file { ioctl read getattr lock write append };

# Read the devpts root directory.
allow newrole_t devpts_t:dir { read getattr lock search ioctl };

# Read the /etc/security/default_type file
allow newrole_t etc_t:file { read getattr lock ioctl };

# Read /var.
allow newrole_t var_t:dir { read getattr lock search ioctl };
allow newrole_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };

# Read /dev directories and any symbolic links.
allow newrole_t device_t:dir { read getattr lock search ioctl };

# Relabel terminals.
allow newrole_t ttyfile:chr_file { getattr relabelfrom relabelto };
allow newrole_t ptyfile:chr_file { getattr relabelfrom relabelto };

# Access terminals.
allow newrole_t ttyfile:chr_file { ioctl read getattr lock write append };
allow newrole_t ptyfile:chr_file { ioctl read getattr lock write append };


#
# Allow sysadm_t to reap a user_t process 
# created via newrole.
#
allow userdomain userdomain:process { sigchld };

#
# Allow newrole to obtain SIDs to relabel TTYs
#
allow newrole_t security_t:security { sid_to_context context_to_sid change_sid };

allow newrole_t fs_t:filesystem getattr;

# for some PAM modules and for cwd
dontaudit newrole_t { home_root_t home_type }:dir search;

# Failed reads to /proc cause no harm, so don't audit them
dontaudit newrole_t proc_t:dir search;
#DESC Passwd - Password utilities
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

#################################
#
# Rules for the passwd_t domain.
#
# passwd_t is the domain of the passwd program when
# it is executed through the spasswd wrapper.
# passwd_exec_t is the type of the spasswd wrapper.
# This domain and type is also used for wrappers for
# chfn and chsh.
#
type passwd_t, domain, privlog, auth, privowner;

#line 6282
role user_r types passwd_t;
#line 6282
#role staff_r types passwd_t;
#line 6282

role sysadm_r types passwd_t;

type passwd_exec_t, file_type, sysadmfile, exec_type;
type passwd_real_exec_t, file_type, sysadmfile;
type admin_passwd_exec_t, file_type, sysadmfile;


#line 6289
# Access other processes in the same domain.
#line 6289
allow passwd_t self:process *;
#line 6289

#line 6289
# Access /proc/PID files for processes in the same domain.
#line 6289
allow passwd_t self:dir { read getattr lock search ioctl };
#line 6289
allow passwd_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6289

#line 6289
# Access file descriptions, pipes, and sockets
#line 6289
# created by processes in the same domain.
#line 6289
allow passwd_t self:fd *;
#line 6289
allow passwd_t self:fifo_file { ioctl read getattr lock write append };
#line 6289
allow passwd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6289
allow passwd_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6289

#line 6289
# Allow the domain to communicate with other processes in the same domain.
#line 6289
allow passwd_t self:unix_dgram_socket sendto;
#line 6289
allow passwd_t self:unix_stream_socket connectto;
#line 6289

#line 6289
# Access System V IPC objects created by processes in the same domain.
#line 6289
allow passwd_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 6289
allow passwd_t self:msg  { send receive };
#line 6289
allow passwd_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 6289
allow passwd_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 6289

#line 6289
;


#line 6291
allow passwd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6291
allow passwd_t ld_so_t:file { read getattr lock execute ioctl };
#line 6291
allow passwd_t ld_so_t:file execute_no_trans;
#line 6291
allow passwd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6291
allow passwd_t shlib_t:file { read getattr lock execute ioctl };
#line 6291
allow passwd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6291
allow passwd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6291
allow passwd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6291
;


#line 6293

#line 6293

#line 6293
#
#line 6293
# Allow the process to transition to the new domain.
#line 6293
#
#line 6293
allow userdomain passwd_t:process transition;
#line 6293

#line 6293
#
#line 6293
# Allow the process to execute the program.
#line 6293
# 
#line 6293
allow userdomain passwd_exec_t:file { getattr execute };
#line 6293

#line 6293
#
#line 6293
# Allow the process to reap the new domain.
#line 6293
#
#line 6293
allow passwd_t userdomain:process sigchld;
#line 6293

#line 6293
#
#line 6293
# Allow the new domain to inherit and use file 
#line 6293
# descriptions from the creating process and vice versa.
#line 6293
#
#line 6293
allow passwd_t userdomain:fd use;
#line 6293
allow userdomain passwd_t:fd use;
#line 6293

#line 6293
#
#line 6293
# Allow the new domain to write back to the old domain via a pipe.
#line 6293
#
#line 6293
allow passwd_t userdomain:fifo_file { ioctl read getattr lock write append };
#line 6293

#line 6293
#
#line 6293
# Allow the new domain to read and execute the program.
#line 6293
#
#line 6293
allow passwd_t passwd_exec_t:file { read getattr lock execute ioctl };
#line 6293

#line 6293
#
#line 6293
# Allow the new domain to be entered via the program.
#line 6293
#
#line 6293
allow passwd_t passwd_exec_t:file entrypoint;
#line 6293

#line 6293
type_transition userdomain passwd_exec_t:process passwd_t;
#line 6293


#line 6294

#line 6294

#line 6294
#
#line 6294
# Allow the process to transition to the new domain.
#line 6294
#
#line 6294
allow sysadm_t passwd_t:process transition;
#line 6294

#line 6294
#
#line 6294
# Allow the process to execute the program.
#line 6294
# 
#line 6294
allow sysadm_t admin_passwd_exec_t:file { getattr execute };
#line 6294

#line 6294
#
#line 6294
# Allow the process to reap the new domain.
#line 6294
#
#line 6294
allow passwd_t sysadm_t:process sigchld;
#line 6294

#line 6294
#
#line 6294
# Allow the new domain to inherit and use file 
#line 6294
# descriptions from the creating process and vice versa.
#line 6294
#
#line 6294
allow passwd_t sysadm_t:fd use;
#line 6294
allow sysadm_t passwd_t:fd use;
#line 6294

#line 6294
#
#line 6294
# Allow the new domain to write back to the old domain via a pipe.
#line 6294
#
#line 6294
allow passwd_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 6294

#line 6294
#
#line 6294
# Allow the new domain to read and execute the program.
#line 6294
#
#line 6294
allow passwd_t admin_passwd_exec_t:file { read getattr lock execute ioctl };
#line 6294

#line 6294
#
#line 6294
# Allow the new domain to be entered via the program.
#line 6294
#
#line 6294
allow passwd_t admin_passwd_exec_t:file entrypoint;
#line 6294

#line 6294
type_transition sysadm_t admin_passwd_exec_t:process passwd_t;
#line 6294


# for vipw - vi looks in the root home directory for config
dontaudit passwd_t sysadm_home_dir_t:dir { getattr search };

# Use capabilities.
allow passwd_t passwd_t:capability { chown dac_override fsetid setuid sys_resource };

# Inherit and use descriptors from login.
allow passwd_t privfd:fd use;

# Execute /usr/bin/{passwd,chfn,chsh} and /usr/sbin/{useradd,vipw}.
allow passwd_t { bin_t sbin_t }:dir { read getattr lock search ioctl };

#line 6307
allow passwd_t { bin_t sbin_t shell_exec_t passwd_real_exec_t }:file { { read getattr lock execute ioctl } execute_no_trans };
#line 6307


# allow checking if a shell is executable
allow passwd_t shell_exec_t:file execute;

# Obtain contexts
allow passwd_t security_t:security { sid_to_context context_to_sid };

# Update /etc/shadow and /etc/passwd

#line 6316

#line 6316

#line 6316

#line 6316
#
#line 6316
# Allow the process to modify the directory.
#line 6316
#
#line 6316
allow passwd_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6316

#line 6316
#
#line 6316
# Allow the process to create the file.
#line 6316
#
#line 6316

#line 6316
allow passwd_t shadow_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6316
allow passwd_t shadow_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6316

#line 6316

#line 6316

#line 6316
type_transition passwd_t etc_t:dir shadow_t;
#line 6316
type_transition passwd_t etc_t:{ file lnk_file sock_file fifo_file } shadow_t;
#line 6316

#line 6316

#line 6316

allow passwd_t etc_t:file { create ioctl read getattr lock write setattr append link unlink rename };
allow passwd_t { etc_t shadow_t }:file { relabelfrom relabelto };

# allow vipw to create temporary files under /var/tmp/vi.recover

#line 6321
type passwd_tmp_t, file_type, sysadmfile, tmpfile ;
#line 6321

#line 6321

#line 6321

#line 6321

#line 6321
#
#line 6321
# Allow the process to modify the directory.
#line 6321
#
#line 6321
allow passwd_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6321

#line 6321
#
#line 6321
# Allow the process to create the file.
#line 6321
#
#line 6321

#line 6321
allow passwd_t passwd_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6321
allow passwd_t passwd_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6321

#line 6321

#line 6321

#line 6321
type_transition passwd_t tmp_t:dir passwd_tmp_t;
#line 6321
type_transition passwd_t tmp_t:{ file lnk_file sock_file fifo_file } passwd_tmp_t;
#line 6321

#line 6321

#line 6321

#line 6321


# Access terminals.
allow passwd_t ttyfile:chr_file { ioctl read getattr lock write append };
allow passwd_t ptyfile:chr_file { ioctl read getattr lock write append };


# for vipw - vi looks in the root home directory for config
dontaudit passwd_t sysadm_home_dir_t:dir { getattr search };

# /usr/bin/passwd asks for w access to utmp, but it will operate
# correctly without it.  Do not audit write denials to utmp.
dontaudit passwd_t initrc_var_run_t:file { read write };

# user generally runs this from their home directory, so do not audit a search
# on user home dir
dontaudit passwd_t { user_home_dir_type user_home_type }:dir search;

# When the wrong current passwd is entered, passwd, for some reason, 
# attempts to access /proc and /dev, but fails appropriately. So don't
# audit those denials.
# Access denials to /var aren't audited either.
dontaudit passwd_t { proc_t device_t var_t }:dir { search read };

allow passwd_t device_t:dir getattr;
#DESC Setfiles - SELinux filesystem labeling utilities
#
# Authors:  Russell Coker <russell@coker.com.au>
#

#################################
#
# Rules for the setfiles_t domain.
#
# setfiles_exec_t is the type of the setfiles executable.
#
type setfiles_t, domain, privlog, privowner;
type setfiles_exec_t, file_type, sysadmfile, exec_type;

role system_r types setfiles_t;
role sysadm_r types setfiles_t;

allow setfiles_t initrc_devpts_t:chr_file { read write ioctl };
allow setfiles_t { sysadm_tty_device_t sysadm_devpts_t }:chr_file { read write ioctl };


#line 6366

#line 6366

#line 6366
#
#line 6366
# Allow the process to transition to the new domain.
#line 6366
#
#line 6366
allow { initrc_t sysadm_t } setfiles_t:process transition;
#line 6366

#line 6366
#
#line 6366
# Allow the process to execute the program.
#line 6366
# 
#line 6366
allow { initrc_t sysadm_t } setfiles_exec_t:file { getattr execute };
#line 6366

#line 6366
#
#line 6366
# Allow the process to reap the new domain.
#line 6366
#
#line 6366
allow setfiles_t { initrc_t sysadm_t }:process sigchld;
#line 6366

#line 6366
#
#line 6366
# Allow the new domain to inherit and use file 
#line 6366
# descriptions from the creating process and vice versa.
#line 6366
#
#line 6366
allow setfiles_t { initrc_t sysadm_t }:fd use;
#line 6366
allow { initrc_t sysadm_t } setfiles_t:fd use;
#line 6366

#line 6366
#
#line 6366
# Allow the new domain to write back to the old domain via a pipe.
#line 6366
#
#line 6366
allow setfiles_t { initrc_t sysadm_t }:fifo_file { ioctl read getattr lock write append };
#line 6366

#line 6366
#
#line 6366
# Allow the new domain to read and execute the program.
#line 6366
#
#line 6366
allow setfiles_t setfiles_exec_t:file { read getattr lock execute ioctl };
#line 6366

#line 6366
#
#line 6366
# Allow the new domain to be entered via the program.
#line 6366
#
#line 6366
allow setfiles_t setfiles_exec_t:file entrypoint;
#line 6366

#line 6366
type_transition { initrc_t sysadm_t } setfiles_exec_t:process setfiles_t;
#line 6366

allow setfiles_t init_t:fd use;
allow setfiles_t privfd:fd use;


#line 6370
allow setfiles_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6370
allow setfiles_t ld_so_t:file { read getattr lock execute ioctl };
#line 6370
allow setfiles_t ld_so_t:file execute_no_trans;
#line 6370
allow setfiles_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6370
allow setfiles_t shlib_t:file { read getattr lock execute ioctl };
#line 6370
allow setfiles_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6370
allow setfiles_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6370
allow setfiles_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6370

allow setfiles_t self:capability { dac_override dac_read_search };

# for upgrading glibc - without this the glibc upgrade scripts will put things
# in a state such that setfiles can not be run!
allow setfiles_t lib_t:file execute;

allow setfiles_t security_t:security { context_to_sid sid_to_context };
allow setfiles_t policy_src_t:file { read getattr lock ioctl };

allow setfiles_t file_type:dir { read getattr lock search ioctl };
allow setfiles_t file_type:lnk_file { read getattr lock ioctl };
allow setfiles_t file_type:{ dir file lnk_file sock_file fifo_file chr_file blk_file } { getattr relabelfrom relabelto };

allow setfiles_t file_labels_t:dir { read getattr lock search ioctl add_name remove_name write };
allow setfiles_t file_labels_t:file { create ioctl read getattr lock write setattr append link unlink rename };

allow setfiles_t kernel_t:system ichsid;

allow setfiles_t fs_t:filesystem getattr;
allow setfiles_t fs_type:dir { read getattr lock search ioctl };

allow setfiles_t etc_runtime_t:file read;
allow setfiles_t etc_t:file read;
allow setfiles_t proc_t:file { getattr read };

# for config files in a home directory
allow setfiles_t home_type:file { read getattr lock ioctl };
#DESC SE Linux User Manager (seuser)
#DEPENDS checkpolicy.te load_policy.te
#
# Authors:   don.patterson@tresys.com mayerf@tresys.com
# Additions: wsalamon@tislabs.com, dac@tresys.com

#

#################################
#
# Rules for the seuser_t domain.
#
# seuser_t is the domain of the seuser application when it is executed.
# seuser_conf_t is the type of the seuser configuration file.
# seuser_exec_t is the type of the seuser executable.
# seuser_tmp_t is the type of the temporary file(s) created by seuser.
# 
##############################################
# Define types, and typical rules including
# access to execute and transition
##############################################

# Defined seuser types
type seuser_t, domain ;
type seuser_conf_t, file_type, sysadmfile ;
type seuser_exec_t, file_type, sysadmfile, exec_type ;
type seuser_tmp_t, file_type, sysadmfile, tmpfile ;

# Authorize roles
role sysadm_r types seuser_t ;

# Allow sysadm_t to run with privilege

#line 6430

#line 6430

#line 6430
#
#line 6430
# Allow the process to transition to the new domain.
#line 6430
#
#line 6430
allow sysadm_t seuser_t:process transition;
#line 6430

#line 6430
#
#line 6430
# Allow the process to execute the program.
#line 6430
# 
#line 6430
allow sysadm_t seuser_exec_t:file { getattr execute };
#line 6430

#line 6430
#
#line 6430
# Allow the process to reap the new domain.
#line 6430
#
#line 6430
allow seuser_t sysadm_t:process sigchld;
#line 6430

#line 6430
#
#line 6430
# Allow the new domain to inherit and use file 
#line 6430
# descriptions from the creating process and vice versa.
#line 6430
#
#line 6430
allow seuser_t sysadm_t:fd use;
#line 6430
allow sysadm_t seuser_t:fd use;
#line 6430

#line 6430
#
#line 6430
# Allow the new domain to write back to the old domain via a pipe.
#line 6430
#
#line 6430
allow seuser_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 6430

#line 6430
#
#line 6430
# Allow the new domain to read and execute the program.
#line 6430
#
#line 6430
allow seuser_t seuser_exec_t:file { read getattr lock execute ioctl };
#line 6430

#line 6430
#
#line 6430
# Allow the new domain to be entered via the program.
#line 6430
#
#line 6430
allow seuser_t seuser_exec_t:file entrypoint;
#line 6430

#line 6430
type_transition sysadm_t seuser_exec_t:process seuser_t;
#line 6430


# Permission to create files in /tmp with seuser_tmp_t derived type rather than 
# the tmp_t type

#line 6434

#line 6434

#line 6434

#line 6434
#
#line 6434
# Allow the process to modify the directory.
#line 6434
#
#line 6434
allow seuser_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6434

#line 6434
#
#line 6434
# Allow the process to create the file.
#line 6434
#
#line 6434

#line 6434
allow seuser_t seuser_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6434
allow seuser_t seuser_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6434

#line 6434

#line 6434

#line 6434
type_transition seuser_t tmp_t:dir seuser_tmp_t;
#line 6434
type_transition seuser_t tmp_t:{ file lnk_file sock_file fifo_file } seuser_tmp_t;
#line 6434

#line 6434

#line 6434


# Grant the new domain permissions to many common operations
# FIX: Should be more resticted than this.

#line 6438

#line 6438
# Grant the permissions common to the test domains.
#line 6438

#line 6438
# Grant permissions within the domain.
#line 6438

#line 6438
# Access other processes in the same domain.
#line 6438
allow seuser_t self:process *;
#line 6438

#line 6438
# Access /proc/PID files for processes in the same domain.
#line 6438
allow seuser_t self:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6438

#line 6438
# Access file descriptions, pipes, and sockets
#line 6438
# created by processes in the same domain.
#line 6438
allow seuser_t self:fd *;
#line 6438
allow seuser_t self:fifo_file { ioctl read getattr lock write append };
#line 6438
allow seuser_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6438
allow seuser_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6438

#line 6438
# Allow the domain to communicate with other processes in the same domain.
#line 6438
allow seuser_t self:unix_dgram_socket sendto;
#line 6438
allow seuser_t self:unix_stream_socket connectto;
#line 6438

#line 6438
# Access System V IPC objects created by processes in the same domain.
#line 6438
allow seuser_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 6438
allow seuser_t self:msg  { send receive };
#line 6438
allow seuser_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 6438
allow seuser_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 6438

#line 6438

#line 6438

#line 6438
# Grant read/search permissions to most of /proc.
#line 6438

#line 6438
# Read system information files in /proc.
#line 6438
allow seuser_t proc_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6438

#line 6438
# Stat /proc/kmsg and /proc/kcore.
#line 6438
allow seuser_t proc_kmsg_t:file { getattr };
#line 6438
allow seuser_t proc_kcore_t:file { getattr };
#line 6438

#line 6438
# Read system variables in /proc/sys.
#line 6438
allow seuser_t sysctl_modprobe_t:file { read getattr lock ioctl };
#line 6438
allow seuser_t sysctl_t:file { read getattr lock ioctl };
#line 6438
allow seuser_t sysctl_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t sysctl_fs_t:file { read getattr lock ioctl };
#line 6438
allow seuser_t sysctl_fs_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t sysctl_kernel_t:file { read getattr lock ioctl };
#line 6438
allow seuser_t sysctl_kernel_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t sysctl_net_t:file { read getattr lock ioctl };
#line 6438
allow seuser_t sysctl_net_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t sysctl_vm_t:file { read getattr lock ioctl };
#line 6438
allow seuser_t sysctl_vm_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t sysctl_dev_t:file { read getattr lock ioctl };
#line 6438
allow seuser_t sysctl_dev_t:dir { read getattr lock search ioctl };
#line 6438

#line 6438

#line 6438
# Grant read/search permissions to many system file types.
#line 6438

#line 6438

#line 6438
# Get attributes of file systems.
#line 6438
allow seuser_t fs_type:filesystem getattr;
#line 6438

#line 6438

#line 6438
# Read /.
#line 6438
allow seuser_t root_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6438

#line 6438
# Read /home.
#line 6438
allow seuser_t home_root_t:dir { read getattr lock search ioctl };
#line 6438

#line 6438
# Read /usr.
#line 6438
allow seuser_t usr_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6438

#line 6438
# Read bin and sbin directories.
#line 6438
allow seuser_t bin_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6438
allow seuser_t sbin_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6438

#line 6438

#line 6438
# Read directories and files with the readable_t type.
#line 6438
# This type is a general type for "world"-readable files.
#line 6438
allow seuser_t readable_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t readable_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6438

#line 6438
# Stat /...security and lost+found.
#line 6438
allow seuser_t file_labels_t:dir getattr;
#line 6438
allow seuser_t lost_found_t:dir getattr;
#line 6438

#line 6438
# Read the devpts root directory.  
#line 6438
allow seuser_t devpts_t:dir { read getattr lock search ioctl };
#line 6438

#line 6438

#line 6438
# Read the /tmp directory and any /tmp files with the base type.
#line 6438
# Temporary files created at runtime will typically use derived types.
#line 6438
allow seuser_t tmp_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t tmp_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438

#line 6438
# Read /var.
#line 6438
allow seuser_t var_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6438

#line 6438
# Read /var/catman.
#line 6438
allow seuser_t catman_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t catman_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438

#line 6438
# Read /var/lib.
#line 6438
allow seuser_t var_lib_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t var_lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6438
allow seuser_t var_lib_nfs_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t var_lib_nfs_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6438

#line 6438

#line 6438
allow seuser_t tetex_data_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t tetex_data_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438

#line 6438

#line 6438
# Read /var/yp.
#line 6438
allow seuser_t var_yp_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t var_yp_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6438

#line 6438
# Read /var/spool.
#line 6438
allow seuser_t var_spool_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t var_spool_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6438

#line 6438
# Read /var/run, /var/lock, /var/log.
#line 6438
allow seuser_t var_run_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t var_run_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438
allow seuser_t var_log_t:dir { read getattr lock search ioctl };
#line 6438
#allow seuser_t var_log_t:{ file lnk_file } r_file_perms;
#line 6438
allow seuser_t var_log_sa_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t var_log_sa_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438
allow seuser_t var_log_ksyms_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438

#line 6438
allow seuser_t var_lock_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t var_lock_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438

#line 6438
# Read /var/run/utmp and /var/log/wtmp.
#line 6438
allow seuser_t initrc_var_run_t:file { read getattr lock ioctl };
#line 6438
allow seuser_t wtmp_t:file { read getattr lock ioctl };
#line 6438

#line 6438
# Read /boot, /boot/System.map*, and /vmlinuz*
#line 6438
allow seuser_t boot_t:dir { search getattr };
#line 6438
allow seuser_t boot_t:file getattr;
#line 6438
allow seuser_t system_map_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438

#line 6438
allow seuser_t boot_t:lnk_file read;
#line 6438

#line 6438
# Read /etc.
#line 6438
allow seuser_t etc_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6438
allow seuser_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438
allow seuser_t etc_aliases_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438
allow seuser_t etc_mail_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t etc_mail_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438
allow seuser_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438
allow seuser_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6438

#line 6438
# Read /lib.
#line 6438
allow seuser_t lib_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t lib_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6438

#line 6438
# Read the linker, shared library, and executable types.
#line 6438
allow seuser_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438
allow seuser_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438
allow seuser_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 6438

#line 6438
# Read man directories and files.
#line 6438
allow seuser_t man_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t man_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6438

#line 6438
# Read /usr/src.
#line 6438
allow seuser_t src_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t src_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6438

#line 6438
# Read module-related files.
#line 6438
allow seuser_t modules_object_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t modules_object_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438
allow seuser_t modules_dep_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438
allow seuser_t modules_conf_t:{ file lnk_file} { read getattr lock ioctl };
#line 6438

#line 6438
# Read /dev directories and any symbolic links.
#line 6438
allow seuser_t device_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t device_t:lnk_file { read getattr lock ioctl };
#line 6438

#line 6438
# Read /dev/random and /dev/zero.
#line 6438
allow seuser_t random_device_t:chr_file { read getattr lock ioctl };
#line 6438
allow seuser_t zero_device_t:chr_file { read getattr lock ioctl };
#line 6438

#line 6438
# Read the root directory of a tmpfs filesytem and any symbolic links.
#line 6438
allow seuser_t tmpfs_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t tmpfs_t:lnk_file { read getattr lock ioctl };
#line 6438

#line 6438
# Read any symbolic links on a devfs file system.
#line 6438
allow seuser_t device_t:lnk_file { read getattr lock ioctl };
#line 6438

#line 6438
# Read the root directory of a usbdevfs filesystem, and
#line 6438
# the devices and drivers files.  Permit stating of the
#line 6438
# device nodes, but nothing else.
#line 6438
allow seuser_t usbdevfs_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t usbdevfs_t:{ file lnk_file } { read getattr lock ioctl };
#line 6438
allow seuser_t usbdevfs_device_t:file getattr;
#line 6438

#line 6438

#line 6438
# Grant write permissions to a small set of system file types.
#line 6438
# No permission to create files is granted here.  Use allow rules to grant 
#line 6438
# create permissions to a type or use file_type_auto_trans rules to set up
#line 6438
# new types for files.
#line 6438

#line 6438

#line 6438
# Read and write /dev/tty and /dev/null.
#line 6438
allow seuser_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 6438
allow seuser_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 6438

#line 6438
# Do not audit write denials to /etc/ld.so.cache.
#line 6438
dontaudit seuser_t ld_so_cache_t:file write;
#line 6438

#line 6438

#line 6438
# Execute from the system shared libraries.
#line 6438
# No permission to execute anything else is granted here.
#line 6438
# Use can_exec or can_exec_any to grant the ability to execute within a domain.
#line 6438
# Use domain_auto_trans for executing and changing domains.
#line 6438

#line 6438
allow seuser_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t ld_so_t:file { read getattr lock execute ioctl };
#line 6438
allow seuser_t ld_so_t:file execute_no_trans;
#line 6438
allow seuser_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6438
allow seuser_t shlib_t:file { read getattr lock execute ioctl };
#line 6438
allow seuser_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6438
allow seuser_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6438
allow seuser_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6438

#line 6438

#line 6438
# read localization information
#line 6438
allow seuser_t locale_t:dir { read getattr lock search ioctl };
#line 6438
allow seuser_t locale_t:{file lnk_file} { read getattr lock ioctl };
#line 6438

#line 6438
# Obtain the context of any SID, the SID for any context, 
#line 6438
# and the list of active SIDs.
#line 6438
allow seuser_t security_t:security { sid_to_context context_to_sid get_sids };
#line 6438

#line 6438

#line 6438

#line 6438
# Grant permissions needed to create TCP and UDP sockets and 
#line 6438
# to access the network.
#line 6438

#line 6438
#
#line 6438
# Allow the domain to create and use UDP and TCP sockets.
#line 6438
# Other kinds of sockets must be separately authorized for use.
#line 6438
allow seuser_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6438
allow seuser_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6438

#line 6438
#
#line 6438
# Allow the domain to send UDP packets.
#line 6438
# Since the destination sockets type is unknown, the generic
#line 6438
# any_socket_t type is used as a placeholder.
#line 6438
#
#line 6438
allow seuser_t any_socket_t:udp_socket sendto;
#line 6438

#line 6438
#
#line 6438
# Allow the domain to send using any network interface.
#line 6438
# netif_type is a type attribute for all network interface types.
#line 6438
#
#line 6438
allow seuser_t netif_type:netif { tcp_send udp_send rawip_send };
#line 6438

#line 6438
#
#line 6438
# Allow packets sent by the domain to be received on any network interface.
#line 6438
#
#line 6438
allow seuser_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 6438

#line 6438
#
#line 6438
# Allow the domain to receive packets from any network interface.
#line 6438
# netmsg_type is a type attribute for all default message types.
#line 6438
#
#line 6438
allow seuser_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 6438

#line 6438
#
#line 6438
# Allow the domain to initiate or accept TCP connections 
#line 6438
# on any network interface.
#line 6438
#
#line 6438
allow seuser_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 6438

#line 6438
#
#line 6438
# Receive resets from the TCP reset socket.
#line 6438
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 6438
#
#line 6438
allow seuser_t tcp_socket_t:tcp_socket recvfrom;
#line 6438

#line 6438
dontaudit seuser_t tcp_socket_t:tcp_socket connectto;
#line 6438

#line 6438
#
#line 6438
# Allow the domain to send to any node.
#line 6438
# node_type is a type attribute for all node types.
#line 6438
#
#line 6438
allow seuser_t node_type:node { tcp_send udp_send rawip_send };
#line 6438

#line 6438
#
#line 6438
# Allow packets sent by the domain to be received from any node.
#line 6438
#
#line 6438
allow seuser_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 6438

#line 6438
#
#line 6438
# Allow the domain to send NFS client requests via the socket
#line 6438
# created by mount.
#line 6438
#
#line 6438
allow seuser_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6438

#line 6438
#
#line 6438
# Bind to the default port type.
#line 6438
# Other port types must be separately authorized.
#line 6438
#
#line 6438
allow seuser_t port_t:udp_socket name_bind;
#line 6438
allow seuser_t port_t:tcp_socket name_bind;
#line 6438

#line 6438


# Use capabilities to self
allow seuser_t self:capability { dac_override setuid setgid } ;

# Read permissions for seuser.conf file
allow seuser_t seuser_conf_t:file { read getattr lock ioctl } ;


###################################################################
# Policy section: Define the ability to change and load policies
###################################################################

# seuser_t domain needs to transition to the checkpolicy and loadpolicy 
# domains in order to install and load new policies.

#line 6453

#line 6453

#line 6453
#
#line 6453
# Allow the process to transition to the new domain.
#line 6453
#
#line 6453
allow seuser_t checkpolicy_t:process transition;
#line 6453

#line 6453
#
#line 6453
# Allow the process to execute the program.
#line 6453
# 
#line 6453
allow seuser_t checkpolicy_exec_t:file { getattr execute };
#line 6453

#line 6453
#
#line 6453
# Allow the process to reap the new domain.
#line 6453
#
#line 6453
allow checkpolicy_t seuser_t:process sigchld;
#line 6453

#line 6453
#
#line 6453
# Allow the new domain to inherit and use file 
#line 6453
# descriptions from the creating process and vice versa.
#line 6453
#
#line 6453
allow checkpolicy_t seuser_t:fd use;
#line 6453
allow seuser_t checkpolicy_t:fd use;
#line 6453

#line 6453
#
#line 6453
# Allow the new domain to write back to the old domain via a pipe.
#line 6453
#
#line 6453
allow checkpolicy_t seuser_t:fifo_file { ioctl read getattr lock write append };
#line 6453

#line 6453
#
#line 6453
# Allow the new domain to read and execute the program.
#line 6453
#
#line 6453
allow checkpolicy_t checkpolicy_exec_t:file { read getattr lock execute ioctl };
#line 6453

#line 6453
#
#line 6453
# Allow the new domain to be entered via the program.
#line 6453
#
#line 6453
allow checkpolicy_t checkpolicy_exec_t:file entrypoint;
#line 6453

#line 6453
type_transition seuser_t checkpolicy_exec_t:process checkpolicy_t;
#line 6453


#line 6454

#line 6454

#line 6454
#
#line 6454
# Allow the process to transition to the new domain.
#line 6454
#
#line 6454
allow seuser_t load_policy_t:process transition;
#line 6454

#line 6454
#
#line 6454
# Allow the process to execute the program.
#line 6454
# 
#line 6454
allow seuser_t load_policy_exec_t:file { getattr execute };
#line 6454

#line 6454
#
#line 6454
# Allow the process to reap the new domain.
#line 6454
#
#line 6454
allow load_policy_t seuser_t:process sigchld;
#line 6454

#line 6454
#
#line 6454
# Allow the new domain to inherit and use file 
#line 6454
# descriptions from the creating process and vice versa.
#line 6454
#
#line 6454
allow load_policy_t seuser_t:fd use;
#line 6454
allow seuser_t load_policy_t:fd use;
#line 6454

#line 6454
#
#line 6454
# Allow the new domain to write back to the old domain via a pipe.
#line 6454
#
#line 6454
allow load_policy_t seuser_t:fifo_file { ioctl read getattr lock write append };
#line 6454

#line 6454
#
#line 6454
# Allow the new domain to read and execute the program.
#line 6454
#
#line 6454
allow load_policy_t load_policy_exec_t:file { read getattr lock execute ioctl };
#line 6454

#line 6454
#
#line 6454
# Allow the new domain to be entered via the program.
#line 6454
#
#line 6454
allow load_policy_t load_policy_exec_t:file entrypoint;
#line 6454

#line 6454
type_transition seuser_t load_policy_exec_t:process load_policy_t;
#line 6454


# allow load_policy and checkpolicy domains access to seuser_tmp_t
# files in order for their stdout/stderr able to be put into
# seuser's tmp files.
#
# Since both these domains carefully try to limit where the
# assoicated program can read from, we won't use the standard
# rw_file_perm macro, but instead only grant the minimum needed
# to redirect output, write and getattr.
allow checkpolicy_t seuser_tmp_t:file { getattr write } ;
allow load_policy_t seuser_tmp_t:file { getattr write } ;

# FIX:  Temporarily allow seuser_t permissions for executing programs with a 
# bint_t type without changing domains. We have to give seuser_t the following 
# access because we use the policy make process to build new plicy.conf files. 
# At some point, a new policy management infrastructure should remove the ability 
# to modify policy source files with arbitrary progams
#

#line 6473
allow seuser_t bin_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 6473


#line 6474
allow seuser_t shell_exec_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 6474



# Read/write permission to the login context files in /etc/security
allow seuser_t login_contexts:file { create ioctl read getattr lock write setattr append link unlink rename } ;

# Read/write permission to the policy source and its' directory
allow seuser_t policy_src_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir } ;
allow seuser_t policy_src_t:file { create ioctl read getattr lock write setattr append link unlink rename } ;

# Allow search and stat for policy_config_t
allow seuser_t policy_config_t:dir { search getattr } ;
allow seuser_t policy_config_t:file { getattr };


#line 6502

#line 6505


# seuser_t domain needs execute access to the library files so that it can run.

#line 6508
allow seuser_t lib_t:file { { read getattr lock execute ioctl } execute_no_trans };
#line 6508


# Access ttys
allow seuser_t sysadm_tty_device_t:chr_file { ioctl read getattr lock write append } ;
allow seuser_t sysadm_devpts_t:chr_file { ioctl read getattr lock write append } ;

#DESC SSH - SSH daemon
#
# Authors:  Anthony Colatrella (NSA) <amcolat@epoch.ncsc.mil>
# Modified by: Russell Coker <russell@coker.com.au>
#

type ssh_port_t, port_type;

#line 6608

#################################
#
# Rules for the sshd_t domain, et al.
#
# sshd_t is the domain for the sshd program.
# sshd_login_t is the domain for sshds login spawn
# sshd_exec_t is the type of the sshd executable.
# sshd_key_t is the type of the ssh private key files
#

#line 6618
type sshd_t, domain, privuser, privrole, privlog, privowner, privfd;
#line 6618
role system_r types sshd_t;
#line 6618

#line 6618
# Access other processes in the same domain.
#line 6618
allow sshd_t self:process *;
#line 6618

#line 6618
# Access /proc/PID files for processes in the same domain.
#line 6618
allow sshd_t self:dir { read getattr lock search ioctl };
#line 6618
allow sshd_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6618

#line 6618
# Access file descriptions, pipes, and sockets
#line 6618
# created by processes in the same domain.
#line 6618
allow sshd_t self:fd *;
#line 6618
allow sshd_t self:fifo_file { ioctl read getattr lock write append };
#line 6618
allow sshd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6618
allow sshd_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6618

#line 6618
# Allow the domain to communicate with other processes in the same domain.
#line 6618
allow sshd_t self:unix_dgram_socket sendto;
#line 6618
allow sshd_t self:unix_stream_socket connectto;
#line 6618

#line 6618
# Access System V IPC objects created by processes in the same domain.
#line 6618
allow sshd_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 6618
allow sshd_t self:msg  { send receive };
#line 6618
allow sshd_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 6618
allow sshd_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 6618

#line 6618

#line 6618

#line 6618
allow sshd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6618
allow sshd_t ld_so_t:file { read getattr lock execute ioctl };
#line 6618
allow sshd_t ld_so_t:file execute_no_trans;
#line 6618
allow sshd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6618
allow sshd_t shlib_t:file { read getattr lock execute ioctl };
#line 6618
allow sshd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6618
allow sshd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6618
allow sshd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6618

#line 6618

#line 6618
# Read system information files in /proc.
#line 6618
allow sshd_t proc_t:dir { read getattr lock search ioctl };
#line 6618
allow sshd_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6618

#line 6618
# Get attributes of file systems.
#line 6618
allow sshd_t fs_type:filesystem getattr;
#line 6618

#line 6618

#line 6618
# Read /.
#line 6618
allow sshd_t root_t:dir { read getattr lock search ioctl };
#line 6618
allow sshd_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6618

#line 6618
# Read /home.
#line 6618
allow sshd_t home_root_t:dir { read getattr lock search ioctl };
#line 6618

#line 6618
# Read /usr.
#line 6618
allow sshd_t usr_t:dir { read getattr lock search ioctl };
#line 6618
allow sshd_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6618

#line 6618
# Read bin and sbin directories.
#line 6618
allow sshd_t bin_t:dir { read getattr lock search ioctl };
#line 6618
allow sshd_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6618
allow sshd_t sbin_t:dir { read getattr lock search ioctl };
#line 6618
allow sshd_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6618

#line 6618

#line 6618
# Read the devpts root directory.
#line 6618
allow sshd_t devpts_t:dir { read getattr lock search ioctl };
#line 6618

#line 6618
# Read /var.
#line 6618
allow sshd_t var_t:dir { read getattr lock search ioctl };
#line 6618
allow sshd_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6618

#line 6618
# Read /var/log.
#line 6618
allow sshd_t var_log_t:dir { read getattr lock search ioctl };
#line 6618
allow sshd_t var_log_t:{ file lnk_file } { read getattr lock ioctl };
#line 6618

#line 6618
# Read /etc.
#line 6618
allow sshd_t etc_t:dir { read getattr lock search ioctl };
#line 6618
allow sshd_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6618
allow sshd_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 6618
allow sshd_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 6618

#line 6618
# Read the linker, shared library, and executable types.
#line 6618
allow sshd_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 6618
allow sshd_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 6618
allow sshd_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 6618

#line 6618
# Read /dev directories and any symbolic links.
#line 6618
allow sshd_t device_t:dir { read getattr lock search ioctl };
#line 6618
allow sshd_t device_t:lnk_file { read getattr lock ioctl };
#line 6618

#line 6618
# Read and write /dev/tty and /dev/null.
#line 6618
allow sshd_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 6618
allow sshd_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 6618

#line 6618
# Read /dev/random and /dev/zero.
#line 6618
allow sshd_t random_device_t:chr_file { read getattr lock ioctl };
#line 6618
#allow sshd_t zero_device_t:chr_file r_file_perms;
#line 6618

#line 6618
# Read PID files in /var/run.  pidfile is a type attribute for
#line 6618
# all types used for such files.
#line 6618
allow sshd_t pidfile:file { read getattr lock ioctl };
#line 6618

#line 6618

#line 6618
#allow sshd_t security_t:security { sid_to_context context_to_sid get_sids };
#line 6618
allow sshd_t security_t:security { sid_to_context context_to_sid };
#line 6618

#line 6618
#
#line 6618
# Allow the domain to create and use UDP and TCP sockets.
#line 6618
# Other kinds of sockets must be separately authorized for use.
#line 6618
allow sshd_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6618
allow sshd_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6618

#line 6618
#
#line 6618
# Allow the domain to send UDP packets.
#line 6618
# Since the destination sockets type is unknown, the generic
#line 6618
# any_socket_t type is used as a placeholder.
#line 6618
#
#line 6618
allow sshd_t any_socket_t:udp_socket sendto;
#line 6618

#line 6618
#
#line 6618
# Allow the domain to send using any network interface.
#line 6618
# netif_type is a type attribute for all network interface types.
#line 6618
#
#line 6618
allow sshd_t netif_type:netif { tcp_send udp_send rawip_send };
#line 6618

#line 6618
#
#line 6618
# Allow packets sent by the domain to be received on any network interface.
#line 6618
#
#line 6618
allow sshd_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 6618

#line 6618
#
#line 6618
# Allow the domain to receive packets from any network interface.
#line 6618
# netmsg_type is a type attribute for all default message types.
#line 6618
#
#line 6618
allow sshd_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 6618

#line 6618
#
#line 6618
# Allow the domain to initiate or accept TCP connections 
#line 6618
# on any network interface.
#line 6618
#
#line 6618
allow sshd_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 6618

#line 6618
#
#line 6618
# Receive resets from the TCP reset socket.
#line 6618
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 6618
#
#line 6618
allow sshd_t tcp_socket_t:tcp_socket recvfrom;
#line 6618

#line 6618
dontaudit sshd_t tcp_socket_t:tcp_socket connectto;
#line 6618

#line 6618
#
#line 6618
# Allow the domain to send to any node.
#line 6618
# node_type is a type attribute for all node types.
#line 6618
#
#line 6618
allow sshd_t node_type:node { tcp_send udp_send rawip_send };
#line 6618

#line 6618
#
#line 6618
# Allow packets sent by the domain to be received from any node.
#line 6618
#
#line 6618
allow sshd_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 6618

#line 6618
#
#line 6618
# Allow the domain to send NFS client requests via the socket
#line 6618
# created by mount.
#line 6618
#
#line 6618
allow sshd_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6618

#line 6618
#
#line 6618
# Bind to the default port type.
#line 6618
# Other port types must be separately authorized.
#line 6618
#
#line 6618
allow sshd_t port_t:udp_socket name_bind;
#line 6618
allow sshd_t port_t:tcp_socket name_bind;
#line 6618

#line 6618

#line 6618
allow sshd_t self:capability { chown dac_override fowner fsetid setgid setuid net_bind_service sys_tty_config };
#line 6618
allow sshd_t shadow_t:file { read getattr };
#line 6618
allow sshd_t { home_root_t user_home_dir_type sysadm_home_dir_t }:dir { search getattr };
#line 6618

#line 6618
# Run shells in user_t by default
#line 6618

#line 6618

#line 6618

#line 6618
#
#line 6618
# Allow the process to transition to the new domain.
#line 6618
#
#line 6618
allow sshd_t user_t:process transition;
#line 6618

#line 6618
#
#line 6618
# Allow the process to execute the program.
#line 6618
# 
#line 6618
allow sshd_t shell_exec_t:file { getattr execute };
#line 6618

#line 6618
#
#line 6618
# Allow the process to reap the new domain.
#line 6618
#
#line 6618
allow user_t sshd_t:process sigchld;
#line 6618

#line 6618
#
#line 6618
# Allow the new domain to inherit and use file 
#line 6618
# descriptions from the creating process and vice versa.
#line 6618
#
#line 6618
allow user_t sshd_t:fd use;
#line 6618
allow sshd_t user_t:fd use;
#line 6618

#line 6618
#
#line 6618
# Allow the new domain to write back to the old domain via a pipe.
#line 6618
#
#line 6618
allow user_t sshd_t:fifo_file { ioctl read getattr lock write append };
#line 6618

#line 6618
#
#line 6618
# Allow the new domain to read and execute the program.
#line 6618
#
#line 6618
allow user_t shell_exec_t:file { read getattr lock execute ioctl };
#line 6618

#line 6618
#
#line 6618
# Allow the new domain to be entered via the program.
#line 6618
#
#line 6618
allow user_t shell_exec_t:file entrypoint;
#line 6618

#line 6618
type_transition sshd_t shell_exec_t:process user_t;
#line 6618

#line 6618

#line 6618

#line 6618
#
#line 6618
# Allow the process to transition to the new domain.
#line 6618
#
#line 6618
allow sshd_t unpriv_userdomain:process transition;
#line 6618

#line 6618
#
#line 6618
# Allow the process to execute the program.
#line 6618
# 
#line 6618
allow sshd_t shell_exec_t:file { getattr execute };
#line 6618

#line 6618
#
#line 6618
# Allow the process to reap the new domain.
#line 6618
#
#line 6618
allow unpriv_userdomain sshd_t:process sigchld;
#line 6618

#line 6618
#
#line 6618
# Allow the new domain to inherit and use file 
#line 6618
# descriptions from the creating process and vice versa.
#line 6618
#
#line 6618
allow unpriv_userdomain sshd_t:fd use;
#line 6618
allow sshd_t unpriv_userdomain:fd use;
#line 6618

#line 6618
#
#line 6618
# Allow the new domain to write back to the old domain via a pipe.
#line 6618
#
#line 6618
allow unpriv_userdomain sshd_t:fifo_file { ioctl read getattr lock write append };
#line 6618

#line 6618
#
#line 6618
# Allow the new domain to read and execute the program.
#line 6618
#
#line 6618
allow unpriv_userdomain shell_exec_t:file { read getattr lock execute ioctl };
#line 6618

#line 6618
#
#line 6618
# Allow the new domain to be entered via the program.
#line 6618
#
#line 6618
allow unpriv_userdomain shell_exec_t:file entrypoint;
#line 6618

#line 6618

#line 6618
# Allow shells to be run in sysadm_t as well.
#line 6618
# Commented out.  Use newrole rather than directly entering sysadm_t.
#line 6618
#domain_trans(sshd_t, shell_exec_t, sysadm_t)
#line 6618

#line 6618
# Update utmp.
#line 6618
allow sshd_t initrc_var_run_t:file { ioctl read getattr lock write append };
#line 6618

#line 6618
# Update wtmp.
#line 6618
allow sshd_t wtmp_t:file { ioctl read getattr lock write append };
#line 6618

#line 6618
# Obtain the SID to use for relabeling ptys
#line 6618
allow sshd_t security_t:security change_sid;
#line 6618

#line 6618
# Allow read access to login context
#line 6618
allow sshd_t default_context_t:file { read getattr lock ioctl };
#line 6618

#line 6618
# Determine the set of legal user SIDs that can be reached.
#line 6618
allow sshd_t security_t:security get_user_sids;
#line 6618

#line 6618

allow sshd_t initrc_devpts_t:chr_file { ioctl read getattr lock write append };
allow sshd_t ssh_port_t:tcp_socket name_bind;

#line 6621
type sshd_login_t, domain, privuser, privrole, privlog, privowner, privfd;
#line 6621
role system_r types sshd_login_t;
#line 6621

#line 6621
# Access other processes in the same domain.
#line 6621
allow sshd_login_t self:process *;
#line 6621

#line 6621
# Access /proc/PID files for processes in the same domain.
#line 6621
allow sshd_login_t self:dir { read getattr lock search ioctl };
#line 6621
allow sshd_login_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6621

#line 6621
# Access file descriptions, pipes, and sockets
#line 6621
# created by processes in the same domain.
#line 6621
allow sshd_login_t self:fd *;
#line 6621
allow sshd_login_t self:fifo_file { ioctl read getattr lock write append };
#line 6621
allow sshd_login_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6621
allow sshd_login_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6621

#line 6621
# Allow the domain to communicate with other processes in the same domain.
#line 6621
allow sshd_login_t self:unix_dgram_socket sendto;
#line 6621
allow sshd_login_t self:unix_stream_socket connectto;
#line 6621

#line 6621
# Access System V IPC objects created by processes in the same domain.
#line 6621
allow sshd_login_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 6621
allow sshd_login_t self:msg  { send receive };
#line 6621
allow sshd_login_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 6621
allow sshd_login_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 6621

#line 6621

#line 6621

#line 6621
allow sshd_login_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6621
allow sshd_login_t ld_so_t:file { read getattr lock execute ioctl };
#line 6621
allow sshd_login_t ld_so_t:file execute_no_trans;
#line 6621
allow sshd_login_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6621
allow sshd_login_t shlib_t:file { read getattr lock execute ioctl };
#line 6621
allow sshd_login_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6621
allow sshd_login_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6621
allow sshd_login_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6621

#line 6621

#line 6621
# Read system information files in /proc.
#line 6621
allow sshd_login_t proc_t:dir { read getattr lock search ioctl };
#line 6621
allow sshd_login_t proc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6621

#line 6621
# Get attributes of file systems.
#line 6621
allow sshd_login_t fs_type:filesystem getattr;
#line 6621

#line 6621

#line 6621
# Read /.
#line 6621
allow sshd_login_t root_t:dir { read getattr lock search ioctl };
#line 6621
allow sshd_login_t root_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6621

#line 6621
# Read /home.
#line 6621
allow sshd_login_t home_root_t:dir { read getattr lock search ioctl };
#line 6621

#line 6621
# Read /usr.
#line 6621
allow sshd_login_t usr_t:dir { read getattr lock search ioctl };
#line 6621
allow sshd_login_t usr_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6621

#line 6621
# Read bin and sbin directories.
#line 6621
allow sshd_login_t bin_t:dir { read getattr lock search ioctl };
#line 6621
allow sshd_login_t bin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6621
allow sshd_login_t sbin_t:dir { read getattr lock search ioctl };
#line 6621
allow sshd_login_t sbin_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6621

#line 6621

#line 6621
# Read the devpts root directory.
#line 6621
allow sshd_login_t devpts_t:dir { read getattr lock search ioctl };
#line 6621

#line 6621
# Read /var.
#line 6621
allow sshd_login_t var_t:dir { read getattr lock search ioctl };
#line 6621
allow sshd_login_t var_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6621

#line 6621
# Read /var/log.
#line 6621
allow sshd_login_t var_log_t:dir { read getattr lock search ioctl };
#line 6621
allow sshd_login_t var_log_t:{ file lnk_file } { read getattr lock ioctl };
#line 6621

#line 6621
# Read /etc.
#line 6621
allow sshd_login_t etc_t:dir { read getattr lock search ioctl };
#line 6621
allow sshd_login_t etc_t:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6621
allow sshd_login_t etc_runtime_t:{ file lnk_file } { read getattr lock ioctl };
#line 6621
allow sshd_login_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };
#line 6621

#line 6621
# Read the linker, shared library, and executable types.
#line 6621
allow sshd_login_t ld_so_t:{ file lnk_file } { read getattr lock ioctl };
#line 6621
allow sshd_login_t shlib_t:{ file lnk_file } { read getattr lock ioctl };
#line 6621
allow sshd_login_t exec_type:{ file lnk_file } { read getattr lock ioctl };
#line 6621

#line 6621
# Read /dev directories and any symbolic links.
#line 6621
allow sshd_login_t device_t:dir { read getattr lock search ioctl };
#line 6621
allow sshd_login_t device_t:lnk_file { read getattr lock ioctl };
#line 6621

#line 6621
# Read and write /dev/tty and /dev/null.
#line 6621
allow sshd_login_t devtty_t:chr_file { ioctl read getattr lock write append };
#line 6621
allow sshd_login_t { null_device_t zero_device_t }:chr_file { ioctl read getattr lock write append };
#line 6621

#line 6621
# Read /dev/random and /dev/zero.
#line 6621
allow sshd_login_t random_device_t:chr_file { read getattr lock ioctl };
#line 6621
#allow sshd_login_t zero_device_t:chr_file r_file_perms;
#line 6621

#line 6621
# Read PID files in /var/run.  pidfile is a type attribute for
#line 6621
# all types used for such files.
#line 6621
allow sshd_login_t pidfile:file { read getattr lock ioctl };
#line 6621

#line 6621

#line 6621
#allow sshd_login_t security_t:security { sid_to_context context_to_sid get_sids };
#line 6621
allow sshd_login_t security_t:security { sid_to_context context_to_sid };
#line 6621

#line 6621
#
#line 6621
# Allow the domain to create and use UDP and TCP sockets.
#line 6621
# Other kinds of sockets must be separately authorized for use.
#line 6621
allow sshd_login_t self:udp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6621
allow sshd_login_t self:tcp_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6621

#line 6621
#
#line 6621
# Allow the domain to send UDP packets.
#line 6621
# Since the destination sockets type is unknown, the generic
#line 6621
# any_socket_t type is used as a placeholder.
#line 6621
#
#line 6621
allow sshd_login_t any_socket_t:udp_socket sendto;
#line 6621

#line 6621
#
#line 6621
# Allow the domain to send using any network interface.
#line 6621
# netif_type is a type attribute for all network interface types.
#line 6621
#
#line 6621
allow sshd_login_t netif_type:netif { tcp_send udp_send rawip_send };
#line 6621

#line 6621
#
#line 6621
# Allow packets sent by the domain to be received on any network interface.
#line 6621
#
#line 6621
allow sshd_login_t netif_type:netif { tcp_recv udp_recv rawip_recv };
#line 6621

#line 6621
#
#line 6621
# Allow the domain to receive packets from any network interface.
#line 6621
# netmsg_type is a type attribute for all default message types.
#line 6621
#
#line 6621
allow sshd_login_t netmsg_type:{ udp_socket tcp_socket rawip_socket } recvfrom;
#line 6621

#line 6621
#
#line 6621
# Allow the domain to initiate or accept TCP connections 
#line 6621
# on any network interface.
#line 6621
#
#line 6621
allow sshd_login_t netmsg_type:tcp_socket { connectto acceptfrom };
#line 6621

#line 6621
#
#line 6621
# Receive resets from the TCP reset socket.
#line 6621
# The TCP reset socket is labeled with the tcp_socket_t type.
#line 6621
#
#line 6621
allow sshd_login_t tcp_socket_t:tcp_socket recvfrom;
#line 6621

#line 6621
dontaudit sshd_login_t tcp_socket_t:tcp_socket connectto;
#line 6621

#line 6621
#
#line 6621
# Allow the domain to send to any node.
#line 6621
# node_type is a type attribute for all node types.
#line 6621
#
#line 6621
allow sshd_login_t node_type:node { tcp_send udp_send rawip_send };
#line 6621

#line 6621
#
#line 6621
# Allow packets sent by the domain to be received from any node.
#line 6621
#
#line 6621
allow sshd_login_t node_type:node { tcp_recv udp_recv rawip_recv };
#line 6621

#line 6621
#
#line 6621
# Allow the domain to send NFS client requests via the socket
#line 6621
# created by mount.
#line 6621
#
#line 6621
allow sshd_login_t mount_t:udp_socket { ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6621

#line 6621
#
#line 6621
# Bind to the default port type.
#line 6621
# Other port types must be separately authorized.
#line 6621
#
#line 6621
allow sshd_login_t port_t:udp_socket name_bind;
#line 6621
allow sshd_login_t port_t:tcp_socket name_bind;
#line 6621

#line 6621

#line 6621
allow sshd_login_t self:capability { chown dac_override fowner fsetid setgid setuid net_bind_service sys_tty_config };
#line 6621
allow sshd_login_t shadow_t:file { read getattr };
#line 6621
allow sshd_login_t { home_root_t user_home_dir_type sysadm_home_dir_t }:dir { search getattr };
#line 6621

#line 6621
# Run shells in user_t by default
#line 6621

#line 6621

#line 6621

#line 6621
#
#line 6621
# Allow the process to transition to the new domain.
#line 6621
#
#line 6621
allow sshd_login_t user_t:process transition;
#line 6621

#line 6621
#
#line 6621
# Allow the process to execute the program.
#line 6621
# 
#line 6621
allow sshd_login_t shell_exec_t:file { getattr execute };
#line 6621

#line 6621
#
#line 6621
# Allow the process to reap the new domain.
#line 6621
#
#line 6621
allow user_t sshd_login_t:process sigchld;
#line 6621

#line 6621
#
#line 6621
# Allow the new domain to inherit and use file 
#line 6621
# descriptions from the creating process and vice versa.
#line 6621
#
#line 6621
allow user_t sshd_login_t:fd use;
#line 6621
allow sshd_login_t user_t:fd use;
#line 6621

#line 6621
#
#line 6621
# Allow the new domain to write back to the old domain via a pipe.
#line 6621
#
#line 6621
allow user_t sshd_login_t:fifo_file { ioctl read getattr lock write append };
#line 6621

#line 6621
#
#line 6621
# Allow the new domain to read and execute the program.
#line 6621
#
#line 6621
allow user_t shell_exec_t:file { read getattr lock execute ioctl };
#line 6621

#line 6621
#
#line 6621
# Allow the new domain to be entered via the program.
#line 6621
#
#line 6621
allow user_t shell_exec_t:file entrypoint;
#line 6621

#line 6621
type_transition sshd_login_t shell_exec_t:process user_t;
#line 6621

#line 6621

#line 6621

#line 6621
#
#line 6621
# Allow the process to transition to the new domain.
#line 6621
#
#line 6621
allow sshd_login_t unpriv_userdomain:process transition;
#line 6621

#line 6621
#
#line 6621
# Allow the process to execute the program.
#line 6621
# 
#line 6621
allow sshd_login_t shell_exec_t:file { getattr execute };
#line 6621

#line 6621
#
#line 6621
# Allow the process to reap the new domain.
#line 6621
#
#line 6621
allow unpriv_userdomain sshd_login_t:process sigchld;
#line 6621

#line 6621
#
#line 6621
# Allow the new domain to inherit and use file 
#line 6621
# descriptions from the creating process and vice versa.
#line 6621
#
#line 6621
allow unpriv_userdomain sshd_login_t:fd use;
#line 6621
allow sshd_login_t unpriv_userdomain:fd use;
#line 6621

#line 6621
#
#line 6621
# Allow the new domain to write back to the old domain via a pipe.
#line 6621
#
#line 6621
allow unpriv_userdomain sshd_login_t:fifo_file { ioctl read getattr lock write append };
#line 6621

#line 6621
#
#line 6621
# Allow the new domain to read and execute the program.
#line 6621
#
#line 6621
allow unpriv_userdomain shell_exec_t:file { read getattr lock execute ioctl };
#line 6621

#line 6621
#
#line 6621
# Allow the new domain to be entered via the program.
#line 6621
#
#line 6621
allow unpriv_userdomain shell_exec_t:file entrypoint;
#line 6621

#line 6621

#line 6621
# Allow shells to be run in sysadm_t as well.
#line 6621
# Commented out.  Use newrole rather than directly entering sysadm_t.
#line 6621
#domain_trans(sshd_login_t, shell_exec_t, sysadm_t)
#line 6621

#line 6621
# Update utmp.
#line 6621
allow sshd_login_t initrc_var_run_t:file { ioctl read getattr lock write append };
#line 6621

#line 6621
# Update wtmp.
#line 6621
allow sshd_login_t wtmp_t:file { ioctl read getattr lock write append };
#line 6621

#line 6621
# Obtain the SID to use for relabeling ptys
#line 6621
allow sshd_login_t security_t:security change_sid;
#line 6621

#line 6621
# Allow read access to login context
#line 6621
allow sshd_login_t default_context_t:file { read getattr lock ioctl };
#line 6621

#line 6621
# Determine the set of legal user SIDs that can be reached.
#line 6621
allow sshd_login_t security_t:security get_user_sids;
#line 6621

#line 6621


type sshd_exec_t, file_type, exec_type, sysadmfile;

#line 6624

#line 6624

#line 6624
#
#line 6624
# Allow the process to transition to the new domain.
#line 6624
#
#line 6624
allow initrc_t sshd_t:process transition;
#line 6624

#line 6624
#
#line 6624
# Allow the process to execute the program.
#line 6624
# 
#line 6624
allow initrc_t sshd_exec_t:file { getattr execute };
#line 6624

#line 6624
#
#line 6624
# Allow the process to reap the new domain.
#line 6624
#
#line 6624
allow sshd_t initrc_t:process sigchld;
#line 6624

#line 6624
#
#line 6624
# Allow the new domain to inherit and use file 
#line 6624
# descriptions from the creating process and vice versa.
#line 6624
#
#line 6624
allow sshd_t initrc_t:fd use;
#line 6624
allow initrc_t sshd_t:fd use;
#line 6624

#line 6624
#
#line 6624
# Allow the new domain to write back to the old domain via a pipe.
#line 6624
#
#line 6624
allow sshd_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 6624

#line 6624
#
#line 6624
# Allow the new domain to read and execute the program.
#line 6624
#
#line 6624
allow sshd_t sshd_exec_t:file { read getattr lock execute ioctl };
#line 6624

#line 6624
#
#line 6624
# Allow the new domain to be entered via the program.
#line 6624
#
#line 6624
allow sshd_t sshd_exec_t:file entrypoint;
#line 6624

#line 6624
type_transition initrc_t sshd_exec_t:process sshd_t;
#line 6624

type sshd_key_t, file_type, sysadmfile;

# so a tunnel can point to another ssh tunnel...

#line 6628
allow sshd_t sshd_t:tcp_socket { connectto recvfrom };
#line 6628
allow sshd_t sshd_t:tcp_socket { acceptfrom recvfrom };
#line 6628
allow sshd_t tcp_socket_t:tcp_socket { recvfrom };
#line 6628
allow sshd_t tcp_socket_t:tcp_socket { recvfrom };
#line 6628


type sshd_tmp_t, file_type, sysadmfile, tmpfile;

#line 6631

#line 6631

#line 6631

#line 6631
#
#line 6631
# Allow the process to modify the directory.
#line 6631
#
#line 6631
allow sshd_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6631

#line 6631
#
#line 6631
# Allow the process to create the file.
#line 6631
#
#line 6631

#line 6631
allow sshd_t sshd_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6631
allow sshd_t sshd_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6631

#line 6631

#line 6631

#line 6631
type_transition sshd_t tmp_t:dir sshd_tmp_t;
#line 6631
type_transition sshd_t tmp_t:{ file lnk_file sock_file fifo_file } sshd_tmp_t;
#line 6631

#line 6631

#line 6631


# Inherit and use descriptors from init.
allow sshd_t init_t:fd use;

# Can create ptys

#line 6637

#line 6637
type sshd_devpts_t, file_type, sysadmfile, ptyfile ;
#line 6637

#line 6637
# Allow the pty to be associated with the file system.
#line 6637
allow sshd_devpts_t devpts_t:filesystem associate;
#line 6637

#line 6637
# Access the pty master multiplexer.
#line 6637
allow sshd_t ptmx_t:chr_file { ioctl read getattr lock write append };
#line 6637

#line 6637
# Label pty files with a derived type.
#line 6637
type_transition sshd_t devpts_t:chr_file sshd_devpts_t;
#line 6637

#line 6637
# Read and write my pty files.
#line 6637
allow sshd_t sshd_devpts_t:chr_file { setattr { ioctl read getattr lock write append } };
#line 6637

#line 6637

#line 6637

#line 6637


# Execute Login

#line 6640

#line 6640

#line 6640
#
#line 6640
# Allow the process to transition to the new domain.
#line 6640
#
#line 6640
allow sshd_t sshd_login_t:process transition;
#line 6640

#line 6640
#
#line 6640
# Allow the process to execute the program.
#line 6640
# 
#line 6640
allow sshd_t login_exec_t:file { getattr execute };
#line 6640

#line 6640
#
#line 6640
# Allow the process to reap the new domain.
#line 6640
#
#line 6640
allow sshd_login_t sshd_t:process sigchld;
#line 6640

#line 6640
#
#line 6640
# Allow the new domain to inherit and use file 
#line 6640
# descriptions from the creating process and vice versa.
#line 6640
#
#line 6640
allow sshd_login_t sshd_t:fd use;
#line 6640
allow sshd_t sshd_login_t:fd use;
#line 6640

#line 6640
#
#line 6640
# Allow the new domain to write back to the old domain via a pipe.
#line 6640
#
#line 6640
allow sshd_login_t sshd_t:fifo_file { ioctl read getattr lock write append };
#line 6640

#line 6640
#
#line 6640
# Allow the new domain to read and execute the program.
#line 6640
#
#line 6640
allow sshd_login_t login_exec_t:file { read getattr lock execute ioctl };
#line 6640

#line 6640
#
#line 6640
# Allow the new domain to be entered via the program.
#line 6640
#
#line 6640
allow sshd_login_t login_exec_t:file entrypoint;
#line 6640

#line 6640
type_transition sshd_t login_exec_t:process sshd_login_t;
#line 6640


# Use capabilities.
allow sshd_t self:capability { sys_chroot sys_resource };

# Create /var/run/sshd.pid
type sshd_var_run_t, file_type, sysadmfile, pidfile;

#line 6647

#line 6647

#line 6647

#line 6647
#
#line 6647
# Allow the process to modify the directory.
#line 6647
#
#line 6647
allow sshd_t var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6647

#line 6647
#
#line 6647
# Allow the process to create the file.
#line 6647
#
#line 6647

#line 6647
allow sshd_t sshd_var_run_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6647
allow sshd_t sshd_var_run_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6647

#line 6647

#line 6647

#line 6647
type_transition sshd_t var_run_t:dir sshd_var_run_t;
#line 6647
type_transition sshd_t var_run_t:{ file lnk_file sock_file fifo_file } sshd_var_run_t;
#line 6647

#line 6647

#line 6647


# Access key files
allow sshd_t sshd_key_t:file { ioctl read getattr lock write append };

# Update /var/log/lastlog.
allow sshd_t lastlog_t:file { ioctl read getattr lock write append };



# Signal the user domains.
allow sshd_t unpriv_userdomain:process signal;

# Relabel and access ptys created by sshd
allow sshd_t sshd_devpts_t:chr_file { setattr getattr relabelfrom relabelto };
allow sshd_t userpty_type:chr_file { setattr relabelto { ioctl read getattr lock write append } };

#################################
#
# Rules for the sshd_login_t domain
#
# sshd_login_t is the domain of a login process
# spawned by sshd

# Use the pty created by sshd
allow sshd_login_t sshd_devpts_t:chr_file { setattr { ioctl read getattr lock write append } };
allow sshd_login_t ptyfile:chr_file { setattr { ioctl read getattr lock write append } };

# Write to /var/log/lastlog
allow sshd_login_t lastlog_t:file { ioctl read getattr lock write append };

# Relabel ptys created by sshd
allow sshd_login_t sshd_devpts_t:chr_file { relabelfrom relabelto };
allow sshd_login_t userpty_type:chr_file { getattr relabelfrom relabelto };

# read localization information
allow sshd_t locale_t:dir { read getattr lock search ioctl };
allow sshd_t locale_t:{file lnk_file} { read getattr lock ioctl };

# Allow checking user's mail at login
allow sshd_t mail_spool_t:dir search;
allow sshd_t mail_spool_t:lnk_file read;
allow sshd_t mail_spool_t:file getattr;
#
# Author:  Stephen Smalley <sds@epoch.ncsc.mil>
#

# Type for the ssh executable.
type ssh_exec_t, file_type, exec_type, sysadmfile;

allow sysadm_ssh_t user_home_dir_type:dir search;

#line 6698
allow sysadm_ssh_t user_home_ssh_t:dir { read getattr lock search ioctl };
#line 6698
allow sysadm_ssh_t user_home_ssh_t:{ file lnk_file } { read getattr lock ioctl };
#line 6698


# Everything else is in the ssh_domain macro in
# macros/program/ssh_macros.te.

#DESC Su - Run shells with substitute user and group
#
# Domains for the su program.

#
# su_exec_t is the type of the su executable.
#
type su_exec_t, file_type, sysadmfile, exec_type;

allow sysadm_su_t user_home_dir_type:dir search;

# Everything else is in the su_domain macro in
# macros/program/su_macros.te.
#DESC Syslogd - System log daemon
#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

#################################
#
# Rules for the syslogd_t domain.
#
# syslogd_t is the domain of syslogd.
# syslogd_exec_t is the type of the syslogd executable.
# devlog_t is the type of the Unix domain socket created 
# by syslogd.
#
type syslogd_t, domain;
role system_r types syslogd_t;

#line 6732
allow syslogd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6732
allow syslogd_t ld_so_t:file { read getattr lock execute ioctl };
#line 6732
allow syslogd_t ld_so_t:file execute_no_trans;
#line 6732
allow syslogd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6732
allow syslogd_t shlib_t:file { read getattr lock execute ioctl };
#line 6732
allow syslogd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6732
allow syslogd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6732
allow syslogd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6732

type syslogd_exec_t, file_type, sysadmfile, exec_type;

#line 6734

#line 6734

#line 6734
#
#line 6734
# Allow the process to transition to the new domain.
#line 6734
#
#line 6734
allow initrc_t syslogd_t:process transition;
#line 6734

#line 6734
#
#line 6734
# Allow the process to execute the program.
#line 6734
# 
#line 6734
allow initrc_t syslogd_exec_t:file { getattr execute };
#line 6734

#line 6734
#
#line 6734
# Allow the process to reap the new domain.
#line 6734
#
#line 6734
allow syslogd_t initrc_t:process sigchld;
#line 6734

#line 6734
#
#line 6734
# Allow the new domain to inherit and use file 
#line 6734
# descriptions from the creating process and vice versa.
#line 6734
#
#line 6734
allow syslogd_t initrc_t:fd use;
#line 6734
allow initrc_t syslogd_t:fd use;
#line 6734

#line 6734
#
#line 6734
# Allow the new domain to write back to the old domain via a pipe.
#line 6734
#
#line 6734
allow syslogd_t initrc_t:fifo_file { ioctl read getattr lock write append };
#line 6734

#line 6734
#
#line 6734
# Allow the new domain to read and execute the program.
#line 6734
#
#line 6734
allow syslogd_t syslogd_exec_t:file { read getattr lock execute ioctl };
#line 6734

#line 6734
#
#line 6734
# Allow the new domain to be entered via the program.
#line 6734
#
#line 6734
allow syslogd_t syslogd_exec_t:file entrypoint;
#line 6734

#line 6734
type_transition initrc_t syslogd_exec_t:process syslogd_t;
#line 6734

type devlog_t, file_type, sysadmfile;
allow syslogd_t self:process { fork signal };

# if something can log to syslog they should be able to log to the console
allow privlog console_device_t:chr_file { ioctl read write getattr };

type syslogd_tmp_t, file_type, sysadmfile, tmpfile;

#line 6742

#line 6742

#line 6742

#line 6742
#
#line 6742
# Allow the process to modify the directory.
#line 6742
#
#line 6742
allow syslogd_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6742

#line 6742
#
#line 6742
# Allow the process to create the file.
#line 6742
#
#line 6742

#line 6742
allow syslogd_t syslogd_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6742
allow syslogd_t syslogd_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6742

#line 6742

#line 6742

#line 6742
type_transition syslogd_t tmp_t:dir syslogd_tmp_t;
#line 6742
type_transition syslogd_t tmp_t:{ file lnk_file sock_file fifo_file } syslogd_tmp_t;
#line 6742

#line 6742

#line 6742

type syslogd_var_run_t, file_type, sysadmfile, pidfile;

#line 6744

#line 6744

#line 6744

#line 6744
#
#line 6744
# Allow the process to modify the directory.
#line 6744
#
#line 6744
allow syslogd_t var_run_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6744

#line 6744
#
#line 6744
# Allow the process to create the file.
#line 6744
#
#line 6744

#line 6744
allow syslogd_t syslogd_var_run_t:file { create ioctl read getattr lock write setattr append link unlink rename };
#line 6744

#line 6744

#line 6744

#line 6744
type_transition syslogd_t var_run_t:file syslogd_var_run_t;
#line 6744

#line 6744

#line 6744

allow syslogd_t var_t:dir { read getattr lock search ioctl };

# read files in /etc
allow syslogd_t etc_t:file { read getattr lock ioctl };
allow syslogd_t resolv_conf_t:{ file lnk_file } { read getattr lock ioctl };

# read localization information
allow syslogd_t locale_t:dir { read getattr lock search ioctl };
allow syslogd_t locale_t:{file lnk_file} { read getattr lock ioctl };

# Use capabilities.
allow syslogd_t syslogd_t:capability { net_bind_service dac_override };

# Inherit and use descriptors from init.
allow syslogd_t init_t:fd use;
allow syslogd_t { initrc_devpts_t console_device_t }:chr_file { read write };

# Modify/create log files.

#line 6763
allow syslogd_t var_log_t:dir { read getattr search add_name write };
#line 6763
allow syslogd_t var_log_t:file { create ioctl getattr setattr append link };
#line 6763


# Create and bind to /dev/log or /var/run/log.

#line 6766

#line 6766

#line 6766

#line 6766
#
#line 6766
# Allow the process to modify the directory.
#line 6766
#
#line 6766
allow syslogd_t { device_t var_run_t }:dir { read getattr lock search ioctl add_name remove_name write };
#line 6766

#line 6766
#
#line 6766
# Allow the process to create the file.
#line 6766
#
#line 6766

#line 6766
allow syslogd_t devlog_t:sock_file { create ioctl read getattr lock write setattr append link unlink rename };
#line 6766

#line 6766

#line 6766

#line 6766
type_transition syslogd_t { device_t var_run_t }:sock_file devlog_t;
#line 6766

#line 6766

#line 6766

allow syslogd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
allow syslogd_t self:unix_dgram_socket { sendto };
allow syslogd_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
allow syslogd_t self:unix_stream_socket { listen accept };
allow syslogd_t devlog_t:unix_stream_socket name_bind;
allow syslogd_t devlog_t:unix_dgram_socket name_bind;

# Domains with the privlog attribute may log to syslogd.
allow privlog devlog_t:sock_file { ioctl read getattr lock write append };

#line 6776
allow privlog syslogd_t:unix_dgram_socket sendto;
#line 6776


#line 6777
allow privlog syslogd_t:unix_stream_socket connectto;
#line 6777

# allow /dev/log to be a link elsewhere for chroot setup
allow privlog devlog_t:lnk_file read;

# Write to the cron log.
allow syslogd_t cron_log_t:file { ioctl read getattr lock write append };
#DESC Tmpreaper - Monitor and maintain temporary files
#
# Author:  Russell Coker <russell@coker.com.au>
#

#################################
#
# Rules for the tmpreaper_t domain.
#
type tmpreaper_t, domain, privlog;
type tmpreaper_exec_t, file_type, sysadmfile, exec_type;

role system_r types tmpreaper_t;


#line 6797

#line 6797

#line 6797
#
#line 6797
# Allow the process to transition to the new domain.
#line 6797
#
#line 6797
allow system_crond_t tmpreaper_t:process transition;
#line 6797

#line 6797
#
#line 6797
# Allow the process to execute the program.
#line 6797
# 
#line 6797
allow system_crond_t tmpreaper_exec_t:file { getattr execute };
#line 6797

#line 6797
#
#line 6797
# Allow the process to reap the new domain.
#line 6797
#
#line 6797
allow tmpreaper_t system_crond_t:process sigchld;
#line 6797

#line 6797
#
#line 6797
# Allow the new domain to inherit and use file 
#line 6797
# descriptions from the creating process and vice versa.
#line 6797
#
#line 6797
allow tmpreaper_t system_crond_t:fd use;
#line 6797
allow system_crond_t tmpreaper_t:fd use;
#line 6797

#line 6797
#
#line 6797
# Allow the new domain to write back to the old domain via a pipe.
#line 6797
#
#line 6797
allow tmpreaper_t system_crond_t:fifo_file { ioctl read getattr lock write append };
#line 6797

#line 6797
#
#line 6797
# Allow the new domain to read and execute the program.
#line 6797
#
#line 6797
allow tmpreaper_t tmpreaper_exec_t:file { read getattr lock execute ioctl };
#line 6797

#line 6797
#
#line 6797
# Allow the new domain to be entered via the program.
#line 6797
#
#line 6797
allow tmpreaper_t tmpreaper_exec_t:file entrypoint;
#line 6797

#line 6797
type_transition system_crond_t tmpreaper_exec_t:process tmpreaper_t;
#line 6797


#line 6798
allow tmpreaper_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6798
allow tmpreaper_t ld_so_t:file { read getattr lock execute ioctl };
#line 6798
allow tmpreaper_t ld_so_t:file execute_no_trans;
#line 6798
allow tmpreaper_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6798
allow tmpreaper_t shlib_t:file { read getattr lock execute ioctl };
#line 6798
allow tmpreaper_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6798
allow tmpreaper_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6798
allow tmpreaper_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6798

allow tmpreaper_t crond_t:fd use;
allow tmpreaper_t crond_t:fifo_file { read write };
allow tmpreaper_t tmpfile:dir { { read getattr lock search ioctl add_name remove_name write } rmdir };
allow tmpreaper_t tmpfile:{ file lnk_file sock_file fifo_file } { getattr unlink };
allow tmpreaper_t home_type:{ file lnk_file sock_file fifo_file } { getattr unlink };
allow tmpreaper_t self:process { fork sigchld };
allow tmpreaper_t self:capability { dac_override dac_read_search fowner };
allow tmpreaper_t fs_t:filesystem getattr;


#line 6808
allow tmpreaper_t etc_t:dir { read getattr lock search ioctl };
#line 6808
allow tmpreaper_t etc_t:{ file lnk_file } { read getattr lock ioctl };
#line 6808

allow tmpreaper_t var_t:dir { getattr search };

#line 6810
allow tmpreaper_t var_lib_t:dir { read getattr lock search ioctl };
#line 6810
allow tmpreaper_t var_lib_t:{ file lnk_file } { read getattr lock ioctl };
#line 6810

allow tmpreaper_t device_t:dir { getattr search };

#line 6816

#DESC Useradd - Manage system user accounts
#
# Authors:  Chris Vance <cvance@tislabs.com>
#

#################################
#
# Rules for the useradd_t domain.
#
# useradd_t is the domain of the useradd/userdel programs when
# executed through the suseradd/suserdel wrapper.
#
type useradd_t, domain, privlog, auth, privowner;
role sysadm_r types useradd_t;


#line 6832
# Access other processes in the same domain.
#line 6832
allow useradd_t self:process *;
#line 6832

#line 6832
# Access /proc/PID files for processes in the same domain.
#line 6832
allow useradd_t self:dir { read getattr lock search ioctl };
#line 6832
allow useradd_t self:{ file lnk_file sock_file fifo_file } { read getattr lock ioctl };
#line 6832

#line 6832
# Access file descriptions, pipes, and sockets
#line 6832
# created by processes in the same domain.
#line 6832
allow useradd_t self:fd *;
#line 6832
allow useradd_t self:fifo_file { ioctl read getattr lock write append };
#line 6832
allow useradd_t self:unix_dgram_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown };
#line 6832
allow useradd_t self:unix_stream_socket { create ioctl read getattr write setattr append bind connect getopt setopt shutdown listen accept };
#line 6832

#line 6832
# Allow the domain to communicate with other processes in the same domain.
#line 6832
allow useradd_t self:unix_dgram_socket sendto;
#line 6832
allow useradd_t self:unix_stream_socket connectto;
#line 6832

#line 6832
# Access System V IPC objects created by processes in the same domain.
#line 6832
allow useradd_t self:sem  { associate getattr setattr create destroy read write unix_read unix_write };
#line 6832
allow useradd_t self:msg  { send receive };
#line 6832
allow useradd_t self:msgq { associate getattr setattr create destroy read write enqueue unix_read unix_write };
#line 6832
allow useradd_t self:shm  { associate getattr setattr create destroy read write lock unix_read unix_write };
#line 6832

#line 6832
;


#line 6834
allow useradd_t { root_t usr_t lib_t etc_t }:dir { read getattr lock search ioctl };
#line 6834
allow useradd_t ld_so_t:file { read getattr lock execute ioctl };
#line 6834
allow useradd_t ld_so_t:file execute_no_trans;
#line 6834
allow useradd_t ld_so_t:lnk_file { read getattr lock ioctl };
#line 6834
allow useradd_t shlib_t:file { read getattr lock execute ioctl };
#line 6834
allow useradd_t shlib_t:lnk_file { read getattr lock ioctl };
#line 6834
allow useradd_t ld_so_cache_t:file { read getattr lock ioctl };
#line 6834
allow useradd_t null_device_t:chr_file { ioctl read getattr lock write append };
#line 6834
;

type useradd_exec_t, file_type, sysadmfile, exec_type;

#line 6837

#line 6837

#line 6837
#
#line 6837
# Allow the process to transition to the new domain.
#line 6837
#
#line 6837
allow sysadm_t useradd_t:process transition;
#line 6837

#line 6837
#
#line 6837
# Allow the process to execute the program.
#line 6837
# 
#line 6837
allow sysadm_t useradd_exec_t:file { getattr execute };
#line 6837

#line 6837
#
#line 6837
# Allow the process to reap the new domain.
#line 6837
#
#line 6837
allow useradd_t sysadm_t:process sigchld;
#line 6837

#line 6837
#
#line 6837
# Allow the new domain to inherit and use file 
#line 6837
# descriptions from the creating process and vice versa.
#line 6837
#
#line 6837
allow useradd_t sysadm_t:fd use;
#line 6837
allow sysadm_t useradd_t:fd use;
#line 6837

#line 6837
#
#line 6837
# Allow the new domain to write back to the old domain via a pipe.
#line 6837
#
#line 6837
allow useradd_t sysadm_t:fifo_file { ioctl read getattr lock write append };
#line 6837

#line 6837
#
#line 6837
# Allow the new domain to read and execute the program.
#line 6837
#
#line 6837
allow useradd_t useradd_exec_t:file { read getattr lock execute ioctl };
#line 6837

#line 6837
#
#line 6837
# Allow the new domain to be entered via the program.
#line 6837
#
#line 6837
allow useradd_t useradd_exec_t:file entrypoint;
#line 6837

#line 6837
type_transition sysadm_t useradd_exec_t:process useradd_t;
#line 6837


# Add/remove user home directories

#line 6840

#line 6840

#line 6840

#line 6840
#
#line 6840
# Allow the process to modify the directory.
#line 6840
#
#line 6840
allow useradd_t home_root_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6840

#line 6840
#
#line 6840
# Allow the process to create the file.
#line 6840
#
#line 6840

#line 6840
allow useradd_t user_home_dir_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6840
allow useradd_t user_home_dir_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6840

#line 6840

#line 6840

#line 6840
type_transition useradd_t home_root_t:dir user_home_dir_t;
#line 6840
type_transition useradd_t home_root_t:{ file lnk_file sock_file fifo_file } user_home_dir_t;
#line 6840

#line 6840

#line 6840


#line 6841

#line 6841

#line 6841

#line 6841
#
#line 6841
# Allow the process to modify the directory.
#line 6841
#
#line 6841
allow useradd_t user_home_dir_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6841

#line 6841
#
#line 6841
# Allow the process to create the file.
#line 6841
#
#line 6841

#line 6841
allow useradd_t user_home_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6841
allow useradd_t user_home_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6841

#line 6841

#line 6841

#line 6841
type_transition useradd_t user_home_dir_t:dir user_home_t;
#line 6841
type_transition useradd_t user_home_dir_t:{ file lnk_file sock_file fifo_file } user_home_t;
#line 6841

#line 6841

#line 6841


# create mail spool file in /var/mail
allow useradd_t mail_spool_t:dir {search write add_name remove_name};
allow useradd_t mail_spool_t:file {create setattr getattr unlink};
# /var/mail is a link to /var/spool/mail
allow useradd_t mail_spool_t:lnk_file {read};

# Use capabilities.
allow useradd_t useradd_t:capability { fowner chown dac_override fsetid setuid sys_resource };

# Allow access to context for shadow file
allow useradd_t security_t:security { context_to_sid };

# Inherit and use descriptors from login.
allow useradd_t privfd:fd use;

# Execute /usr/bin/{passwd,chfn,chsh} and /usr/sbin/{useradd,vipw}.
allow useradd_t { bin_t sbin_t }:dir { read getattr lock search ioctl };

#line 6860
allow useradd_t { bin_t sbin_t shell_exec_t }:file { { read getattr lock execute ioctl } execute_no_trans };
#line 6860


# allow checking if a shell is executable
allow useradd_t shell_exec_t:file execute;

# Update /etc/shadow and /etc/passwd

#line 6866

#line 6866

#line 6866

#line 6866
#
#line 6866
# Allow the process to modify the directory.
#line 6866
#
#line 6866
allow useradd_t etc_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6866

#line 6866
#
#line 6866
# Allow the process to create the file.
#line 6866
#
#line 6866

#line 6866
allow useradd_t shadow_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6866
allow useradd_t shadow_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6866

#line 6866

#line 6866

#line 6866
type_transition useradd_t etc_t:dir shadow_t;
#line 6866
type_transition useradd_t etc_t:{ file lnk_file sock_file fifo_file } shadow_t;
#line 6866

#line 6866

#line 6866

allow useradd_t etc_t:file { create ioctl read getattr lock write setattr append link unlink rename };

allow useradd_t { etc_t shadow_t }:file { relabelfrom relabelto };

# allow vipw to create temporary files under /var/tmp/vi.recover

#line 6872
type useradd_tmp_t, file_type, sysadmfile, tmpfile ;
#line 6872

#line 6872

#line 6872

#line 6872

#line 6872
#
#line 6872
# Allow the process to modify the directory.
#line 6872
#
#line 6872
allow useradd_t tmp_t:dir { read getattr lock search ioctl add_name remove_name write };
#line 6872

#line 6872
#
#line 6872
# Allow the process to create the file.
#line 6872
#
#line 6872

#line 6872
allow useradd_t useradd_tmp_t:{ file lnk_file sock_file fifo_file } { create ioctl read getattr lock write setattr append link unlink rename };
#line 6872
allow useradd_t useradd_tmp_t:dir { create read getattr lock setattr link unlink rename search add_name remove_name reparent write rmdir };
#line 6872

#line 6872

#line 6872

#line 6872
type_transition useradd_t tmp_t:dir useradd_tmp_t;
#line 6872
type_transition useradd_t tmp_t:{ file lnk_file sock_file fifo_file } useradd_tmp_t;
#line 6872

#line 6872

#line 6872

#line 6872


# /usr/bin/userdel locks the user being deleted, allow write access to utmp
allow useradd_t initrc_var_run_t:file { write };

# useradd/userdel request read/write for /var/log/lastlog, and read of /dev, 
# but will operate without them.
dontaudit useradd_t { device_t var_t }:dir { search };

# Access terminals.
allow useradd_t ttyfile:chr_file { ioctl read getattr lock write append };
allow useradd_t ptyfile:chr_file { ioctl read getattr lock write append };

##############################
#
# Assertions for the type enforcement (TE) configuration.
#

#
# Authors:  Stephen Smalley <sds@epoch.ncsc.mil> and Timothy Fraser  
#

##################################
#
# Access vector assertions.
#
# An access vector assertion specifies permissions that should not be in
# an access vector based on a source type, a target type, and a class.
# If any of the specified permissions are in the corresponding access
# vector, then the policy compiler will reject the policy configuration.
# Currently, there is only one kind of access vector assertion, neverallow, 
# but support for the other kinds of vectors could be easily added.  Access 
# vector assertions use the same syntax as access vector rules.
#

#
# Verify that every type that can be entered by
# a domain is also tagged as a domain.
#
neverallow domain ~domain:process transition;

#
# Verify that only the insmod_t, ifconfig_t, and kernel_t domains 
# have the sys_module capability.
#
neverallow ~{ insmod_t ifconfig_t kernel_t } self:capability sys_module;

#
# Verify that executable types, the system dynamic loaders, and the
# system shared libraries can only be modified by administrators.
#
neverallow ~{ldconfig_t admin} { exec_type ld_so_t shlib_t }:file { write append unlink rename };

#
# Verify that other system software can only be modified by administrators.
#
neverallow ~{ldconfig_t admin} { lib_t bin_t sbin_t }:dir { add_name remove_name rename };
neverallow ~admin { lib_t bin_t sbin_t }:file { write append unlink rename };

#
# Verify that only certain domains have access to the raw disk devices.
#
neverallow ~{  fsadm_t mount_t } fixed_disk_device_t:{ chr_file blk_file } { read write append };

#
# Verify that only the X server and klogd have access to memory devices.
#
neverallow ~privmem memory_device_t:{ chr_file blk_file } { read write append };

#
# Verify that /proc/kmsg is only accessible to klogd.
#
neverallow ~klogd_t proc_kmsg_t:file ~{ getattr };

#
# Verify that /proc/kcore is inaccessible.
#
neverallow * proc_kcore_t:file ~{ getattr };

#
# Verify that sysctl variables are only changeable
# by initrc and administrators.
#
neverallow ~{ initrc_t admin kernel_t insmod_t } sysctl_t:file { write append };
neverallow ~{ initrc_t admin } sysctl_fs_t:file { write append };
neverallow ~{ init_t initrc_t admin kernel_t insmod_t } sysctl_kernel_t:file { write append };
neverallow ~{ initrc_t admin } sysctl_net_t:file { write append };
neverallow ~{ initrc_t admin } sysctl_net_unix_t:file { write append };
neverallow ~{ initrc_t admin } sysctl_vm_t:file { write append };
neverallow ~{ initrc_t admin } sysctl_dev_t:file { write append };
neverallow ~{ initrc_t admin } sysctl_modprobe_t:file { write append };

#
# Verify that certain domains are limited to only being
# entered by their entrypoint types and to only executing
# the dynamic loader without a transition to another domain.
#

#line 6974



#line 6976
    neverallow getty_t ~getty_exec_t:file entrypoint; neverallow getty_t ~{ getty_exec_t ld_so_t }:file execute_no_trans;

#line 6977
    neverallow klogd_t ~klogd_exec_t:file entrypoint; neverallow klogd_t ~{ klogd_exec_t ld_so_t }:file execute_no_trans;




#line 6981
    neverallow syslogd_t ~syslogd_exec_t:file entrypoint; neverallow syslogd_t ~{ syslogd_exec_t ld_so_t }:file execute_no_trans;






#line 6991

#line 6991
neverallow { local_login_t remote_login_t } ~login_exec_t:file entrypoint;
#line 6991
neverallow { local_login_t remote_login_t } ~ld_so_t:file execute_no_trans;
#line 6991


#
# Verify that the passwd domain can only be entered by its
# entrypoint type and can only execute the dynamic loader
# and the ordinary passwd program without a transition to another domain.
#
#line 7000
neverallow passwd_t ~{ admin_passwd_exec_t passwd_exec_t }:file entrypoint;
#line 7000
neverallow passwd_t ~{ bin_t sbin_t shell_exec_t ld_so_t passwd_real_exec_t }:file execute_no_trans;

#
# Verify that only the admin domains and initrc_t have avc_toggle.
#
neverallow ~{ admin initrc_t } kernel_t:system avc_toggle;
#line 1 "rbac"
################################################
#
# Role-based access control (RBAC) configuration.
#

#line 9

#line 13

#line 15

########################################
#
# Role allow rules.
#
# A role allow rule specifies the allowable
# transitions between roles on an execve.
# If no rule is specified, then the change in
# roles will not be permitted.  Additional
# controls over role transitions based on the
# type of the process may be specified through
# the constraints file.
#
# The syntax of a role allow rule is:
# 	allow current_role new_role ;
#

#
# Allow the system_r role to transition 
# into the sysadm_r role.
#
allow system_r sysadm_r;

#
# Allow the user and admin role to transition to httpd_admin_r
#
#line 43


# 
# Allow the admin role to transition to the system
# role for run_init.
#
allow sysadm_r system_r;
